(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1273571,      38185]*)
(*NotebookOutlinePosition[   1274323,      38211]*)
(*  CellTagsIndexPosition[   1274279,      38207]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Continuous-time Fourier transform (CTFT) examples", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " definitions"
}], "Section"],

Cell[CellGroupData[{

Cell["Load needed packages for this notebook", "Subsection"],

Cell[BoxData[{
    \(\(<< Graphics`Colors`;\)\), "\[IndentingNewLine]", 
    \(\(<< Calculus`FourierTransform`;\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set up defaults", "Subsection"],

Cell[CellGroupData[{

Cell["Turn off annoying warning messages", "Subsubsection"],

Cell[BoxData[{
    \(\(Off[General::spell];\)\), "\[IndentingNewLine]", 
    \(\(Off[General::spell1];\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Set default options for specific functions", "Subsubsection"],

Cell[BoxData[{
    \(\(SetOptions[Plot, Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, Frame \[Rule] True, \ PlotJoined \[Rule] True, \ 
        Axes \[Rule] {True, False}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Fourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourier, 
        FourierParameters \[Rule] {1, \(-1\)}];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[FourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\), "\
\[IndentingNewLine]", 
    \(\(SetOptions[InverseFourierTransform, \ 
        FourierParameters \[Rule] {0, \(-2\) \[Pi]}];\)\)}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Visualization functions", "Subsection"],

Cell[CellGroupData[{

Cell["Fix time variable for sampled signals", "Subsubsection"],

Cell[BoxData[
    \(\(FixTime[signal_, 
          sampleRate_] := \[IndentingNewLine]Module[{time, 
            data}, \[IndentingNewLine]time = 
            Table[i/sampleRate, {i, 1, 
                Length[signal]}]; \[IndentingNewLine]data\  = \ {time, 
                signal} // Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generate periodic waveform from one period", "Subsubsection"],

Cell["\<\
PeriodicSignal[f, {dmin, dmax}, {t, min, max}] generates a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax].\
\>", "Text"],

Cell[BoxData[
    \(\(PeriodicSignal[
          f_, {dmin_, dmax_}, {t_, min_, 
            max_}] := \[IndentingNewLine]Module[{T, imin, 
            imax}, \[IndentingNewLine]T\  = \ 
            dmax\  - \ dmin; \[IndentingNewLine]imin = 
            Floor[\((min - dmin)\)/T]; \[IndentingNewLine]imax = 
            Ceiling[\((max - dmax)\)/T]; \ \[IndentingNewLine]Sum[
            f[t - i\ T]\ \((UnitStep[t - dmin - i\ T]\  - \ 
                  UnitStep[t - dmax - i\ T])\), {i, imin, 
              imax}]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot periodic waveforms", "Subsubsection"],

Cell[TextData[{
  "PeriodicPlot[f, {dmin, dmax}, {t, min, max}, opts] plots a a periodic \
waveform for the interval [min, max]. It is assumed that one period of the \
function f(t) is defined over the interval [dmin, dmax]. The 'opts' argument \
passed plotting options to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Plot[ ]."
}], "Text"],

Cell[BoxData[
    \(\(PeriodicPlot[f_, {dmin_, dmax_}, {t_, min_, max_}, 
          opts___] := \[IndentingNewLine]Module[{fnc}, \[IndentingNewLine]fnc \
= PeriodicSignal[f, {dmin, dmax}, {t, min, max}]; \[IndentingNewLine]Plot[
            fnc, {t, min, max}, opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot discrete-time signal as sequence of amplitude lines", \
"Subsubsection"],

Cell[BoxData[
    \(\(DiscreteListPlot[signal_, color_:  Black, 
          opts___] := \[IndentingNewLine]Module[{data, g1, 
            g2}, \[IndentingNewLine]If[
            Length[signal[\([1]\)]]\  \[Equal] \ 2, \[IndentingNewLine]data = 
              signal, \[IndentingNewLine]data = 
              FixTime[signal, 
                1]\[IndentingNewLine]]; \[IndentingNewLine]g1 = \
\(Line[{{#[\([1]\)], 0}, {#[\([1]\)], #[\([2]\)]}}] &\)\  /@ \ 
              data; \[IndentingNewLine]g2 = \({PointSize[ .015], 
                  Point[#]} &\)\  /@ \ data; \[IndentingNewLine]Show[
            Graphics[{color, g1, g2}], 
            opts]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier rearrange", "Subsection"],

Cell[TextData[{
  "FourierRearrange[fft] rearranges the result of an FFT (",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function Fourier[ ]), to a easier to visualize the spectrum represented \
by 'fft'. The length of the list 'fft' is assumed to be even; if it is not, \
the last term in 'fft' is dropped. "
}], "Text"],

Cell[BoxData[
    \(\(FourierRearrange[fft_, \ 
          samplingRate_] := \[IndentingNewLine]Module[{fft2, n, 
            n2}, \[IndentingNewLine]If[EvenQ[Length[fft]], \ 
            fft2\  = \ fft, \ 
            fft2\  = \ Drop[fft, \(-1\)]]; \ \[IndentingNewLine]n = 
            Length[fft]; 
          n2 = n/2; \[IndentingNewLine]{Table[\ 
                samplingRate\ i/n, {i, \(-n2\) + 1, n2}], 
              Take[fft2, {n2 + 2, n2*2}]~Join~Take[fft2, {1, n2 + 1}]} // 
            Transpose\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Short-cut functions", "Subsection"],

Cell[CellGroupData[{

Cell["Dirac delta function", "Subsubsection"],

Cell[BoxData[
    \(\(\[Delta][t_] := DiracDelta[t];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Unit step function", "Subsubsection"],

Cell[BoxData[
    \(\(u[t_] := UnitStep[t];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Pulse of width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]]
}], "Subsubsection"],

Cell[BoxData[
    \(\(p[t_, w_] := u[t + w/2] - u[t - w/2];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Hack to plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]]
}], "Subsection"],

Cell[BoxData[
    \(PlotConvert[X_, 
        w_] := \[IndentingNewLine]X\  /. \ {\[Delta][a_] \[Rule] 
            p[a, w]}\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Sampler (CT to DT converter)", "Subsection"],

Cell[BoxData[
    \(\(sampler[xc_, fs_, 
          range_: {0, 5}] := \[IndentingNewLine]Table[{n, xc[n/fs]}, {n, 
            range[\([1]\)]*fs, range[\([2]\)]*fs}];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier series to Fourier transform", "Section"],

Cell[CellGroupData[{

Cell["Square wave, T = 2", "Subsection"],

Cell[CellGroupData[{

Cell["Define and plot square wave", "Subsubsection"],

Cell[BoxData[
    \(\(T0 = 2;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Pulse1[
          t_] := \((UnitStep[t + 1/2]\  - 
            UnitStep[t - 1/2])\);\)\), "\[IndentingNewLine]", 
    \(\(fnc1\  = \ 
        PeriodicSignal[
          Pulse1, {\(-T0\)/2, T0/2}, {t, \(-10\), 
            10}];\)\), "\[IndentingNewLine]", 
    \(\(g1 = 
        Plot[fnc1, {t, \(-10\), 10}, \ PlotPoints \[Rule] 100, 
          PlotStyle \[Rule] {Blue}, 
          PlotRange \[Rule] {\(-1.01\), 3.01}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.155277 0.15374 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00154 -12 -4.5 ]
[-0.0125 .00154 0 4.5 ]
[-0.0125 .15528 -6 -4.5 ]
[-0.0125 .15528 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46276 -6 -4.5 ]
[-0.0125 .46276 0 4.5 ]
[-0.0125 .6165 -6 -4.5 ]
[-0.0125 .6165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00154 m
.00625 .00154 L
s
[(-1)] -0.0125 .00154 1 0 Mshowa
0 .15528 m
.00625 .15528 L
s
[(0)] -0.0125 .15528 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .46276 m
.00625 .46276 L
s
[(2)] -0.0125 .46276 1 0 Mshowa
0 .6165 m
.00625 .6165 L
s
[(3)] -0.0125 .6165 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .06303 m
.00375 .06303 L
s
0 .09378 m
.00375 .09378 L
s
0 .12453 m
.00375 .12453 L
s
0 .18603 m
.00375 .18603 L
s
0 .21677 m
.00375 .21677 L
s
0 .24752 m
.00375 .24752 L
s
0 .27827 m
.00375 .27827 L
s
0 .33976 m
.00375 .33976 L
s
0 .37051 m
.00375 .37051 L
s
0 .40126 m
.00375 .40126 L
s
0 .43201 m
.00375 .43201 L
s
0 .4935 m
.00375 .4935 L
s
0 .52425 m
.00375 .52425 L
s
0 .555 m
.00375 .555 L
s
0 .58575 m
.00375 .58575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00154 m
1 .00154 L
s
.99375 .15528 m
1 .15528 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46276 m
1 .46276 L
s
.99375 .6165 m
1 .6165 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .06303 m
1 .06303 L
s
.99625 .09378 m
1 .09378 L
s
.99625 .12453 m
1 .12453 L
s
.99625 .18603 m
1 .18603 L
s
.99625 .21677 m
1 .21677 L
s
.99625 .24752 m
1 .24752 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .37051 m
1 .37051 L
s
.99625 .40126 m
1 .40126 L
s
.99625 .43201 m
1 .43201 L
s
.99625 .4935 m
1 .4935 L
s
.99625 .52425 m
1 .52425 L
s
.99625 .555 m
1 .555 L
s
.99625 .58575 m
1 .58575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .15528 m
1 .15528 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30902 m
.03318 .30902 L
.03805 .30902 L
.04063 .30902 L
.04339 .30902 L
.04473 .30902 L
.04599 .30902 L
.04654 .30902 L
.04713 .30902 L
.04743 .30902 L
.0476 .30902 L
.04777 .15528 L
.04805 .15528 L
.04836 .15528 L
.05298 .15528 L
.06298 .15528 L
.0726 .15528 L
.08186 .15528 L
.08703 .15528 L
.09172 .15528 L
.09286 .15528 L
.09406 .15528 L
.09469 .15528 L
.09487 .15528 L
.09505 .15528 L
.09522 .15528 L
.09538 .30902 L
.09568 .30902 L
.09601 .30902 L
.0966 .30902 L
.1012 .30902 L
.11109 .30902 L
.12061 .30902 L
.12976 .30902 L
.13484 .30902 L
.13707 .30902 L
.13951 .30902 L
.14065 .30902 L
.14128 .30902 L
.14187 .30902 L
.14243 .30902 L
.14274 .30902 L
.14303 .15528 L
.14327 .15528 L
.14354 .15528 L
.14407 .15528 L
.14888 .15528 L
.15866 .15528 L
.16808 .15528 L
.17808 .15528 L
Mistroke
.18308 .15528 L
.18552 .15528 L
.18772 .15528 L
.18883 .15528 L
.18942 .15528 L
.18974 .15528 L
.19003 .15528 L
.1903 .15528 L
.19058 .30902 L
.19089 .30902 L
.19117 .30902 L
.19221 .30902 L
.19699 .30902 L
.20666 .30902 L
.21597 .30902 L
.22587 .30902 L
.23079 .30902 L
.2332 .30902 L
.2354 .30902 L
.23652 .30902 L
.23755 .30902 L
.23782 .30902 L
.23807 .30902 L
.23837 .15528 L
.23863 .15528 L
.23981 .15528 L
.24456 .15528 L
.2539 .15528 L
.26383 .15528 L
.2734 .15528 L
.27821 .15528 L
.2826 .15528 L
.28376 .15528 L
.28437 .15528 L
.28502 .15528 L
.28529 .15528 L
.28559 .15528 L
.28576 .30902 L
.28591 .30902 L
.28622 .30902 L
.28732 .30902 L
.29239 .30902 L
.30199 .30902 L
.31122 .30902 L
.32104 .30902 L
.32558 .30902 L
.3305 .30902 L
.33181 .30902 L
.33252 .30902 L
.33287 .30902 L
Mistroke
.33319 .30902 L
.33348 .15528 L
.33376 .15528 L
.33437 .15528 L
.33567 .15528 L
.34055 .15528 L
.34982 .15528 L
.35967 .15528 L
.36917 .15528 L
.37401 .15528 L
.37656 .15528 L
.37795 .15528 L
.37925 .15528 L
.37985 .15528 L
.38042 .15528 L
.38073 .15528 L
.38091 .15528 L
.38107 .30902 L
.38136 .30902 L
.38166 .30902 L
.38431 .30902 L
.38897 .30902 L
.39813 .30902 L
.40788 .30902 L
.41726 .30902 L
.42203 .30902 L
.42455 .30902 L
.42593 .30902 L
.42724 .30902 L
.42785 .30902 L
.42818 .30902 L
.42849 .30902 L
.42865 .15528 L
.42883 .15528 L
.4292 .15528 L
.42985 .15528 L
.43222 .15528 L
.43685 .15528 L
.44686 .15528 L
.4565 .15528 L
.46578 .15528 L
.47096 .15528 L
.47341 .15528 L
.47448 .15528 L
.47509 .15528 L
.47538 .15528 L
.47565 .15528 L
.47594 .15528 L
.4762 .30902 L
.47649 .30902 L
Mistroke
.4768 .30902 L
.47801 .30902 L
.48055 .30902 L
.48515 .30902 L
.49506 .30902 L
.5046 .30902 L
.51376 .30902 L
.51886 .30902 L
.52128 .30902 L
.52246 .30902 L
.52297 .30902 L
.52324 .30902 L
.52353 .30902 L
.52383 .15528 L
.5241 .15528 L
.52464 .15528 L
.52583 .15528 L
.52834 .15528 L
.53292 .15528 L
.54213 .15528 L
.55192 .15528 L
.56135 .15528 L
.56615 .15528 L
.56869 .15528 L
.57007 .15528 L
.57075 .15528 L
.57105 .15528 L
.57121 .15528 L
.57138 .15528 L
.57167 .30902 L
.57194 .30902 L
.57252 .30902 L
.57376 .30902 L
.57639 .30902 L
.58103 .30902 L
.59109 .30902 L
.60078 .30902 L
.6101 .30902 L
.61492 .30902 L
.61735 .30902 L
.61801 .30902 L
.61838 .30902 L
.61856 .30902 L
.61873 .30902 L
.61888 .30902 L
.61905 .15528 L
.61923 .15528 L
.6194 .15528 L
.62002 .15528 L
.62974 .15528 L
Mistroke
.6391 .15528 L
.64905 .15528 L
.654 .15528 L
.65863 .15528 L
.66308 .15528 L
.66436 .15528 L
.66557 .15528 L
.6661 .15528 L
.66639 .15528 L
.66666 .15528 L
.66695 .30902 L
.66711 .30902 L
.66728 .30902 L
.66784 .30902 L
.67783 .30902 L
.68744 .30902 L
.69669 .30902 L
.70185 .30902 L
.70653 .30902 L
.70887 .30902 L
.71141 .30902 L
.71257 .30902 L
.71321 .30902 L
.71352 .30902 L
.7138 .30902 L
.71406 .30902 L
.71431 .15528 L
.71457 .15528 L
.71485 .15528 L
.71601 .15528 L
.72588 .15528 L
.73539 .15528 L
.74453 .15528 L
.74961 .15528 L
.75427 .15528 L
.75883 .15528 L
.75994 .15528 L
.76112 .15528 L
.76147 .15528 L
.76165 .15528 L
.76181 .15528 L
.7621 .30902 L
.76226 .30902 L
.76243 .30902 L
.76364 .30902 L
.77281 .30902 L
.78258 .30902 L
.79198 .30902 L
.79676 .30902 L
.80198 .30902 L
Mistroke
.80439 .30902 L
.80697 .30902 L
.80822 .30902 L
.80884 .30902 L
.8091 .30902 L
.8094 .30902 L
.80967 .15528 L
.80992 .15528 L
.81046 .15528 L
.8116 .15528 L
.82104 .15528 L
.83107 .15528 L
.84073 .15528 L
.85002 .15528 L
.8525 .15528 L
.85482 .15528 L
.85598 .15528 L
.8563 .15528 L
.85664 .15528 L
.85693 .15528 L
.85724 .30902 L
.85742 .30902 L
.85759 .30902 L
.85791 .30902 L
.85862 .30902 L
.85991 .30902 L
.86924 .30902 L
.87916 .30902 L
.88871 .30902 L
.8979 .30902 L
.90032 .30902 L
.90262 .30902 L
.90388 .30902 L
.90423 .30902 L
.90442 .30902 L
.9046 .30902 L
.90477 .15528 L
.90495 .15528 L
.90526 .15528 L
.90768 .15528 L
.91764 .15528 L
.92722 .15528 L
.93644 .15528 L
.94158 .15528 L
.94626 .15528 L
.94858 .15528 L
.94981 .15528 L
.95111 .15528 L
.95166 .15528 L
.95196 .15528 L
Mistroke
.95225 .15528 L
.95241 .30902 L
.95258 .30902 L
.95289 .30902 L
.9535 .30902 L
.9557 .30902 L
.96555 .30902 L
.97503 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003[ooooo0ol0000hoooo
o`?o00001?ooool2o`0000[ooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=_ooool01Ol0003ooooooooooooooooo000003Oooooo00Co0000oooooooooooo0000>?oo
ool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00009ooooo`004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`00
03cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Wooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>_ooool0
0ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo000Jooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=_ooool4o`0003Sooooo00Co0000oooooooooooo
0000>?ooool4o`0003Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009oooo
o`006Oooool2o`0000Cooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`0ioooo
o`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo00Co0000
oooooooooooo00002Oooool001[ooooo00?o0000ooooooooool00oooool2o`0003Oooooo1Ol0000h
ooooo`;o0000>Oooool5o`0003Sooooo00?o0000ooooooooool00oooool2o`0000[ooooo003ooooo
ob7ooooo003oooooob7ooooo000<ooooo`?o0000oooooolBooooo`003Oooool00ol0003ooooooooo
o`3ooooooa7ooooo0005ooooo`Go00000oooool00ol0003oooooooooo`05oooooooo00001Ol00007
ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo0_l00007ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00083ooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`00
5Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000=ooooo`;o00001_ooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool000cooooo00Co0000oooooooooooo00001Oooool<o`0000go003o
3?l0000=o`00o`co00003Ol00?l;o`0000ko003o2ol0000=o`00o`co00003Ol00?l;o`0000ko003o
2ol0000>o`00o`_o00003Ol00?l<o`0000go003o3?l00007ooooo`003?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool01Oooool000cooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00Gooooo
000<ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`003Oooool2o`0000Kooooo00?o0000ooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0003ooooooooo
o`05ooooo`005Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo00Wooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`005Oooool2o`0000[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool0
1Oooool001Gooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00Gooooo
000Eooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`005Oooool2o`0000[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o0000oooo
ooooool01Oooool001Gooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`05ooooo`00
5Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool01Oooool001Gooooo
00?o0000ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02Oooool00ol0003oooooooooo`05ooooo`005Oooool2o`0000[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`05
ooooo`005Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03
o`000?oooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool02Oooool00ol0003oooooooooo`05ooooo`005Oooool2o`0000[o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wo
oooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`005Oooool00ol0003oooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`000?oooooooooo00Gooooo000E
ooooo`03o`000?oooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo00Wooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo000<ooooo`?o00001_ooool00ol0003oooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`003Oooool00ol0003oooooooooo`05ooooo`;o00001?ooool7
o`00o`_ooooo3_l00?l;ooooo`ko003o2oooool=o`00o`cooooo3Ol00?l;ooooo`ko003o2oooool>
o`00o`_ooooo3Ol00?l<ooooo`go003o2oooool>o`00o`_ooooo1ol00?l4ooooo`;o00001oooool0
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool000gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo
0_l00007ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`05ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`00
5Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020oooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000;ooooo`Go0000
1Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1Oooool000cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool000gooooo00?o0000ooooooooool01Ooo
ool2o`00083ooooo00?o0000ooooooooool0OOooool2o`0000Oooooo000>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000_ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`003?ooool3o`0000Kooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000E
ooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00083ooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003?ooool3o`0000Kooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000;
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool01Oooool000oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000=ooooo`;o00001_ooooooo`00
00Go00001oooool000oooooo00?o0000ooooooooool0ooooool?ooooo`002oooool01Ol0003ooooo
oooooooooooo00000?oooooo4Oooool000cooooo0ol0003ooooooa;ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.2089, -1.31662, \
0.0808208, 0.0250332}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency spectrum", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(spectrum = \ 
        Table[{k/T0, 
            FourierCoefficient[Pulse1[t], t, k, 
              FourierParameters \[Rule] {\(-1\), \(-1\)/T0}]}, {k, \(-4\)*T0, 
            4*T0}];\)\), "\[IndentingNewLine]", 
    \(\(ga = 
        DiscreteListPlot[spectrum, \ Red, \ Frame \[Rule] True, \ 
          PlotRange \[Rule] All, \ Axes \[Rule] {True, False}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.117755 0.971128 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02064 -24 -4.5 ]
[-0.0125 .02064 0 4.5 ]
[-0.0125 .11775 -6 -4.5 ]
[-0.0125 .11775 0 4.5 ]
[-0.0125 .21487 -18 -4.5 ]
[-0.0125 .21487 0 4.5 ]
[-0.0125 .31198 -18 -4.5 ]
[-0.0125 .31198 0 4.5 ]
[-0.0125 .40909 -18 -4.5 ]
[-0.0125 .40909 0 4.5 ]
[-0.0125 .50621 -18 -4.5 ]
[-0.0125 .50621 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02064 m
.00625 .02064 L
s
[(-0.1)] -0.0125 .02064 1 0 Mshowa
0 .11775 m
.00625 .11775 L
s
[(0)] -0.0125 .11775 1 0 Mshowa
0 .21487 m
.00625 .21487 L
s
[(0.1)] -0.0125 .21487 1 0 Mshowa
0 .31198 m
.00625 .31198 L
s
[(0.2)] -0.0125 .31198 1 0 Mshowa
0 .40909 m
.00625 .40909 L
s
[(0.3)] -0.0125 .40909 1 0 Mshowa
0 .50621 m
.00625 .50621 L
s
[(0.4)] -0.0125 .50621 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.5)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04006 m
.00375 .04006 L
s
0 .05949 m
.00375 .05949 L
s
0 .07891 m
.00375 .07891 L
s
0 .09833 m
.00375 .09833 L
s
0 .13718 m
.00375 .13718 L
s
0 .1566 m
.00375 .1566 L
s
0 .17602 m
.00375 .17602 L
s
0 .19545 m
.00375 .19545 L
s
0 .23429 m
.00375 .23429 L
s
0 .25371 m
.00375 .25371 L
s
0 .27314 m
.00375 .27314 L
s
0 .29256 m
.00375 .29256 L
s
0 .3314 m
.00375 .3314 L
s
0 .35083 m
.00375 .35083 L
s
0 .37025 m
.00375 .37025 L
s
0 .38967 m
.00375 .38967 L
s
0 .42852 m
.00375 .42852 L
s
0 .44794 m
.00375 .44794 L
s
0 .46736 m
.00375 .46736 L
s
0 .48678 m
.00375 .48678 L
s
0 .52563 m
.00375 .52563 L
s
0 .54505 m
.00375 .54505 L
s
0 .56447 m
.00375 .56447 L
s
0 .5839 m
.00375 .5839 L
s
0 .00122 m
.00375 .00122 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02064 m
1 .02064 L
s
.99375 .11775 m
1 .11775 L
s
.99375 .21487 m
1 .21487 L
s
.99375 .31198 m
1 .31198 L
s
.99375 .40909 m
1 .40909 L
s
.99375 .50621 m
1 .50621 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04006 m
1 .04006 L
s
.99625 .05949 m
1 .05949 L
s
.99625 .07891 m
1 .07891 L
s
.99625 .09833 m
1 .09833 L
s
.99625 .13718 m
1 .13718 L
s
.99625 .1566 m
1 .1566 L
s
.99625 .17602 m
1 .17602 L
s
.99625 .19545 m
1 .19545 L
s
.99625 .23429 m
1 .23429 L
s
.99625 .25371 m
1 .25371 L
s
.99625 .27314 m
1 .27314 L
s
.99625 .29256 m
1 .29256 L
s
.99625 .3314 m
1 .3314 L
s
.99625 .35083 m
1 .35083 L
s
.99625 .37025 m
1 .37025 L
s
.99625 .38967 m
1 .38967 L
s
.99625 .42852 m
1 .42852 L
s
.99625 .44794 m
1 .44794 L
s
.99625 .46736 m
1 .46736 L
s
.99625 .48678 m
1 .48678 L
s
.99625 .52563 m
1 .52563 L
s
.99625 .54505 m
1 .54505 L
s
.99625 .56447 m
1 .56447 L
s
.99625 .5839 m
1 .5839 L
s
.99625 .00122 m
1 .00122 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11775 m
1 .11775 L
s
1 0 0 r
.5 Mabswid
.02381 .11775 m
.02381 .11775 L
s
.08333 .11775 m
.08333 .0736 L
s
.14286 .11775 m
.14286 .11775 L
s
.20238 .11775 m
.20238 .17958 L
s
.2619 .11775 m
.2619 .11775 L
s
.32143 .11775 m
.32143 .01472 L
s
.38095 .11775 m
.38095 .11775 L
s
.44048 .11775 m
.44048 .42687 L
s
.5 .11775 m
.5 .60332 L
s
.55952 .11775 m
.55952 .42687 L
s
.61905 .11775 m
.61905 .11775 L
s
.67857 .11775 m
.67857 .01472 L
s
.7381 .11775 m
.7381 .11775 L
s
.79762 .11775 m
.79762 .17958 L
s
.85714 .11775 m
.85714 .11775 L
s
.91667 .11775 m
.91667 .0736 L
s
.97619 .11775 m
.97619 .11775 L
s
.015 w
.02381 .11775 Mdot
.08333 .0736 Mdot
.14286 .11775 Mdot
.20238 .17958 Mdot
.2619 .11775 Mdot
.32143 .01472 Mdot
.38095 .11775 Mdot
.44048 .42687 Mdot
.5 .60332 Mdot
.55952 .42687 Mdot
.61905 .11775 Mdot
.67857 .01472 Mdot
.7381 .11775 Mdot
.79762 .17958 Mdot
.85714 .11775 Mdot
.91667 .0736 Mdot
.97619 .11775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`008oooool3o`0003Wooooo1Ol0000hooooo`;o0000>Oooool5o`0003_o
oooo0ol00006ooooo`009?ooool00ol0003oooooooooo`0iooooo`04o`000?ooooooooooo`0003Oo
oooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000looooo`03o`000?oooooo
oooo00Gooooo000Kooooo`Go000000?oooooo`000?l000000ol0000cooooo`Go00000oooool00ol0
003oooooooooo`0gooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>Oooool5
o`0000Kooooo000Qooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0=_ooool0
1?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo0000
1oooool002;ooooo00?o0000ooooool00000>_ooool01Ol0003ooooooooooooooooo000003Oooooo
00Co0000oooooooooooo0000>?ooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000oooo
ool000001oooool002?ooooo0_l0000jooooo`05o`000?ooooooooooooooool00000=oooool01?l0
003oooooooooool0000hooooo`05o`000?ooooooooooooooool00000>oooool2o`0000Oooooo000T
ooooo`03o`000?oooooooooo03Wooooo0ol0000iooooo`;o0000>_ooool3o`0003gooooo00?o0000
ooooooooool01Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool001_oooooool00005o`00007ooooo000Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool000Sooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0?oooooo
0Oooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1?ooooo`?oo`00FOooool3ool005;ooooo0Ol00001ooooo`001Ol0
0002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1?ooooo`?oo`00FOooool3ool005;ooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Cooooo0_l0001@ooooo`?oo`00FOooool3ool0057ooooo
0_l00001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0D?ooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo053ooooo
0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`;o00001_ooool00ol0003ooooo
ooooo`1@ooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0D?ooool1o`00007ooooo
0008ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo053ooooo00?o
o`00ooooooooool0F_ooool00ooo003oooooooooo`1@ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0D?ooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo053ooooo0Ol00001
ooooo`006oooool2o`00057ooooo00?oo`00ooooooooool0F_ooool00ooo003oooooooooo`1?oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`1Jooooo`03
ool00?oooooooooo053ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1@ooooo`03ool0
0?oooooooooo05[ooooo00?oo`00ooooooooool0D?ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo053ooooo00?oo`00ooooooooool0F_ooool00ooo003oooooooooo`1@ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`1Jooooo`03ool00?oooooo
oooo053ooooo0Ol00001ooooo`006oooool2o`00057ooooo00?oo`00ooooooooool0F_ooool00ooo
003oooooooooo`1?ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0D?ooool00ooo003o
ooooooooo`1Jooooo`03ool00?oooooooooo053ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1@ooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0D?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo017ooooo0ooo000looooo`03ool00?oooooooooo05[ooooo00?o
o`00ooooooooool0>Oooool3ool001Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0A
ooooo`?oo`00??ooool00ooo003oooooooooo`1Jooooo`03ool00?oooooooooo03Wooooo0ooo000D
ooooo`7o00000Oooool001_ooooo0_l0000Booooo`?oo`00??ooool00ooo003oooooooooo`1Joooo
o`03ool00?oooooooooo03Wooooo0ooo000Cooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool04_ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo05[ooooo00?oo`00oooooooo
ool0>oooool00ooo003oooooooooo`0Booooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
4_ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0
>oooool00ooo003oooooooooo`0Booooo`7o00000Oooool001_ooooo00?o0000ooooooooool04_oo
ool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0>ooo
ool00ooo003oooooooooo`0Booooo`7o00000Oooool001_ooooo00?o0000ooooooooool04_ooool0
0ooo003oooooooooo`0kooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0>oooool0
0ooo003oooooooooo`0Booooo`7o00000Oooool001_ooooo0_l0000Cooooo`03ool00?oooooooooo
03_ooooo00?oo`00ooooooooool0F_ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo
017ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo03_o
oooo00?oo`00ooooooooool0F_ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo01;o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo03_ooooo
00?oo`00ooooooooool0F_ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo01;ooooo
0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool04_ooool00ooo003ooooooooo
o`0kooooo`03ool00?oooooooooo05[ooooo00?oo`00ooooooooool0>oooool00ooo003ooooooooo
o`0Booooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0Booooo`03ool00?oooooooooo03_ooooo00?oo`00ooooooooool0F_ooool00ooo003ooooooooo
o`0kooooo`03ool00?oooooooooo01;ooooo0Ol00001ooooo`004oooool01?l0003oooooooooool0
0004ooooo`Co00000ooo000>o`000003ool00?l0003o000000_o00000ooo000>o`000003ool00?l0
003o000000_o00000ooo000>o`000003ool00?l0003o000000_o00000ooo000>o`000003ool00?l0
003o000000go000000?oo`00o`000?l000003?l000000ooo003o0000o`00000;o`0000?oo`003_l0
00000ooo003o0000o`00000;o`0000?oo`003_l000000ooo003o0000o`00000;o`0000?oo`003_l0
00000ooo003o0000o`00000;o`0000?oo`001Ol00001ooooo`004oooool01?l0003oooooooooool0
0004ooooo`04o`000?ooooooooooooooo`?oo`007?ooool3ool000kooooo00?oo`00ooooooooool0
2oooool3ool001cooooo0ooo000>ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`0;ooooo`?oo`007?ooool3ool000kooooo00?oo`00ooooooooool0
2oooool3ool001cooooo0ooo0004ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool01?l0003oooooooooooooool3ool001cooooo0ooo000>ooooo`03ool00?oooooooooo00_o
oooo0ooo000Looooo`?oo`003_ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00co
oooo00?oo`00ooooooooool02oooool3ool001cooooo0ooo000>ooooo`03ool00?oooooooooo00_o
oooo0ooo000Looooo`?oo`001?ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0<Oooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo00go
oooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo037o
oooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0<Oooool00ooo003ooooo
ooooo`0kooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003ooooo
ooooo`0kooooo`03ool00?oooooooooo037ooooo0Ol00001ooooo`006oooool2o`0003;ooooo00?o
o`00ooooooooool0>oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?o
o`00ooooooooool0>oooool00ooo003oooooooooo`0`ooooo`;o00000Oooool001_ooooo00?o0000
ooooooooool0<Oooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool03?ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo037ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`0aooooo`03ool00?oooooooooo03_ooooo00?oo`00oooo
ooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo03_ooooo00?oo`00oooo
ooooool0<Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo037ooooo00?oo`00oooooooo
ool0>oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo
ool0>oooool00ooo003oooooooooo`0aooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
<Oooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo037ooooo0Ol00001ooooo`006ooo
ool2o`0003;ooooo00?oo`00ooooooooool0>oooool00ooo003oooooooooo`0=ooooo`03ool00?oo
oooooooo00cooooo00?oo`00ooooooooool0>oooool00ooo003oooooooooo`0`ooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool0<Oooool00ooo003oooooooooo`0kooooo`03ool00?oooooo
oooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0kooooo`03ool00?oooooo
oooo037ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0aooooo`03ool00?oooooooooo
03_ooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo
03_ooooo00?oo`00ooooooooool0<Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo037o
oooo00?oo`00ooooooooool0>oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00co
oooo00?oo`00ooooooooool0>oooool00ooo003oooooooooo`0aooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0<Oooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo00gooooo
00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0kooooo`03ool00?oooooooooo037ooooo
0Ol00001ooooo`006oooool2o`0003;ooooo00?oo`00ooooooooool0>oooool00ooo003ooooooooo
o`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0>oooool00ooo003ooooooooo
o`0`ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0<?ooool3ool003cooooo00?oo`00
ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo03Wooooo0ooo000c
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0<?ooool3ool003cooooo00?oo`00oooo
ooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo03Wooooo0ooo000coooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0<?ooool3ool003cooooo00?oo`00oooooooo
ool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo03Wooooo0ooo000cooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`0=ooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007ooooo000Kooooo`;o0000L?oo
ool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0K_oo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool03Oooool0
0ooo003oooooooooo`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1_ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo
003oooooooooo`1_ooooo`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol00005ooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool03Oooool00ooo003o
ooooooooo`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`001oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Koooool00ooo003o
ooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007o
oooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`00073o
oooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo06ko
oooo0_l00001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00co
oooo00?oo`00ooooooooool0Koooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1_ooooo`03ool00?oooooooooo00go
oooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_ooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002?ooool2o`0000Kooooo00?o0000ooooooooool0Koooool00ooo003o
ooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007o
oooo0008ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06oooooo
00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo06oooooo
0Ol00001ooooo`006oooool2o`00073ooooo00?oo`00ooooooooool03Oooool00ooo003ooooooooo
o`0<ooooo`03ool00?oooooooooo06kooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1_
ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`0=oooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo06oooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03
ool00?oooooooooo06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`03ool0
0?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_ooooo`7o0000
0Oooool001_ooooo0_l0001`ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?oo
ool00ooo003oooooooooo`1^ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Koooool0
0ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool03Oooool00ooo
003oooooooooo`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1_ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003o
ooooooooo`1_ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Koooool00ooo003ooooo
ooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007ooooo
000Kooooo`;o0000L?ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?o
o`00ooooooooool0K_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00
ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1_ooooo`03ool00?oooooooooo00gooooo00?oo`00oooo
ooooool03?ooool00ooo003oooooooooo`1_ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0Koooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo
ool0Koooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool0
3Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1_ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?oo
ool00ooo003oooooooooo`1_ooooo`7o00000Oooool001_ooooo0_l0001`ooooo`03ool00?oooooo
oooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1^ooooo`;o00000Oooool0
01_ooooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo
00cooooo00?oo`00ooooooooool0Koooool1o`00007ooooo0008ooooo`;o00001?ooool01?l0003o
ooooooooooooool5o`0000Cooooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`0=oooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1_
ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_
ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0<
ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0000:
ooooo`03o`000?oooooooooo00?ooooo0_l0001`ooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool03?ooool00ooo003oooooooooo`1^ooooo`;o00000Oooool000Oooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Kooo
ool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Kooo
ool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool03Oooool00ooo003ooooo
ooooo`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`002?ooool2o`0000Wooooo0ol0
0005ooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool03Oooool00ooo003ooooooooo
o`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_
ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_
ooooo`7o00000Oooool001_ooooo0_l0001`ooooo`03ool00?oooooooooo00gooooo00?oo`00oooo
ooooool03?ooool00ooo003oooooooooo`1^ooooo`;o00000Oooool001_ooooo00?o0000oooooooo
ool0Koooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00oooooooo
ool0Koooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool0
3Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`006ooo
ool00ol0003oooooooooo`1_ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?oo
ool00ooo003oooooooooo`1_ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Koooool0
0ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1
o`00007ooooo000Kooooo`;o0000L?ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo
00cooooo00?oo`00ooooooooool0K_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo06oo
oooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo06oo
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`03ool00?oooooooooo00gooooo
00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_ooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0Koooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?o
o`00ooooooooool0Koooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00
ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001
ooooo`006oooool2o`00073ooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0<oooo
o`03ool00?oooooooooo06kooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`03
ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`0=ooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo06oooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oo
oooooooo06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`03ool00?oooooo
oooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_ooooo`7o00000Oooool0
01_ooooo0_l0001`ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo
003oooooooooo`1^ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Koooool00ooo003o
ooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007o
oooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooo
ooooo`1_ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003ooooo
ooooo`1_ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`0=ooooo`03
ool00?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007ooooo0007ooooo`04o`00
0?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1_ooooo`03
ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_ooooo`7o
00000Oooool000Oooooo00Co0000oooooooooooo00002Oooool2o`0000Gooooo0_l0001`ooooo`03
ool00?oooooooooo00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1^ooooo`;o
00000Oooool000Oooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06oooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03
ool00?oooooooooo06oooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1_ooooo`03ool00?oooooooooo
00gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_ooooo`7o00000Oooool000So
oooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`1_ooooo`03ool00?oooooooooo00go
oooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`1_ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0K_ooool3ool000kooooo00?oo`00ooooooooool02oooool3ool0073ooooo
0Ol00001ooooo`006oooool2o`0006oooooo0ooo000>ooooo`03ool00?oooooooooo00_ooooo0ooo
001_ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0K_ooool3ool000kooooo00?oo`00
ooooooooool02oooool3ool0073ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1ooooo
o`03ool00?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03
ool00?oooooooooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03ool0
0?oooooooooo07kooooo0Ol00001ooooo`006oooool2o`00083ooooo00?oo`00ooooooooool0OOoo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo
000Kooooo`;o0000P?ooool00ooo003oooooooooo`1mooooo`;o00000Oooool001_ooooo00?o0000
ooooooooool0Ooooool00ooo003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0Ooooool00ooo003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0Ooooool00ooo003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
Ooooool00ooo003oooooooooo`1nooooo`7o00000Oooool001_ooooo0_l00020ooooo`03ool00?oo
oooooooo07gooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03ool00?oooooo
oooo07kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo
07kooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Co
oooo00?o0000ooooooooool0Ooooool00ooo003oooooooooo`1nooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07oo
oooo00?oo`00ooooooooool0O_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oo
oooo1Ol00004ooooo`;o0000P?ooool00ooo003oooooooooo`1mooooo`;o00000Oooool000Oooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo
07kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`;o00001Oooool00ol0
003oooooooooo`1oooooo`03ool00?oooooooooo07kooooo0Ol00001ooooo`002?ooool2o`0000_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo07ko
oooo0Ol00001ooooo`006oooool2o`00083ooooo00?oo`00ooooooooool0OOooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo000Kooooo`;o0000
P?ooool00ooo003oooooooooo`1mooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Oooo
ool00ooo003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool0
0ooo003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ooo
003oooooooooo`1nooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ooooool00ooo003o
ooooooooo`1nooooo`7o00000Oooool001_ooooo0_l00020ooooo`03ool00?oooooooooo07gooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo07kooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo07kooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo07kooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo07kooooo0Ol00001ooooo`00
6oooool2o`00083ooooo00?oo`00ooooooooool0OOooool2o`00007ooooo000Kooooo`03o`000?oo
oooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo
07kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`1oooooo`03ool00?oooooooooo07kooooo0Ol00001
ooooo`001oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo0_l0001n
ooooo`?oo`00Ooooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1mooooo`?oo`00P?ooool1o`00007ooooo0007oooo
o`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0iooooo`?oo`00??ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`002?ooool2o`0000Sooooo1Ol00004oooo
oooo00001Ol00001ooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.08152, -0.176871, \
0.032354, 0.00396619}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Square wave, T = 4", "Subsection"],

Cell[CellGroupData[{

Cell["Define and plot square wave", "Subsubsection"],

Cell[BoxData[
    \(\(T0 = 4;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Pulse1[
          t_] := \((UnitStep[t + 1/2]\  - 
            UnitStep[t - 1/2])\);\)\), "\[IndentingNewLine]", 
    \(\(fnc1\  = \ 
        PeriodicSignal[
          Pulse1, {\(-T0\)/2, T0/2}, {t, \(-10\), 
            10}];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        Plot[fnc1, {t, \(-10\), 10}, \ PlotPoints \[Rule] 100, 
          PlotStyle \[Rule] {Blue}, 
          PlotRange \[Rule] {\(-1.01\), 3.01}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.155277 0.15374 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00154 -12 -4.5 ]
[-0.0125 .00154 0 4.5 ]
[-0.0125 .15528 -6 -4.5 ]
[-0.0125 .15528 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46276 -6 -4.5 ]
[-0.0125 .46276 0 4.5 ]
[-0.0125 .6165 -6 -4.5 ]
[-0.0125 .6165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00154 m
.00625 .00154 L
s
[(-1)] -0.0125 .00154 1 0 Mshowa
0 .15528 m
.00625 .15528 L
s
[(0)] -0.0125 .15528 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .46276 m
.00625 .46276 L
s
[(2)] -0.0125 .46276 1 0 Mshowa
0 .6165 m
.00625 .6165 L
s
[(3)] -0.0125 .6165 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .06303 m
.00375 .06303 L
s
0 .09378 m
.00375 .09378 L
s
0 .12453 m
.00375 .12453 L
s
0 .18603 m
.00375 .18603 L
s
0 .21677 m
.00375 .21677 L
s
0 .24752 m
.00375 .24752 L
s
0 .27827 m
.00375 .27827 L
s
0 .33976 m
.00375 .33976 L
s
0 .37051 m
.00375 .37051 L
s
0 .40126 m
.00375 .40126 L
s
0 .43201 m
.00375 .43201 L
s
0 .4935 m
.00375 .4935 L
s
0 .52425 m
.00375 .52425 L
s
0 .555 m
.00375 .555 L
s
0 .58575 m
.00375 .58575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00154 m
1 .00154 L
s
.99375 .15528 m
1 .15528 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46276 m
1 .46276 L
s
.99375 .6165 m
1 .6165 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .06303 m
1 .06303 L
s
.99625 .09378 m
1 .09378 L
s
.99625 .12453 m
1 .12453 L
s
.99625 .18603 m
1 .18603 L
s
.99625 .21677 m
1 .21677 L
s
.99625 .24752 m
1 .24752 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .37051 m
1 .37051 L
s
.99625 .40126 m
1 .40126 L
s
.99625 .43201 m
1 .43201 L
s
.99625 .4935 m
1 .4935 L
s
.99625 .52425 m
1 .52425 L
s
.99625 .555 m
1 .555 L
s
.99625 .58575 m
1 .58575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .15528 m
1 .15528 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .15528 m
.03318 .15528 L
.04339 .15528 L
.05298 .15528 L
.06221 .15528 L
.07203 .15528 L
.08148 .15528 L
.0863 .15528 L
.08884 .15528 L
.09153 .15528 L
.09268 .15528 L
.09392 .15528 L
.09429 .15528 L
.09464 .15528 L
.09495 .15528 L
.09512 .15528 L
.09529 .30902 L
.09545 .30902 L
.09561 .30902 L
.0959 .30902 L
.09656 .30902 L
.10121 .30902 L
.11056 .30902 L
.1205 .30902 L
.13007 .30902 L
.13488 .30902 L
.13927 .30902 L
.14044 .30902 L
.14105 .30902 L
.1417 .30902 L
.14227 .30902 L
.14243 .30902 L
.14259 .30902 L
.1429 .15528 L
.14318 .15528 L
.14347 .15528 L
.144 .15528 L
.14907 .15528 L
.15831 .15528 L
.16814 .15528 L
.17761 .15528 L
.18767 .15528 L
.19736 .15528 L
.20669 .15528 L
.21661 .15528 L
.22616 .15528 L
.23534 .15528 L
.24512 .15528 L
.25454 .15528 L
.26454 .15528 L
Mistroke
.27418 .15528 L
.27905 .15528 L
.28116 .15528 L
.28345 .15528 L
.28408 .15528 L
.28474 .15528 L
.2853 .15528 L
.28562 .15528 L
.28592 .30902 L
.28622 .30902 L
.2865 .30902 L
.28703 .30902 L
.28823 .30902 L
.29332 .30902 L
.30262 .30902 L
.31252 .30902 L
.32205 .30902 L
.32684 .30902 L
.32893 .30902 L
.33122 .30902 L
.33179 .30902 L
.33241 .30902 L
.3327 .30902 L
.33298 .30902 L
.33324 .30902 L
.33351 .15528 L
.3338 .15528 L
.33412 .15528 L
.33476 .15528 L
.33592 .15528 L
.34098 .15528 L
.35077 .15528 L
.36019 .15528 L
.37021 .15528 L
.37987 .15528 L
.38915 .15528 L
.39903 .15528 L
.40854 .15528 L
.41768 .15528 L
.42742 .15528 L
.43679 .15528 L
.44676 .15528 L
.45636 .15528 L
.46559 .15528 L
.47073 .15528 L
.47317 .15528 L
.47424 .15528 L
.47484 .15528 L
.47541 .15528 L
.47569 .15528 L
Mistroke
.47596 .15528 L
.47626 .30902 L
.47654 .30902 L
.47774 .30902 L
.48027 .30902 L
.48487 .30902 L
.49413 .30902 L
.50399 .30902 L
.51348 .30902 L
.51833 .30902 L
.52088 .30902 L
.52227 .30902 L
.52295 .30902 L
.52325 .30902 L
.5234 .30902 L
.52357 .30902 L
.52388 .15528 L
.52417 .15528 L
.52473 .15528 L
.52598 .15528 L
.52863 .15528 L
.53329 .15528 L
.54244 .15528 L
.55219 .15528 L
.56158 .15528 L
.57155 .15528 L
.58117 .15528 L
.59041 .15528 L
.60025 .15528 L
.60972 .15528 L
.61978 .15528 L
.62948 .15528 L
.63881 .15528 L
.64873 .15528 L
.65367 .15528 L
.65829 .15528 L
.66272 .15528 L
.664 .15528 L
.66521 .15528 L
.66574 .15528 L
.6663 .15528 L
.66646 .15528 L
.66662 .15528 L
.66691 .30902 L
.66718 .30902 L
.66748 .30902 L
.67744 .30902 L
.68703 .30902 L
.69625 .30902 L
.70139 .30902 L
Mistroke
.70607 .30902 L
.7084 .30902 L
.71093 .30902 L
.71208 .30902 L
.71272 .30902 L
.71331 .30902 L
.71382 .30902 L
.7141 .30902 L
.71436 .15528 L
.71465 .15528 L
.71495 .15528 L
.71552 .15528 L
.72537 .15528 L
.73485 .15528 L
.74493 .15528 L
.75464 .15528 L
.76398 .15528 L
.77392 .15528 L
.78349 .15528 L
.79269 .15528 L
.80249 .15528 L
.81192 .15528 L
.82194 .15528 L
.8316 .15528 L
.84089 .15528 L
.84558 .15528 L
.85077 .15528 L
.85313 .15528 L
.85437 .15528 L
.85568 .15528 L
.85623 .15528 L
.85654 .15528 L
.85683 .15528 L
.85699 .15528 L
.85717 .30902 L
.85748 .30902 L
.85808 .30902 L
.86029 .30902 L
.8702 .30902 L
.87975 .30902 L
.88893 .30902 L
.89404 .30902 L
.89871 .30902 L
.90102 .30902 L
.90224 .30902 L
.90291 .30902 L
.90354 .30902 L
.90414 .30902 L
.9043 .30902 L
.90447 .30902 L
Mistroke
.90478 .15528 L
.90506 .15528 L
.90532 .15528 L
.90591 .15528 L
.90812 .15528 L
.91756 .15528 L
.9276 .15528 L
.93727 .15528 L
.94657 .15528 L
.95647 .15528 L
.96599 .15528 L
.97516 .15528 L
.97619 .15528 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003[ooooo0ol0000hoooo
o`?o00001?ooool2o`0000[ooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=_ooool01Ol0003ooooooooooooooooo000003Oooooo00Co0000oooooooooooo0000>?oo
ool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00009ooooo`004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`00
03cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Wooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>_ooool0
0ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo000Jooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=_ooool4o`0003Sooooo00Co0000oooooooooooo
0000>?ooool4o`0003Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009oooo
o`006Oooool2o`0000Cooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`0ioooo
o`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo00Co0000
oooooooooooo00002Oooool001[ooooo00?o0000ooooooooool00oooool2o`0003Oooooo1Ol0000h
ooooo`;o0000>Oooool5o`0003Sooooo00?o0000ooooooooool00oooool2o`0000[ooooo003ooooo
ob7ooooo003oooooob7ooooo000<ooooo`?o0000oooooolBooooo`003Oooool00ol0003ooooooooo
o`3ooooooa7ooooo0005ooooo`Go00000oooool00ol0003oooooooooo`05oooooooo00001Ol00007
ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo0_l00007ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00083ooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`00
5Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000=ooooo`;o00001_ooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool000cooooo00Co0000oooooooooooo00001Oooool6o`0001Co003o
2ol0000Vo`00o`_o00009_l00?l<o`0002Ko003o2ol0000Vo`00o`co00004ol00?l6o`0000Oooooo
000<ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool05Oooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?oooooo
ooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool000cooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo02;ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`003?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?oooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Eooooo`03o`000?oooooooooo00Gooooo000=ooooo`;o00001_ooool00ol0003ooooooooo
o`0Eooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0Rooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003ooooooooo
o`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003o
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo02;ooooo00?o003o
ooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eoooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo02;ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`00oooooooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Roooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo02;ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00[ooooo00?o003ooooooooo
ool05Oooool00ol0003oooooooooo`05ooooo`005Oooool2o`0001Kooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
8_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
8_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oo
oooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02_ooool0
0ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo
01Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08_ooool00ol00?oo
ooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool08_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo
000Eooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?oooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08_ooool00ol00?oooooooooo
o`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool08_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`;o00005_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo02;ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool08_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o0000oooo
ooooool01Oooool001Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Rooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0
5Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0
8_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool0
1Oooool001Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooo
oooooooo01Gooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool05Oooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo
00Wooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
01Gooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool05Oooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?oo
ooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool001Gooooo
00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo02;ooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool08_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo
00?o0000ooooooooool01Oooool001Gooooo0_l0000Fooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o
003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo02;ooooo00?o
003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0E
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0R
ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05
ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo02;ooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`00
5Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
8_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0
5Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooo
oooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool08_ooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02Oooool0
0ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
02;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo
00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool2o`0001Ko
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wo
oooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Go
oooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?oooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08_ooool00ol00?oooooo
ooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o
003oooooooooool08_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o
003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000E
ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0R
ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09
ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0E
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool08_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03
o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Rooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo02;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03
o`000?oooooooooo00Gooooo000<ooooo`?o00001_ooool00ol0003oooooooooo`0Eooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool08_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo02;ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo02;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0Rooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0Rooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool08_oo
ool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool08_oo
ool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000=ooooo`03o`000?oooooo
oooo00Gooooo0_l0000Fooooo`ko003o9?ooool=o`00obCooooo3_l00?lTooooo`go003o9?ooool>
o`00oaKooooo0_l00007ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`05ooooo`003?ooool2o`0000Oooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo00Gooooo000=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000E
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05
ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooo
ooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03
o`000?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000E
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05
ooooo`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l0
0020ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool000_ooooo1Ol00005ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0
O_ooool00ol0003oooooooooo`05ooooo`003?ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`;o0000P?ooool00ol0003oooooooooo`1mooooo`;o00001ooo
ool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool000_ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05
ooooo`002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000<ooooo`?o00001_ooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Go
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Go
oooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Go
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Go
oooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo
000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00
083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo
000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool0
0ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo
07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo
000<ooooo`?o00001_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool01Oooool000_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
00gooooo0_l00006oooooooo00001Ol00007ooooo`003oooool00ol0003oooooooooo`3oooooo`oo
oooo000;ooooo`05o`000?ooooooooooooooool00000oooooolAooooo`003?ooool3o`000?oooooo
4_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.2089, -1.31662, \
0.0808208, 0.0250332}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency spectrum", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(spectrum = \ 
        Table[{k/T0, 
            FourierCoefficient[Pulse1[t], t, k, 
              FourierParameters \[Rule] {\(-1\), \(-1\)/T0}]}, {k, \(-4\)*T0, 
            4*T0}];\)\), "\[IndentingNewLine]", 
    \(\(gb = 
        DiscreteListPlot[spectrum, \ Red, \ Frame \[Rule] True, \ 
          PlotRange \[Rule] All, \ Axes \[Rule] {True, False}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.117755 1.94226 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02064 -30 -4.5 ]
[-0.0125 .02064 0 4.5 ]
[-0.0125 .11775 -6 -4.5 ]
[-0.0125 .11775 0 4.5 ]
[-0.0125 .21487 -24 -4.5 ]
[-0.0125 .21487 0 4.5 ]
[-0.0125 .31198 -18 -4.5 ]
[-0.0125 .31198 0 4.5 ]
[-0.0125 .40909 -24 -4.5 ]
[-0.0125 .40909 0 4.5 ]
[-0.0125 .50621 -18 -4.5 ]
[-0.0125 .50621 0 4.5 ]
[-0.0125 .60332 -24 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02064 m
.00625 .02064 L
s
[(-0.05)] -0.0125 .02064 1 0 Mshowa
0 .11775 m
.00625 .11775 L
s
[(0)] -0.0125 .11775 1 0 Mshowa
0 .21487 m
.00625 .21487 L
s
[(0.05)] -0.0125 .21487 1 0 Mshowa
0 .31198 m
.00625 .31198 L
s
[(0.1)] -0.0125 .31198 1 0 Mshowa
0 .40909 m
.00625 .40909 L
s
[(0.15)] -0.0125 .40909 1 0 Mshowa
0 .50621 m
.00625 .50621 L
s
[(0.2)] -0.0125 .50621 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.25)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04006 m
.00375 .04006 L
s
0 .05949 m
.00375 .05949 L
s
0 .07891 m
.00375 .07891 L
s
0 .09833 m
.00375 .09833 L
s
0 .13718 m
.00375 .13718 L
s
0 .1566 m
.00375 .1566 L
s
0 .17602 m
.00375 .17602 L
s
0 .19545 m
.00375 .19545 L
s
0 .23429 m
.00375 .23429 L
s
0 .25371 m
.00375 .25371 L
s
0 .27314 m
.00375 .27314 L
s
0 .29256 m
.00375 .29256 L
s
0 .3314 m
.00375 .3314 L
s
0 .35083 m
.00375 .35083 L
s
0 .37025 m
.00375 .37025 L
s
0 .38967 m
.00375 .38967 L
s
0 .42852 m
.00375 .42852 L
s
0 .44794 m
.00375 .44794 L
s
0 .46736 m
.00375 .46736 L
s
0 .48678 m
.00375 .48678 L
s
0 .52563 m
.00375 .52563 L
s
0 .54505 m
.00375 .54505 L
s
0 .56447 m
.00375 .56447 L
s
0 .5839 m
.00375 .5839 L
s
0 .00122 m
.00375 .00122 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02064 m
1 .02064 L
s
.99375 .11775 m
1 .11775 L
s
.99375 .21487 m
1 .21487 L
s
.99375 .31198 m
1 .31198 L
s
.99375 .40909 m
1 .40909 L
s
.99375 .50621 m
1 .50621 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04006 m
1 .04006 L
s
.99625 .05949 m
1 .05949 L
s
.99625 .07891 m
1 .07891 L
s
.99625 .09833 m
1 .09833 L
s
.99625 .13718 m
1 .13718 L
s
.99625 .1566 m
1 .1566 L
s
.99625 .17602 m
1 .17602 L
s
.99625 .19545 m
1 .19545 L
s
.99625 .23429 m
1 .23429 L
s
.99625 .25371 m
1 .25371 L
s
.99625 .27314 m
1 .27314 L
s
.99625 .29256 m
1 .29256 L
s
.99625 .3314 m
1 .3314 L
s
.99625 .35083 m
1 .35083 L
s
.99625 .37025 m
1 .37025 L
s
.99625 .38967 m
1 .38967 L
s
.99625 .42852 m
1 .42852 L
s
.99625 .44794 m
1 .44794 L
s
.99625 .46736 m
1 .46736 L
s
.99625 .48678 m
1 .48678 L
s
.99625 .52563 m
1 .52563 L
s
.99625 .54505 m
1 .54505 L
s
.99625 .56447 m
1 .56447 L
s
.99625 .5839 m
1 .5839 L
s
.99625 .00122 m
1 .00122 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11775 m
1 .11775 L
s
1 0 0 r
.5 Mabswid
.02381 .11775 m
.02381 .11775 L
s
.05357 .11775 m
.05357 .08861 L
s
.08333 .11775 m
.08333 .0736 L
s
.1131 .11775 m
.1131 .08413 L
s
.14286 .11775 m
.14286 .11775 L
s
.17262 .11775 m
.17262 .1575 L
s
.20238 .11775 m
.20238 .17958 L
s
.23214 .11775 m
.23214 .16633 L
s
.2619 .11775 m
.2619 .11775 L
s
.29167 .11775 m
.29167 .0553 L
s
.32143 .11775 m
.32143 .01472 L
s
.35119 .11775 m
.35119 .03032 L
s
.38095 .11775 m
.38095 .11775 L
s
.41071 .11775 m
.41071 .26348 L
s
.44048 .11775 m
.44048 .42687 L
s
.47024 .11775 m
.47024 .55492 L
s
.5 .11775 m
.5 .60332 L
s
.52976 .11775 m
.52976 .55492 L
s
.55952 .11775 m
.55952 .42687 L
s
.58929 .11775 m
.58929 .26348 L
s
.61905 .11775 m
.61905 .11775 L
s
.64881 .11775 m
.64881 .03032 L
s
.67857 .11775 m
.67857 .01472 L
s
.70833 .11775 m
.70833 .0553 L
s
.7381 .11775 m
.7381 .11775 L
s
.76786 .11775 m
.76786 .16633 L
s
.79762 .11775 m
.79762 .17958 L
s
.82738 .11775 m
.82738 .1575 L
s
.85714 .11775 m
.85714 .11775 L
s
.8869 .11775 m
.8869 .08413 L
s
.91667 .11775 m
.91667 .0736 L
s
.94643 .11775 m
.94643 .08861 L
s
.97619 .11775 m
.97619 .11775 L
s
.015 w
.02381 .11775 Mdot
.05357 .08861 Mdot
.08333 .0736 Mdot
.1131 .08413 Mdot
.14286 .11775 Mdot
.17262 .1575 Mdot
.20238 .17958 Mdot
.23214 .16633 Mdot
.2619 .11775 Mdot
.29167 .0553 Mdot
.32143 .01472 Mdot
.35119 .03032 Mdot
.38095 .11775 Mdot
.41071 .26348 Mdot
.44048 .42687 Mdot
.47024 .55492 Mdot
.5 .60332 Mdot
.52976 .55492 Mdot
.55952 .42687 Mdot
.58929 .26348 Mdot
.61905 .11775 Mdot
.64881 .03032 Mdot
.67857 .01472 Mdot
.70833 .0553 Mdot
.7381 .11775 Mdot
.76786 .16633 Mdot
.79762 .17958 Mdot
.82738 .1575 Mdot
.85714 .11775 Mdot
.8869 .08413 Mdot
.91667 .0736 Mdot
.94643 .08861 Mdot
.97619 .11775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00:Oooool3o`0003Oooooo1Ol0
000gooooo`;o0000>?ooool5o`0003Wooooo0ol00006ooooo`00:_ooool00ol0003oooooooooo`0g
ooooo`04o`000?ooooooooooo`0003Kooooo00Co0000oooooooooooo0000>?ooool01?l0003ooooo
ooooool0000jooooo`03o`000?oooooooooo00Gooooo000Qooooo`Go000000?oooooo`000?l00000
0ol0000aooooo`Go00000oooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0003Wo
oooo00?o0000ooooooooool0=oooool5o`0000Kooooo000Wooooo`04o`000?ooooooooooo`0003_o
oooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo
03Kooooo00Co0000oooooooooooo00001oooool002Sooooo00?o0000ooooool00000>?ooool01Ol0
003ooooooooooooooooo000003Kooooo00Co0000oooooooooooo0000=oooool01Ol0003ooooooooo
oooooooo000003Sooooo00?o0000ooooool000001oooool002Wooooo0_l0000hooooo`05o`000?oo
ooooooooooooool00000=_ooool01?l0003oooooooooool0000gooooo`05o`000?oooooooooooooo
ool00000>Oooool2o`0000Oooooo000Zooooo`03o`000?oooooooooo03Oooooo0ol0000hooooo`;o
0000>Oooool3o`0003_ooooo00?o0000ooooooooool01Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool0027oooooo_l00001ooooo`008Oooool2o`0000Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`;o00000Oooool0027ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00?ooooo0Ol0
0001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005
ooooo`03o`000?oooooooooo04gooooo0ooo001Gooooo`?oo`00D?ooool1o`00007ooooo0007oooo
o`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0COooool3ool005Oooooo0ooo001@ooooo`7o0000
0Oooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`?oo`00Eoooool3ool0053o
oooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool00_ooool2o`0004oooooo00?oo`00ooooooooool0F?ooool00ooo
003oooooooooo`1=ooooo`;o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01Ol0
003oooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`1>ooooo`03ool00?oooooo
oooo00?ooooo0ooo0019ooooo`?oo`001_ooool00ooo003oooooooooo`1>ooooo`7o00000Oooool0
00Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000Sooooo
00?o0000ooooooooool0C_ooool00ooo003oooooooooo`03ooooo`?oo`00BOooool3ool000Kooooo
00?oo`00ooooooooool0C_ooool1o`00007ooooo0008ooooo`;o00002_ooool2o`0000;ooooo1Ol0
0004ooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool00oooool3ool004Wooooo0ooo
0006ooooo`03ool00?oooooooooo04kooooo0Ol00001ooooo`008Oooool2o`0004oooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`18ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool0COooool2o`00007ooooo000Qooooo`03o`000?oooooooooo04kooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`18ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool0C_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo04kooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`18ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool0C_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`18ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
C_ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo04Gooooo0ooo0006ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool0B?ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00?ooooo0ooo0018ooooo`7o00000Oooool0027ooooo0_l00016ooooo`?oo`001_ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo04Sooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`03ooooo`?oo`00Aoooool2o`00007ooooo000Qooooo`03o`000?oooooooooo
04Gooooo0ooo0006ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0B?ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00?ooooo0ooo0018ooooo`7o00000Oooool0027o
oooo00?o0000ooooooooool0Aoooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool0B?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool0Aoooool1o`00007ooooo000Qooooo`03o`000?oooooooooo013ooooo
0ooo000dooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`18ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0aooooo`?oo`004oooool1o`00007ooooo000Qooooo`03o`000?oooooooooo013ooooo0ooo
000dooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`18ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0aooooo`?oo`004oooool1o`00007ooooo000Qooooo`;o00004Oooool3ool003Cooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo04Sooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo037ooooo0ooo000B
ooooo`;o00000Oooool0027ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`03oooo
o`?oo`00;?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool0B?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool0:Oooool3ool000Kooooo00?oo`00ooooooooool04_ooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo00Wooooo0ooo0006ooooo`03ool00?oooooooooo00?ooooo0ooo000/ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`18ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Yooooo`?o
o`001_ooool00ooo003oooooooooo`03ooooo`?oo`003?ooool1o`00007ooooo000Qooooo`03o`00
0?oooooooooo00Wooooo0ooo0006ooooo`03ool00?oooooooooo00?ooooo0ooo000/ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`18ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Yooooo`?oo`00
1_ooool00ooo003oooooooooo`03ooooo`?oo`003?ooool1o`00007ooooo000Qooooo`03o`000?oo
oooooooo00Wooooo0ooo0006ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0B?oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo000<ooooo`7o00000Ooo
ool0027ooooo0_l0000;ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`18ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0[ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`09ooooo`;o00000Oooool0027ooooo00?o0000ooooooooool02_ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0B?ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0:oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02_ooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo04Sooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo02_ooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00[ooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
00?o0000ooooooooool02_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool0:oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0B?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool0:oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool02_ooool1o`00007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool02_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool0:oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0B?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo
00?oo`00ooooooooool0:oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool02_ooool1o`00007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo
1?l00003ool000Ko000000?oo`00o`000?l000001Ol000000ooo003o0000o`000004o`000003ool0
0?l0003o000000Co00000ooo0005o`000003ool00?l0003o000000Go000000?oo`00o`000?l00000
1Ol000000ooo003o0000o`000003o`0000?oo`001_l000000ooo003o0000o`000004o`000003ool0
0?l0003o000000Go000000?oo`00o`000?l000000ol00003ool000Ko000000?oo`00o`000?l00000
1?l000000ooo003o0000o`000005o`000003ool00?l0003o000000Go000000?oo`00o`000?l00000
1?l000000ooo003o0000o`000005o`000003ool00?l0003o000000Co000000?oo`00o`000?l00000
0ol00003ool000Ko000000?oo`00o`000?l000001Ol000000ooo003o0000o`000004o`000003ool0
0?l0003o000000Co00000ooo0005o`000003ool00?l0003o000000Go000000?oo`00o`000?l00000
1Ol000000ooo003o0000o`000003o`0000?oo`001_l000000ooo003o0000o`000004o`000003ool0
0?l0003o000000Go000000?oo`00o`000?l000000ol00003ool000Go00000Oooool001Wooooo00Co
0000oooooooooooo00001?ooool01?l0003oooooooooooooool3ool001cooooo0ooo0005ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`03ooooo`?o
o`006oooool3ool000Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool00oooool3ool001cooooo0ooo0005ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`03ooooo`?o
o`006oooool3ool000Cooooo0Ol00001ooooo`006Oooool01?l0003oooooooooool00004ooooo`04
o`000?ooooooooooooooo`?oo`007?ooool3ool000Gooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00?ooooo0ooo000Kooooo`?oo`001_ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`03ooooo`?oo`007?ooool3ool000Gooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00?ooooo0ooo000Kooooo`?oo`001?ooool1o`00
007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:?ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0:_ooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`0Zooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`0Xooooo`7o00000Oooool001[ooooo0_l00005ooooo`03o`000?oooooooooo02So
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo02[o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool0:?ooool1o`00007ooooo000Qooooo`;o0000:Oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0:_ooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0Zooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`0Wooooo`;o00000Oooool0027ooooo00?o0000ooooooooool0:?ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0:_ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0Zooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`0Xooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Z
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0X
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Zoooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Xoooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool0:?ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Zooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Xooooo`7o
00000Oooool0027ooooo0_l0000Xooooo`?oo`001_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo02[ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool0:_ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00?ooooo0ooo000Yooooo`;o00000Oooool0027ooooo00?o0000ooooooooool09ooo
ool3ool000Kooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Zooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo02[ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`03ooooo`?oo`00:_oo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo02Oooooo0ooo0006ooooo`03ool00?oooooo
oooo00?ooooo0ooo000/ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo02Wooooo0ooo0006ooooo`03ool00?oooooo
oooo00?ooooo0ooo000Zooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0<?ooool00ooo
003oooooooooo`03ooooo`?oo`00;?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Yooooo`?oo`001_ooool00ooo
003oooooooooo`0`ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0<?ooool00ooo003o
ooooooooo`03ooooo`?oo`00;?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Yooooo`?oo`001_ooool00ooo003o
ooooooooo`0`ooooo`7o00000Oooool0027ooooo0_l0000`ooooo`?oo`00<oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`0aooooo`?oo`00<?ooool2o`00007ooooo000Qooooo`03o`000?oooooooooo02oooooo0ooo
000cooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo037ooooo0ooo000aooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0;oooool3ool003?ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0<Oooool3ool0037ooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`1Uooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo06Gooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`1Uooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo06Gooooo0Ol00001ooooo`00
8Oooool2o`0006Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool0I?ooool2o`00007ooooo000Qooooo`03o`000?oo
oooooooo06Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool0IOooool1o`00007ooooo0008ooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0IOooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`1Uooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Uooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo06Gooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1Uooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo06Gooooo0Ol00001ooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool2o`00
06Kooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool0I?ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0IOooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`1Uooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0IOooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003ooooo
ooooo`1Uooooo`7o00000Oooool000Sooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo00?o
0000ooooooooool0IOooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`1Uooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0IOooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`1Uooooo`7o00000Oooool0027ooooo0_l0001Voooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo06Cooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1Uooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo06Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1Uooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool0
0?oooooooooo06Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1Uooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo06Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1Uooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo06Gooooo0Ol00001ooooo`008Oooool2o`0006Kooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0I?ooool2o`00
007ooooo000Qooooo`03o`000?oooooooooo06Gooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0IOooool1o`00007o
oooo000Qooooo`03o`000?oooooooooo06?ooooo0ooo0006ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool00oooool3ool006Kooooo0Ol00001ooooo`008Oooool00ol0003ooooooooo
o`1Sooooo`?oo`001_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00?ooooo0ooo
001Vooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0Hoooool3ool000Kooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`03ooooo`?oo`00I_ooool1o`00007ooooo000Qoooo
o`;o0000KOooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06_ooooo0_l00001oooo
o`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool0K?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo06cooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`1/ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0K?oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06cooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`1/ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool0
0ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0K?ooool1
o`00007ooooo000Qooooo`;o0000KOooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo
06_ooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Go
oooo00?oo`00ooooooooool0K?ooool1o`00007ooooo000>ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0K?ooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0K?ooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool01?ooool2o`0006gooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`1[ooooo`;o00000Oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06cooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`1/ooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06cooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooo
ooooo`1/ooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00002?ooool2o`0000Kooooo
00?o0000ooooooooool0K?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06cooooo
0Ol00001ooooo`003_ooool2o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1/ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0K?ooool1o`00007ooooo000Q
ooooo`;o0000KOooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06_ooooo0_l00001
ooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool0K?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo06cooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`1/ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
K?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06cooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0K?oo
ool1o`00007ooooo000Qooooo`;o0000KOooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo06_ooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool0K?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo06co
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1/ooooo`7o00000Oooool0027ooooo
00?o0000ooooooooool0K?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06cooooo
0Ol00001ooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool0K?ooool1o`00007ooooo000Qooooo`;o0000KOooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo06_ooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1/oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0K?ooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo06cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1/ooooo`7o
00000Oooool0027ooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03ool0
0?oooooooooo06cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1/ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oo
oooooooo00Gooooo00?oo`00ooooooooool0K?ooool1o`00007ooooo000Qooooo`;o0000KOooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo06_ooooo0_l00001ooooo`008Oooool00ol0
003oooooooooo`1/ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0K?ooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo06cooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003o
ooooooooo`1/ooooo`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo
0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool0K?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0K?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06cooooo0Ol00001ooooo`00
1oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool2o`0006gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`1[ooooo`;o
00000Oooool000Oooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo06cooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`04
o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool0K?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00Sooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0K?ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`05ooooo`03ool00?oooooooooo06cooooo0Ol00001ooooo`002?ooool2o`0000[o
oooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo06_ooooo0ooo0006oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`03oooo
o`?oo`00K_ooool1o`00007ooooo000Qooooo`;o0000K?ooool3ool000Kooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo001]ooooo`;o
00000Oooool0027ooooo00?o0000ooooooooool0Joooool3ool000Kooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00?ooooo0ooo001^ooooo`7o0000
0Oooool0027ooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`05ooooo`03ool00?oo
oooooooo00Cooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000Qooooo`03o`000?oooooo
oooo07Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo07Cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1dooooo`7o00000Oooool0027o
oooo0_l0001eooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`1cooooo`;o00000Oooool0027ooooo00?o0000ooooooooool0M?ooool00ooo003ooooo
ooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo
000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1d
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1d
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000Qooooo`;o
0000MOooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00oooooooo
ool0Loooool2o`00007ooooo000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`008Ooo
ool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`1dooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0M?ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0M?ooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`008Oooool2o`0007Go
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo07?o
oooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1dooooo`7o00000Oooool000kooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`1dooooo`03ool0
0?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1dooooo`7o0000
0Oooool000gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo07Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo07Cooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Cooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000=ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool2o`0007Gooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo07?ooooo0_l00001ooooo`00
3Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1dooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo
003oooooooooo`1dooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000>oooo
o`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`05oooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000Qooooo`03
o`000?oooooooooo07Cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`04ooooo`03
ool00?oooooooooo07Cooooo0Ol00001ooooo`008Oooool2o`0007Gooooo00?oo`00ooooooooool0
1Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo07?ooooo0_l00001ooooo`008Ooo
ool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?oo
ool00ooo003oooooooooo`1dooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0M?ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0M?ooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool01Oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`1dooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01?ooool00ooo003o
ooooooooo`1dooooo`7o00000Oooool0027ooooo0_l0001eooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1cooooo`;o00000Oooool0027ooooo00?o
0000ooooooooool0Loooool3ool000Kooooo00?oo`00ooooooooool00oooool3ool007Gooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`1cooooo`?oo`001_ooool00ooo003oooooooooo`03
ooooo`?oo`00MOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo07?ooooo0ooo0006oooo
o`03ool00?oooooooooo00?ooooo0ooo001eooooo`7o00000Oooool0027ooooo00?o0000oooooooo
ool0O?ooool00ooo003oooooooooo`1kooooo`7o00000Oooool0027ooooo0_l0001mooooo`03ool0
0?oooooooooo07[ooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1looooo`03ool00?oo
oooooooo07_ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1looooo`03ool00?oooooo
oooo07_ooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1looooo`03ool00?oooooooooo
07_ooooo0Ol00001ooooo`008Oooool2o`0007gooooo00?oo`00ooooooooool0N_ooool2o`00007o
oooo000Qooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool0Noooool1o`00007ooooo
000Qooooo`03o`000?oooooooooo07cooooo00?oo`00ooooooooool0Noooool1o`00007ooooo0008
ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00005ooooo`03o`000?oo
oooooooo07cooooo00?oo`00ooooooooool0Noooool1o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0O?ooool00ooo003oooooooooo`1kooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo0_l0001kooooo`?oo`00O?ooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07[o
oooo0ooo001mooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01_l0003o
oooooooooooooooo0000ooooo`Co00001Oooool00ol0003oooooooooo`1jooooo`?oo`00OOooool1
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?ooooo0Ol00001ooooo`002?ooool2o`0000Wooooo0ol00002ooooo`Go00001?oo
ooono`00007ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.29832, -0.0926375, \
0.0331097, 0.00202941}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Square wave, T = 6", "Subsection"],

Cell[CellGroupData[{

Cell["Define and plot square wave", "Subsubsection"],

Cell[BoxData[
    \(\(T0 = 6;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Pulse1[
          t_] := \((UnitStep[t + 1/2]\  - 
            UnitStep[t - 1/2])\);\)\), "\[IndentingNewLine]", 
    \(\(fnc1\  = \ 
        PeriodicSignal[
          Pulse1, {\(-T0\)/2, T0/2}, {t, \(-10\), 
            10}];\)\), "\[IndentingNewLine]", 
    \(\(g3 = 
        Plot[fnc1, {t, \(-10\), 10}, \ PlotPoints \[Rule] 100, 
          PlotStyle \[Rule] {Blue}, 
          PlotRange \[Rule] {\(-1.01\), 3.01}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.155277 0.15374 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00154 -12 -4.5 ]
[-0.0125 .00154 0 4.5 ]
[-0.0125 .15528 -6 -4.5 ]
[-0.0125 .15528 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46276 -6 -4.5 ]
[-0.0125 .46276 0 4.5 ]
[-0.0125 .6165 -6 -4.5 ]
[-0.0125 .6165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00154 m
.00625 .00154 L
s
[(-1)] -0.0125 .00154 1 0 Mshowa
0 .15528 m
.00625 .15528 L
s
[(0)] -0.0125 .15528 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .46276 m
.00625 .46276 L
s
[(2)] -0.0125 .46276 1 0 Mshowa
0 .6165 m
.00625 .6165 L
s
[(3)] -0.0125 .6165 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .06303 m
.00375 .06303 L
s
0 .09378 m
.00375 .09378 L
s
0 .12453 m
.00375 .12453 L
s
0 .18603 m
.00375 .18603 L
s
0 .21677 m
.00375 .21677 L
s
0 .24752 m
.00375 .24752 L
s
0 .27827 m
.00375 .27827 L
s
0 .33976 m
.00375 .33976 L
s
0 .37051 m
.00375 .37051 L
s
0 .40126 m
.00375 .40126 L
s
0 .43201 m
.00375 .43201 L
s
0 .4935 m
.00375 .4935 L
s
0 .52425 m
.00375 .52425 L
s
0 .555 m
.00375 .555 L
s
0 .58575 m
.00375 .58575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00154 m
1 .00154 L
s
.99375 .15528 m
1 .15528 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46276 m
1 .46276 L
s
.99375 .6165 m
1 .6165 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .06303 m
1 .06303 L
s
.99625 .09378 m
1 .09378 L
s
.99625 .12453 m
1 .12453 L
s
.99625 .18603 m
1 .18603 L
s
.99625 .21677 m
1 .21677 L
s
.99625 .24752 m
1 .24752 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .37051 m
1 .37051 L
s
.99625 .40126 m
1 .40126 L
s
.99625 .43201 m
1 .43201 L
s
.99625 .4935 m
1 .4935 L
s
.99625 .52425 m
1 .52425 L
s
.99625 .555 m
1 .555 L
s
.99625 .58575 m
1 .58575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .15528 m
1 .15528 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .15528 m
.03318 .15528 L
.04339 .15528 L
.05298 .15528 L
.06221 .15528 L
.07203 .15528 L
.08148 .15528 L
.09153 .15528 L
.10121 .15528 L
.11052 .15528 L
.12043 .15528 L
.12997 .15528 L
.13914 .15528 L
.14891 .15528 L
.15831 .15528 L
.1683 .15528 L
.17793 .15528 L
.18278 .15528 L
.18719 .15528 L
.18837 .15528 L
.18899 .15528 L
.18964 .15528 L
.18992 .15528 L
.19022 .15528 L
.19039 .15528 L
.19054 .30902 L
.19085 .30902 L
.19196 .30902 L
.19704 .30902 L
.2067 .30902 L
.21599 .30902 L
.22588 .30902 L
.23079 .30902 L
.23319 .30902 L
.2354 .30902 L
.23651 .30902 L
.23754 .30902 L
.23781 .30902 L
.23806 .30902 L
.23836 .15528 L
.23862 .15528 L
.2398 .15528 L
.24455 .15528 L
.25387 .15528 L
.26379 .15528 L
.27335 .15528 L
.28253 .15528 L
.29231 .15528 L
.30172 .15528 L
.31173 .15528 L
Mistroke
.32137 .15528 L
.33064 .15528 L
.3405 .15528 L
.35 .15528 L
.3601 .15528 L
.36982 .15528 L
.37918 .15528 L
.38913 .15528 L
.39872 .15528 L
.40794 .15528 L
.41775 .15528 L
.42719 .15528 L
.43723 .15528 L
.44691 .15528 L
.45621 .15528 L
.46611 .15528 L
.47103 .15528 L
.47344 .15528 L
.47449 .15528 L
.47505 .15528 L
.47535 .15528 L
.47564 .15528 L
.47592 .15528 L
.47623 .30902 L
.4765 .30902 L
.47676 .30902 L
.47779 .30902 L
.48005 .30902 L
.48481 .30902 L
.49437 .30902 L
.50357 .30902 L
.51336 .30902 L
.51787 .30902 L
.52025 .30902 L
.52156 .30902 L
.52278 .30902 L
.52339 .30902 L
.52356 .30902 L
.52374 .30902 L
.52405 .15528 L
.52422 .15528 L
.5244 .15528 L
.52472 .15528 L
.52545 .15528 L
.52793 .15528 L
.5328 .15528 L
.54286 .15528 L
.55254 .15528 L
.56186 .15528 L
.57177 .15528 L
Mistroke
.58131 .15528 L
.59049 .15528 L
.60026 .15528 L
.60967 .15528 L
.61967 .15528 L
.6293 .15528 L
.63856 .15528 L
.64842 .15528 L
.65791 .15528 L
.66799 .15528 L
.67771 .15528 L
.68706 .15528 L
.69701 .15528 L
.70659 .15528 L
.7158 .15528 L
.7256 .15528 L
.73504 .15528 L
.74507 .15528 L
.75009 .15528 L
.75473 .15528 L
.75924 .15528 L
.76034 .15528 L
.76091 .15528 L
.76152 .15528 L
.76168 .15528 L
.76184 .15528 L
.76203 .30902 L
.7622 .30902 L
.76281 .30902 L
.76403 .30902 L
.7741 .30902 L
.78379 .30902 L
.79312 .30902 L
.79785 .30902 L
.80305 .30902 L
.80543 .30902 L
.80674 .30902 L
.80799 .30902 L
.80855 .30902 L
.80914 .30902 L
.80932 .30902 L
.80948 .30902 L
.80979 .15528 L
.81009 .15528 L
.8104 .15528 L
.8126 .15528 L
.82256 .15528 L
.83215 .15528 L
.84138 .15528 L
.85119 .15528 L
Mistroke
.86064 .15528 L
.87069 .15528 L
.88036 .15528 L
.88967 .15528 L
.89958 .15528 L
.90911 .15528 L
.91828 .15528 L
.92805 .15528 L
.93744 .15528 L
.94743 .15528 L
.95706 .15528 L
.96631 .15528 L
.97616 .15528 L
.97619 .15528 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003[ooooo0ol0000hoooo
o`?o00001?ooool2o`0000[ooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=_ooool01Ol0003ooooooooooooooooo000003Oooooo00Co0000oooooooooooo0000>?oo
ool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00009ooooo`004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`00
03cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Wooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>_ooool0
0ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo000Jooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=_ooool4o`0003Sooooo00Co0000oooooooooooo
0000>?ooool4o`0003Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009oooo
o`006Oooool2o`0000Cooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`0ioooo
o`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo00Co0000
oooooooooooo00002Oooool001[ooooo00?o0000ooooooooool00oooool2o`0003Oooooo1Ol0000h
ooooo`;o0000>Oooool5o`0003Sooooo00?o0000ooooooooool00oooool2o`0000[ooooo003ooooo
ob7ooooo003oooooob7ooooo000<ooooo`?o0000oooooolBooooo`003Oooool00ol0003ooooooooo
o`3ooooooa7ooooo0005ooooo`Go00000oooool00ol0003oooooooooo`05oooooooo00001Ol00007
ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo0_l00007ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00083ooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`00
5Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000=ooooo`;o00001_ooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool000cooooo00Co0000oooooooooooo00001Oooool6o`0002co003o
3?l0000no`00o`co0000?ol00?l;o`0002go003o1Ol00007ooooo`003?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0;_ooool00ol0003ooooo
ooooo`05ooooo`003?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo02kooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool0;_ooool00ol0003oooooooooo`05ooooo`003?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0;_ooool00ol0003ooooo
ooooo`05ooooo`003Oooool2o`0000Kooooo00?o0000ooooooooool0;_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0^ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo02kooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0^oooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`09oooo
o`03o`00oooooooooooo02kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo03[ooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo03_ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo000Eooooo`;o0000
;oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oo
oooooooo02kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`0^ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0>_ooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0>oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
03[ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
03_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0;_ooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool0>_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool0>oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo
00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0;_ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool02Oooool00ol00?oooooooooo
o`0^ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo02kooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003o
ooooooooool0;_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`0002oooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool0;_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0^ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo02kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0
;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oo
oooooooo02kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`0^ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0>_ooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0>oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
03[ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
03_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0;_ooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool0>_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool0>oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo
00?o0000ooooooooool01Oooool001Gooooo0_l0000_ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool0>_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool0>oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo00?o
0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0^
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo02kooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool0;_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0^ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo02kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0
;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oo
oooooooo02kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`0^ooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0>_ooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0>oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
03[ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
03_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo
00Gooooo000Eooooo`;o0000;oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo03[o
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo03_o
oooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0^ooooo`03o`000?oooooooooo00Go
oooo000Eooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0;_ooool00ol0003ooooo
ooooo`05ooooo`005Oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool0>_ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool0>oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo02kooooo00?o
0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo03[ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo03_ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0^
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo02kooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003ooooo
ooooool0;_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0^ooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool0>_ooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`09ooooo`03
o`00oooooooooooo02kooooo00?o0000ooooooooool01Oooool000cooooo0ol00006ooooo`03o`00
0?oooooooooo02kooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0jooooo`03o`00
oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`0kooooo`03o`00
oooooooooooo00Wooooo00?o003oooooooooool0;_ooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`0jooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool0;_oo
ool00ol0003oooooooooo`05ooooo`003Oooool00ol0003oooooooooo`05ooooo`;o0000;oooool>
o`00occooooo3_l00?lmooooo`go003o;oooool2o`0000Oooooo000=ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
00Gooooo000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000<ooooo`;o00001oooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Go
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Go
oooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Go
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Go
oooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`05ooooo`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Go
oooo0_l00020ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo
000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`05ooooo`002oooool5o`0000Gooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000<ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000=ooooo`03o`000?oooooooooo00Gooooo0_l00020ooooo`03o`000?oo
oooooooo07gooooo0_l00007ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`002oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo00Gooooo000;ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool0
00cooooo0ol00006ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00083ooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool000cooooo0ol00006ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`002oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`003Oooool2o`0000Koooooool00005o`0000Oooooo000?ooooo`03
o`000?oooooooooo0?oooooo3oooool000_ooooo00Go0000ooooooooooooooooo`00003ooooooa7o
oooo000<ooooo`?o0000oooooolBooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.2089, -1.31662, \
0.0808208, 0.0250332}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency spectrum", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(spectrum = \ 
        Table[{k/T0, 
            FourierCoefficient[Pulse1[t], t, k, 
              FourierParameters \[Rule] {\(-1\), \(-1\)/T0}]}, {k, \(-4\)*T0, 
            4*T0}];\)\), "\[IndentingNewLine]", 
    \(\(gc = 
        DiscreteListPlot[spectrum, \ Red, \ Frame \[Rule] True, \ 
          PlotRange \[Rule] All, \ Axes \[Rule] {True, False}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.117755 2.91338 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11775 -6 -4.5 ]
[-0.0125 .11775 0 4.5 ]
[-0.0125 .26342 -24 -4.5 ]
[-0.0125 .26342 0 4.5 ]
[-0.0125 .40909 -18 -4.5 ]
[-0.0125 .40909 0 4.5 ]
[-0.0125 .55476 -24 -4.5 ]
[-0.0125 .55476 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11775 m
.00625 .11775 L
s
[(0)] -0.0125 .11775 1 0 Mshowa
0 .26342 m
.00625 .26342 L
s
[(0.05)] -0.0125 .26342 1 0 Mshowa
0 .40909 m
.00625 .40909 L
s
[(0.1)] -0.0125 .40909 1 0 Mshowa
0 .55476 m
.00625 .55476 L
s
[(0.15)] -0.0125 .55476 1 0 Mshowa
.125 Mabswid
0 .14689 m
.00375 .14689 L
s
0 .17602 m
.00375 .17602 L
s
0 .20516 m
.00375 .20516 L
s
0 .23429 m
.00375 .23429 L
s
0 .29256 m
.00375 .29256 L
s
0 .32169 m
.00375 .32169 L
s
0 .35083 m
.00375 .35083 L
s
0 .37996 m
.00375 .37996 L
s
0 .43823 m
.00375 .43823 L
s
0 .46736 m
.00375 .46736 L
s
0 .49649 m
.00375 .49649 L
s
0 .52563 m
.00375 .52563 L
s
0 .08862 m
.00375 .08862 L
s
0 .05949 m
.00375 .05949 L
s
0 .03035 m
.00375 .03035 L
s
0 .00122 m
.00375 .00122 L
s
0 .5839 m
.00375 .5839 L
s
0 .61303 m
.00375 .61303 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11775 m
1 .11775 L
s
.99375 .26342 m
1 .26342 L
s
.99375 .40909 m
1 .40909 L
s
.99375 .55476 m
1 .55476 L
s
.125 Mabswid
.99625 .14689 m
1 .14689 L
s
.99625 .17602 m
1 .17602 L
s
.99625 .20516 m
1 .20516 L
s
.99625 .23429 m
1 .23429 L
s
.99625 .29256 m
1 .29256 L
s
.99625 .32169 m
1 .32169 L
s
.99625 .35083 m
1 .35083 L
s
.99625 .37996 m
1 .37996 L
s
.99625 .43823 m
1 .43823 L
s
.99625 .46736 m
1 .46736 L
s
.99625 .49649 m
1 .49649 L
s
.99625 .52563 m
1 .52563 L
s
.99625 .08862 m
1 .08862 L
s
.99625 .05949 m
1 .05949 L
s
.99625 .03035 m
1 .03035 L
s
.99625 .00122 m
1 .00122 L
s
.99625 .5839 m
1 .5839 L
s
.99625 .61303 m
1 .61303 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11775 m
1 .11775 L
s
1 0 0 r
.5 Mabswid
.02381 .11775 m
.02381 .11775 L
s
.04365 .11775 m
.04365 .09759 L
s
.06349 .11775 m
.06349 .08125 L
s
.08333 .11775 m
.08333 .0736 L
s
.10317 .11775 m
.10317 .0776 L
s
.12302 .11775 m
.12302 .09335 L
s
.14286 .11775 m
.14286 .11775 L
s
.1627 .11775 m
.1627 .14503 L
s
.18254 .11775 m
.18254 .16795 L
s
.20238 .11775 m
.20238 .17958 L
s
.22222 .11775 m
.22222 .17512 L
s
.24206 .11775 m
.24206 .15342 L
s
.2619 .11775 m
.2619 .11775 L
s
.28175 .11775 m
.28175 .0756 L
s
.30159 .11775 m
.30159 .03744 L
s
.32143 .11775 m
.32143 .01472 L
s
.34127 .11775 m
.34127 .01737 L
s
.36111 .11775 m
.36111 .05152 L
s
.38095 .11775 m
.38095 .11775 L
s
.40079 .11775 m
.40079 .21049 L
s
.42063 .11775 m
.42063 .31853 L
s
.44048 .11775 m
.44048 .42687 L
s
.46032 .11775 m
.46032 .51931 L
s
.48016 .11775 m
.48016 .58143 L
s
.5 .11775 m
.5 .60332 L
s
.51984 .11775 m
.51984 .58143 L
s
.53968 .11775 m
.53968 .51931 L
s
.55952 .11775 m
.55952 .42687 L
s
.57937 .11775 m
.57937 .31853 L
s
.59921 .11775 m
.59921 .21049 L
s
.61905 .11775 m
.61905 .11775 L
s
.63889 .11775 m
.63889 .05152 L
s
.65873 .11775 m
.65873 .01737 L
s
.67857 .11775 m
.67857 .01472 L
s
.69841 .11775 m
.69841 .03744 L
s
.71825 .11775 m
.71825 .0756 L
s
.7381 .11775 m
.7381 .11775 L
s
.75794 .11775 m
.75794 .15342 L
s
.77778 .11775 m
.77778 .17512 L
s
.79762 .11775 m
.79762 .17958 L
s
.81746 .11775 m
.81746 .16795 L
s
.8373 .11775 m
.8373 .14503 L
s
.85714 .11775 m
.85714 .11775 L
s
.87698 .11775 m
.87698 .09335 L
s
.89683 .11775 m
.89683 .0776 L
s
.91667 .11775 m
.91667 .0736 L
s
.93651 .11775 m
.93651 .08125 L
s
.95635 .11775 m
.95635 .09759 L
s
.97619 .11775 m
.97619 .11775 L
s
.015 w
.02381 .11775 Mdot
.04365 .09759 Mdot
.06349 .08125 Mdot
.08333 .0736 Mdot
.10317 .0776 Mdot
.12302 .09335 Mdot
.14286 .11775 Mdot
.1627 .14503 Mdot
.18254 .16795 Mdot
.20238 .17958 Mdot
.22222 .17512 Mdot
.24206 .15342 Mdot
.2619 .11775 Mdot
.28175 .0756 Mdot
.30159 .03744 Mdot
.32143 .01472 Mdot
.34127 .01737 Mdot
.36111 .05152 Mdot
.38095 .11775 Mdot
.40079 .21049 Mdot
.42063 .31853 Mdot
.44048 .42687 Mdot
.46032 .51931 Mdot
.48016 .58143 Mdot
.5 .60332 Mdot
.51984 .58143 Mdot
.53968 .51931 Mdot
.55952 .42687 Mdot
.57937 .31853 Mdot
.59921 .21049 Mdot
.61905 .11775 Mdot
.63889 .05152 Mdot
.65873 .01737 Mdot
.67857 .01472 Mdot
.69841 .03744 Mdot
.71825 .0756 Mdot
.7381 .11775 Mdot
.75794 .15342 Mdot
.77778 .17512 Mdot
.79762 .17958 Mdot
.81746 .16795 Mdot
.8373 .14503 Mdot
.85714 .11775 Mdot
.87698 .09335 Mdot
.89683 .0776 Mdot
.91667 .0736 Mdot
.93651 .08125 Mdot
.95635 .09759 Mdot
.97619 .11775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`008oooool3o`0003Wooooo1Ol0000hooooo`;o0000
>Oooool5o`0003_ooooo0ol00006ooooo`009?ooool00ol0003oooooooooo`0iooooo`04o`000?oo
ooooooooo`0003Oooooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000loooo
o`03o`000?oooooooooo00Gooooo000Kooooo`Go000000?oooooo`000?l000000ol0000cooooo`Go
00000oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003[ooooo00?o0000oooo
ooooool0>Oooool5o`0000Kooooo000Qooooo`04o`000?ooooooooooo`0003gooooo00?o0000oooo
ooooool0=_ooool01?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Sooooo00Co0000
oooooooooooo00001oooool002;ooooo00?o0000ooooool00000>_ooool01Ol0003ooooooooooooo
oooo000003Oooooo00Co0000oooooooooooo0000>?ooool01Ol0003ooooooooooooooooo000003[o
oooo00?o0000ooooool000001oooool002?ooooo0_l0000jooooo`05o`000?ooooooooooooooool0
0000=oooool01?l0003oooooooooool0000hooooo`05o`000?ooooooooooooooool00000>oooool2
o`0000Oooooo000Tooooo`03o`000?oooooooooo03Wooooo0ol0000iooooo`;o0000>_ooool3o`00
03gooooo00?o0000ooooooooool01Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool001_oooooool00005o`00007ooooo000Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1?ooooo`?oo`00FOooool3ool005;ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1?ooooo`?oo`000_ooool3ool004oooooo0ooo0002
ooooo`?oo`00D_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04oooooo0ooo0002oooo
o`?oo`00Coooool3ool000;ooooo0ooo001Booooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0D?ooool01?oo003oooooooooooooool3ool004oooooo0ooo0004ooooo`03ool00?oooooooooo
053ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1@ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0D?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo053o
oooo0Ol00001ooooo`006oooool2o`00057ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`1@ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Coooool2o`00007ooooo
000Kooooo`03o`000?oooooooooo04[ooooo0ooo0003ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0D?ooool00ooo003oooooooooo`02ooooo`04ool00?ooooooooooooooo`?oo`00
C?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04[ooooo0ooo0003ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0D?ooool00ooo003oooooooooo`02ooooo`04ool00?oo
ooooooooooooo`?oo`00C?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04[ooooo0ooo
0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0D?ooool00ooo003ooooooooo
o`02ooooo`04ool00?ooooooooooooooo`?oo`00C?ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo04_ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo053ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo04_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool3ool004Gooooo0ooo
0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1;ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo0015ooooo`?oo`001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Booo
ool1o`00007ooooo000Kooooo`;o0000C?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Coo`00oooooooooooooooo0ooo0015ooooo`?oo`001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0B_ooool2o`00007ooooo000K
ooooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1;
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`15oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo04_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Aooooo`?o
o`00=oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`15ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03Cooooo0ooo000Dooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool04Oooool3ool0033ooooo0ooo0004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo04Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo000`ooooo`?oo`005?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo00cooooo0ooo0002ooooo`?oo`000_ooool3ool002_ooooo
0ooo0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo04Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo000[ooooo`?o
o`000_ooool3ool000;ooooo0ooo000?ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
3?ooool3ool000?ooooo00Coo`00oooooooooooooooo0ooo000[ooooo`?oo`001?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`15ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`04ool00?ooooooooooooooo`?oo`00:oooool3ool000Cooooo00?oo`00oooo
ooooool00ooo000?ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool03?ooool3ool000?o
oooo00Coo`00oooooooooooooooo0ooo000]ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0AOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02[ooooo0ooo0004oooo
o`03ool00?oooooooooo00?oo`003oooool1o`00007ooooo000Kooooo`;o00003_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0:oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo04Gooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0/ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`0<ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool03Oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00ooo000Xooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo02Gooooo0ooo0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`0=ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01ooo
ool3ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00?oo`00:?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04Gooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0Uooooo`?oo`001?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo0009ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool01oooool3ool000?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?oo`00:?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo04Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0Uooooo`?oo`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Co
o`00oooooooooooooooo0ooo0009ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool01ooo
ool3ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo04Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Vooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`04ool00?oo
ooooooooooooo`?oo`002Oooool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003ooooooooo
o`08ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool09_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo04Gooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0Vooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool02?ooool1o`00007ooooo000C
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool02?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`15ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool09_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00Sooooo0Ol00001ooooo`004oooool01?l0003oooooooooool0
0004ooooo`Co00000ooo0004o`000003ool00?l0003o000000;o000000?oo`00o`000?l000000_l0
00000ooo003o0000o`000003o`000003ool00?l0003o000000;o000000?oo`00o`000?l000000ooo
0004o`000003ool00?l0003o000000;o000000?oo`00o`000?l000000_l000000ooo003o0000o`00
0002o`000003ool00?l0003o000000?o000000?oo`00o`000?l000000ooo0004o`000003ool00?l0
003o000000;o000000?oo`00o`000?l000000_l000000ooo003o0000o`000002o`000003ool00?l0
003o000000?o000000?oo`00o`000?l000000ooo0004o`000003ool00?l0003o000000;o000000?o
o`00o`000?l000000_l000000ooo003o0000o`000002o`000003ool00?l0003o000000;o000000?o
o`00o`000?l000000ol000000ooo003o0000o`000002o`000003ool00?l0003o000000;o000000?o
o`00o`000?l000000_l000000ooo003o0000o`000002o`000003ool00?l0003o000000;o000000Co
o`00o`000?l0003o00000ooo0004o`000003ool00?l0003o000000;o000000?oo`00o`000?l00000
0_l000000ooo003o0000o`000002o`000003ool00?l0003o000000;o000000Coo`00o`000?l0003o
00000ooo0004o`000003ool00?l0003o000000;o000000?oo`00o`000?l000000_l000000ooo003o
0000o`000002o`000003ool00?l0003o000000;o000000Coo`00o`000?l0003o00000ooo0003o`00
0003ool00?l0003o000000?o000000?oo`00o`000?l000000_l000000ooo003o0000o`000002o`00
0003ool00?l0003o000000;o000000Coo`00o`000?l0003o00000ooo0005o`00007ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0ooo000Looooo`?oo`001?oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?oo`007?ooool3ool000Cooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool01?oo003oooooooooooooool3ool001cooooo0ooo0004ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo000Looooo`?oo`001?ooool1o`00007o
oooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0ooo000Loooo
o`?oo`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?oo`007?ooool3ool0
00Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool01?oo003oooooooooooooool3ool001cooooo0ooo0004
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo000Looooo`?oo`001?oo
ool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool09ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Kooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool09ooo
ool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0Wooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo02Oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Wooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool09oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
02Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Wooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool09oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02Oo
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02Oo
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Vooooo`?oo`000oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0Vooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool09oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01?oo003ooooo
ooooooooool3ool002Sooooo0Ol00001ooooo`006oooool2o`0002Oooooo0ooo0003ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo02Kooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Wooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`04ool0
0?ooooooooooooooo`?oo`009oooool2o`00007ooooo000Kooooo`03o`000?oooooooooo02Kooooo
0ooo0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01?oo003ooooo
ooooooooool3ool002Sooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Uooooo`?o
o`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooo
oooooooo0ooo000Xooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0;?ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo000Xoooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool09Oooool3ool000Cooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02cooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`0/ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool01?oo003oooooooooooooool3ool002Sooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0Uooooo`?oo`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0;?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo02co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02co
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0/ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0/ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0:oooool3ool000?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0/ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0;?ooool00ooo003ooooo
ooooo`02ooooo`04ool00?ooooooooooooooo`?oo`00;Oooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo02_ooooo0ooo0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
;?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo02cooooo00?oo`00ooooooooool0
0_ooool01?oo003oooooooooooooool3ool002gooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`0[ooooo`?oo`000oooool01?oo003oooooooooooooool3ool002gooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0Zooooo`?oo`001?ooool01?oo003oooooooooooooool3ool0
02gooooo0Ol00001ooooo`006oooool2o`00037ooooo0ooo0002ooooo`?oo`00;Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo02[ooooo0ooo0002ooooo`?oo`00<_ooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo033ooooo0ooo0002ooooo`?oo`00;Oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo02[ooooo0ooo0002ooooo`?oo`00<oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo033ooooo0ooo000booooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0;oooool3ool003?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1U
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0IOooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo06Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Uoooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0IOooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo06Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Uooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0IOooool1o`00007ooooo000Kooooo`;o0000I_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo06Cooooo0_l00001ooooo`006oooool0
0ol0003oooooooooo`1Sooooo`?oo`001?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00Coo`00oooooooooooooooo0ooo001Vooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0Hoooool3ool000Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`04ool00?ooooooooooooooo`?oo`00I_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo06?ooooo0ooo0004ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
1?oo003oooooooooooooool3ool006Kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Z
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Z
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0J_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0J_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo06[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo06[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Zooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Zooooo`7o0000
0Oooool001_ooooo0_l0001[ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`1Yooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0J_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0J_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo06[ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo06[ooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1Zooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`1Zooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0J_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0J_ooool1o`00007ooooo
0002ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o
0000ooooooooool0J_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool0J_ooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0J_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0J_ooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000Joooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0JOooool2o`00007ooooo00001Ooooooo
0000oooooooooooo000000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo06[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo06[ooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008
ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03o`000?oooooooooo06[ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo06[ooooo0Ol0
0001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06o`000?ooooooooooo`000?oooooo
00002?ooool00ol0003oooooooooo`1Zooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`1Zooooo`7o00000Oooool000;ooooo0_l0000:ooooo`;o0000
0_ooool5o`0000Cooooo00?o0000ooooooooool0J_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0J_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo06[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo06[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Zooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Zooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0J_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0J_ooool1o`00007ooooo000Kooooo`;o0000Joooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0JOooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo06[ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo06[ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1Zooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1Zooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0J_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0J_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo06[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo06[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Zooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Zooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0JOooool3ool000?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooo
oooo0ooo001[ooooo`7o00000Oooool001_ooooo0_l0001Zooooo`?oo`000oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool01?oo003ooooo
ooooooooool3ool006[ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1Yooooo`?oo`00
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01?oo003oooooooooooooool3ool006_ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1_ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1_ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo06oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo06oooooo0Ol00001ooooo`006oooool2o`00073ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0K_oo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo06oooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool1o`00007ooooo000Kooooo`;o
0000L?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`1^ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
Koooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`1_ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Kooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`1_ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Koooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`1_ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Koooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`1_ooooo`7o00000Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol00005ooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool1o`00007o
oooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1_ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`001oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0001`ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo06ko
oooo0_l00001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1_ooooo`7o00000Oooool000Oooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06oo
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0Koooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo0_l00006ooooo`03o`000?oooooooooo06oooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0Koooool1o`00007o
oooo0008ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo
0ooo0003ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00;ooooo00Coo`00oooooooooooooooo0ooo001`ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0K_ooool3ool000?ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool01?oo003oooooooooooooool3ool0073ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1^ooooo`?oo`000oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`04ool00?ooooooooooooooo`?o
o`00L?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0_ooool00ooo003oooooooooo`1dooooo`7o00000Oooool001_ooooo0_l0001eooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0Loooool2o`00007ooooo000Kooooo`03o`000?oooooo
oooo07Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1dooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
07Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Cooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1dooooo`7o00000Oooool001_ooooo00?o
0000ooooooooool0M?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07Cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool0M?ooool1o`00007ooooo000Kooooo`;o0000MOooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo07?ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1dooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1dooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oo
oooooooo07Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1dooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
07Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1dooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07Co
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool0M?ooool1o`00007ooooo000Kooooo`;o0000MOooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo07?ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1d
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1doooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo07Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1dooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo07?ooooo0ooo0003ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ool007Kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1c
ooooo`?oo`000oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00ooo001fooooo`7o00000Oooool001_ooooo0_l0001dooooo`?oo`000oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo001eoooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo07Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1iooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo0002ooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00000oooool3o`0000Gooooo00?o0000ooooooooool0NOooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00
007ooooo00001Ooooooo0000oooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo00001Ooo
oooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo07Wooooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000009
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0007[ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo07Sooooo0_l00001
ooooo`0000Goooooo`000?ooooooooooo`000009ooooo`04o`000?ooooooooooooooo`Co00001Ooo
ool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`1iooooo`7o00000Oooool00005ooooool0003oooooooooool000002?oo
ool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1iooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1iooooo`7o00000Ooo
ool000;ooooo0_l0000:ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003ooooooooo
o`1iooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1iooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo07Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1hooooo`?o
o`001?ooool00ooo003oooooooooo`03ool007_ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1hooooo`?oo`001?ooool00ooo003oooooooooo`03ool007_ooooo0Ol00001ooooo`006ooo
ool2o`0007Wooooo0ooo0004ooooo`03ool00?oooooooooo00?oo`00N_ooool2o`00007ooooo000K
ooooo`03o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo07oooooo00?oo`00ooooooooool0O_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07gooooo0ooo0020ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0OOoo
ool3ool0083ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1mooooo`?oo`00P?ooool1
o`00007ooooo000Kooooo`;o00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo0_l00001ooooo`006oooooooo`0000Go00000Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.08152, -0.0594072, \
0.032354, 0.00132207}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Square wave, T = 8", "Subsection"],

Cell[CellGroupData[{

Cell["Define and plot square wave", "Subsubsection"],

Cell[BoxData[
    \(\(T0 = 8;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Pulse1[
          t_] := \((UnitStep[t + 1/2]\  - 
            UnitStep[t - 1/2])\);\)\), "\[IndentingNewLine]", 
    \(\(fnc1\  = \ 
        PeriodicSignal[
          Pulse1, {\(-T0\)/2, T0/2}, {t, \(-10\), 
            10}];\)\), "\[IndentingNewLine]", 
    \(\(g4 = 
        Plot[fnc1, {t, \(-10\), 10}, \ PlotPoints \[Rule] 100, 
          PlotStyle \[Rule] {Blue}, 
          PlotRange \[Rule] {\(-1.01\), 3.01}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.155277 0.15374 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00154 -12 -4.5 ]
[-0.0125 .00154 0 4.5 ]
[-0.0125 .15528 -6 -4.5 ]
[-0.0125 .15528 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46276 -6 -4.5 ]
[-0.0125 .46276 0 4.5 ]
[-0.0125 .6165 -6 -4.5 ]
[-0.0125 .6165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00154 m
.00625 .00154 L
s
[(-1)] -0.0125 .00154 1 0 Mshowa
0 .15528 m
.00625 .15528 L
s
[(0)] -0.0125 .15528 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .46276 m
.00625 .46276 L
s
[(2)] -0.0125 .46276 1 0 Mshowa
0 .6165 m
.00625 .6165 L
s
[(3)] -0.0125 .6165 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .06303 m
.00375 .06303 L
s
0 .09378 m
.00375 .09378 L
s
0 .12453 m
.00375 .12453 L
s
0 .18603 m
.00375 .18603 L
s
0 .21677 m
.00375 .21677 L
s
0 .24752 m
.00375 .24752 L
s
0 .27827 m
.00375 .27827 L
s
0 .33976 m
.00375 .33976 L
s
0 .37051 m
.00375 .37051 L
s
0 .40126 m
.00375 .40126 L
s
0 .43201 m
.00375 .43201 L
s
0 .4935 m
.00375 .4935 L
s
0 .52425 m
.00375 .52425 L
s
0 .555 m
.00375 .555 L
s
0 .58575 m
.00375 .58575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00154 m
1 .00154 L
s
.99375 .15528 m
1 .15528 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46276 m
1 .46276 L
s
.99375 .6165 m
1 .6165 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .06303 m
1 .06303 L
s
.99625 .09378 m
1 .09378 L
s
.99625 .12453 m
1 .12453 L
s
.99625 .18603 m
1 .18603 L
s
.99625 .21677 m
1 .21677 L
s
.99625 .24752 m
1 .24752 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .37051 m
1 .37051 L
s
.99625 .40126 m
1 .40126 L
s
.99625 .43201 m
1 .43201 L
s
.99625 .4935 m
1 .4935 L
s
.99625 .52425 m
1 .52425 L
s
.99625 .555 m
1 .555 L
s
.99625 .58575 m
1 .58575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .15528 m
1 .15528 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .15528 m
.03318 .15528 L
.04339 .15528 L
.05298 .15528 L
.06221 .15528 L
.07203 .15528 L
.08148 .15528 L
.0863 .15528 L
.08884 .15528 L
.09153 .15528 L
.09268 .15528 L
.09392 .15528 L
.09429 .15528 L
.09464 .15528 L
.09495 .15528 L
.09512 .15528 L
.09529 .30902 L
.09545 .30902 L
.09561 .30902 L
.0959 .30902 L
.09656 .30902 L
.10121 .30902 L
.11056 .30902 L
.1205 .30902 L
.13007 .30902 L
.13488 .30902 L
.13927 .30902 L
.14044 .30902 L
.14105 .30902 L
.1417 .30902 L
.14227 .30902 L
.14243 .30902 L
.14259 .30902 L
.1429 .15528 L
.14318 .15528 L
.14347 .15528 L
.144 .15528 L
.14907 .15528 L
.15831 .15528 L
.16814 .15528 L
.17761 .15528 L
.18767 .15528 L
.19736 .15528 L
.20669 .15528 L
.21661 .15528 L
.22616 .15528 L
.23534 .15528 L
.24512 .15528 L
.25454 .15528 L
.26454 .15528 L
Mistroke
.27418 .15528 L
.28345 .15528 L
.29332 .15528 L
.30282 .15528 L
.31291 .15528 L
.32264 .15528 L
.33199 .15528 L
.34195 .15528 L
.35153 .15528 L
.36075 .15528 L
.37056 .15528 L
.38001 .15528 L
.39005 .15528 L
.39972 .15528 L
.40902 .15528 L
.41892 .15528 L
.42846 .15528 L
.43762 .15528 L
.44738 .15528 L
.45677 .15528 L
.46154 .15528 L
.46676 .15528 L
.46917 .15528 L
.47174 .15528 L
.47299 .15528 L
.47417 .15528 L
.47523 .15528 L
.47552 .15528 L
.47583 .15528 L
.47609 .15528 L
.47638 .30902 L
.47669 .30902 L
.47698 .30902 L
.47764 .30902 L
.47884 .30902 L
.4811 .30902 L
.48617 .30902 L
.49568 .30902 L
.50482 .30902 L
.5099 .30902 L
.51456 .30902 L
.51912 .30902 L
.52142 .30902 L
.52205 .30902 L
.52272 .30902 L
.52305 .30902 L
.52335 .30902 L
.52363 .30902 L
.52393 .15528 L
.52423 .15528 L
Mistroke
.5245 .15528 L
.52511 .15528 L
.52622 .15528 L
.52874 .15528 L
.53384 .15528 L
.54347 .15528 L
.55274 .15528 L
.5626 .15528 L
.57209 .15528 L
.58217 .15528 L
.59189 .15528 L
.60124 .15528 L
.61119 .15528 L
.62076 .15528 L
.62997 .15528 L
.63978 .15528 L
.64922 .15528 L
.65925 .15528 L
.66891 .15528 L
.67821 .15528 L
.6881 .15528 L
.69762 .15528 L
.70678 .15528 L
.71653 .15528 L
.72592 .15528 L
.73589 .15528 L
.7455 .15528 L
.75475 .15528 L
.76458 .15528 L
.77406 .15528 L
.78412 .15528 L
.79382 .15528 L
.80315 .15528 L
.81307 .15528 L
.82263 .15528 L
.83182 .15528 L
.8416 .15528 L
.85102 .15528 L
.85348 .15528 L
.85478 .15528 L
.85549 .15528 L
.85616 .15528 L
.85647 .15528 L
.8568 .15528 L
.85697 .15528 L
.85715 .30902 L
.85733 .30902 L
.85748 .30902 L
.85869 .30902 L
.86103 .30902 L
Mistroke
.87048 .30902 L
.88053 .30902 L
.8902 .30902 L
.89951 .30902 L
.90199 .30902 L
.90321 .30902 L
.90374 .30902 L
.90432 .30902 L
.90463 .30902 L
.90492 .15528 L
.90519 .15528 L
.90549 .15528 L
.90674 .15528 L
.90942 .15528 L
.91949 .15528 L
.9292 .15528 L
.93855 .15528 L
.94848 .15528 L
.95805 .15528 L
.96726 .15528 L
.97619 .15528 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003[ooooo0ol0000hoooo
o`?o00001?ooool2o`0000[ooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=_ooool01Ol0003ooooooooooooooooo000003Oooooo00Co0000oooooooooooo0000>?oo
ool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00009ooooo`004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`00
03cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Wooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>_ooool0
0ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo000Jooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=_ooool4o`0003Sooooo00Co0000oooooooooooo
0000>?ooool4o`0003Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009oooo
o`006Oooool2o`0000Cooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`0ioooo
o`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo00Co0000
oooooooooooo00002Oooool001[ooooo00?o0000ooooooooool00oooool2o`0003Oooooo1Ol0000h
ooooo`;o0000>Oooool5o`0003Sooooo00?o0000ooooooooool00oooool2o`0000[ooooo003ooooo
ob7ooooo003oooooob7ooooo000<ooooo`?o0000oooooolBooooo`003Oooool00ol0003ooooooooo
o`3ooooooa7ooooo0005ooooo`Go00000oooool00ol0003oooooooooo`05oooooooo00001Ol00007
ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo0_l00007ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00083ooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`00
5Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000=ooooo`;o00001_ooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool000cooooo00Co0000oooooooooooo00001Oooool6o`0001Co003o
2ol0001Go`00o`co0000Eol00?l<o`0001?o003o1_l00007ooooo`003?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003ooooo
ooooo`05ooooo`003?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01Gooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`003?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003ooooo
ooooo`05ooooo`003Oooool2o`0000Kooooo00?o0000ooooooooool05Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eoooo
o`03o`00oooooooooooo00[ooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`0:oooo
o`03o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo05?ooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo05?ooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`;o0000
5_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oo
oooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0Doooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0Doooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
05?ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
05?ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool0Doooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool0Doooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo
00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool05Oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool02_ooool00ol00?oooooooooo
o`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003o
ooooooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool2o`0001Kooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0
5Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oo
oooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0Doooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0Doooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
05?ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
05?ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oo
ooooooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo
00?o003oooooooooool0Doooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool0Doooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo
00?o0000ooooooooool01Oooool001Gooooo0_l0000Fooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool0Doooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool0Doooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o
0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0E
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0
5Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool0
2_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oo
oooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00oooo
oooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0Doooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0Doooool0
0ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
05?ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
05?ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo
00Gooooo000Eooooo`;o00005_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo05?o
oooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo05?o
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Eooooo`03o`000?oooooooooo00Go
oooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?oooooo
ooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003ooooo
ooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool0Doooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool0Doooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo01Gooooo00?o
0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool05Oooool00ol00?ooooooooooo`0:
ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0E
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o003ooooo
ooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003ooooo
ooooool05Oooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0Doooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo01Gooooo00?o0000ooooooooool01Oooool000cooooo0ol00006ooooo`03o`00
0?oooooooooo01Gooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`1Cooooo`03o`00
oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1Cooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool05Oooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o003oooooooooool02_oo
ool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol00?ooooooooooo`1Cooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool05Ooo
ool00ol0003oooooooooo`05ooooo`003Oooool00ol0003oooooooooo`05ooooo`;o00005_ooool>
o`00oeGooooo3_l00?mEooooo`ko003o5_ooool2o`0000Oooooo000=ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
00Gooooo000=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000<ooooo`;o00001oooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooo
ooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Go
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Go
oooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Go
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Go
oooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`05ooooo`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Go
oooo0_l00020ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo
000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooooooo
o`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000
ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1noooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`05ooooo`002oooool5o`0000Gooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000<ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000=ooooo`03o`000?oooooooooo00Gooooo0_l00020ooooo`03o`000?oo
oooooooo07gooooo0_l00007ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`002oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1n
ooooo`03o`000?oooooooooo00Gooooo000;ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool0
00cooooo0ol00006ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00083ooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool000cooooo0ol00006ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`002oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`003Oooool2o`0000Koooooool00005o`0000Oooooo000?ooooo`03
o`000?oooooooooo0?oooooo3oooool000_ooooo00Go0000ooooooooooooooooo`00003ooooooa7o
oooo000<ooooo`?o0000oooooolBooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.2089, -1.31662, \
0.0808208, 0.0250332}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency spectrum", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(spectrum = \ 
        Table[{k/T0, 
            FourierCoefficient[Pulse1[t], t, k, 
              FourierParameters \[Rule] {\(-1\), \(-1\)/T0}]}, {k, \(-4\)*T0, 
            4*T0}];\)\), "\[IndentingNewLine]", 
    \(\(gd = 
        DiscreteListPlot[spectrum, \ Red, \ Frame \[Rule] True, \ 
          PlotRange \[Rule] All, \ Axes \[Rule] {True, False}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.118423 3.87917 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04084 -30 -4.5 ]
[-0.0125 .04084 0 4.5 ]
[-0.0125 .11842 -6 -4.5 ]
[-0.0125 .11842 0 4.5 ]
[-0.0125 .19601 -24 -4.5 ]
[-0.0125 .19601 0 4.5 ]
[-0.0125 .27359 -24 -4.5 ]
[-0.0125 .27359 0 4.5 ]
[-0.0125 .35117 -24 -4.5 ]
[-0.0125 .35117 0 4.5 ]
[-0.0125 .42876 -24 -4.5 ]
[-0.0125 .42876 0 4.5 ]
[-0.0125 .50634 -18 -4.5 ]
[-0.0125 .50634 0 4.5 ]
[-0.0125 .58392 -24 -4.5 ]
[-0.0125 .58392 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04084 m
.00625 .04084 L
s
[(-0.02)] -0.0125 .04084 1 0 Mshowa
0 .11842 m
.00625 .11842 L
s
[(0)] -0.0125 .11842 1 0 Mshowa
0 .19601 m
.00625 .19601 L
s
[(0.02)] -0.0125 .19601 1 0 Mshowa
0 .27359 m
.00625 .27359 L
s
[(0.04)] -0.0125 .27359 1 0 Mshowa
0 .35117 m
.00625 .35117 L
s
[(0.06)] -0.0125 .35117 1 0 Mshowa
0 .42876 m
.00625 .42876 L
s
[(0.08)] -0.0125 .42876 1 0 Mshowa
0 .50634 m
.00625 .50634 L
s
[(0.1)] -0.0125 .50634 1 0 Mshowa
0 .58392 m
.00625 .58392 L
s
[(0.12)] -0.0125 .58392 1 0 Mshowa
.125 Mabswid
0 .06024 m
.00375 .06024 L
s
0 .07963 m
.00375 .07963 L
s
0 .09903 m
.00375 .09903 L
s
0 .13782 m
.00375 .13782 L
s
0 .15721 m
.00375 .15721 L
s
0 .17661 m
.00375 .17661 L
s
0 .2154 m
.00375 .2154 L
s
0 .2348 m
.00375 .2348 L
s
0 .25419 m
.00375 .25419 L
s
0 .29299 m
.00375 .29299 L
s
0 .31238 m
.00375 .31238 L
s
0 .33178 m
.00375 .33178 L
s
0 .37057 m
.00375 .37057 L
s
0 .38996 m
.00375 .38996 L
s
0 .40936 m
.00375 .40936 L
s
0 .44815 m
.00375 .44815 L
s
0 .46755 m
.00375 .46755 L
s
0 .48694 m
.00375 .48694 L
s
0 .52574 m
.00375 .52574 L
s
0 .54513 m
.00375 .54513 L
s
0 .56453 m
.00375 .56453 L
s
0 .02144 m
.00375 .02144 L
s
0 .00205 m
.00375 .00205 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04084 m
1 .04084 L
s
.99375 .11842 m
1 .11842 L
s
.99375 .19601 m
1 .19601 L
s
.99375 .27359 m
1 .27359 L
s
.99375 .35117 m
1 .35117 L
s
.99375 .42876 m
1 .42876 L
s
.99375 .50634 m
1 .50634 L
s
.99375 .58392 m
1 .58392 L
s
.125 Mabswid
.99625 .06024 m
1 .06024 L
s
.99625 .07963 m
1 .07963 L
s
.99625 .09903 m
1 .09903 L
s
.99625 .13782 m
1 .13782 L
s
.99625 .15721 m
1 .15721 L
s
.99625 .17661 m
1 .17661 L
s
.99625 .2154 m
1 .2154 L
s
.99625 .2348 m
1 .2348 L
s
.99625 .25419 m
1 .25419 L
s
.99625 .29299 m
1 .29299 L
s
.99625 .31238 m
1 .31238 L
s
.99625 .33178 m
1 .33178 L
s
.99625 .37057 m
1 .37057 L
s
.99625 .38996 m
1 .38996 L
s
.99625 .40936 m
1 .40936 L
s
.99625 .44815 m
1 .44815 L
s
.99625 .46755 m
1 .46755 L
s
.99625 .48694 m
1 .48694 L
s
.99625 .52574 m
1 .52574 L
s
.99625 .54513 m
1 .54513 L
s
.99625 .56453 m
1 .56453 L
s
.99625 .02144 m
1 .02144 L
s
.99625 .00205 m
1 .00205 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11842 m
1 .11842 L
s
1 0 0 r
.5 Mabswid
.02381 .11842 m
.02381 .11842 L
s
.03869 .11842 m
.03869 .10318 L
s
.05357 .11842 m
.05357 .08932 L
s
.06845 .11842 m
.06845 .07909 L
s
.08333 .11842 m
.08333 .07432 L
s
.09821 .11842 m
.09821 .07617 L
s
.1131 .11842 m
.1131 .08484 L
s
.12798 .11842 m
.12798 .09952 L
s
.14286 .11842 m
.14286 .11842 L
s
.15774 .11842 m
.15774 .13897 L
s
.17262 .11842 m
.17262 .15811 L
s
.1875 .11842 m
.1875 .17275 L
s
.20238 .11842 m
.20238 .18016 L
s
.21726 .11842 m
.21726 .17846 L
s
.23214 .11842 m
.23214 .16693 L
s
.24702 .11842 m
.24702 .14622 L
s
.2619 .11842 m
.2619 .11842 L
s
.27679 .11842 m
.27679 .08692 L
s
.29167 .11842 m
.29167 .05606 L
s
.30655 .11842 m
.30655 .03067 L
s
.32143 .11842 m
.32143 .01552 L
s
.33631 .11842 m
.33631 .01472 L
s
.35119 .11842 m
.35119 .03111 L
s
.36607 .11842 m
.36607 .06592 L
s
.38095 .11842 m
.38095 .11842 L
s
.39583 .11842 m
.39583 .18593 L
s
.41071 .11842 m
.41071 .26394 L
s
.4256 .11842 m
.4256 .34658 L
s
.44048 .11842 m
.44048 .42712 L
s
.45536 .11842 m
.45536 .49868 L
s
.47024 .11842 m
.47024 .55498 L
s
.48512 .11842 m
.48512 .59095 L
s
.5 .11842 m
.5 .60332 L
s
.51488 .11842 m
.51488 .59095 L
s
.52976 .11842 m
.52976 .55498 L
s
.54464 .11842 m
.54464 .49868 L
s
.55952 .11842 m
.55952 .42712 L
s
.5744 .11842 m
.5744 .34658 L
s
.58929 .11842 m
.58929 .26394 L
s
.60417 .11842 m
.60417 .18593 L
s
.61905 .11842 m
.61905 .11842 L
s
.63393 .11842 m
.63393 .06592 L
s
.64881 .11842 m
.64881 .03111 L
s
.66369 .11842 m
.66369 .01472 L
s
.67857 .11842 m
.67857 .01552 L
s
.69345 .11842 m
.69345 .03067 L
s
.70833 .11842 m
.70833 .05606 L
s
.72321 .11842 m
.72321 .08692 L
s
.7381 .11842 m
.7381 .11842 L
s
.75298 .11842 m
.75298 .14622 L
s
.76786 .11842 m
.76786 .16693 L
s
.78274 .11842 m
.78274 .17846 L
s
.79762 .11842 m
.79762 .18016 L
s
.8125 .11842 m
.8125 .17275 L
s
.82738 .11842 m
.82738 .15811 L
s
.84226 .11842 m
.84226 .13897 L
s
.85714 .11842 m
.85714 .11842 L
s
.87202 .11842 m
.87202 .09952 L
s
.8869 .11842 m
.8869 .08484 L
s
.90179 .11842 m
.90179 .07617 L
s
.91667 .11842 m
.91667 .07432 L
s
.93155 .11842 m
.93155 .07909 L
s
.94643 .11842 m
.94643 .08932 L
s
.96131 .11842 m
.96131 .10318 L
s
.97619 .11842 m
.97619 .11842 L
s
.015 w
.02381 .11842 Mdot
.03869 .10318 Mdot
.05357 .08932 Mdot
.06845 .07909 Mdot
.08333 .07432 Mdot
.09821 .07617 Mdot
.1131 .08484 Mdot
.12798 .09952 Mdot
.14286 .11842 Mdot
.15774 .13897 Mdot
.17262 .15811 Mdot
.1875 .17275 Mdot
.20238 .18016 Mdot
.21726 .17846 Mdot
.23214 .16693 Mdot
.24702 .14622 Mdot
.2619 .11842 Mdot
.27679 .08692 Mdot
.29167 .05606 Mdot
.30655 .03067 Mdot
.32143 .01552 Mdot
.33631 .01472 Mdot
.35119 .03111 Mdot
.36607 .06592 Mdot
.38095 .11842 Mdot
.39583 .18593 Mdot
.41071 .26394 Mdot
.4256 .34658 Mdot
.44048 .42712 Mdot
.45536 .49868 Mdot
.47024 .55498 Mdot
.48512 .59095 Mdot
.5 .60332 Mdot
.51488 .59095 Mdot
.52976 .55498 Mdot
.54464 .49868 Mdot
.55952 .42712 Mdot
.5744 .34658 Mdot
.58929 .26394 Mdot
.60417 .18593 Mdot
.61905 .11842 Mdot
.63393 .06592 Mdot
.64881 .03111 Mdot
.66369 .01472 Mdot
.67857 .01552 Mdot
.69345 .03067 Mdot
.70833 .05606 Mdot
.72321 .08692 Mdot
.7381 .11842 Mdot
.75298 .14622 Mdot
.76786 .16693 Mdot
.78274 .17846 Mdot
.79762 .18016 Mdot
.8125 .17275 Mdot
.82738 .15811 Mdot
.84226 .13897 Mdot
.85714 .11842 Mdot
.87202 .09952 Mdot
.8869 .08484 Mdot
.90179 .07617 Mdot
.91667 .07432 Mdot
.93155 .07909 Mdot
.94643 .08932 Mdot
.96131 .10318 Mdot
.97619 .11842 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00:Oooool3
o`0003Oooooo1Ol0000gooooo`;o0000>?ooool5o`0003Wooooo0ol00006ooooo`00:_ooool00ol0
003oooooooooo`0gooooo`04o`000?ooooooooooo`0003Kooooo00Co0000oooooooooooo0000>?oo
ool01?l0003oooooooooool0000jooooo`03o`000?oooooooooo00Gooooo000Qooooo`Go000000?o
ooooo`000?l000000ol0000aooooo`Go00000oooool00ol0003oooooooooo`0fooooo`04o`000?oo
ooooooooo`0003Wooooo00?o0000ooooooooool0=oooool5o`0000Kooooo000Wooooo`04o`000?oo
ooooooooo`0003_ooooo00?o0000ooooooooool0=Oooool01?l0003oooooooooool0000jooooo`03
o`000?oooooooooo03Kooooo00Co0000oooooooooooo00001oooool002Sooooo00?o0000ooooool0
0000>?ooool01Ol0003ooooooooooooooooo000003Kooooo00Co0000oooooooooooo0000=oooool0
1Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooool000001oooool002Wooooo0_l0000h
ooooo`05o`000?ooooooooooooooool00000=_ooool01?l0003oooooooooool0000gooooo`05o`00
0?ooooooooooooooool00000>Oooool2o`0000Oooooo000Zooooo`03o`000?oooooooooo03Oooooo
0ol0000hooooo`;o0000>Oooool3o`0003_ooooo00?o0000ooooooooool01Oooool00?oooooo8Ooo
ool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0027oooooo_l00001ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo0?[ooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`1=ooooo`?oo`0000Coooooool00?oo003oo`00D?ooool6ool0053ooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`1=ooooo`?oo`0000Coooooool00?oo003oo`00D?ooool6
ool0053ooooo0Ol00001ooooo`008Oooool2o`0004kooooo0ooo00001?ooooooo`00ool00?oo001@
ooooo`Koo`00Coooool2o`00007ooooo000Qooooo`03o`000?oooooooooo04kooooo00Goo`00oooo
ooooooooooooool0001Booooo`05ool00?oooooooooooooooooo0000D?ooool1o`00007ooooo000Q
ooooo`03o`000?oooooooooo04Wooooo0ooo0002ooooo`06ool00?oooooooooooooooooo003ooooo
0ooo0019ooooo`?oo`000_ooool01_oo003oooooooooooooooooo`00ooooo`?oo`00C?ooool1o`00
007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000Co
oooo00?o0000ooooooooool0BOooool3ool000;ooooo00Koo`00ooooooooooooooooool00?ooool3
ool004Wooooo0ooo0002ooooo`06ool00?oooooooooooooooooo003ooooo0ooo001<ooooo`7o0000
0Oooool000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0BOooool3ool000;ooooo00Koo`00oooo
ooooooooooooool00?ooool3ool004Wooooo0ooo0002ooooo`06ool00?oooooooooooooooooo003o
oooo0ooo001<ooooo`7o00000Oooool000Go00000_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool2o`0004_ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000B_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0001;ooooo`;o00000Oooool000Oooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0B_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool0001:ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0004cooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`06
o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo04[ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
B_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0001<oooo
o`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`15ooooo`?oo`000_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0001:ooooo`05
ool00?oooooooooooooooooo00000oooool01_oo003oooooooooooooooooo`00ooooo`?oo`00B?oo
ool1o`00007ooooo0008ooooo`;o00002_ooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooo
oooo04Gooooo0ooo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0004[ooooo00Goo`00ooooooooooooooooool00003ooooo`06ool00?oooooooooooooo
oooo003ooooo0ooo0018ooooo`7o00000Oooool0027ooooo0_l00016ooooo`?oo`000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0001:ooooo`05ool00?oo
oooooooooooooooo00000oooool01_oo003oooooooooooooooooo`00ooooo`?oo`00Aoooool2o`00
007ooooo000Qooooo`03o`000?oooooooooo04Oooooo00Coo`00ooooooooooooo`000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo00000_oo0011ooooo`?oo`000_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool0
0?oooooooooo04Oooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`17ooooo`04ool00?oo
ooooooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?ooooooo`0000;o
o`00@Oooool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000_ooool00ooo003oooooooooo`17ooooo`7o00000Oooool0027ooooo00?o0000oooo
ooooool04?ooool3ool00004oooooooo003oo`00ool0033ooooo00Coo`00ooooooooooooo`000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo00000_oo0011ooooo`?oo`00
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002oooo
o`03ool00?oooooooooo02gooooo0ooo00001?ooooooo`00ool00?oo000Cooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool03Oooool6ool00004oooooooo003oo`00ool0033ooooo00Coo`00
ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00013ooooo`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`04ool00?ooooooooooool002oooooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`00
3oooool1o`00007ooooo000Qooooo`;o00003_ooool6ool00004oooooooo003oo`00ool0033ooooo
00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00013ooooo`04ool00?ooooooooooool000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`04ool00?ooooooooooool002oooooo0ooo00001Oooooooo`00ool00?oo003ooooo
00?oo`003_ooool2o`00007ooooo000Qooooo`03o`000?oooooooooo00gooooo0ooo0002ooooo`06
ool00?oooooooooooooooooo003ooooo0ooo000Wooooo`?oo`000_ooool01?oo003ooooooooooooo
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0004?o
oooo00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00
ooooooooooooo`000_ooool3ool002Kooooo0ooo0002ooooo`05ool00?oooooooooooooooooo0000
0_ooool3ool000oooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`09ooooo`?oo`000_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo00000_oo000Wooooo`?oo`00
0_ooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0004?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Coo`00ooooooooooooo`000_ooool3ool002Kooooo0ooo0002ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooool00002ool000cooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`09ooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00oooooooo00000_oo000Wooooo`?oo`000_ooool01?oo003ooooooooooooo0003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0004?ooooo
00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooo
ooooooooo`000_ooool3ool002Kooooo0ooo0002ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooool00002ool000cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`09
ooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`00
0_ooool3ool002Cooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0@Oooool0
1?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooo
oooooooo0003ooooo`03ool00?oooooooooo02;ooooo0ooo0002ooooo`04ool00?ooooooooooool0
00?ooooo00Koo`00ooooooooooooooooool00?ooool3ool000cooooo0Ol00001ooooo`008Oooool2
o`0000Kooooo0ooo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00?oo`00ooooooooool00ooo000Tooooo`05ool00?oooooooooooooooooo
00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo047ooooo00Coo`00ooooooooooooo`000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`0Rooooo`?o
o`000_ooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooool00002ool000Oooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`05oooo
o`?oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0002ooooo`03ool00?oooooooooo00?oo`009?ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`11ooooo`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool08_ooool3ool000;ooooo
00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
oooo00000_oo0008ooooo`7o00000Oooool001[ooooo0_l00005ooooo`03o`000?oooooooooo00Go
oooo0ooo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Goo`00ooooooooooooooooool0000Uooooo`05ool00?oooooooooooooooooo0000
0_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo047ooooo00Coo`00ooooooooooooo`000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`0Sooooo`05ool0
0?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Koo`00oooo
ooooooooooooool00?ooool3ool000Sooooo0Ol00001ooooo`006Oooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Kooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo
02?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0@Oooool01?oo003ooooo
oooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003
ooooo`03ool00?oooooooooo02?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool01_ooool1o`00007ooooo000Iooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooo
oooooooo0ooo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`03ool001_ooooo
0ooo0002ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?ooooooo`0000;oo`00>Oooool3
ool000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`03ool001_ooooo0ooo0002ooooo`05
ool00?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?ooooooo`0000;oo`001?ooool1o`00007ooooo000I
ooooo`04o`000?ooooooooooo`0000Cooooo1?l00003ool000;o000000Goo`00o`000?l0003o0000
ool00003o`000005ool00?l0003o0000o`000?oo00000ol000001?oo003o0000o`000?oo0003o`00
0003ool00?l0003o000000?oo`000_l000001?oo003o0000o`000?oo0003o`000005ool00?l0003o
0000o`000?oo00000ol000001Ooo003o0000o`000?l0003oo`0000;o000000?oo`00o`000?l00000
0ooo0002o`000005ool00?l0003o0000o`000?oo00000_l000001Ooo003o0000o`000?l0003oo`00
00?o000000Goo`00o`000?l0003o0000ool00003o`000003ool00?l0003oo`0000;oo`000_l00000
1Ooo003o0000o`000?l0003oo`0000?o000000Coo`00o`000?l0003oo`000ol000001Ooo003o0000
o`000?l0003oo`0000?o000000Goo`00o`000?l0003o0000ool00002o`000005ool00?l0003o0000
o`000?oo00000ol000001Ooo003o0000o`000?l0003oo`0000;o000000Goo`00o`000?l0003o0000
ool00003o`000003ool00?l0003oo`0000;oo`000ol000001?oo003o0000o`000?oo0003o`000005
ool00?l0003o0000o`000?oo00000ol000001?oo003o0000o`000?oo0003o`000003ool00?l0003o
000000?oo`000_l000001?oo003o0000o`000?oo0003o`000005ool00?l0003o0000o`000?oo0000
0ol000001Ooo003o0000o`000?l0003oo`0000;o000000?oo`00o`000?l000000ooo0002o`000005
ool00?l0003o0000o`000?oo00000_l000001Ooo003o0000o`000?l0003oo`0000?o000000Goo`00
o`000?l0003o0000ool00003o`000003ool00?l0003oo`0000;oo`001Ol00001ooooo`006Oooool0
1?l0003oooooooooool00004ooooo`04o`000?ooooooooooooooo`?oo`007?ooool3ool000;ooooo
00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00002ooooo`03ool00?oooooooooo00?oo`006oooool3ool000;ooooo00Goo`00
ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooool00002ool001cooooo0ooo0002ooooo`04ool00?ooooooooooool000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool0
0ooo003oooooooooo`03ool001_ooooo0ooo0004ooooo`7o00000Oooool001Wooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`0Uooooo`04ool00?ooooooooooool000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003o
ooooooooo`0Sooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool08oooool01?oo003ooooooooooooo
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;o
oooo00?oo`00ooooooooool09Oooool1o`00007ooooo000Jooooo`;o00001Oooool00ol0003ooooo
ooooo`0Uooooo`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`0Sooooo`05ool00?oooooo
oooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool08oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool09Oooool1
o`00007ooooo000Qooooo`03o`000?oooooooooo02?ooooo0ooo0002ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`00
9Oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo02?ooooo00Coo`00ooooooooooooo`000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Koo`00ooooooooooooooooool00?ooool3ool002Ko
oooo0Ol00001ooooo`008Oooool2o`0002Cooooo0ooo0002ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`009Oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo02?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Koo`00ooooooooooooooooool00?ooool3ool002Gooooo0_l0
0001ooooo`008Oooool00ol0003oooooooooo`0Sooooo`?oo`000_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?ooooooo`0000;oo`00
9?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo027ooooo0ooo0002ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo00000_oo
000Vooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0:?ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?ooooooo`0000;oo`00
9?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo027ooooo0ooo0002ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0:?oo
ool1o`00007ooooo000Qooooo`03o`000?oooooooooo02Sooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooool00002ool002Cooooo
00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`0Qooooo`?oo`000_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo02Sooooo0Ol0
0001ooooo`008Oooool00ol0003oooooooooo`0Wooooo`?oo`000_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool0000Xooooo`05ool00?oooooooooooooooooo
00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool09_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Koo`00ooooooooooooooooool0
0?ooool3ool002[ooooo0Ol00001ooooo`008Oooool2o`0002Sooooo0ooo0002ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0002Sooooo00Goo`00oooooooo
ooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`0Vooooo`05ool00?oooooooooooooooooo00000oooool01_oo003ooooooooo
ooooooooo`00ooooo`?oo`00:Oooool2o`00007ooooo000Qooooo`03o`000?oooooooooo02Oooooo
0ooo0002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooool00002ool002So
oooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooo
oooooooo00000oooool00ooo003oooooooooo`0Uooooo`?oo`000_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00oooooooo00000_oo000Zooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0;?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo00000_oo
000Xooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool09Oooool3ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`03ool00?oooooooooo02cooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`0[ooooo`?oo`000_ooool01_oo003oooooooooooooooooo`00ooooo`?oo`00:?ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo02Gooooo0ooo0002ooooo`06ool00?oooooooooooooooooo
003ooooo0ooo000^ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0:oooool3ool000;o
oooo00?oo`00oooooooo00000_oo000/ooooo`05ool00?oooooooooooooooooo00000oooool01?oo
003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0:Oooool3
ool000;ooooo00?oo`00oooooooo00000_oo000^ooooo`7o00000Oooool0027ooooo0_l0000/oooo
o`?oo`0000?oooooool00?oo00001?oo000/ooooo`05ool00?oooooooooooooooooo00000oooool0
1?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0:Ooo
ool3ool00003oooooooo003oo`0000Coo`00;Oooool2o`00007ooooo000Qooooo`03o`000?oooooo
oooo02oooooo1_oo000[ooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003o
oooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo
0003ooooo`03ool00?oooooooooo00?oo`00:_ooool3ool00004oooooooo003oo`00ool0037ooooo
0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol0
0004ooooo`03o`000?oooooooooo02oooooo0ooo000^ooooo`?oo`000_ooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000ooo
ool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00?oo`00;_ooool3ool0037ooooo
0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Pooooo`?oo`000_ooool01Ooo
003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooo
oooo00000oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo00?oo`00H_ooool1
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`04ooooo`;o0000I_ooool01Ooo003oooooooooooooooooo`0000;ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo
003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooo
oooo0003ooooo`03ool00?oooooooooo06Cooooo0_l00001ooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Uooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00?oo`00oooo
ooooool0IOooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0IOoo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooo
oooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo06Gooooo
0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oo
oooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Gooooo00Goo`00oooo
ooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`1Uooooo`7o00000Oooool0
00Sooooo0_l0000:ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0IOooool01Ooo
003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooo
oooo00000oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo06Gooooo0Ol00001
ooooo`008Oooool2o`0006Kooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooo
o`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool0
0ooo003oooooooooo`1Tooooo`;o00000Oooool0027ooooo00?o0000ooooooooool0IOooool01Ooo
003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooo
oooo00000oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo06Gooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`1Uooooo`05ool00?oooooooooooooooooo00000_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool0
0?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?oooooooooo
ool000?ooooo00?oo`00ooooooooool0IOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo
06Gooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`1U
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0IOooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo
003ooooooooooooo0003ooooo`03ool00?oooooooooo06Gooooo0Ol00001ooooo`008Oooool2o`00
06Kooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`1T
ooooo`;o00000Oooool0027ooooo00?o0000ooooooooool0IOooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo
003ooooooooooooo0003ooooo`03ool00?oooooooooo06Gooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`1Uooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00?oo`00
ooooooooool0IOooool1o`00007ooooo000Qooooo`03o`000?oooooooooo06Gooooo00Goo`00oooo
ooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`1Uooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool0IOooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooo
oooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003
ooooo`03ool00?oooooooooo06Gooooo0Ol00001ooooo`008Oooool2o`0006Kooooo00Goo`00oooo
ooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`1Tooooo`;o00000Oooool0
027ooooo00?o0000ooooooooool0IOooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooo
oooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003
ooooo`03ool00?oooooooooo06Gooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1Soooo
o`?oo`000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`03ool006Kooooo0Ol00001oooo
o`002?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol00004ooooo`03
o`000?oooooooooo06?ooooo0ooo0003ooooo`04ool00?ooooooooooool000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo00?o
o`00I_ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo0ooo0003oooo
o`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00002ooooo`03ool00?oooooooooo00?oo`00I_ooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`05o`0000Cooooo0_l0001Z
ooooo`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00002ooooo`03ool00?oooooooooo06Sooooo0_l00001ooooo`001oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo06Wooooo00Coo`00ooooooooooooo`000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool0
JOooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo06Wooooo00Coo`00oooooooo
ooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;o
oooo00?oo`00ooooooooool0JOooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000oooool2o`0000Gooooo00?o0000ooooooooool0JOooool01?oo
003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000_ooool00ooo003oooooooooo`1Yooooo`7o00000Oooool000Sooooo0_l0000:ooooo`;o
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Wooooo00Coo`00oooooooo
ooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;o
oooo00?oo`00ooooooooool0JOooool1o`00007ooooo000Qooooo`;o0000J_ooool01?oo003ooooo
oooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0_ooool00ooo003oooooooooo`1Xooooo`;o00000Oooool0027ooooo00?o0000ooooooooool0JOoo
ool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000_ooool00ooo003oooooooooo`1Yooooo`7o00000Oooool0027ooooo00?o0000
ooooooooool0JOooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`1Yooooo`7o00000Oooool0
027ooooo00?o0000ooooooooool0JOooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003oooooooooo`1Yoooo
o`7o00000Oooool0027ooooo00?o0000ooooooooool0JOooool01?oo003ooooooooooooo0003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool00ooo003o
ooooooooo`1Yooooo`7o00000Oooool0027ooooo0_l0001Zooooo`04ool00?ooooooooooool000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool0
0?oooooooooo06Sooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1Yooooo`04ool00?oo
ooooooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0002ooooo`03ool00?oooooooooo06Wooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1Y
ooooo`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00002ooooo`03ool00?oooooooooo06Wooooo0Ol00001ooooo`008Oooool00ol0
003oooooooooo`1Yooooo`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo06Wooooo0Ol00001oooo
o`008Oooool00ol0003oooooooooo`1Yooooo`04ool00?ooooooooooool000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo06Wo
oooo0Ol00001ooooo`008Oooool2o`0006[ooooo00Coo`00ooooooooooooo`000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool0
J?ooool2o`00007ooooo000Qooooo`03o`000?oooooooooo06Wooooo00Coo`00ooooooooooooo`00
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00?o
o`00ooooooooool0JOooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0JOooool01?oo003ooooooooooooo
0003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool0
0ooo003oooooooooo`1Yooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1Wooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?ooooooo`0000;oo`00J_ooool1o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Ioooool3ool000;ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooool00002ool006[ooooo0Ol00001ooooo`001ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`;o
0000J?ooool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooool00002ool006Wooooo0_l00001ooooo`001oooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`1/oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Co
o`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool0K?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06cooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooo
oooo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1/ooooo`7o
00000Oooool000Sooooo0_l0000:ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0
K?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo06cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1/ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooo
o`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0K?ooool1o`00
007ooooo000Qooooo`;o0000KOooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo06_ooooo0_l00001ooooo`008Oooool00ol0003ooooooooo
o`1/ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool0K?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo06cooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooo
oooo0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1/ooooo`7o
00000Oooool0027ooooo00?o0000ooooooooool0K?ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo06cooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`1/ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool0K?ooool1o`00007ooooo000Qooooo`;o0000KOooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?oooooo
ooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo06_ooooo
0_l00001ooooo`008Oooool00ol0003oooooooooo`1/ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0K?ooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo06cooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`1/ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0
K?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`04ool00?ooooooooooool000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo06cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1/ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00oooooooooooo
o`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0K?ooool1o`00
007ooooo000Qooooo`;o0000KOooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo06_ooooo0_l00001ooooo`008Oooool00ol0003ooooooooo
o`1/ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?o
oooo00Coo`00ooooooooooooo`000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00
ooooooooool0K?ooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0K?ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo06cooooo0Ol00001ooooo`00
1oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06_ooooo0ooo0002ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?ooooooo`0000;oo`00K_ooool1o`00007ooooo0007ooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo
oooo00;ooooo0_l0001/ooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooool00002ool006gooooo0_l00001ooooo`001oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000;ooooo0ol00005ooooo`03o`000?oooooooooo06_ooooo0ooo0002oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?ooooooo`0000;oo`00K_ooool1o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0L?ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`1`ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo0000
2?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1`ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo073ooooo
0Ol00001ooooo`002?ooool2o`0000[ooooo0_l00003ooooo`?o00001Oooool00ol0003ooooooooo
o`1`ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo073ooooo0Ol00001oooo
o`008Oooool2o`00077ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0Kooo
ool2o`00007ooooo000Qooooo`03o`000?oooooooooo073ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool0L?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo073ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0L?ooool1o`00007ooooo000Qoooo
o`03o`000?oooooooooo073ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
L?ooool1o`00007ooooo000Qooooo`03o`000?oooooooooo073ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool0L?ooool1o`00007ooooo000Qooooo`;o0000LOooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`1_ooooo`;o00000Oooool0027ooooo00?o0000
ooooooooool0L?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1`ooooo`7o
00000Oooool0027ooooo00?o0000ooooooooool0L?ooool01Ooo003oooooooooooooooooo`0000?o
oooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`1`ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0L?ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`1`ooooo`7o00000Oooool0027ooooo00?o
0000ooooooooool0L?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00002ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1`oooo
o`7o00000Oooool0027ooooo0_l0001aooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oo
oooooooo06oooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1`ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo073ooooo0Ol00001ooooo`008Oooool00ol0003ooooo
ooooo`1`ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo073ooooo0Ol00001
ooooo`003_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooo
ooooool0Koooool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`04ool00?oooooo
ooooool000?ooooo00?oo`00oooooooo00000_oo001booooo`7o00000Oooool000gooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06oooooo0ooo
0002ooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`03
ool00?ooooooo`0000;oo`00L_ooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool01?ooool2o`00073ooooo0ooo0002ooooo`05ool00?oooooooooooooo
oooo00000oooool01?oo003ooooooooooooo0003ooooo`03ool00?ooooooo`0000;oo`00LOooool2
o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1dooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooo
oooo0003ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`003Oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0M?ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000oooool00ooo003oooooooooo`1doooo
o`7o00000Oooool000gooooo00Co0000oooooooooooo00002?ooool2o`0000Kooooo00?o0000oooo
ooooool0M?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Coo`00ooooooooooooo`000ooo
ool00ooo003oooooooooo`1dooooo`7o00000Oooool000kooooo0_l0000:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0M?ooool01Ooo003oooooooooooooooooo`0000?ooooo00Co
o`00ooooooooooooo`000oooool00ooo003oooooooooo`1dooooo`7o00000Oooool0027ooooo0_l0
001eooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`03
ool00?oooooooooo07?ooooo0_l00001ooooo`008Oooool00ol0003oooooooooo`1dooooo`05ool0
0?oooooooooooooooooo00000oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo
07Cooooo0Ol00001ooooo`008Oooool00ol0003oooooooooo`1dooooo`05ool00?oooooooooooooo
oooo00000oooool01?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo07Cooooo0Ol00001
ooooo`008Oooool00ol0003oooooooooo`1dooooo`05ool00?oooooooooooooooooo00000oooool0
1?oo003ooooooooooooo0003ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`008Oooool0
0ol0003oooooooooo`1dooooo`05ool00?oooooooooooooooooo00000oooool01?oo003ooooooooo
oooo0003ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`008Oooool2o`0007Gooooo00Go
o`00ooooooooooooooooool00003ooooo`04ool00?ooooooooooool000?ooooo00?oo`00oooooooo
ool0Loooool2o`00007ooooo000Qooooo`03o`000?oooooooooo07Cooooo00Goo`00oooooooooooo
ooooool00003ooooo`04ool00?ooooooooooool000?ooooo00?oo`00ooooooooool0M?ooool1o`00
007ooooo000Qooooo`03o`000?oooooooooo07?ooooo0ooo0002ooooo`05ool00?oooooooooooooo
oooo00000_ooool00ooo003oooooooooo`03ool007Gooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`1cooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00oooo
ooooool00ooo001eooooo`7o00000Oooool0027ooooo00?o0000ooooooooool0Loooool3ool000;o
oooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo00?oo`00MOooool1o`00
007ooooo000Qooooo`;o0000NOooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00oooo
ooooool0Moooool2o`00007ooooo000Qooooo`03o`000?oooooooooo07Sooooo00Goo`00oooooooo
ooooooooool00002ooooo`03ool00?oooooooooo07Sooooo0Ol00001ooooo`002?ooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo07So
oooo00Goo`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo07Sooooo0Ol00001oooo
o`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`1hooooo`05ool00?oooooooooooooooooo00000_oo
ool00ooo003oooooooooo`1hooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N?oo
ool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00ooooooooool0N?ooool1o`00007ooooo
0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`;o0000NOooool01Ooo003oooooooooooooooooo`0000;ooooo00?oo`00oooooooo
ool0Moooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_ooool3ool0
00?ooooo00?oo`00oooooooo00000_oo001iooooo`7o00000Oooool000Oooooo00Co0000oooooooo
oooo00002?ooool2o`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo07Kooooo0ooo0003ooooo`03ool00?ooooooo`0000;oo`00NOooool1o`00007ooooo0008oooo
o`;o00002_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003oooooooooo`1foooo
o`?oo`000oooool00ooo003oooooool00002ool007Wooooo0Ol00001ooooo`008Oooool00ol0003o
ooooooooo`1jooooo`?oo`00OOooool1o`00007ooooo000Qooooo`;o0000Noooool3ool007cooooo
0_l00001ooooo`008Oooool00ol0003oooooooooo`1jooooo`?oo`00OOooool1o`00007ooooo000Q
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`03
ooooo`7o00000Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`008Oooooono`00007ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.29832, -0.0469451, \
0.0331097, 0.00101611}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Show results of previous four subsections", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{g1, g2}, {g3, g4}}], 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.155277 0.15374 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00154 -12 -4.5 ]
[-0.0125 .00154 0 4.5 ]
[-0.0125 .15528 -6 -4.5 ]
[-0.0125 .15528 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46276 -6 -4.5 ]
[-0.0125 .46276 0 4.5 ]
[-0.0125 .6165 -6 -4.5 ]
[-0.0125 .6165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00154 m
.00625 .00154 L
s
[(-1)] -0.0125 .00154 1 0 Mshowa
0 .15528 m
.00625 .15528 L
s
[(0)] -0.0125 .15528 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .46276 m
.00625 .46276 L
s
[(2)] -0.0125 .46276 1 0 Mshowa
0 .6165 m
.00625 .6165 L
s
[(3)] -0.0125 .6165 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .06303 m
.00375 .06303 L
s
0 .09378 m
.00375 .09378 L
s
0 .12453 m
.00375 .12453 L
s
0 .18603 m
.00375 .18603 L
s
0 .21677 m
.00375 .21677 L
s
0 .24752 m
.00375 .24752 L
s
0 .27827 m
.00375 .27827 L
s
0 .33976 m
.00375 .33976 L
s
0 .37051 m
.00375 .37051 L
s
0 .40126 m
.00375 .40126 L
s
0 .43201 m
.00375 .43201 L
s
0 .4935 m
.00375 .4935 L
s
0 .52425 m
.00375 .52425 L
s
0 .555 m
.00375 .555 L
s
0 .58575 m
.00375 .58575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00154 m
1 .00154 L
s
.99375 .15528 m
1 .15528 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46276 m
1 .46276 L
s
.99375 .6165 m
1 .6165 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .06303 m
1 .06303 L
s
.99625 .09378 m
1 .09378 L
s
.99625 .12453 m
1 .12453 L
s
.99625 .18603 m
1 .18603 L
s
.99625 .21677 m
1 .21677 L
s
.99625 .24752 m
1 .24752 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .37051 m
1 .37051 L
s
.99625 .40126 m
1 .40126 L
s
.99625 .43201 m
1 .43201 L
s
.99625 .4935 m
1 .4935 L
s
.99625 .52425 m
1 .52425 L
s
.99625 .555 m
1 .555 L
s
.99625 .58575 m
1 .58575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .15528 m
1 .15528 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .15528 m
.03318 .15528 L
.04339 .15528 L
.05298 .15528 L
.06221 .15528 L
.07203 .15528 L
.08148 .15528 L
.09153 .15528 L
.10121 .15528 L
.11052 .15528 L
.12043 .15528 L
.12997 .15528 L
.13914 .15528 L
.14891 .15528 L
.15831 .15528 L
.1683 .15528 L
.17793 .15528 L
.18278 .15528 L
.18719 .15528 L
.18837 .15528 L
.18899 .15528 L
.18964 .15528 L
.18992 .15528 L
.19022 .15528 L
.19039 .15528 L
.19054 .30902 L
.19085 .30902 L
.19196 .30902 L
.19704 .30902 L
.2067 .30902 L
.21599 .30902 L
.22588 .30902 L
.23079 .30902 L
.23319 .30902 L
.2354 .30902 L
.23651 .30902 L
.23754 .30902 L
.23781 .30902 L
.23806 .30902 L
.23836 .15528 L
.23862 .15528 L
.2398 .15528 L
.24455 .15528 L
.25387 .15528 L
.26379 .15528 L
.27335 .15528 L
.28253 .15528 L
.29231 .15528 L
.30172 .15528 L
.31173 .15528 L
Mistroke
.32137 .15528 L
.33064 .15528 L
.3405 .15528 L
.35 .15528 L
.3601 .15528 L
.36982 .15528 L
.37918 .15528 L
.38913 .15528 L
.39872 .15528 L
.40794 .15528 L
.41775 .15528 L
.42719 .15528 L
.43723 .15528 L
.44691 .15528 L
.45621 .15528 L
.46611 .15528 L
.47103 .15528 L
.47344 .15528 L
.47449 .15528 L
.47505 .15528 L
.47535 .15528 L
.47564 .15528 L
.47592 .15528 L
.47623 .30902 L
.4765 .30902 L
.47676 .30902 L
.47779 .30902 L
.48005 .30902 L
.48481 .30902 L
.49437 .30902 L
.50357 .30902 L
.51336 .30902 L
.51787 .30902 L
.52025 .30902 L
.52156 .30902 L
.52278 .30902 L
.52339 .30902 L
.52356 .30902 L
.52374 .30902 L
.52405 .15528 L
.52422 .15528 L
.5244 .15528 L
.52472 .15528 L
.52545 .15528 L
.52793 .15528 L
.5328 .15528 L
.54286 .15528 L
.55254 .15528 L
.56186 .15528 L
.57177 .15528 L
Mistroke
.58131 .15528 L
.59049 .15528 L
.60026 .15528 L
.60967 .15528 L
.61967 .15528 L
.6293 .15528 L
.63856 .15528 L
.64842 .15528 L
.65791 .15528 L
.66799 .15528 L
.67771 .15528 L
.68706 .15528 L
.69701 .15528 L
.70659 .15528 L
.7158 .15528 L
.7256 .15528 L
.73504 .15528 L
.74507 .15528 L
.75009 .15528 L
.75473 .15528 L
.75924 .15528 L
.76034 .15528 L
.76091 .15528 L
.76152 .15528 L
.76168 .15528 L
.76184 .15528 L
.76203 .30902 L
.7622 .30902 L
.76281 .30902 L
.76403 .30902 L
.7741 .30902 L
.78379 .30902 L
.79312 .30902 L
.79785 .30902 L
.80305 .30902 L
.80543 .30902 L
.80674 .30902 L
.80799 .30902 L
.80855 .30902 L
.80914 .30902 L
.80932 .30902 L
.80948 .30902 L
.80979 .15528 L
.81009 .15528 L
.8104 .15528 L
.8126 .15528 L
.82256 .15528 L
.83215 .15528 L
.84138 .15528 L
.85119 .15528 L
Mistroke
.86064 .15528 L
.87069 .15528 L
.88036 .15528 L
.88967 .15528 L
.89958 .15528 L
.90911 .15528 L
.91828 .15528 L
.92805 .15528 L
.93744 .15528 L
.94743 .15528 L
.95706 .15528 L
.96631 .15528 L
.97616 .15528 L
.97619 .15528 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.155277 0.15374 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00154 -12 -4.5 ]
[-0.0125 .00154 0 4.5 ]
[-0.0125 .15528 -6 -4.5 ]
[-0.0125 .15528 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46276 -6 -4.5 ]
[-0.0125 .46276 0 4.5 ]
[-0.0125 .6165 -6 -4.5 ]
[-0.0125 .6165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00154 m
.00625 .00154 L
s
[(-1)] -0.0125 .00154 1 0 Mshowa
0 .15528 m
.00625 .15528 L
s
[(0)] -0.0125 .15528 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .46276 m
.00625 .46276 L
s
[(2)] -0.0125 .46276 1 0 Mshowa
0 .6165 m
.00625 .6165 L
s
[(3)] -0.0125 .6165 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .06303 m
.00375 .06303 L
s
0 .09378 m
.00375 .09378 L
s
0 .12453 m
.00375 .12453 L
s
0 .18603 m
.00375 .18603 L
s
0 .21677 m
.00375 .21677 L
s
0 .24752 m
.00375 .24752 L
s
0 .27827 m
.00375 .27827 L
s
0 .33976 m
.00375 .33976 L
s
0 .37051 m
.00375 .37051 L
s
0 .40126 m
.00375 .40126 L
s
0 .43201 m
.00375 .43201 L
s
0 .4935 m
.00375 .4935 L
s
0 .52425 m
.00375 .52425 L
s
0 .555 m
.00375 .555 L
s
0 .58575 m
.00375 .58575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00154 m
1 .00154 L
s
.99375 .15528 m
1 .15528 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46276 m
1 .46276 L
s
.99375 .6165 m
1 .6165 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .06303 m
1 .06303 L
s
.99625 .09378 m
1 .09378 L
s
.99625 .12453 m
1 .12453 L
s
.99625 .18603 m
1 .18603 L
s
.99625 .21677 m
1 .21677 L
s
.99625 .24752 m
1 .24752 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .37051 m
1 .37051 L
s
.99625 .40126 m
1 .40126 L
s
.99625 .43201 m
1 .43201 L
s
.99625 .4935 m
1 .4935 L
s
.99625 .52425 m
1 .52425 L
s
.99625 .555 m
1 .555 L
s
.99625 .58575 m
1 .58575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .15528 m
1 .15528 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .15528 m
.03318 .15528 L
.04339 .15528 L
.05298 .15528 L
.06221 .15528 L
.07203 .15528 L
.08148 .15528 L
.0863 .15528 L
.08884 .15528 L
.09153 .15528 L
.09268 .15528 L
.09392 .15528 L
.09429 .15528 L
.09464 .15528 L
.09495 .15528 L
.09512 .15528 L
.09529 .30902 L
.09545 .30902 L
.09561 .30902 L
.0959 .30902 L
.09656 .30902 L
.10121 .30902 L
.11056 .30902 L
.1205 .30902 L
.13007 .30902 L
.13488 .30902 L
.13927 .30902 L
.14044 .30902 L
.14105 .30902 L
.1417 .30902 L
.14227 .30902 L
.14243 .30902 L
.14259 .30902 L
.1429 .15528 L
.14318 .15528 L
.14347 .15528 L
.144 .15528 L
.14907 .15528 L
.15831 .15528 L
.16814 .15528 L
.17761 .15528 L
.18767 .15528 L
.19736 .15528 L
.20669 .15528 L
.21661 .15528 L
.22616 .15528 L
.23534 .15528 L
.24512 .15528 L
.25454 .15528 L
.26454 .15528 L
Mistroke
.27418 .15528 L
.28345 .15528 L
.29332 .15528 L
.30282 .15528 L
.31291 .15528 L
.32264 .15528 L
.33199 .15528 L
.34195 .15528 L
.35153 .15528 L
.36075 .15528 L
.37056 .15528 L
.38001 .15528 L
.39005 .15528 L
.39972 .15528 L
.40902 .15528 L
.41892 .15528 L
.42846 .15528 L
.43762 .15528 L
.44738 .15528 L
.45677 .15528 L
.46154 .15528 L
.46676 .15528 L
.46917 .15528 L
.47174 .15528 L
.47299 .15528 L
.47417 .15528 L
.47523 .15528 L
.47552 .15528 L
.47583 .15528 L
.47609 .15528 L
.47638 .30902 L
.47669 .30902 L
.47698 .30902 L
.47764 .30902 L
.47884 .30902 L
.4811 .30902 L
.48617 .30902 L
.49568 .30902 L
.50482 .30902 L
.5099 .30902 L
.51456 .30902 L
.51912 .30902 L
.52142 .30902 L
.52205 .30902 L
.52272 .30902 L
.52305 .30902 L
.52335 .30902 L
.52363 .30902 L
.52393 .15528 L
.52423 .15528 L
Mistroke
.5245 .15528 L
.52511 .15528 L
.52622 .15528 L
.52874 .15528 L
.53384 .15528 L
.54347 .15528 L
.55274 .15528 L
.5626 .15528 L
.57209 .15528 L
.58217 .15528 L
.59189 .15528 L
.60124 .15528 L
.61119 .15528 L
.62076 .15528 L
.62997 .15528 L
.63978 .15528 L
.64922 .15528 L
.65925 .15528 L
.66891 .15528 L
.67821 .15528 L
.6881 .15528 L
.69762 .15528 L
.70678 .15528 L
.71653 .15528 L
.72592 .15528 L
.73589 .15528 L
.7455 .15528 L
.75475 .15528 L
.76458 .15528 L
.77406 .15528 L
.78412 .15528 L
.79382 .15528 L
.80315 .15528 L
.81307 .15528 L
.82263 .15528 L
.83182 .15528 L
.8416 .15528 L
.85102 .15528 L
.85348 .15528 L
.85478 .15528 L
.85549 .15528 L
.85616 .15528 L
.85647 .15528 L
.8568 .15528 L
.85697 .15528 L
.85715 .30902 L
.85733 .30902 L
.85748 .30902 L
.85869 .30902 L
.86103 .30902 L
Mistroke
.87048 .30902 L
.88053 .30902 L
.8902 .30902 L
.89951 .30902 L
.90199 .30902 L
.90321 .30902 L
.90374 .30902 L
.90432 .30902 L
.90463 .30902 L
.90492 .15528 L
.90519 .15528 L
.90549 .15528 L
.90674 .15528 L
.90942 .15528 L
.91949 .15528 L
.9292 .15528 L
.93855 .15528 L
.94848 .15528 L
.95805 .15528 L
.96726 .15528 L
.97619 .15528 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.155277 0.15374 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00154 -12 -4.5 ]
[-0.0125 .00154 0 4.5 ]
[-0.0125 .15528 -6 -4.5 ]
[-0.0125 .15528 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46276 -6 -4.5 ]
[-0.0125 .46276 0 4.5 ]
[-0.0125 .6165 -6 -4.5 ]
[-0.0125 .6165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00154 m
.00625 .00154 L
s
[(-1)] -0.0125 .00154 1 0 Mshowa
0 .15528 m
.00625 .15528 L
s
[(0)] -0.0125 .15528 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .46276 m
.00625 .46276 L
s
[(2)] -0.0125 .46276 1 0 Mshowa
0 .6165 m
.00625 .6165 L
s
[(3)] -0.0125 .6165 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .06303 m
.00375 .06303 L
s
0 .09378 m
.00375 .09378 L
s
0 .12453 m
.00375 .12453 L
s
0 .18603 m
.00375 .18603 L
s
0 .21677 m
.00375 .21677 L
s
0 .24752 m
.00375 .24752 L
s
0 .27827 m
.00375 .27827 L
s
0 .33976 m
.00375 .33976 L
s
0 .37051 m
.00375 .37051 L
s
0 .40126 m
.00375 .40126 L
s
0 .43201 m
.00375 .43201 L
s
0 .4935 m
.00375 .4935 L
s
0 .52425 m
.00375 .52425 L
s
0 .555 m
.00375 .555 L
s
0 .58575 m
.00375 .58575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00154 m
1 .00154 L
s
.99375 .15528 m
1 .15528 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46276 m
1 .46276 L
s
.99375 .6165 m
1 .6165 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .06303 m
1 .06303 L
s
.99625 .09378 m
1 .09378 L
s
.99625 .12453 m
1 .12453 L
s
.99625 .18603 m
1 .18603 L
s
.99625 .21677 m
1 .21677 L
s
.99625 .24752 m
1 .24752 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .37051 m
1 .37051 L
s
.99625 .40126 m
1 .40126 L
s
.99625 .43201 m
1 .43201 L
s
.99625 .4935 m
1 .4935 L
s
.99625 .52425 m
1 .52425 L
s
.99625 .555 m
1 .555 L
s
.99625 .58575 m
1 .58575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .15528 m
1 .15528 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .30902 m
.03318 .30902 L
.03805 .30902 L
.04063 .30902 L
.04339 .30902 L
.04473 .30902 L
.04599 .30902 L
.04654 .30902 L
.04713 .30902 L
.04743 .30902 L
.0476 .30902 L
.04777 .15528 L
.04805 .15528 L
.04836 .15528 L
.05298 .15528 L
.06298 .15528 L
.0726 .15528 L
.08186 .15528 L
.08703 .15528 L
.09172 .15528 L
.09286 .15528 L
.09406 .15528 L
.09469 .15528 L
.09487 .15528 L
.09505 .15528 L
.09522 .15528 L
.09538 .30902 L
.09568 .30902 L
.09601 .30902 L
.0966 .30902 L
.1012 .30902 L
.11109 .30902 L
.12061 .30902 L
.12976 .30902 L
.13484 .30902 L
.13707 .30902 L
.13951 .30902 L
.14065 .30902 L
.14128 .30902 L
.14187 .30902 L
.14243 .30902 L
.14274 .30902 L
.14303 .15528 L
.14327 .15528 L
.14354 .15528 L
.14407 .15528 L
.14888 .15528 L
.15866 .15528 L
.16808 .15528 L
.17808 .15528 L
Mistroke
.18308 .15528 L
.18552 .15528 L
.18772 .15528 L
.18883 .15528 L
.18942 .15528 L
.18974 .15528 L
.19003 .15528 L
.1903 .15528 L
.19058 .30902 L
.19089 .30902 L
.19117 .30902 L
.19221 .30902 L
.19699 .30902 L
.20666 .30902 L
.21597 .30902 L
.22587 .30902 L
.23079 .30902 L
.2332 .30902 L
.2354 .30902 L
.23652 .30902 L
.23755 .30902 L
.23782 .30902 L
.23807 .30902 L
.23837 .15528 L
.23863 .15528 L
.23981 .15528 L
.24456 .15528 L
.2539 .15528 L
.26383 .15528 L
.2734 .15528 L
.27821 .15528 L
.2826 .15528 L
.28376 .15528 L
.28437 .15528 L
.28502 .15528 L
.28529 .15528 L
.28559 .15528 L
.28576 .30902 L
.28591 .30902 L
.28622 .30902 L
.28732 .30902 L
.29239 .30902 L
.30199 .30902 L
.31122 .30902 L
.32104 .30902 L
.32558 .30902 L
.3305 .30902 L
.33181 .30902 L
.33252 .30902 L
.33287 .30902 L
Mistroke
.33319 .30902 L
.33348 .15528 L
.33376 .15528 L
.33437 .15528 L
.33567 .15528 L
.34055 .15528 L
.34982 .15528 L
.35967 .15528 L
.36917 .15528 L
.37401 .15528 L
.37656 .15528 L
.37795 .15528 L
.37925 .15528 L
.37985 .15528 L
.38042 .15528 L
.38073 .15528 L
.38091 .15528 L
.38107 .30902 L
.38136 .30902 L
.38166 .30902 L
.38431 .30902 L
.38897 .30902 L
.39813 .30902 L
.40788 .30902 L
.41726 .30902 L
.42203 .30902 L
.42455 .30902 L
.42593 .30902 L
.42724 .30902 L
.42785 .30902 L
.42818 .30902 L
.42849 .30902 L
.42865 .15528 L
.42883 .15528 L
.4292 .15528 L
.42985 .15528 L
.43222 .15528 L
.43685 .15528 L
.44686 .15528 L
.4565 .15528 L
.46578 .15528 L
.47096 .15528 L
.47341 .15528 L
.47448 .15528 L
.47509 .15528 L
.47538 .15528 L
.47565 .15528 L
.47594 .15528 L
.4762 .30902 L
.47649 .30902 L
Mistroke
.4768 .30902 L
.47801 .30902 L
.48055 .30902 L
.48515 .30902 L
.49506 .30902 L
.5046 .30902 L
.51376 .30902 L
.51886 .30902 L
.52128 .30902 L
.52246 .30902 L
.52297 .30902 L
.52324 .30902 L
.52353 .30902 L
.52383 .15528 L
.5241 .15528 L
.52464 .15528 L
.52583 .15528 L
.52834 .15528 L
.53292 .15528 L
.54213 .15528 L
.55192 .15528 L
.56135 .15528 L
.56615 .15528 L
.56869 .15528 L
.57007 .15528 L
.57075 .15528 L
.57105 .15528 L
.57121 .15528 L
.57138 .15528 L
.57167 .30902 L
.57194 .30902 L
.57252 .30902 L
.57376 .30902 L
.57639 .30902 L
.58103 .30902 L
.59109 .30902 L
.60078 .30902 L
.6101 .30902 L
.61492 .30902 L
.61735 .30902 L
.61801 .30902 L
.61838 .30902 L
.61856 .30902 L
.61873 .30902 L
.61888 .30902 L
.61905 .15528 L
.61923 .15528 L
.6194 .15528 L
.62002 .15528 L
.62974 .15528 L
Mistroke
.6391 .15528 L
.64905 .15528 L
.654 .15528 L
.65863 .15528 L
.66308 .15528 L
.66436 .15528 L
.66557 .15528 L
.6661 .15528 L
.66639 .15528 L
.66666 .15528 L
.66695 .30902 L
.66711 .30902 L
.66728 .30902 L
.66784 .30902 L
.67783 .30902 L
.68744 .30902 L
.69669 .30902 L
.70185 .30902 L
.70653 .30902 L
.70887 .30902 L
.71141 .30902 L
.71257 .30902 L
.71321 .30902 L
.71352 .30902 L
.7138 .30902 L
.71406 .30902 L
.71431 .15528 L
.71457 .15528 L
.71485 .15528 L
.71601 .15528 L
.72588 .15528 L
.73539 .15528 L
.74453 .15528 L
.74961 .15528 L
.75427 .15528 L
.75883 .15528 L
.75994 .15528 L
.76112 .15528 L
.76147 .15528 L
.76165 .15528 L
.76181 .15528 L
.7621 .30902 L
.76226 .30902 L
.76243 .30902 L
.76364 .30902 L
.77281 .30902 L
.78258 .30902 L
.79198 .30902 L
.79676 .30902 L
.80198 .30902 L
Mistroke
.80439 .30902 L
.80697 .30902 L
.80822 .30902 L
.80884 .30902 L
.8091 .30902 L
.8094 .30902 L
.80967 .15528 L
.80992 .15528 L
.81046 .15528 L
.8116 .15528 L
.82104 .15528 L
.83107 .15528 L
.84073 .15528 L
.85002 .15528 L
.8525 .15528 L
.85482 .15528 L
.85598 .15528 L
.8563 .15528 L
.85664 .15528 L
.85693 .15528 L
.85724 .30902 L
.85742 .30902 L
.85759 .30902 L
.85791 .30902 L
.85862 .30902 L
.85991 .30902 L
.86924 .30902 L
.87916 .30902 L
.88871 .30902 L
.8979 .30902 L
.90032 .30902 L
.90262 .30902 L
.90388 .30902 L
.90423 .30902 L
.90442 .30902 L
.9046 .30902 L
.90477 .15528 L
.90495 .15528 L
.90526 .15528 L
.90768 .15528 L
.91764 .15528 L
.92722 .15528 L
.93644 .15528 L
.94158 .15528 L
.94626 .15528 L
.94858 .15528 L
.94981 .15528 L
.95111 .15528 L
.95166 .15528 L
.95196 .15528 L
Mistroke
.95225 .15528 L
.95241 .30902 L
.95258 .30902 L
.95289 .30902 L
.9535 .30902 L
.9557 .30902 L
.96555 .30902 L
.97503 .30902 L
.97619 .30902 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.155277 0.15374 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00154 -12 -4.5 ]
[-0.0125 .00154 0 4.5 ]
[-0.0125 .15528 -6 -4.5 ]
[-0.0125 .15528 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46276 -6 -4.5 ]
[-0.0125 .46276 0 4.5 ]
[-0.0125 .6165 -6 -4.5 ]
[-0.0125 .6165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00154 m
.00625 .00154 L
s
[(-1)] -0.0125 .00154 1 0 Mshowa
0 .15528 m
.00625 .15528 L
s
[(0)] -0.0125 .15528 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .46276 m
.00625 .46276 L
s
[(2)] -0.0125 .46276 1 0 Mshowa
0 .6165 m
.00625 .6165 L
s
[(3)] -0.0125 .6165 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .06303 m
.00375 .06303 L
s
0 .09378 m
.00375 .09378 L
s
0 .12453 m
.00375 .12453 L
s
0 .18603 m
.00375 .18603 L
s
0 .21677 m
.00375 .21677 L
s
0 .24752 m
.00375 .24752 L
s
0 .27827 m
.00375 .27827 L
s
0 .33976 m
.00375 .33976 L
s
0 .37051 m
.00375 .37051 L
s
0 .40126 m
.00375 .40126 L
s
0 .43201 m
.00375 .43201 L
s
0 .4935 m
.00375 .4935 L
s
0 .52425 m
.00375 .52425 L
s
0 .555 m
.00375 .555 L
s
0 .58575 m
.00375 .58575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00154 m
1 .00154 L
s
.99375 .15528 m
1 .15528 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46276 m
1 .46276 L
s
.99375 .6165 m
1 .6165 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .06303 m
1 .06303 L
s
.99625 .09378 m
1 .09378 L
s
.99625 .12453 m
1 .12453 L
s
.99625 .18603 m
1 .18603 L
s
.99625 .21677 m
1 .21677 L
s
.99625 .24752 m
1 .24752 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .37051 m
1 .37051 L
s
.99625 .40126 m
1 .40126 L
s
.99625 .43201 m
1 .43201 L
s
.99625 .4935 m
1 .4935 L
s
.99625 .52425 m
1 .52425 L
s
.99625 .555 m
1 .555 L
s
.99625 .58575 m
1 .58575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .15528 m
1 .15528 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .15528 m
.03318 .15528 L
.04339 .15528 L
.05298 .15528 L
.06221 .15528 L
.07203 .15528 L
.08148 .15528 L
.0863 .15528 L
.08884 .15528 L
.09153 .15528 L
.09268 .15528 L
.09392 .15528 L
.09429 .15528 L
.09464 .15528 L
.09495 .15528 L
.09512 .15528 L
.09529 .30902 L
.09545 .30902 L
.09561 .30902 L
.0959 .30902 L
.09656 .30902 L
.10121 .30902 L
.11056 .30902 L
.1205 .30902 L
.13007 .30902 L
.13488 .30902 L
.13927 .30902 L
.14044 .30902 L
.14105 .30902 L
.1417 .30902 L
.14227 .30902 L
.14243 .30902 L
.14259 .30902 L
.1429 .15528 L
.14318 .15528 L
.14347 .15528 L
.144 .15528 L
.14907 .15528 L
.15831 .15528 L
.16814 .15528 L
.17761 .15528 L
.18767 .15528 L
.19736 .15528 L
.20669 .15528 L
.21661 .15528 L
.22616 .15528 L
.23534 .15528 L
.24512 .15528 L
.25454 .15528 L
.26454 .15528 L
Mistroke
.27418 .15528 L
.27905 .15528 L
.28116 .15528 L
.28345 .15528 L
.28408 .15528 L
.28474 .15528 L
.2853 .15528 L
.28562 .15528 L
.28592 .30902 L
.28622 .30902 L
.2865 .30902 L
.28703 .30902 L
.28823 .30902 L
.29332 .30902 L
.30262 .30902 L
.31252 .30902 L
.32205 .30902 L
.32684 .30902 L
.32893 .30902 L
.33122 .30902 L
.33179 .30902 L
.33241 .30902 L
.3327 .30902 L
.33298 .30902 L
.33324 .30902 L
.33351 .15528 L
.3338 .15528 L
.33412 .15528 L
.33476 .15528 L
.33592 .15528 L
.34098 .15528 L
.35077 .15528 L
.36019 .15528 L
.37021 .15528 L
.37987 .15528 L
.38915 .15528 L
.39903 .15528 L
.40854 .15528 L
.41768 .15528 L
.42742 .15528 L
.43679 .15528 L
.44676 .15528 L
.45636 .15528 L
.46559 .15528 L
.47073 .15528 L
.47317 .15528 L
.47424 .15528 L
.47484 .15528 L
.47541 .15528 L
.47569 .15528 L
Mistroke
.47596 .15528 L
.47626 .30902 L
.47654 .30902 L
.47774 .30902 L
.48027 .30902 L
.48487 .30902 L
.49413 .30902 L
.50399 .30902 L
.51348 .30902 L
.51833 .30902 L
.52088 .30902 L
.52227 .30902 L
.52295 .30902 L
.52325 .30902 L
.5234 .30902 L
.52357 .30902 L
.52388 .15528 L
.52417 .15528 L
.52473 .15528 L
.52598 .15528 L
.52863 .15528 L
.53329 .15528 L
.54244 .15528 L
.55219 .15528 L
.56158 .15528 L
.57155 .15528 L
.58117 .15528 L
.59041 .15528 L
.60025 .15528 L
.60972 .15528 L
.61978 .15528 L
.62948 .15528 L
.63881 .15528 L
.64873 .15528 L
.65367 .15528 L
.65829 .15528 L
.66272 .15528 L
.664 .15528 L
.66521 .15528 L
.66574 .15528 L
.6663 .15528 L
.66646 .15528 L
.66662 .15528 L
.66691 .30902 L
.66718 .30902 L
.66748 .30902 L
.67744 .30902 L
.68703 .30902 L
.69625 .30902 L
.70139 .30902 L
Mistroke
.70607 .30902 L
.7084 .30902 L
.71093 .30902 L
.71208 .30902 L
.71272 .30902 L
.71331 .30902 L
.71382 .30902 L
.7141 .30902 L
.71436 .15528 L
.71465 .15528 L
.71495 .15528 L
.71552 .15528 L
.72537 .15528 L
.73485 .15528 L
.74493 .15528 L
.75464 .15528 L
.76398 .15528 L
.77392 .15528 L
.78349 .15528 L
.79269 .15528 L
.80249 .15528 L
.81192 .15528 L
.82194 .15528 L
.8316 .15528 L
.84089 .15528 L
.84558 .15528 L
.85077 .15528 L
.85313 .15528 L
.85437 .15528 L
.85568 .15528 L
.85623 .15528 L
.85654 .15528 L
.85683 .15528 L
.85699 .15528 L
.85717 .30902 L
.85748 .30902 L
.85808 .30902 L
.86029 .30902 L
.8702 .30902 L
.87975 .30902 L
.88893 .30902 L
.89404 .30902 L
.89871 .30902 L
.90102 .30902 L
.90224 .30902 L
.90291 .30902 L
.90354 .30902 L
.90414 .30902 L
.9043 .30902 L
.90447 .30902 L
Mistroke
.90478 .15528 L
.90506 .15528 L
.90532 .15528 L
.90591 .15528 L
.90812 .15528 L
.91756 .15528 L
.9276 .15528 L
.93727 .15528 L
.94657 .15528 L
.95647 .15528 L
.96599 .15528 L
.97516 .15528 L
.97619 .15528 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`008_ooool3o`0000Cooooo0_l0000Zooooo`?o0000
:oooool2o`0002kooooo0ol0000Zooooo`?o00001?ooool2o`0003Cooooo0ol00004ooooo`;o0000
:_ooool3o`0002_ooooo0_l0000]ooooo`?o0000:_ooool3o`0000Cooooo0_l0000Eooooo`008ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002Sooooo00Go0000oooooooooooo
ooooo`00000Yooooo`04o`000?ooooooooooo`0002cooooo00Go0000ooooooooooooooooo`00000Z
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=?ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0002Sooooo00Go0000ooooooooooooooooo`00000Yooooo`04
o`000?ooooooooooo`0002_ooooo00Go0000ooooooooooooooooo`00000Zooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00005?ooool001_ooooo1Ol00003ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00008_ooool5o`0000Gooooo00?o0000ooooooooool09ooo
ool01?l0003oooooooooool0000`ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000/ooooo`Go00000oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0002;ooooo1Ol00005ooooo`03o`000?oooooooooo02Oooooo00Co0000oooo
oooooooo0000;oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00005?ooool002?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
000/ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000<?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=?ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool09oooool01?l0
003oooooooooool0000_ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Dooooo`008oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0002Sooooo1?l0000Zooooo`04o`000?ooooooooooo`0002cooooo1?l0000[ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000=?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0002Sooooo1?l0000Zooooo`04o`000?ooooooooooo`0002_ooooo1?l0000[
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00005?ooool002;ooooo0_l00004
ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool0:oooool01?l0003ooooooooo
ool0000/ooooo`03o`000?oooooooooo02_ooooo0_l00004ooooo`04o`000?ooooooooooo`0003?o
oooo0_l00004ooooo`04o`000?ooooooooooo`0002Sooooo00?o0000ooooooooool0:oooool01?l0
003oooooooooool0000[ooooo`03o`000?oooooooooo02_ooooo0_l00004ooooo`04o`000?oooooo
ooooo`0001Cooooo000Sooooo`03o`000?oooooooooo00?ooooo0_l0000Yooooo`Go0000:_ooool2
o`0002gooooo1Ol0000Zooooo`03o`000?oooooooooo00?ooooo0_l0000eooooo`03o`000?oooooo
oooo00?ooooo0_l0000Yooooo`Go0000:_ooool2o`0002cooooo1Ol0000Zooooo`03o`000?oooooo
oooo00?ooooo0_l0000Eooooo`00oooooooiooooo`00oooooooiooooo`006?ooool3o`000?Oooooo
0ol0003Sooooo`006Oooool00ol0003oooooooooo`3gooooo`03o`000?oooooooooo0>;ooooo000A
ooooo`Go00000oooool00ol0003oooooooooo`03ooooolco00008?ooool5o`0000?ooooo00?o0000
ooooooooool01?ooooo;o`0001?ooooo000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Aooooo`006Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo017ooooo000Hooooo`;o00001Oooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool09Oooool2o`0000Kooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Iooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool2o`0006?o
oooo00?o0000ooooooooool0H_ooool2o`0002oooooo0_l0001Sooooo`03o`000?oooooooooo067o
oooo0_l0000Cooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`;o0000
Hoooool00ol0003oooooooooo`1Rooooo`;o0000;oooool2o`0006?ooooo00?o0000ooooooooool0
HOooool2o`0001?ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo0_l0
001Sooooo`03o`000?oooooooooo06;ooooo0_l0000_ooooo`;o0000Hoooool00ol0003ooooooooo
o`1Qooooo`;o00004oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool2
o`0006?ooooo00?o0000ooooooooool0H_ooool2o`0002oooooo0_l0001Sooooo`03o`000?oooooo
oooo067ooooo0_l0000Cooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`006Oooool2o`0000Cooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02Kooooo0_l0
0005ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0Aooooo`006?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo
000Hooooo`04o`000?ooooooooooo`0000?ooooo1Ol0000So`00o`So0000<_l00?l8o`0003;o003o
2?l0000So`00o`Go00009oooool01?l0003oooooooooool00004ooooo`Go00003ol00?l9o`0004Co
003o2Ol00014o`00o`Wo00003ol00?l5o`0001?ooooo000Hooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02go
oooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02go
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Tooooo`03o`000?oooooooooo02Go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
013ooooo00?o0000ooooooooool04Oooool001Sooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0;Oooool00ol0
0?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0;Oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo02Cooooo00?o0000ooooooooool09Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04?ooool0
0ol0003oooooooooo`0Aooooo`006?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo02Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool09?ooool00ol0003oooooooooo`0Uooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo043ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooo
oooooooo043ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`000?oo
oooooooo017ooooo000Iooooo`;o00001?ooool00ol0003oooooooooo`0Tooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo02Cooooo00?o0000ooooooooool09_ooool2o`0000Gooooo00?o0000ooooooooool04?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo
02Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool09?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
013ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003o
ooooooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0;Oooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0;Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo02Cooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0@ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0@?ooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0@?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001oooooo
0_l0000Uooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0;Oooool00ol00?oooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0;Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo02?ooooo0_l0000_ooooo`;o00004Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool01oooool00ol00?oooooo
ooooo`0?ooooo`;o00004oooool001oooooo00?o0000ooooooooool09?ooool00ol00?oooooooooo
o`06ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0Tooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol00?oooooooooo
o`07ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo02Cooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool09?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00Oooooo00?o003o
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`0Toooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo02Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000oooooooo
ool09?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02gooooo00?o003ooooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo02gooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0Tooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool04?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo043ooooo00?o003ooooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo043ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`00
0?oooooooooo02Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0]ooooo`03o`00
oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0]ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool09?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo013ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`10ooooo`03o`00
oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`10ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Aooooo`007ooo
ool2o`0002Gooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool08oooool2o`0002oooooo0_l0000Aooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07ooooo`03o`00oooo
oooooooo00oooooo0_l0000Cooooo`007oooool00ol0003oooooooooo`0Tooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo02Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooo
oooo013ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool09?ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0Tooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo02Co
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool09?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003ooooo
ooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0;_ooool01Ol00?oooooo
oooooooooooo000000Cooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo02Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0
9?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02kooooo00Go003ooooooooooooo
ooooo`000004ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Tooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`;o00009Oooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo02kooooo00Go003oooooooooooooooooo`000004ooooo`03
o`00oooooooooooo02gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Sooooo`;o
0000;oooool2o`00017ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`10ooooo`03
o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`10ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool2o`0001?ooooo000Oooooo`03o`00
0?oooooooooo02Cooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0^ooooo`05o`00
ooooooooooooooooool000001?ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool09?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013o
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003ooooo
ooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0;_ooool01Ol00?oooooo
oooooooooooo000000Cooooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo02Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0
9?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02kooooo00Go003ooooooooooooo
ooooo`000004ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Tooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo02Cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0^ooooo`05o`00ooooooooooooooooool0
00001?ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool09?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`0Tooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool0;_ooool01Ol00?oooooooooooooooooo000000Co
oooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Co
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool04Oooool001oooooo0_l0000Uooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool0;_ooool01Ol00?oooooooooooooooooo000000Cooooo00?o003ooooooooo
ool0;Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02?ooooo0_l0000_ooooo`;o
00004Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo043ooooo00?o003ooooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo043ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`0?ooooo`;o00004oooool001oooooo00?o0000ooooooooool0
9?ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo02kooooo00Go003ooooooooooooo
ooooo`000004ooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0Tooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo02Cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0^ooooo`05o`00ooooooooooooooooool0
00001?ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool09?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol00?ooooooooooo`10ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`0Tooooo`03o`00
oooooooooooo00Kooooo00?o003oooooooooool0;_ooool01Ol00?oooooooooooooooooo000000Co
oooo00?o003oooooooooool0;Oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo02Co
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool04Oooool001Sooooo0ol00004ooooo`03o`000?oooooooooo02Cooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0^ooooo`05o`00ooooooooooooooooool0
00001?ooool00ol00?ooooooooooo`0]ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool09?ooool00ol0003oooooooooo`0Uooooo`?o00001Oooool00ol0003oooooooooo`0@ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
;_ooool01Ol00?oooooooooooooooooo000000Cooooo00?o003oooooooooool0;Oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo02Cooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`10ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?oo
ooooooooo`10ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo
00?o003oooooooooool01_ooool2o`00oboooooo00Go003oooooooooooooooooo`000004ooooo`03
o`00oooooooooooo02gooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Tooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o003oooooooooool0@?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001Wooooo00?o0000ooooooooool0
0oooool2o`0002Gooooo2_l00?l`ooooo`[o003o;oooool;o`00obCooooo0ol0000Xooooo`03o`00
0?oooooooooo00Cooooo0_l0000Aooooo`_o003o@_ooool;o`00od;ooooo2ol00?lAooooo`;o0000
4oooool001Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`006?ooool2
o`0000Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo02Gooooo0_l00006ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`0Aooooo`006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool04Oooool001oooooo0_l0001Sooooo`03o`000?oooooooooo06;ooooo0_l0
000_ooooo`;o0000Hoooool00ol0003oooooooooo`1Qooooo`;o00004oooool001oooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Ooooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aoooo
o`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Aooooo`007oooool2o`0006?ooooo00?o0000ooooooooool0H_ooool2
o`0002oooooo0_l0001Sooooo`03o`000?oooooooooo067ooooo0_l0000Cooooo`007oooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oo
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017o
oooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1S
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo017ooooo000Oooooo`;o0000Hoooool00ol0003oooooooooo`1Roooo
o`;o0000;oooool2o`0006?ooooo00?o0000ooooooooool0HOooool2o`0001?ooooo000Oooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`00
7oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
4Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool04Oooool001oooooo0_l0001Sooooo`03o`000?oooooooooo06;o
oooo0_l0000_ooooo`;o0000Hoooool00ol0003oooooooooo`1Qooooo`;o00004oooool001oooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo
000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool04Oooool001Oooooo1Ol00003ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`0Tooooo`Go00001?ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001Sooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool09Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`006Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo017ooooo000Jooooo`03o`000?oooooooooo00;ooooo0_l0001Sooooo`03
o`000?oooooooooo067ooooo0ol0000Yooooo`03o`000?oooooooooo00?ooooo0_l0001Sooooo`03
o`000?oooooooooo067ooooo0_l0000Cooooo`005oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0Aooooo`005oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
02Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`006?ooool3o`0000Cooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02Gooooo0ol00005oooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aoooo
o`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo017ooooo000Oooooo`;o0000Hoooool00ol0003oooooooooo`1Rooooo`;o0000;ooo
ool2o`0006?ooooo00?o0000ooooooooool0HOooool2o`0001?ooooo000Oooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oo
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017o
oooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool04Oooool001oooooo0_l0001Sooooo`03o`000?oooooooooo06;ooooo0_l0000_
ooooo`;o0000Hoooool00ol0003oooooooooo`1Qooooo`;o00004oooool001oooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`00
7oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
4Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`0Aooooo`007oooool2o`0006?ooooo00?o0000ooooooooool0H_ooool2o`00
02oooooo0_l0001Sooooo`03o`000?oooooooooo067ooooo0_l0000Cooooo`007oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo
000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool2o`0006?ooooo00?o0000ooooooooool0
H_ooool2o`0002oooooo0_l0001Sooooo`03o`000?oooooooooo067ooooo0_l0000Cooooo`007ooo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Ooo
ool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo017ooooo000Hooooo`?o00001?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool09Oooool3o`0000Gooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Gooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool09?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Kooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`006Oooool2o`0000Coooooc?l0000Xoooo
o`;o00001Oooooo;o`0001?ooooo000Kooooo`03o`000?oooooooooo0?Oooooo00?o0000oooooooo
ool0h?ooool001Oooooo00Go0000ooooooooooooooooo`00003eooooo`05o`000?oooooooooooooo
ool00000h_ooool001Sooooo0ol0003gooooo`?o0000hoooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOoo
ool00?oooooonOooool00?oooooonOooool00?oooooonOooool002;ooooo0ol00004ooooo`;o0000
:_ooool3o`0002_ooooo0_l0000^ooooo`?o0000:_ooool3o`0000Cooooo0_l0000dooooo`?o0000
1?ooool2o`0002[ooooo0ol0000[ooooo`;o0000;Oooool3o`0002[ooooo0ol00004ooooo`;o0000
5Oooool002?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`05o`00
0?ooooooooooooooool00000:Oooool01?l0003oooooooooool0000/ooooo`05o`000?oooooooooo
ooooool00000:_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003Cooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000Xooooo`05o`000?ooooooooooooooool0
0000:Oooool01?l0003oooooooooool0000[ooooo`05o`000?ooooooooooooooool00000:_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Cooooo000Kooooo`Go00000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0002;ooooo1Ol00005ooooo`03o`000?oo
oooooooo02Oooooo00Co0000oooooooooooo0000<?ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo0000;?ooool5o`0000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Rooooo`Go00001Oooool00ol0003oooooooooo`0Woooo
o`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0001Cooooo000Sooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo0000;?ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`00033ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003Co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo
02Oooooo00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo00005?ooool002?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool0000Xooooo`Co0000:_ooool01?l0003oooooooooool0000/ooooo`Co0000
:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000Xooooo`Co0000:_ooool01?l0003oooooooooool0000[
ooooo`Co0000:oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0001Cooooo000R
ooooo`;o00001?ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo02_ooooo00Co
0000oooooooooooo0000;?ooool00ol0003oooooooooo`0[ooooo`;o00001?ooool01?l0003ooooo
ooooool0000cooooo`;o00001?ooool01?l0003oooooooooool0000Xooooo`03o`000?oooooooooo
02_ooooo00Co0000oooooooooooo0000:oooool00ol0003oooooooooo`0[ooooo`;o00001?ooool0
1?l0003oooooooooool0000Dooooo`008oooool00ol0003oooooooooo`03ooooo`;o0000:Oooool5
o`0002[ooooo0_l0000]ooooo`Go0000:_ooool00ol0003oooooooooo`03ooooo`;o0000=Oooool0
0ol0003oooooooooo`03ooooo`;o0000:Oooool5o`0002[ooooo0_l0000/ooooo`Go0000:_ooool0
0ol0003oooooooooo`03ooooo`;o00005Oooool00?oooooonOooool00?oooooonOooool001Sooooo
0ol0003gooooo`?o0000hoooool001Wooooo00?o0000ooooooooool0moooool00ol0003ooooooooo
o`3Rooooo`004Oooool5o`0000?ooooo00?o0000ooooooooool00oooooo<o`00023ooooo1Ol00003
ooooo`03o`000?oooooooooo00Cooooobol0000Cooooo`006Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool001Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`0Aooooo`006?ooool2o`0000Gooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02Gooooo0_l00006ooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`006Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool2o`00
06?ooooo00?o0000ooooooooool0H_ooool2o`0002oooooo0_l0001Sooooo`03o`000?oooooooooo
067ooooo0_l0000Cooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`00
7oooool2o`0006?ooooo00?o0000ooooooooool0H_ooool2o`0002oooooo0_l0001Sooooo`03o`00
0?oooooooooo067ooooo0_l0000Cooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo
000Oooooo`;o0000Hoooool00ol0003oooooooooo`1Rooooo`;o0000;oooool2o`0006?ooooo00?o
0000ooooooooool0HOooool2o`0001?ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007ooo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Ooo
ool001oooooo0_l0001Sooooo`03o`000?oooooooooo06;ooooo0_l0000_ooooo`;o0000Hoooool0
0ol0003oooooooooo`1Qooooo`;o00004oooool001oooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001Wooooo0_l0
0004ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003ooooooooo
o`0Vooooo`;o00001Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool04Oooool001Sooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool09Oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`0Aooooo`006?ooool01?l0003oooooooooool00003ooooo`[o00002ol00?l8o`0000_o003o
2?l0000;o`00o`Wo00002_l00?l9o`0000_o003o2?l0000;o`00o`So00002ol00?l9o`0000_o003o
2?l0000;o`00o`So00002ol00?l:o`0002Oooooo00Co0000oooooooooooo00001?ooool5o`0000oo
003o2Ol0000No`00o`So00007_l00?l9o`0001ko003o2?l0000No`00o`Wo00003ol00?l5o`0001?o
oooo000Hooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol0003o
ooooooooo`0Uooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001So
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo
02Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo01[ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo
oooo00Oooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Aooooo`006?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool09Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01ooo
ool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Iooooo`;o00001?ooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`000?oooooooooo02Kooooo0_l00005ooooo`03o`000?oooooo
oooo013ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooo
oooo01[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooo
oooo017ooooo000Oooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0@ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[o
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo013o
oooo00?o0000ooooooooool04Oooool001oooooo0_l00008ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`;o0000;oooool2o`00017ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo
00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o003oooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0?ooooo`;o00004oooool001oooooo00?o
0000ooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o
003oooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
003oooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o
003oooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000O
ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0J
ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0A
ooooo`007oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool04?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo013ooooo00?o0000oooo
ooooool04Oooool001oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo013ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Jooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo01[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03
o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
6_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool0
4?ooool00ol0003oooooooooo`0Aooooo`007oooool2o`0000Sooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo0_l0000_ooooo`;o00004Ooo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06_oo
ool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00oooooo0_l0000Cooooo`007oooool0
0ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool0
0ol00?ooooooooooo`07ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06_ooool0
0ol00?ooooooooooo`07ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool0
01oooooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
013ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo
017ooooo000Oooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00Go003oooooooooooooooooo`000004oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`007oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`07ooooo`05o`00ooooooooooooooooool000001?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`07ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001oo
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo000000Cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`;o
00002?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool01oooool01Ol00?oooooooooooooooooo000000Cooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool2o`00
02oooooo0_l0000Aooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03oooool2o`00
01?ooooo000Oooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00Go003oooooooooooooooooo`000004oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@oooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo00Oooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`007oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool01oooool00ol00?ooooooooooo`07ooooo`05o`00ooooooooooooooooool000001?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`07ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001oo
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo000000Cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Oooooo00Go003oooooooooooooooooo`000004ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`07ooooo`05o`00ooooooooooooooooool000001?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001oooooo0_l00008ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`05
o`00ooooooooooooooooool000001?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`;o0000;oooool2o`00
017ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo
00Kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0?ooooo`;o00004oooool001oo
oooo00?o0000ooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01oooool01Ol00?oooooooooooooooooo000000Cooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool01oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`000?oooooooooo017ooooo000Oooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Oooooo00Go003oooooooooooooooooo`000004ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo
01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool04?ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003o
ooooooooo`07ooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?oo
ooooooooo`07ooooo`05o`00ooooooooooooooooool000001?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`0Joooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`07oooo
o`03o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001Sooooo0ol00004ooooo`03
o`000?oooooooooo00Oooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`06ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00Oooooo00Go003oooooooooooooooooo`000004ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo
00Oooooo00?o0000ooooooooool09Oooool3o`0000Gooooo00?o0000ooooooooool04?ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo01[ooooo00?o003oooooooooool01_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`0Jooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool06_ooool00ol0
0?ooooooooooo`07ooooo`03o`00oooooooooooo013ooooo00?o0000ooooooooool04Oooool001Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo00Oo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Ko
oooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`05o`00oooooooooooooooo
ool000001?ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool01oooool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool06_ooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo01[ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0Jooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool04?ooool00ol0003oooooooooo`0Aooooo`006Oooool00ol0003oooooooooo`03ooooo`;o
00000oooool6o`00o`Wooooo2_l00?l9ooooo`_o003o2?ooool;o`00o`Sooooo2ol00?l9ooooo`[o
003o2Oooool;o`00o`Sooooo2ol00?l8ooooo`_o003o2Oooool:o`00o`Wooooo1_l00?l2ooooo`?o
0000:?ooool00ol0003oooooooooo`04ooooo`;o00004Oooool;o`00oacooooo2_l00?lLooooo`_o
003o7?ooool:o`00oacooooo2ol00?lAooooo`;o00004oooool001Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`0Aooooo`006Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo017ooooo000Hooooo`;o00001Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool09Oooool2o`0000Kooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Iooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool2o`0006?ooooo00?o
0000ooooooooool0H_ooool2o`0002oooooo0_l0001Sooooo`03o`000?oooooooooo067ooooo0_l0
000Cooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`;o0000Hoooool0
0ol0003oooooooooo`1Rooooo`;o0000;oooool2o`0006?ooooo00?o0000ooooooooool0HOooool2
o`0001?ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo0_l0001Soooo
o`03o`000?oooooooooo06;ooooo0_l0000_ooooo`;o0000Hoooool00ol0003oooooooooo`1Qoooo
o`;o00004oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool2o`0006?o
oooo00?o0000ooooooooool0H_ooool2o`0002oooooo0_l0001Sooooo`03o`000?oooooooooo067o
oooo0_l0000Cooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`005oooool5o`0000?ooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02Cooooo1Ol00004oooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0Aoooo
o`006?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Ioooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Soooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001[ooooo00?o0000oooooooo
ool00_ooool2o`0006?ooooo00?o0000ooooooooool0HOooool3o`0002Wooooo00?o0000oooooooo
ool00oooool2o`0006?ooooo00?o0000ooooooooool0HOooool2o`0001?ooooo000Gooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Gooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Hoooo
o`?o00001?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool09Oooool3o`0000Gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000oooooooo
ool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo0_l0001Sooooo`03o`000?oo
oooooooo06;ooooo0_l0000_ooooo`;o0000Hoooool00ol0003oooooooooo`1Qooooo`;o00004ooo
ool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0
003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;o
oooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o
0000ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool2o`0006?ooooo00?o0000
ooooooooool0H_ooool2o`0002oooooo0_l0001Sooooo`03o`000?oooooooooo067ooooo0_l0000C
ooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`;o0000Hoooool00ol0
003oooooooooo`1Rooooo`;o0000;oooool2o`0006?ooooo00?o0000ooooooooool0HOooool2o`00
01?ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool04Oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0Hoooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001oooooo0_l0001Sooooo`03
o`000?oooooooooo06;ooooo0_l0000_ooooo`;o0000Hoooool00ol0003oooooooooo`1Qooooo`;o
00004oooool001oooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`1Rooooo`03o`00
0?oooooooooo017ooooo000Oooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0H_oo
ool00ol0003oooooooooo`0Aooooo`007oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo06?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool04Oooool001Sooooo0ol00004ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Uooooo`?o00001Oooool00ol0
003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool001Oo
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06;ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`0Tooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1Rooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool04Oooool0
01_ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo000Ioooo
o`;o00001?ooooo<o`0002Sooooo0_l00005oooool_o00004oooool001_ooooo00?o0000oooooooo
ool0moooool00ol0003oooooooooo`3Pooooo`005oooool01Ol0003ooooooooooooooooo00000?Go
oooo00Go0000ooooooooooooooooo`00003Rooooo`006?ooool3o`000?Oooooo0ol0003Sooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-13.7915, \
-1.61983, 0.103805, 0.0321522}, {{262.875, 490.688}, {303, 162.25}} -> \
{-39.8043, -1.61983, 0.103805, 0.0321522}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-13.7915, -6.59939, 0.103805, 0.0321522}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-39.8043, -6.59939, 0.103805, 0.0321522}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{ga, gb}, {gc, gd}}], 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.117755 2.91338 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11775 -6 -4.5 ]
[-0.0125 .11775 0 4.5 ]
[-0.0125 .26342 -24 -4.5 ]
[-0.0125 .26342 0 4.5 ]
[-0.0125 .40909 -18 -4.5 ]
[-0.0125 .40909 0 4.5 ]
[-0.0125 .55476 -24 -4.5 ]
[-0.0125 .55476 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11775 m
.00625 .11775 L
s
[(0)] -0.0125 .11775 1 0 Mshowa
0 .26342 m
.00625 .26342 L
s
[(0.05)] -0.0125 .26342 1 0 Mshowa
0 .40909 m
.00625 .40909 L
s
[(0.1)] -0.0125 .40909 1 0 Mshowa
0 .55476 m
.00625 .55476 L
s
[(0.15)] -0.0125 .55476 1 0 Mshowa
.125 Mabswid
0 .14689 m
.00375 .14689 L
s
0 .17602 m
.00375 .17602 L
s
0 .20516 m
.00375 .20516 L
s
0 .23429 m
.00375 .23429 L
s
0 .29256 m
.00375 .29256 L
s
0 .32169 m
.00375 .32169 L
s
0 .35083 m
.00375 .35083 L
s
0 .37996 m
.00375 .37996 L
s
0 .43823 m
.00375 .43823 L
s
0 .46736 m
.00375 .46736 L
s
0 .49649 m
.00375 .49649 L
s
0 .52563 m
.00375 .52563 L
s
0 .08862 m
.00375 .08862 L
s
0 .05949 m
.00375 .05949 L
s
0 .03035 m
.00375 .03035 L
s
0 .00122 m
.00375 .00122 L
s
0 .5839 m
.00375 .5839 L
s
0 .61303 m
.00375 .61303 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11775 m
1 .11775 L
s
.99375 .26342 m
1 .26342 L
s
.99375 .40909 m
1 .40909 L
s
.99375 .55476 m
1 .55476 L
s
.125 Mabswid
.99625 .14689 m
1 .14689 L
s
.99625 .17602 m
1 .17602 L
s
.99625 .20516 m
1 .20516 L
s
.99625 .23429 m
1 .23429 L
s
.99625 .29256 m
1 .29256 L
s
.99625 .32169 m
1 .32169 L
s
.99625 .35083 m
1 .35083 L
s
.99625 .37996 m
1 .37996 L
s
.99625 .43823 m
1 .43823 L
s
.99625 .46736 m
1 .46736 L
s
.99625 .49649 m
1 .49649 L
s
.99625 .52563 m
1 .52563 L
s
.99625 .08862 m
1 .08862 L
s
.99625 .05949 m
1 .05949 L
s
.99625 .03035 m
1 .03035 L
s
.99625 .00122 m
1 .00122 L
s
.99625 .5839 m
1 .5839 L
s
.99625 .61303 m
1 .61303 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11775 m
1 .11775 L
s
1 0 0 r
.5 Mabswid
.02381 .11775 m
.02381 .11775 L
s
.04365 .11775 m
.04365 .09759 L
s
.06349 .11775 m
.06349 .08125 L
s
.08333 .11775 m
.08333 .0736 L
s
.10317 .11775 m
.10317 .0776 L
s
.12302 .11775 m
.12302 .09335 L
s
.14286 .11775 m
.14286 .11775 L
s
.1627 .11775 m
.1627 .14503 L
s
.18254 .11775 m
.18254 .16795 L
s
.20238 .11775 m
.20238 .17958 L
s
.22222 .11775 m
.22222 .17512 L
s
.24206 .11775 m
.24206 .15342 L
s
.2619 .11775 m
.2619 .11775 L
s
.28175 .11775 m
.28175 .0756 L
s
.30159 .11775 m
.30159 .03744 L
s
.32143 .11775 m
.32143 .01472 L
s
.34127 .11775 m
.34127 .01737 L
s
.36111 .11775 m
.36111 .05152 L
s
.38095 .11775 m
.38095 .11775 L
s
.40079 .11775 m
.40079 .21049 L
s
.42063 .11775 m
.42063 .31853 L
s
.44048 .11775 m
.44048 .42687 L
s
.46032 .11775 m
.46032 .51931 L
s
.48016 .11775 m
.48016 .58143 L
s
.5 .11775 m
.5 .60332 L
s
.51984 .11775 m
.51984 .58143 L
s
.53968 .11775 m
.53968 .51931 L
s
.55952 .11775 m
.55952 .42687 L
s
.57937 .11775 m
.57937 .31853 L
s
.59921 .11775 m
.59921 .21049 L
s
.61905 .11775 m
.61905 .11775 L
s
.63889 .11775 m
.63889 .05152 L
s
.65873 .11775 m
.65873 .01737 L
s
.67857 .11775 m
.67857 .01472 L
s
.69841 .11775 m
.69841 .03744 L
s
.71825 .11775 m
.71825 .0756 L
s
.7381 .11775 m
.7381 .11775 L
s
.75794 .11775 m
.75794 .15342 L
s
.77778 .11775 m
.77778 .17512 L
s
.79762 .11775 m
.79762 .17958 L
s
.81746 .11775 m
.81746 .16795 L
s
.8373 .11775 m
.8373 .14503 L
s
.85714 .11775 m
.85714 .11775 L
s
.87698 .11775 m
.87698 .09335 L
s
.89683 .11775 m
.89683 .0776 L
s
.91667 .11775 m
.91667 .0736 L
s
.93651 .11775 m
.93651 .08125 L
s
.95635 .11775 m
.95635 .09759 L
s
.97619 .11775 m
.97619 .11775 L
s
.015 w
.02381 .11775 Mdot
.04365 .09759 Mdot
.06349 .08125 Mdot
.08333 .0736 Mdot
.10317 .0776 Mdot
.12302 .09335 Mdot
.14286 .11775 Mdot
.1627 .14503 Mdot
.18254 .16795 Mdot
.20238 .17958 Mdot
.22222 .17512 Mdot
.24206 .15342 Mdot
.2619 .11775 Mdot
.28175 .0756 Mdot
.30159 .03744 Mdot
.32143 .01472 Mdot
.34127 .01737 Mdot
.36111 .05152 Mdot
.38095 .11775 Mdot
.40079 .21049 Mdot
.42063 .31853 Mdot
.44048 .42687 Mdot
.46032 .51931 Mdot
.48016 .58143 Mdot
.5 .60332 Mdot
.51984 .58143 Mdot
.53968 .51931 Mdot
.55952 .42687 Mdot
.57937 .31853 Mdot
.59921 .21049 Mdot
.61905 .11775 Mdot
.63889 .05152 Mdot
.65873 .01737 Mdot
.67857 .01472 Mdot
.69841 .03744 Mdot
.71825 .0756 Mdot
.7381 .11775 Mdot
.75794 .15342 Mdot
.77778 .17512 Mdot
.79762 .17958 Mdot
.81746 .16795 Mdot
.8373 .14503 Mdot
.85714 .11775 Mdot
.87698 .09335 Mdot
.89683 .0776 Mdot
.91667 .0736 Mdot
.93651 .08125 Mdot
.95635 .09759 Mdot
.97619 .11775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.118423 3.87917 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04084 -30 -4.5 ]
[-0.0125 .04084 0 4.5 ]
[-0.0125 .11842 -6 -4.5 ]
[-0.0125 .11842 0 4.5 ]
[-0.0125 .19601 -24 -4.5 ]
[-0.0125 .19601 0 4.5 ]
[-0.0125 .27359 -24 -4.5 ]
[-0.0125 .27359 0 4.5 ]
[-0.0125 .35117 -24 -4.5 ]
[-0.0125 .35117 0 4.5 ]
[-0.0125 .42876 -24 -4.5 ]
[-0.0125 .42876 0 4.5 ]
[-0.0125 .50634 -18 -4.5 ]
[-0.0125 .50634 0 4.5 ]
[-0.0125 .58392 -24 -4.5 ]
[-0.0125 .58392 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04084 m
.00625 .04084 L
s
[(-0.02)] -0.0125 .04084 1 0 Mshowa
0 .11842 m
.00625 .11842 L
s
[(0)] -0.0125 .11842 1 0 Mshowa
0 .19601 m
.00625 .19601 L
s
[(0.02)] -0.0125 .19601 1 0 Mshowa
0 .27359 m
.00625 .27359 L
s
[(0.04)] -0.0125 .27359 1 0 Mshowa
0 .35117 m
.00625 .35117 L
s
[(0.06)] -0.0125 .35117 1 0 Mshowa
0 .42876 m
.00625 .42876 L
s
[(0.08)] -0.0125 .42876 1 0 Mshowa
0 .50634 m
.00625 .50634 L
s
[(0.1)] -0.0125 .50634 1 0 Mshowa
0 .58392 m
.00625 .58392 L
s
[(0.12)] -0.0125 .58392 1 0 Mshowa
.125 Mabswid
0 .06024 m
.00375 .06024 L
s
0 .07963 m
.00375 .07963 L
s
0 .09903 m
.00375 .09903 L
s
0 .13782 m
.00375 .13782 L
s
0 .15721 m
.00375 .15721 L
s
0 .17661 m
.00375 .17661 L
s
0 .2154 m
.00375 .2154 L
s
0 .2348 m
.00375 .2348 L
s
0 .25419 m
.00375 .25419 L
s
0 .29299 m
.00375 .29299 L
s
0 .31238 m
.00375 .31238 L
s
0 .33178 m
.00375 .33178 L
s
0 .37057 m
.00375 .37057 L
s
0 .38996 m
.00375 .38996 L
s
0 .40936 m
.00375 .40936 L
s
0 .44815 m
.00375 .44815 L
s
0 .46755 m
.00375 .46755 L
s
0 .48694 m
.00375 .48694 L
s
0 .52574 m
.00375 .52574 L
s
0 .54513 m
.00375 .54513 L
s
0 .56453 m
.00375 .56453 L
s
0 .02144 m
.00375 .02144 L
s
0 .00205 m
.00375 .00205 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04084 m
1 .04084 L
s
.99375 .11842 m
1 .11842 L
s
.99375 .19601 m
1 .19601 L
s
.99375 .27359 m
1 .27359 L
s
.99375 .35117 m
1 .35117 L
s
.99375 .42876 m
1 .42876 L
s
.99375 .50634 m
1 .50634 L
s
.99375 .58392 m
1 .58392 L
s
.125 Mabswid
.99625 .06024 m
1 .06024 L
s
.99625 .07963 m
1 .07963 L
s
.99625 .09903 m
1 .09903 L
s
.99625 .13782 m
1 .13782 L
s
.99625 .15721 m
1 .15721 L
s
.99625 .17661 m
1 .17661 L
s
.99625 .2154 m
1 .2154 L
s
.99625 .2348 m
1 .2348 L
s
.99625 .25419 m
1 .25419 L
s
.99625 .29299 m
1 .29299 L
s
.99625 .31238 m
1 .31238 L
s
.99625 .33178 m
1 .33178 L
s
.99625 .37057 m
1 .37057 L
s
.99625 .38996 m
1 .38996 L
s
.99625 .40936 m
1 .40936 L
s
.99625 .44815 m
1 .44815 L
s
.99625 .46755 m
1 .46755 L
s
.99625 .48694 m
1 .48694 L
s
.99625 .52574 m
1 .52574 L
s
.99625 .54513 m
1 .54513 L
s
.99625 .56453 m
1 .56453 L
s
.99625 .02144 m
1 .02144 L
s
.99625 .00205 m
1 .00205 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11842 m
1 .11842 L
s
1 0 0 r
.5 Mabswid
.02381 .11842 m
.02381 .11842 L
s
.03869 .11842 m
.03869 .10318 L
s
.05357 .11842 m
.05357 .08932 L
s
.06845 .11842 m
.06845 .07909 L
s
.08333 .11842 m
.08333 .07432 L
s
.09821 .11842 m
.09821 .07617 L
s
.1131 .11842 m
.1131 .08484 L
s
.12798 .11842 m
.12798 .09952 L
s
.14286 .11842 m
.14286 .11842 L
s
.15774 .11842 m
.15774 .13897 L
s
.17262 .11842 m
.17262 .15811 L
s
.1875 .11842 m
.1875 .17275 L
s
.20238 .11842 m
.20238 .18016 L
s
.21726 .11842 m
.21726 .17846 L
s
.23214 .11842 m
.23214 .16693 L
s
.24702 .11842 m
.24702 .14622 L
s
.2619 .11842 m
.2619 .11842 L
s
.27679 .11842 m
.27679 .08692 L
s
.29167 .11842 m
.29167 .05606 L
s
.30655 .11842 m
.30655 .03067 L
s
.32143 .11842 m
.32143 .01552 L
s
.33631 .11842 m
.33631 .01472 L
s
.35119 .11842 m
.35119 .03111 L
s
.36607 .11842 m
.36607 .06592 L
s
.38095 .11842 m
.38095 .11842 L
s
.39583 .11842 m
.39583 .18593 L
s
.41071 .11842 m
.41071 .26394 L
s
.4256 .11842 m
.4256 .34658 L
s
.44048 .11842 m
.44048 .42712 L
s
.45536 .11842 m
.45536 .49868 L
s
.47024 .11842 m
.47024 .55498 L
s
.48512 .11842 m
.48512 .59095 L
s
.5 .11842 m
.5 .60332 L
s
.51488 .11842 m
.51488 .59095 L
s
.52976 .11842 m
.52976 .55498 L
s
.54464 .11842 m
.54464 .49868 L
s
.55952 .11842 m
.55952 .42712 L
s
.5744 .11842 m
.5744 .34658 L
s
.58929 .11842 m
.58929 .26394 L
s
.60417 .11842 m
.60417 .18593 L
s
.61905 .11842 m
.61905 .11842 L
s
.63393 .11842 m
.63393 .06592 L
s
.64881 .11842 m
.64881 .03111 L
s
.66369 .11842 m
.66369 .01472 L
s
.67857 .11842 m
.67857 .01552 L
s
.69345 .11842 m
.69345 .03067 L
s
.70833 .11842 m
.70833 .05606 L
s
.72321 .11842 m
.72321 .08692 L
s
.7381 .11842 m
.7381 .11842 L
s
.75298 .11842 m
.75298 .14622 L
s
.76786 .11842 m
.76786 .16693 L
s
.78274 .11842 m
.78274 .17846 L
s
.79762 .11842 m
.79762 .18016 L
s
.8125 .11842 m
.8125 .17275 L
s
.82738 .11842 m
.82738 .15811 L
s
.84226 .11842 m
.84226 .13897 L
s
.85714 .11842 m
.85714 .11842 L
s
.87202 .11842 m
.87202 .09952 L
s
.8869 .11842 m
.8869 .08484 L
s
.90179 .11842 m
.90179 .07617 L
s
.91667 .11842 m
.91667 .07432 L
s
.93155 .11842 m
.93155 .07909 L
s
.94643 .11842 m
.94643 .08932 L
s
.96131 .11842 m
.96131 .10318 L
s
.97619 .11842 m
.97619 .11842 L
s
.015 w
.02381 .11842 Mdot
.03869 .10318 Mdot
.05357 .08932 Mdot
.06845 .07909 Mdot
.08333 .07432 Mdot
.09821 .07617 Mdot
.1131 .08484 Mdot
.12798 .09952 Mdot
.14286 .11842 Mdot
.15774 .13897 Mdot
.17262 .15811 Mdot
.1875 .17275 Mdot
.20238 .18016 Mdot
.21726 .17846 Mdot
.23214 .16693 Mdot
.24702 .14622 Mdot
.2619 .11842 Mdot
.27679 .08692 Mdot
.29167 .05606 Mdot
.30655 .03067 Mdot
.32143 .01552 Mdot
.33631 .01472 Mdot
.35119 .03111 Mdot
.36607 .06592 Mdot
.38095 .11842 Mdot
.39583 .18593 Mdot
.41071 .26394 Mdot
.4256 .34658 Mdot
.44048 .42712 Mdot
.45536 .49868 Mdot
.47024 .55498 Mdot
.48512 .59095 Mdot
.5 .60332 Mdot
.51488 .59095 Mdot
.52976 .55498 Mdot
.54464 .49868 Mdot
.55952 .42712 Mdot
.5744 .34658 Mdot
.58929 .26394 Mdot
.60417 .18593 Mdot
.61905 .11842 Mdot
.63393 .06592 Mdot
.64881 .03111 Mdot
.66369 .01472 Mdot
.67857 .01552 Mdot
.69345 .03067 Mdot
.70833 .05606 Mdot
.72321 .08692 Mdot
.7381 .11842 Mdot
.75298 .14622 Mdot
.76786 .16693 Mdot
.78274 .17846 Mdot
.79762 .18016 Mdot
.8125 .17275 Mdot
.82738 .15811 Mdot
.84226 .13897 Mdot
.85714 .11842 Mdot
.87202 .09952 Mdot
.8869 .08484 Mdot
.90179 .07617 Mdot
.91667 .07432 Mdot
.93155 .07909 Mdot
.94643 .08932 Mdot
.96131 .10318 Mdot
.97619 .11842 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.117755 0.971128 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02064 -24 -4.5 ]
[-0.0125 .02064 0 4.5 ]
[-0.0125 .11775 -6 -4.5 ]
[-0.0125 .11775 0 4.5 ]
[-0.0125 .21487 -18 -4.5 ]
[-0.0125 .21487 0 4.5 ]
[-0.0125 .31198 -18 -4.5 ]
[-0.0125 .31198 0 4.5 ]
[-0.0125 .40909 -18 -4.5 ]
[-0.0125 .40909 0 4.5 ]
[-0.0125 .50621 -18 -4.5 ]
[-0.0125 .50621 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02064 m
.00625 .02064 L
s
[(-0.1)] -0.0125 .02064 1 0 Mshowa
0 .11775 m
.00625 .11775 L
s
[(0)] -0.0125 .11775 1 0 Mshowa
0 .21487 m
.00625 .21487 L
s
[(0.1)] -0.0125 .21487 1 0 Mshowa
0 .31198 m
.00625 .31198 L
s
[(0.2)] -0.0125 .31198 1 0 Mshowa
0 .40909 m
.00625 .40909 L
s
[(0.3)] -0.0125 .40909 1 0 Mshowa
0 .50621 m
.00625 .50621 L
s
[(0.4)] -0.0125 .50621 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.5)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04006 m
.00375 .04006 L
s
0 .05949 m
.00375 .05949 L
s
0 .07891 m
.00375 .07891 L
s
0 .09833 m
.00375 .09833 L
s
0 .13718 m
.00375 .13718 L
s
0 .1566 m
.00375 .1566 L
s
0 .17602 m
.00375 .17602 L
s
0 .19545 m
.00375 .19545 L
s
0 .23429 m
.00375 .23429 L
s
0 .25371 m
.00375 .25371 L
s
0 .27314 m
.00375 .27314 L
s
0 .29256 m
.00375 .29256 L
s
0 .3314 m
.00375 .3314 L
s
0 .35083 m
.00375 .35083 L
s
0 .37025 m
.00375 .37025 L
s
0 .38967 m
.00375 .38967 L
s
0 .42852 m
.00375 .42852 L
s
0 .44794 m
.00375 .44794 L
s
0 .46736 m
.00375 .46736 L
s
0 .48678 m
.00375 .48678 L
s
0 .52563 m
.00375 .52563 L
s
0 .54505 m
.00375 .54505 L
s
0 .56447 m
.00375 .56447 L
s
0 .5839 m
.00375 .5839 L
s
0 .00122 m
.00375 .00122 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02064 m
1 .02064 L
s
.99375 .11775 m
1 .11775 L
s
.99375 .21487 m
1 .21487 L
s
.99375 .31198 m
1 .31198 L
s
.99375 .40909 m
1 .40909 L
s
.99375 .50621 m
1 .50621 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04006 m
1 .04006 L
s
.99625 .05949 m
1 .05949 L
s
.99625 .07891 m
1 .07891 L
s
.99625 .09833 m
1 .09833 L
s
.99625 .13718 m
1 .13718 L
s
.99625 .1566 m
1 .1566 L
s
.99625 .17602 m
1 .17602 L
s
.99625 .19545 m
1 .19545 L
s
.99625 .23429 m
1 .23429 L
s
.99625 .25371 m
1 .25371 L
s
.99625 .27314 m
1 .27314 L
s
.99625 .29256 m
1 .29256 L
s
.99625 .3314 m
1 .3314 L
s
.99625 .35083 m
1 .35083 L
s
.99625 .37025 m
1 .37025 L
s
.99625 .38967 m
1 .38967 L
s
.99625 .42852 m
1 .42852 L
s
.99625 .44794 m
1 .44794 L
s
.99625 .46736 m
1 .46736 L
s
.99625 .48678 m
1 .48678 L
s
.99625 .52563 m
1 .52563 L
s
.99625 .54505 m
1 .54505 L
s
.99625 .56447 m
1 .56447 L
s
.99625 .5839 m
1 .5839 L
s
.99625 .00122 m
1 .00122 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11775 m
1 .11775 L
s
1 0 0 r
.5 Mabswid
.02381 .11775 m
.02381 .11775 L
s
.08333 .11775 m
.08333 .0736 L
s
.14286 .11775 m
.14286 .11775 L
s
.20238 .11775 m
.20238 .17958 L
s
.2619 .11775 m
.2619 .11775 L
s
.32143 .11775 m
.32143 .01472 L
s
.38095 .11775 m
.38095 .11775 L
s
.44048 .11775 m
.44048 .42687 L
s
.5 .11775 m
.5 .60332 L
s
.55952 .11775 m
.55952 .42687 L
s
.61905 .11775 m
.61905 .11775 L
s
.67857 .11775 m
.67857 .01472 L
s
.7381 .11775 m
.7381 .11775 L
s
.79762 .11775 m
.79762 .17958 L
s
.85714 .11775 m
.85714 .11775 L
s
.91667 .11775 m
.91667 .0736 L
s
.97619 .11775 m
.97619 .11775 L
s
.015 w
.02381 .11775 Mdot
.08333 .0736 Mdot
.14286 .11775 Mdot
.20238 .17958 Mdot
.2619 .11775 Mdot
.32143 .01472 Mdot
.38095 .11775 Mdot
.44048 .42687 Mdot
.5 .60332 Mdot
.55952 .42687 Mdot
.61905 .11775 Mdot
.67857 .01472 Mdot
.7381 .11775 Mdot
.79762 .17958 Mdot
.85714 .11775 Mdot
.91667 .0736 Mdot
.97619 .11775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.117755 1.94226 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02064 -30 -4.5 ]
[-0.0125 .02064 0 4.5 ]
[-0.0125 .11775 -6 -4.5 ]
[-0.0125 .11775 0 4.5 ]
[-0.0125 .21487 -24 -4.5 ]
[-0.0125 .21487 0 4.5 ]
[-0.0125 .31198 -18 -4.5 ]
[-0.0125 .31198 0 4.5 ]
[-0.0125 .40909 -24 -4.5 ]
[-0.0125 .40909 0 4.5 ]
[-0.0125 .50621 -18 -4.5 ]
[-0.0125 .50621 0 4.5 ]
[-0.0125 .60332 -24 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02064 m
.00625 .02064 L
s
[(-0.05)] -0.0125 .02064 1 0 Mshowa
0 .11775 m
.00625 .11775 L
s
[(0)] -0.0125 .11775 1 0 Mshowa
0 .21487 m
.00625 .21487 L
s
[(0.05)] -0.0125 .21487 1 0 Mshowa
0 .31198 m
.00625 .31198 L
s
[(0.1)] -0.0125 .31198 1 0 Mshowa
0 .40909 m
.00625 .40909 L
s
[(0.15)] -0.0125 .40909 1 0 Mshowa
0 .50621 m
.00625 .50621 L
s
[(0.2)] -0.0125 .50621 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.25)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04006 m
.00375 .04006 L
s
0 .05949 m
.00375 .05949 L
s
0 .07891 m
.00375 .07891 L
s
0 .09833 m
.00375 .09833 L
s
0 .13718 m
.00375 .13718 L
s
0 .1566 m
.00375 .1566 L
s
0 .17602 m
.00375 .17602 L
s
0 .19545 m
.00375 .19545 L
s
0 .23429 m
.00375 .23429 L
s
0 .25371 m
.00375 .25371 L
s
0 .27314 m
.00375 .27314 L
s
0 .29256 m
.00375 .29256 L
s
0 .3314 m
.00375 .3314 L
s
0 .35083 m
.00375 .35083 L
s
0 .37025 m
.00375 .37025 L
s
0 .38967 m
.00375 .38967 L
s
0 .42852 m
.00375 .42852 L
s
0 .44794 m
.00375 .44794 L
s
0 .46736 m
.00375 .46736 L
s
0 .48678 m
.00375 .48678 L
s
0 .52563 m
.00375 .52563 L
s
0 .54505 m
.00375 .54505 L
s
0 .56447 m
.00375 .56447 L
s
0 .5839 m
.00375 .5839 L
s
0 .00122 m
.00375 .00122 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02064 m
1 .02064 L
s
.99375 .11775 m
1 .11775 L
s
.99375 .21487 m
1 .21487 L
s
.99375 .31198 m
1 .31198 L
s
.99375 .40909 m
1 .40909 L
s
.99375 .50621 m
1 .50621 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04006 m
1 .04006 L
s
.99625 .05949 m
1 .05949 L
s
.99625 .07891 m
1 .07891 L
s
.99625 .09833 m
1 .09833 L
s
.99625 .13718 m
1 .13718 L
s
.99625 .1566 m
1 .1566 L
s
.99625 .17602 m
1 .17602 L
s
.99625 .19545 m
1 .19545 L
s
.99625 .23429 m
1 .23429 L
s
.99625 .25371 m
1 .25371 L
s
.99625 .27314 m
1 .27314 L
s
.99625 .29256 m
1 .29256 L
s
.99625 .3314 m
1 .3314 L
s
.99625 .35083 m
1 .35083 L
s
.99625 .37025 m
1 .37025 L
s
.99625 .38967 m
1 .38967 L
s
.99625 .42852 m
1 .42852 L
s
.99625 .44794 m
1 .44794 L
s
.99625 .46736 m
1 .46736 L
s
.99625 .48678 m
1 .48678 L
s
.99625 .52563 m
1 .52563 L
s
.99625 .54505 m
1 .54505 L
s
.99625 .56447 m
1 .56447 L
s
.99625 .5839 m
1 .5839 L
s
.99625 .00122 m
1 .00122 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11775 m
1 .11775 L
s
1 0 0 r
.5 Mabswid
.02381 .11775 m
.02381 .11775 L
s
.05357 .11775 m
.05357 .08861 L
s
.08333 .11775 m
.08333 .0736 L
s
.1131 .11775 m
.1131 .08413 L
s
.14286 .11775 m
.14286 .11775 L
s
.17262 .11775 m
.17262 .1575 L
s
.20238 .11775 m
.20238 .17958 L
s
.23214 .11775 m
.23214 .16633 L
s
.2619 .11775 m
.2619 .11775 L
s
.29167 .11775 m
.29167 .0553 L
s
.32143 .11775 m
.32143 .01472 L
s
.35119 .11775 m
.35119 .03032 L
s
.38095 .11775 m
.38095 .11775 L
s
.41071 .11775 m
.41071 .26348 L
s
.44048 .11775 m
.44048 .42687 L
s
.47024 .11775 m
.47024 .55492 L
s
.5 .11775 m
.5 .60332 L
s
.52976 .11775 m
.52976 .55492 L
s
.55952 .11775 m
.55952 .42687 L
s
.58929 .11775 m
.58929 .26348 L
s
.61905 .11775 m
.61905 .11775 L
s
.64881 .11775 m
.64881 .03032 L
s
.67857 .11775 m
.67857 .01472 L
s
.70833 .11775 m
.70833 .0553 L
s
.7381 .11775 m
.7381 .11775 L
s
.76786 .11775 m
.76786 .16633 L
s
.79762 .11775 m
.79762 .17958 L
s
.82738 .11775 m
.82738 .1575 L
s
.85714 .11775 m
.85714 .11775 L
s
.8869 .11775 m
.8869 .08413 L
s
.91667 .11775 m
.91667 .0736 L
s
.94643 .11775 m
.94643 .08861 L
s
.97619 .11775 m
.97619 .11775 L
s
.015 w
.02381 .11775 Mdot
.05357 .08861 Mdot
.08333 .0736 Mdot
.1131 .08413 Mdot
.14286 .11775 Mdot
.17262 .1575 Mdot
.20238 .17958 Mdot
.23214 .16633 Mdot
.2619 .11775 Mdot
.29167 .0553 Mdot
.32143 .01472 Mdot
.35119 .03032 Mdot
.38095 .11775 Mdot
.41071 .26348 Mdot
.44048 .42687 Mdot
.47024 .55492 Mdot
.5 .60332 Mdot
.52976 .55492 Mdot
.55952 .42687 Mdot
.58929 .26348 Mdot
.61905 .11775 Mdot
.64881 .03032 Mdot
.67857 .01472 Mdot
.70833 .0553 Mdot
.7381 .11775 Mdot
.76786 .16633 Mdot
.79762 .17958 Mdot
.82738 .1575 Mdot
.85714 .11775 Mdot
.8869 .08413 Mdot
.91667 .0736 Mdot
.94643 .08861 Mdot
.97619 .11775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00;Oooool3o`0002_ooooo1Ol0000Zooooo`;o0000;?ooool5o`0002gooooo0ol0003ooooo
o`cooooo000^ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo0000:Oooool01?l0
003oooooooooool0000/ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool0oooo
ool;ooooo`009Oooool5o`000003ooooool0003o000000?o00009Oooool5o`0000?ooooo00?o0000
ooooooooool0:Oooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02_ooooo1Ol0
0010ooooo`?o0000:_ooool5o`0002Sooooo0_l0000[ooooo`Go0000:oooool3o`00017ooooo000[
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool0:?ooool01?l0003ooooooooo
ool0000^ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo0000@_ooool00ol0003o
ooooooooo`0Zooooo`04o`000?ooooooooooo`0002Oooooo00Co0000oooooooooooo0000:oooool0
1?l0003oooooooooool0000/ooooo`03o`000?oooooooooo013ooooo000/ooooo`03o`000?oooooo
000002cooooo00Go0000ooooooooooooooooo`00000Yooooo`04o`000?ooooooooooo`0002_ooooo
00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oooooo000003Wooooo1Ol000000ooooooo
0000o`000003o`0002Cooooo1Ol00003ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooo
oooo0000;?ooool00ol0003oooooooooo`0Yooooo`Go00004Oooool002gooooo0_l0000/ooooo`05
o`000?ooooooooooooooool00000:Oooool01?l0003oooooooooool0000[ooooo`05o`000?oooooo
ooooooooool00000;Oooool2o`0003oooooo00Co0000oooooooooooo0000;_ooool00ol0003ooooo
ooooo`0Vooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0:?ooool01?l0003o
ooooooooool0000Booooo`00;_ooool00ol0003oooooooooo`0[ooooo`?o0000:oooool2o`0002go
oooo0ol0000_ooooo`03o`000?oooooooooo03kooooo00?o0000ooooool00000:oooool01Ol0003o
oooooooooooooooo000002Oooooo00Co0000oooooooooooo0000:_ooool01Ol0003ooooooooooooo
oooo000002[ooooo00?o0000ooooool000004_ooool00?oooooo;_ooool2o`0002_ooooo00Go0000
ooooooooooooooooo`00000Wooooo`04o`000?ooooooooooo`0002[ooooo00Go0000oooooooooooo
ooooo`00000[ooooo`;o00004_ooool00?oooooo;oooool00ol0003oooooooooo`0Zooooo`?o0000
:Oooool2o`0002cooooo0ol0000]ooooo`03o`000?oooooooooo013ooooo003oooooooWooooo000V
oooool[o0000ooooool9ooooo`009_ooool2o`0000?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo00000?oooooo2Oooool002Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00Sooooo0ooo000Rooooo`03o`000?oooooooooo
023ooooo0ooo000:ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000g
ooooolCo00003Oooool002Kooooo00?o0000ooooooooool0?Oooool3ool00004oooooooo003oo`00
ool003gooooo0ooo00001?ooooooo`00ool00?oo000nooooo`03o`000?oooooooooo03Gooooo0_l0
0002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooooooo0_l0000=ooooo`009_oo
ool00ol0003oooooooooo`0mooooo`?oo`0000Coooooool00?oo003oo`00?Oooool3ool00004oooo
oooo003oo`00ool003kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`30ooooo`03
o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool0
0ooo000mooooo`?oo`000_ooool00ooo003oooooooooo`0mooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0>oooool2ool00003oooooooo003oo`0003gooooo0_oo00000oooooooo`00
ool0000nooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo03kooooo00Go
o`00ooooooooooooooooool0000oooooo`05ool00?oooooooooooooooooo0000?oooool00ol0003o
ooooooooo`0eooooo`;o0000??ooool2ool00003oooooooo003oo`0003gooooo0_oo00000ooooooo
o`00ool0000mooooo`;o00003Oooool002Kooooo0_l0000jooooo`?oo`000_ooool01Ooo003ooooo
ooooooooooooo`0003oooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`00>_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo0000?oooool01?oo
003ooooooooooooo000nooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo
03Wooooo0ooo0002ooooo`05ool00?oooooooooooooooooo0000?oooool01Ooo003ooooooooooooo
ooooo`0000;ooooo0ooo000jooooo`03o`000?oooooooooo01cooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo0_l00002ooooo`Go00001?ooool00ol0003oooooooooo`0hooooo`;oo`000_oo
ool01?oo003oooooool00?ooool2ool003Wooooo0_oo00001_ooooooo`00ooooooooooooo`00oooo
o`;oo`00>oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0iooooo`?o
o`000_ooool01Ooo003oooooooooooooooooo`0003oooooo00Goo`00ooooooooooooooooool00002
ooooo`?oo`00>_ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03So
oooo0_oo0002ooooo`04ool00?ooooooo`00ooooo`;oo`00>Oooool2ool00006oooooooo003ooooo
oooooooo003ooooo0_oo000kooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo03[ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`00=Ooo
ool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo03Wooooo
00?o0000ooooooooool05?ooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Cooooo0_l0000jooooo`06ool00?oooooooooo
ool00?ooooooo`000_ooool00ooo003oooooooooo`0gooooo`04ool00?ooooooooooool000;ooooo
00Coo`00ooooooooooooo`00>_ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo03[ooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`00=Oooool3ool000;o
oooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo03Wooooo00?o0000oooo
ooooool06oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0iooooo`06ool00?ooooooooooool00?oooooo
o`000_ooool00ooo003oooooooooo`0gooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`00>oooool00ol0003oooooooooo`0;ooooo`009_ooool2o`0003_ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`00=Oooool3ool000;ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo03Wooooo00?o0000ooooooooool06ooo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo00Koo`00ooooooooooooo`00oooooooo
0002ooooo`03ool00?oooooooooo03Oooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo000kooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo03[ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000=oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0000kooooo`03o`000?oo
oooooooo01_ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eooooo`;oo`000_ooool01_oo
003ooooooooooooo003oooooool000;ooooo00?oo`00ooooooooool0=oooool01?oo003ooooooooo
oooo0002ooooo`05ool00?ooooooooooool00?ooool00_oo000hooooo`03o`000?oooooooooo00_o
oooo000Vooooo`03o`000?oooooooooo00gooooo0ooo000Zooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0003Oooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo0000:_ooool3ool000kooooo00?o0000ooooooooool07?oo
ool2o`0000[ooooo0_l00003ooooo`?o00001Oooool2o`0003Kooooo0_oo0002ooooo`06ool00?oo
ooooooooool00?ooooooo`000_ooool00ooo003oooooooooo`0gooooo`04ool00?ooooooooooool0
00;ooooo00Goo`00ooooooooooooo`00ooooo`02ool003Oooooo0_l0000=ooooo`009_ooool00ol0
003oooooooooo`0=ooooo`?oo`0000Coooooool00?oo003oo`008Oooool3ool000;ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000=oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`008Oooool3ool0
0004oooooooo003oo`00ool000kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0f
ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo003oooooool0
0?oo000cooooo`;oo`0000Goooooool00?ooooooooooool00002ooooo`04ool00?ooooooooooool0
00;ooooo00?oo`00ooooooooool0=_ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003o
ooooooooo`09ooooo`?oo`0000Goooooool00?oo003oo`00ooooo`03ool0027ooooo0ooo0002oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0003Oooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool3ool0027o
oooo0ooo00001Oooooooo`00ool00?oo003ooooo00?oo`002_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo03Kooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00002
ooooo`04ool00?ooooooo`00ool003?ooooo0_oo00001Oooooooo`00ooooooooooooo`0000;ooooo
00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`0fooooo`03o`000?oooooooooo00_o
oooo000Vooooo`03o`000?oooooooooo00Wooooo0ooo0002ooooo`03ool00?oooooooooo00?oo`00
8Oooool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo0000=oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0002ooooo`?oo`008Oooool3ool000;ooooo00?oo`00ooooooooool00ooo000:ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool03?ooool2ool00003oooooooo003oo`0002Gooooo00Co
o`00ooooooooooooo`000_ooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool003Co
oooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool002Cooooo0_oo00000oooooooo`00ool0000?ooooo`03o`000?oooooooooo00_ooooo000Voooo
o`;o00002_ooool3ool000;ooooo00Goo`00ooooooooooooooooool00002ooooo`?oo`007_ooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo03Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`0Looooo`?oo`000_ooool01Ooo003ooooooooooooooooo
o`0000;ooooo0ooo000:ooooo`03o`000?oooooooooo03Gooooo0_l0000:ooooo`;oo`0000Cooooo
ool00?oo003ooooo0_oo000Uooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo0000
0_ooool01?oo003ooooooooooooo000dooooo`03ool00?ooooooo`0000;ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo000Tooooo`;oo`0000Coooooool00?oo003ooooo0_oo
000;ooooo`;o00003Oooool002Kooooo00?o0000ooooooooool01Oooool3ool000;ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`007_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo03Go
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
0ooo003oooooooooo`0Looooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool00ooo0006ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Ooo
ool2ool000;ooooo00Goo`00ooooooooooooo`00ooooo`02ool001kooooo0_oo0002ooooo`04ool0
0?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo000doooo
o`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooo
003ooooo00;oo`007_ooool2ool000;ooooo00Goo`00ooooooooooooo`00ooooo`02ool000cooooo
00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool01Oooool3ool000;ooooo00Go
o`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`007_ooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
03Gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`0Looooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool00ooo0006ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
1_ooool2ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003oooooool00?oo000Noooo
o`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00
ooooooooooooo`00=?ooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooo`00ooooo`02ool001kooooo0_oo0002ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00oooooooo003oo`002Oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0
003oooooooooo`05ooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool0000Oooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00?oo`00ooooooooool0=Oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo01gooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool3ool000Kooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`;oo`000_ooool01?oo003ooooo
oooooooo0002ooooo`04ool00?ooooooooooool001oooooo00Coo`00ooooooooooooo`000_ooool0
1_oo003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`00=?ooool00ooo003o
ooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
0ooo003oooooooooo`0Mooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooo`00
ooooo`02ool000Wooooo00?o0000ooooooooool02oooool0023ooooo0_l00004ooooo`03o`000?oo
oooooooo00Kooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`0Mooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0=Oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo01gooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`;oo`000_ooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo003oo`00
7?ooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool0
1?oo003ooooooooooooo000dooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo01Wooooo0_oo0002ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003oooooool00?oo
0005ooooo`;o00003Oooool001oooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ooooool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`03ool001Gooooo0ooo0002ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool00ooo
000]ooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo00?oo`005Oooool3ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`03
ool000;ooooo00?o0000ooooooooool0;_ooool2o`0000Gooooo00?o0000ooooooooool00oooool2
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooo`00ool001cooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003o
ooooool000;ooooo00Coo`00ooooooooooooo`00=?ooool00ooo003oooooool00002ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`0Ioooo
o`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00oooooooo003oo`001_ooool00ol0003oooooooooo`0;ooooo`007oooool01?l0003ooooooooo
ool00003ooooo`Co00000ooo0002o`000005ool00?l0003o0000o`000?oo00000ol000001Ooo003o
0000o`000?l0003oo`0000?o000000?oo`00o`000?l000000ooo0002o`000005ool00?l0003o0000
o`000?oo00000ol000001Ooo003o0000o`000?l0003oo`0000?o000000?oo`00o`000?l000000ooo
0002o`000005ool00?l0003o0000o`000?oo00000ol000001Ooo003o0000o`000?l0003oo`0000?o
000000?oo`00o`000?l000000ooo0002o`000005ool00?l0003o0000o`000?oo00000ol000001Ooo
003o0000o`000?l0003oo`0000?o000000Goo`00o`000?l0003o0000ool00003o`000005ool00?l0
003o0000o`000?oo00000ol000001Ooo003o0000o`000?l0003oo`0000?o000000?oo`00o`000?l0
00000ooo0002o`000005ool00?l0003o0000o`000?oo00000ol000001Ooo003o0000o`000?l0003o
o`0000?o000000?oo`00o`000?l000000ooo0002o`000005ool00?l0003o0000o`000?oo00000ol0
00001Ooo003o0000o`000?l0003oo`0000?o000000?oo`00o`000?l000000ooo0002o`000005ool0
0?l0003o0000o`000?oo00000ol000001Ooo003o0000o`000?l0003oo`0000?o000000?oo`00o`00
0?l000000ooo0003o`0002oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo0002ooooo`03ool00?oooooooooo01[ooooo00Coo`00ooooooooooooo`000_ooool01_oo
003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`00=?ooool00ooo003ooooo
ool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooooooo`0Jooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0
2oooool001oooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooooooool3ool001Go
oooo0ooo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool00ooo000Eooooo`?oo`000_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00?oo`005Oooool3ool000;ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`03ool001Gooooo
0ooo0002ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00001?ooool4o`0000;o
o`0000Go0000ool00?l0003o0000ool00002o`000004ool00?l0003o0000ool000;o000000Coo`00
o`000?l0003oo`000_l000001?oo003o0000ool00?oo0002o`000006ool00?l0003o0000ool00?l0
003oo`000_l000001?oo003o0000o`000?oo0002o`000005ool00?l0003o0000ool00?l000000_oo
0002o`000004ool00?l0003o0000ool000;o000000Koo`00o`000?l0003oo`00o`000?oo0002o`00
0005ool00?l0003o0000ool00?l000000_oo0002o`000004ool00?l0003o0000ool000;o000000Co
o`00o`000?l0003oo`000_l000001?oo003o0000o`000?oo0002o`000003ool00?l0003oo`0000;o
000000Coo`00o`000?l0003oo`000_l000001?oo003o0000o`000?oo0002o`000004ool00?l0003o
0000ool000;o000000Coo`00o`000?oo003oo`000_l000000ooo003o0000ool00002o`000004ool0
0?l0003o0000ool000;o000000Coo`00o`000?l0003oo`000_l000001?oo003o0000ool00?oo0002
o`000004ool00?l0003o0000ool000;o000000Koo`00o`000?l0003oo`00o`000?oo0002o`000005
ool00?l0003o0000ool00?l000000_oo0002o`000004ool00?l0003o0000ool000;o000000Coo`00
o`000?l0003oo`000_l000001?oo003o0000o`000?oo0002o`0000Coo`001?l0000=ooooo`007ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo01kooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Moooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool07Oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo01gooooo00?o
0000ooooooooool0;Oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooooooo`;o
o`005Oooool2ool000;ooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00Goo`00ooooooooooooo`00ooooo`02ool001Gooooo0_oo0002ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002
ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo003oo`005Oooool2ool0
00;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooool000;ooooo
00Goo`00ooooooooooooo`00ooooo`02ool001Gooooo0_oo0004ooooo`03o`000?oooooooooo00_o
oooo000Oooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool07_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo01gooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Mooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
7Oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool07?ooool01_oo003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo000Looooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00
ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00?oo`00ooooooooool06_ooool01?oo003ooooooooooooo0002ooooo`06ool00?oooooooooo
ool00?ooooooo`000_ooool01?oo003ooooooooooooo000Nooooo`03o`000?oooooooooo00_ooooo
000Pooooo`;o00001?ooool00ol0003oooooooooo`0Nooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool07Oooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`03ool00?oooooooooo01gooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Mooooo`03o`000?oooooo
oooo02gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Looooo`06ool00?oo
ooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool001cooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooooooo
o`0Jooooo`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00oooooooo0002oooo
o`04ool00?ooooooooooool001kooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooo
ooooool07Oooool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00007oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo01gooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000_ooool3ool001ko
oooo00?o0000ooooooooool0;_ooool2o`0000Gooooo0_l0000Looooo`;oo`000_ooool00ooo003o
ooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`007?ooool0
1?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo01[ooooo00Co
o`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooool000;ooooo00Coo`00oooo
oooo003oo`007Oooool2o`0000gooooo000Vooooo`;o00007_ooool3ool000;ooooo00Goo`00oooo
ooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`007_ooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo01cooooo0ooo0002ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`03ool001kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Kooooo`;oo`000_ooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo
00Coo`00ooooooooooooo`007?ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00002ooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`03ool00?oooooooooo01[ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo
003oooooool000;ooooo00Coo`00oooooooo003oo`007_ooool00ol0003oooooooooo`0;ooooo`00
9_ooool00ol0003oooooooooo`0Mooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0000?o
oooo00?oo`00ooooooooool00ooo000Nooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool07?ooool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00?oo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01oooooo00?oo`00oooo
oooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooo`00ool001cooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`0Iooooo`;oo`00
0_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo
ool07oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Rooooo`05ool0
0?oooooooooooooooooo00000oooool00ooo003oooooooooo`03ool001kooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`0Looooo`?oo`000_ooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool08Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
01oooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
o`00ool001cooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ooooo`0Iooooo`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;o
oooo00?oo`00ooooooooool07oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003ooooo
ooooo`0Qooooo`?oo`000_ooool01Ooo003oooooooooooooooooo`0002?ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo
00000oooool00ooo003oooooooooo`0Qooooo`05ool00?oooooooooooooooooo00000_ooool3ool0
02;ooooo00?o0000ooooooooool0=Oooool2o`0001oooooo0_oo00001Oooooooo`00oooooooooooo
o`0000;ooooo00Coo`00ooooooooooooo`007oooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0002ooooo`03ool00?oooooooooo01gooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
ooooool00?ooool2ool0023ooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`0Qooooo`?o
o`000_ooool01Ooo003oooooooooooooooooo`0002?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`0Qooooo`05ool00?oooooooooooooooooo00000_ooool3ool002;ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Nooooo`;oo`0000Goooooool00?ooooooooooool0
0002ooooo`04ool00?ooooooooooool001oooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool0
1?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`0Mooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
oooo003ooooo0_oo000Qooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo
027ooooo0ooo0002ooooo`03ool00?oooooooooo00?oo`008_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003oooo
o`03ool00?oooooooooo023ooooo0ooo0002ooooo`03ool00?oooooooooo00?oo`008_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo027ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003oooooool00?oo000Oooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00?oo`00ooooooooool07?ooool2ool000;ooooo00Koo`00ooooooooooooo`00oooooooo000Toooo
o`03o`000?oooooooooo00_ooooo000Vooooo`;o00009_ooool3ool00004oooooooo003oo`00ool0
02;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`0Pooooo`?oo`0000Coooooool0
0?oo003oo`009_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo023ooooo0_oo0002
ooooo`05ool00?ooooooooooool00?ooool00_oo000Oooooo`04ool00?ooooooooooool000;ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`00
00;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00?oo`00ooooooooool07?ooool2ool000;ooooo00Goo`00oooooooooooo
o`00ooooo`02ool002?ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0
9Oooool3ool00004oooooooo003oo`00ool002;ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`0Pooooo`?oo`0000Coooooool00?oo003oo`009_ooool00ol0003oooooooooo`0eoooo
o`;o00008Oooool2ool00004oooooooo003oo`00ooooo`;oo`008_ooool01?oo003ooooooooooooo
0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003o
ooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo01oooooo0_oo00001?ooooooo`00ool0
0?ooool2ool002;ooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`0Uooooo`?oo`009_oo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`03ool00?oooooooooo02Cooooo0ooo000Vooooo`03o`000?oo
oooooooo01cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00001?oo
ool00ol0003oooooooooo`0Sooooo`;oo`0000?oooooool00?oo00008Oooool2ool000;ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool0
0?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00Goo`00ooooooooooooo`00ooooo`02ool0027ooooo0_oo00000oooooooo`00ool0000Vooooo`03
o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo04kooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0BOooool2ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool000;ooooo00Goo`00ooooooooooooo`00ooooo`02ool004cooooo
00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0C_ooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool06oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1=ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1_oo003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool004oooooo00?o0000ooooooooool02oooool0
02Kooooo00?o0000ooooooooool0C_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooo
ooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
04gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00oooool2o`0004kooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`00C_ooool2o`0000gooooo000Vooooo`;o0000C_ooool3ool000;ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`00C_oo
ool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00
oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo001?ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo04gooooo0ooo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`03ool004kooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04gooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00Coooool00ol0
003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1=ooooo`?oo`000_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
0ooo001>ooooo`03o`000?oooooooooo01cooooo0_l0000:ooooo`;o00000oooool3o`0000Gooooo
0_l0001>ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo
003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo0002ooooo`04ool00?ooooooooooool004kooooo0_l0000=ooooo`009_ooool00ol0003o
ooooooooo`1Booooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
COooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00oooo
ooooooooo`00oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool01?oo003ooooooooooooo001?ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03
o`000?oooooooooo05;ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo057ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`1=ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo
003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo0002ooooo`04ool00?ooooooooooool004oooooo00?o0000ooooooooool02oooool002Ko
oooo00?o0000ooooooooool0D_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00?oo`00ooooooooool0DOooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo04gooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00Coooool00ol0003oooooooooo`0;oooo
o`009_ooool2o`0005?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooo
oooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo057ooooo00?o0000ooooooooool0=Oooool2o`0004kooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool00?oooooooooo
ool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`00C_ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo05;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo057ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1=ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003o
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool004oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooooooo
ool0D_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool0DOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo04gooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool00?oooooooooo
ool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`00Coooool00ol0003oooooooooo`0;ooooo`003_ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00004ooooo`03o`000?oooooooooo05;o
oooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo057ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1=ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003o
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool004oooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooo
oooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000oooooooooooooooo
o`00001Dooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo03Gooooo0_l0001>ooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003ooooo
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool004kooooo0_l0000=ooooo`003Oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooooooo0ol0001Booooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1@oooo
o`;o00007_ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0ol00004oooo
o`03o`000?oooooooooo04gooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo
0002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00Coooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00Go0000ooooooooooooooooo`00001Dooooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0C?ooool2ool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooo`00ool004oooooo00?o0000oooo
ooooool02oooool000gooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003o
oooo00Co00001?ooool00ol0003oooooooooo`1Booooo`05ool00?oooooooooooooooooo00000ooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Go00001?oo
ool00ol0003oooooooooo`1<ooooo`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo003oo`00Coooool00ol0003ooooooooo
o`0;ooooo`003Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00001oooool00ol0003oooooooooo`1Booooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000
ooooooooool00oooool2o`00057ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`03ool00?oooooooooo04oooooo0_l0000=ooooo`003_ooool2o`0000[o
oooo0_l00002ooooo`Go00000oooool00ol0003oooooooooo`1Booooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Aooooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool0D?ooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0D?ooool00ol0003o
ooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Booooo`05ool00?oooooooooooooooooo
00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Aooooo`03o`000?oo
oooooooo01_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`;o
00001Oooool00ol0003oooooooooo`1@ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00ooooooooooooo`000_ooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo00_ooooo
000Vooooo`;o0000Doooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool0DOooool00ol0003oooooooooo`0Looooo`;o00002_ooool2
o`0000Gooooo00?o0000ooooooooool00oooool2o`00057ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00oooooooooooo
o`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo04oooooo0_l0000=oooo
o`009_ooool00ol0003oooooooooo`1Booooo`05ool00?oooooooooooooooooo00000oooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0D?ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0;ooooo`009_ooool0
0ol0003oooooooooo`1Booooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooo
oooo00000oooool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0D?ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?o
o`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003ooooo
ooooo`1Booooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000ooo
ool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0D?oo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo
00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00
ooooooooool0D?ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Boooo
o`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00Go
o`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003o
ooooooooo`1Aooooo`03o`000?oooooooooo03Gooooo0_l0001Aooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1?ooooo`;o0000
3Oooool002Kooooo00?o0000ooooooooool0DOooool3ool000;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00?oo`00ooooooooool00ooo001Booooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0D?ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?o
o`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0;ooooo`009_ooool2o`0005;ooooo
0ooo0002ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`00
00?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo00?oo`00D_ooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo053ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00oooooooooooo
o`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo053ooooo00?o0000oooo
ooooool02oooool002Kooooo00?o0000ooooooooool0DOooool3ool000;ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool00ooo001Booooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0D?ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool000;ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0
003oooooooooo`1Fooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo05Gooooo
00?o0000ooooooooool0=Oooool2o`00057ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo04oooooo0_l0000=ooooo`009_ooool0
0ol0003oooooooooo`1Fooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo05Go
oooo00?o0000ooooooooool07?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?o
oooo0ol00005ooooo`03o`000?oooooooooo053ooooo00Coo`00ooooooooooooo`000_ooool01?oo
003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool0
2oooool002Kooooo00?o0000ooooooooool0E_ooool01Ooo003oooooooooooooooooo`0000?ooooo
00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo
003oooooooooo`1Eooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1@ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo05Kooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo0000
0oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0EOooool00ol0003o
ooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Coooool2ool000;ooooo00Co
o`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01Ooo003ooooooooooooo003ooooo00;oo`00D_ooool00ol0003ooooooooo
o`0;ooooo`009_ooool2o`0005Oooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool0EOooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
oooooooo0000ooooo`04o`0000Gooooo0_l0001@ooooo`;oo`000_ooool01?oo003ooooooooooooo
0002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`05ool00?ooooooooooool00?ooool00_oo001Aooooo`;o00003Oooool002Kooooo00?o0000oooo
ooooool0E_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Eooooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000Sooooo00?o0000ooooooooool0Doooool01?oo003ooooooooooooo0002ooooo`06ool00?oo
ooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool005Gooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0E_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oo
oooooooooooooooo00000oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Doooool01?oo003ooooooooooooo0002ooooo`06ool00?oooooo
ooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
05Gooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0E_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo01cooooo0_l0
000:ooooo`;o00001?ooool2o`0000Gooooo00?o0000ooooooooool0Doooool01?oo003ooooooooo
oooo0002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool005Gooooo00?o0000ooooooooool02oooool002Kooooo00?o0000
ooooooooool0E_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooooooo
ool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Eooooo`03
o`000?oooooooooo03Gooooo0_l0001Dooooo`04ool00?ooooooooooool000;ooooo00Koo`00oooo
ooooooooo`00oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`00E?ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo05Kooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo05?ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooool000;o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo001Eooooo`03o`000?oooooo
oooo00_ooooo000Vooooo`;o0000Eoooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Doooool01?oo003ooooo
oooooooo0002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo
0002ooooo`04ool00?ooooooooooool005Gooooo00?o0000ooooooooool02oooool002Kooooo00?o
0000ooooooooool0E_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Eoooo
o`03o`000?oooooooooo03Gooooo0_l0001Dooooo`04ool00?ooooooooooool000;ooooo00Koo`00
ooooooooooooo`00oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`00E?ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo05Kooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooo
ooooo`0000?ooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo05?ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooool0
00;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo001Eooooo`03o`000?oo
oooooooo00_ooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool0
0ol0003oooooooooo`1Fooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo05Go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Cooooo`04ool00?ooooooooooool0
00;ooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00Coo`00ooooooooooooo`00EOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`05ool00?oooooo
oooooooooooo00000oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0Doooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?oo
ooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool005Gooooo00?o
0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05Kooooo00Goo`00ooooooooooooooooool00003ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool0EOooool00ol0003oooooooooo`0eooooo`;o0000E?ooool01?oo003ooooooooooooo0002
ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool005Cooooo0_l0000=ooooo`004oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00?ooooo0ol0001Fooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool0
0?oooooooooo05Cooooo0_l0000Nooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool3o`0000Gooooo00?o0000ooooooooool0Doooool01?oo003ooooooooooooo0002ooooo`06
ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool005Gooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool01Ooo003ooooooooooooooooo
o`0000?ooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Doooool01?oo003ooooooooooooo0002ooooo`06ool00?oooooooooo
ool00?ooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool005Go
oooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002?ooool2o`0000Go
oooo00?o0000ooooooooool0EOooool3ool000;ooooo00Goo`00ooooooooooooooooool00003oooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`03ool005Kooooo00?o0000
ooooooooool06oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?ooooo00Coo`00oooooooo
ooooo`000_ooool01_oo003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo001Eooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o0000
2_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Gooooo0ooo0002ooooo`05ool0
0?oooooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooo
ooooool00ooo001Fooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`?o00001Oooool2o`0005?ooooo0_oo0002ooooo`04ool00?oo
ooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooo`00ool005Cooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`1Eooooo`?o
o`000_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003
ooooo`03ool00?oooooooooo00?oo`00E_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0D_ooool2ool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo003oo`00EOoo
ool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Jooooo`05ool00?oooooo
oooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0
FOooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooooooo`1Fooooo`03o`000?oooooooooo00_ooooo000Vooooo`;o0000Fooo
ool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03
ool00?oooooooooo05Wooooo00?o0000ooooooooool07?ooool2o`0000[ooooo0_l00003ooooo`?o
00001Oooool00ol0003oooooooooo`1Fooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
oooo00000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo05Kooooo00?o0000
ooooooooool02oooool002Kooooo00?o0000ooooooooool0F_ooool01Ooo003ooooooooooooooooo
o`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo05Wooooo00?o
0000ooooooooool0=Oooool2o`0005Oooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ool00002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0EOooool2o`0000go
oooo000Vooooo`03o`000?oooooooooo05[ooooo00Goo`00ooooooooooooooooool00003ooooo`05
ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0E_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1Fooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`03o`000?oooooooooo05[ooooo00Goo`00ooooooooooooooooool0
0003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Iooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0E_ooool01?oo003ooooooooooooo0002ooooo`03
ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1Foooo
o`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo05[ooooo00Goo`00oooooooo
ooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1I
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0E_ooool01?oo003ooooooooooooo
0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00_ooooo000Vooooo`;o0000Foooool01Ooo003ooooooooo
ooooooooo`0000?ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo05Wo
oooo00?o0000ooooooooool0=Oooool2o`0005Oooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0EOooool2
o`0000gooooo000Vooooo`03o`000?oooooooooo05[ooooo00Goo`00ooooooooooooooooool00003
ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Iooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0E_ooool01?oo003ooooooooooooo0002ooooo`03ool0
0?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1Fooooo`03
o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo05[ooooo00Goo`00oooooooooooo
ooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Ioooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0E_ooool01?oo003ooooooooooooo0002
ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooooooo
o`1Fooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo05[ooooo00Goo`00
ooooooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooo
ooooo`1Iooooo`03o`000?oooooooooo03Gooooo0_l0001Gooooo`04ool00?ooooooooooool000;o
oooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo
05Gooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`1Jooooo`05ool00?oooooooooooooo
oooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0FOooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo05Kooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0
E_ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Jooooo`05ool00?oo
oooooooooooooooo00000oooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00oooooooo
ool0FOooool00ol0003oooooooooo`0Rooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`1Fooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooo
oooo00000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo05Kooooo00?o0000
ooooooooool02oooool002Kooooo0_l0001Kooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0FOooool00ol0003ooooooooo
o`0Qooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Eooooo`;oo`000_ooool01_oo003ooooooooooooo003oooooool000;ooooo00Goo`00oooo
ooooooooo`00ooooo`02ool005Sooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooo
ooooool0F_ooool01Ooo003oooooooooooooooooo`0000?ooooo00Goo`00ooooooooooooooooool0
0003ooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool08Oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Cooooo0_l0001Fooooo`;oo`000_ooool01_oo003ooooo
oooooooo003oooooool000;ooooo00Goo`00ooooooooooooo`00ooooo`02ool005Oooooo0_l0000=
ooooo`009_ooool00ol0003oooooooooo`1Jooooo`05ool00?oooooooooooooooooo00000oooool0
1Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0FOooool00ol0003ooooooooo
o`0Qooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Iooooo`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo001K
ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo05[ooooo00Goo`00oooo
ooooooooooooool00003ooooo`05ool00?oooooooooooooooooo00000oooool00ooo003ooooooooo
o`1Iooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05Wooooo00Koo`00ooooooooooooo`00oooooooo0002oooo
o`04ool00?ooooooooooool005_ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooo
ooooool0FOooool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooo
oooo00?oo`00F_ooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Sooooo0_l0
0006ooooo`03o`000?oooooooooo05Wooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`04
ool00?ooooooooooool005_ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooooooo
ool0FOooool3ool000;ooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo
00?oo`00F_ooool00ol0003oooooooooo`0Rooooo`;o00002_ooool00ol0003oooooooooo`04oooo
o`;o0000F_ooool01_oo003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`00
F_ooool2o`0000gooooo000Vooooo`;o0000F_ooool3ool000;ooooo00Goo`00oooooooooooooooo
ool00003ooooo`03ool00?oooooooooo00?oo`00F_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo05Wooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`04ool00?oooooooooo
ool005_ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0G_ooool01Ooo
003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo05Wooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`04ool0
0?ooooooooooool005_ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0
G_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0GOooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo05Wooooo00Koo`00ooooooooooooo`00oooooooo0002
ooooo`04ool00?ooooooooooool005_ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000
ooooooooool0G_ooool01Ooo003oooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0GOoo
ool00ol0003oooooooooo`0eooooo`;o0000F_ooool01_oo003ooooooooooooo003oooooool000;o
oooo00Coo`00ooooooooooooo`00F_ooool2o`0000gooooo000>ooooo`;o00001?ooool00ol0003o
ooooooooo`02ooooo`?o00000oooool3o`0000Cooooo00?o0000ooooooooool0G_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo05Wooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`04ool00?oo
ooooooooool005_ooooo00?o0000ooooooooool02oooool000gooooo00Co0000oooooooooooo0000
2Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00001Poooo
o`05ool00?oooooooooooooooooo00000oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0F?ooool2ool000;ooooo00?oo`00oooooooo00000_ooool0
1?oo003oooooool00?oo001Kooooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool3o`0005kooooo
00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo05cooooo0_l0000gooooo`;o
0000FOooool2ool000;ooooo00?oo`00oooooooo00000_ooool01?oo003oooooool00?oo001Joooo
o`;o00003Oooool000gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool00000H?ooool01Ooo003oooooooooooooooooo`0000?ooooo00?o
o`00ooooooooool0GOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05cooooo00?o
o`00oooooooo00000_ooool00ooo003oooooooooo`1Looooo`03o`000?oooooooooo00_ooooo000=
ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`00
0?oooooooooo05kooooo00Goo`00ooooooooooooooooool00003ooooo`03ool00?oooooooooo05go
oooo00?o0000ooooooooool07?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000;o
oooo1Ol00004ooooo`03o`000?oooooooooo05cooooo00?oo`00oooooooo00000_ooool00ooo003o
ooooooooo`1Looooo`03o`000?oooooooooo00_ooooo000=ooooo`04o`000?ooooooooooo`0000So
oooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0G_ooool01Ooo003o
ooooooooooooooooo`0000?ooooo00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0Koooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo05cooooo00?oo`00oooooooo00000_ooool00ooo003ooooooooo
o`1Looooo`03o`000?oooooooooo00_ooooo000>ooooo`;o00002_ooool01?l0003ooooooooooooo
ool5o`0000?ooooo00?o0000ooooooooool0GOooool3ool000;ooooo00?oo`00ooooooooool00ooo
001Nooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo0_l0001Mooooo`03ool00?ooooooo`0000;ooooo
00?oo`00ooooooooool0Foooool2o`0000gooooo000Vooooo`03o`000?oooooooooo05gooooo0ooo
0002ooooo`03ool00?oooooooooo00?oo`00G_ooool00ol0003oooooooooo`0Kooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05cooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`1Looooo`03o`00
0?oooooooooo00_ooooo000Vooooo`;o0000G_ooool3ool000;ooooo00?oo`00ooooooooool00ooo
001Nooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Kooooo`;o
o`0000?oooooool00?ooool00_oo001Nooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`00
0?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0Kooooo`04o`00
0?ooooooooooo`0000Sooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`1Kooooo`;oo`0000?oooooool00?ooool00_oo001Nooooo`03o`000?oooooooooo
00_ooooo000Vooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003o
ooooooooo`0Looooo`;o00002_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool2o`0005oo
oooo0_oo001Oooooo`;o00003Oooool002Kooooo00?o0000ooooooooool0HOooool3ool006;ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Nooooo`;oo`00H?ooool00ol0003ooooo
ooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Qooooo`?oo`00H_ooool00ol0003ooooooooo
o`0eooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo067ooooo0ooo001Rooooo`03o`000?oo
oooooooo03Goooooa?l0000=ooooo`009_ooool2o`0000?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
1Ol0003ooooooooooooooooo00000?oooooo2Oooool002Kooooob_l0003oooooo`Wooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo000]ooooo`?o0000:oooool5o`0002[ooooo0_l0
000/ooooo`Go0000;Oooool3o`000?oooooo3?ooool002kooooo00?o0000ooooooooool0:oooool0
1?l0003oooooooooool0000Yooooo`04o`000?ooooooooooo`0002cooooo00Co0000oooooooooooo
0000;_ooool00ol0003oooooooooo`3oooooo`_ooooo000Uooooo`Go000000?oooooo`000?l00000
0ol0000Uooooo`Go00000oooool00ol0003oooooooooo`0Yooooo`04o`000?ooooooooooo`0002go
oooo00?o0000ooooooooool0:oooool5o`00043ooooo0ol0000Zooooo`Go0000:?ooool2o`0002_o
oooo1Ol0000[ooooo`?o00004Oooool002_ooooo00Co0000oooooooooooo0000;oooool00ol0003o
ooooooooo`0Xooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool0:_ooool01?l0
003oooooooooool00012ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00009ooo
ool01?l0003oooooooooool0000[ooooo`04o`000?ooooooooooo`0002cooooo00?o0000oooooooo
ool04?ooool002cooooo00?o0000ooooool00000;?ooool01Ol0003ooooooooooooooooo000002Wo
oooo00Co0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000002cooooo00?o0000
ooooool00000>Oooool5o`000003ooooool0003o000000?o00009?ooool5o`0000?ooooo00?o0000
ooooooooool09oooool01?l0003oooooooooool0000/ooooo`03o`000?oooooooooo02Wooooo1Ol0
000Aooooo`00;Oooool2o`0002cooooo00Go0000ooooooooooooooooo`00000Yooooo`04o`000?oo
ooooooooo`0002_ooooo00Go0000ooooooooooooooooo`00000]ooooo`;o0000?oooool01?l0003o
ooooooooool0000^ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo0000;Oooool0
0ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0001;ooooo000^ooooo`03o`000?oooooo
oooo02_ooooo0ol0000[ooooo`;o0000;Oooool3o`0002oooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooo`00000[ooooo`05o`000?ooooooooooooooool000009oooool01?l0003ooooooooo
ool0000Zooooo`05o`000?ooooooooooooooool00000:_ooool00ol0003oooooo`00000Booooo`00
ooooool^ooooo`;o0000:oooool01Ol0003ooooooooooooooooo000002Oooooo00Co0000oooooooo
oooo0000:_ooool01Ol0003ooooooooooooooooo000002_ooooo0_l0000Booooo`00ooooool_oooo
o`03o`000?oooooooooo02[ooooo0ol0000Yooooo`;o0000;?ooool3o`0002gooooo00?o0000oooo
ooooool04?ooool00?oooooonOooool00?oooooonOooool002Kooooob_l0003oooooo`Wooooo000D
ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000gooooolCo00003Ooo
ool001?ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03gooooo0ooo0015ooooo`?oo`00?_ooool00ol0003oooooooooo`0eooooo`;o00000_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooooooo`;o00003Oooool000cooooo1Ol0
0002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0mooooo`?oo`00AOooool3ool003kooooo00?o0000ooooooooool07?ooool2o`0000Cooooo
00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`05o`000?ooooooooooooooool0
0000;_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool3o`0003gooooo0ooo0015ooooo`?o
o`00?Oooool2o`0001gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`;oo`00@ooo
ool2ool003kooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool0AOoo
ool00ooo003oooooooooo`0mooooo`03o`000?oooooooooo01Cooooo1Ol00002ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o
0000??ooool2ool004?ooooo0_oo000mooooo`;o00003Oooool001?ooooo00Co0000oooooooooooo
00002?ooool2o`0000Gooooo00?o0000ooooooooool0?_ooool00ooo003oooooooooo`15ooooo`03
ool00?oooooooooo03gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0l
ooooo`03ool00?oooooooooo04;ooooo00?oo`00ooooooooool0??ooool00ol0003oooooooooo`0;
ooooo`005?ooool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0noooo
o`03ool00?oooooooooo04Gooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`0Koooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o
0000ooooooooool0??ooool01?oo003oooooooooooooool2ool003Wooooo0_oo0004ooooo`03ool0
0?oooooooooo03cooooo00?o0000ooooooooool02oooool002Kooooo0_l0000oooooo`03ool00?oo
oooooooo04Gooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`0Kooooo`04o`000?oo
ooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo
03cooooo00Coo`00oooooooooooooooo0_oo000iooooo`;oo`001?ooool00ooo003oooooooooo`0l
ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo03kooooo00?oo`00oooo
ooooool0AOooool00ooo003oooooooooo`0mooooo`03o`000?oooooooooo01cooooo0_l0000:oooo
o`;o00000_ooool5o`0000Cooooo0_l0000mooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0=oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo03_ooooo0_l0000=oooo
o`009_ooool00ol0003oooooooooo`0nooooo`03ool00?oooooooooo04Gooooo00?oo`00oooooooo
ool0?Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`0gooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool0??ooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0nooooo`03ool0
0?oooooooooo04Gooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03cooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0gooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool0??ooool00ol0003oooooooooo`0;ooooo`009_oo
ool2o`0003oooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`0mooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0=Oooool2ool000Gooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0gooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool2ool003Sooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool03Oooool3
ool002kooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`0/ooooo`?oo`003_ooool0
0ol0003oooooooooo`0eooooo`;o0000=_ooool2ool000Gooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0gooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool2
ool003Oooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`0=ooooo`?oo`00;_ooool00ooo
003oooooooooo`15ooooo`03ool00?oooooooooo02cooooo0ooo000>ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0=_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool0=oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool0=_ooool00ol0003oooooooooo`0;ooooo`009_ooool2o`0000ko
oooo0ooo000^ooooo`03ool00?oooooooooo04Gooooo00?oo`00ooooooooool0;?ooool3ool000ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0gooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0fooooo`03o`000?oooooooooo00_o
oooo000Vooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0;Oooool00ooo003ooooo
ooooo`15ooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool03Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00cooooo0_oo000Xooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0gooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Uooooo`;oo`003oooool00ol0003ooooo
ooooo`0;ooooo`009_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo02gooooo00?o
o`00ooooooooool0AOooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo00gooooo00?o
0000ooooooooool0=Oooool2o`0000gooooo0_oo000Xooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`0gooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`0Uooooo`;oo`003_ooool2o`0000gooooo000V
ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`15
ooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool00_ooool2ool002;ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03Oooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo01oooooo0_oo0005
ooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool02oooool002Kooooo0_l0000?oooo
o`03ool00?oooooooooo02gooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`0]oooo
o`03ool00?oooooooooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06oooo
o`;oo`001Oooool00ooo003oooooooooo`02ooooo`;oo`008_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0=oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool07oooool2ool000Gooooo00?oo`00oooo
ooooool00_ooool2ool000Wooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooooooo
ool03_ooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo04Gooooo00?oo`00oooooooo
ool0;Oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool01_ooool2ool000Gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Pooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0gooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Pooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool2ool000Wooooo00?o0000oooooooo
ool02oooool0023ooooo0_l00004ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0
;Oooool00ooo003oooooooooo`15ooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool0
3Oooool00ol0003oooooooooo`0eooooo`;o00002?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0=oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool01_ooool2o`0000gooooo000Oooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooooooo0ooo000:ooooo`03ool00?oooooooooo00So
oooo0ooo000Eooooo`?oo`002_ooool00ooo003oooooooooo`08ooooo`?oo`00;Oooool3ool000[o
oooo00?oo`00ooooooooool02?ooool3ool001Gooooo0ooo000:ooooo`03ool00?oooooooooo00So
oooo0ooo0002ooooo`03o`000?oooooooooo02kooooo0_l00005ooooo`03o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo023o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03Oo
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo023o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00Oo
oooo00?o0000ooooooooool02oooool001oooooo00Co0000oooooooooooo00000oooool4o`0000?o
o`002_l000000ooo003o0000o`000008o`0000?oo`002_l000000ooo003o0000o`000008o`0000?o
o`002_l000000ooo003o0000o`000008o`0000?oo`002_l000000ooo003o0000o`000009o`000003
ool00?l0003o000000Wo000000?oo`00o`000?l000002?l00003ool000[o000000?oo`00o`000?l0
00002?l00003ool000[o000000?oo`00o`000?l000002?l00003ool000[o000000?oo`00o`000?l0
00002?l00003ool000?o0000;oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
023ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
03Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
023ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00Oooooo00?o0000ooooooooool02oooool001oooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooooooool3ool001Gooooo0ooo000:ooooo`03ool00?oooooooooo00Sooooo0ooo000E
ooooo`?oo`002_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool02?ooool3ool001Gooooo0ooo000:ooooo`03ool00?oooooooooo00Sooooo0ooo000E
ooooo`?oo`000_ooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000Cooooo1?l0
0002ool000Co000000?oo`00o`000?l000000ol000000ooo003o0000o`000003o`000003ool00?l0
003o000000;o00000_oo0005o`000003ool00?l0003o000000;o000000?oo`00o`000?l000000ol0
00000ooo003o0000o`000002o`0000;oo`001Ol000000ooo003o0000o`000003o`000003ool00?l0
003o000000;o000000?oo`00o`000?l000000_l00002ool000Go000000?oo`00o`000?l000000ol0
00000ooo003o0000o`000003o`000003ool00?l0003o000000;o000000?oo`00o`000?l000000ol0
00000ooo003o0000o`000003o`000003ool00?l0003o000000?o000000?oo`00o`000?l000000_l0
0002ool000Co000000?oo`00o`000?l000000ol000000ooo003o0000o`000003o`000003ool00?l0
003o000000;o00000_oo0005o`000003ool00?l0003o000000?o000000?oo`00o`000?l000000_l0
00000ooo003o0000o`000002o`0000;oo`001Ol000000ooo003o0000o`000003o`000003ool00?l0
003o000000?o000000Coo`00o`000?l0003o00000ooo0004o`0000gooooo000Oooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0]ooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0]ooooo`03ool0
0?oooooooooo02Gooooo00?o0000ooooooooool0;Oooool01?l0003oooooooooool00004ooooo`04
o`000?ooooooooooooooo`;oo`005Oooool2ool000Gooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo0_oo000Eooooo`;oo`001Oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`02ooooo`;oo`005Oooool2ool000Gooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00;ooooo0_oo000Eooooo`;oo`001?ooool00ol0
003oooooooooo`0;ooooo`007oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
02Kooooo00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`0Uooooo`03o`000?oooooooooo
02gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Oooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo023ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo01oooooo00?o0000ooooooooool02oooool0023ooooo0_l00004ooooo`;o00009oooool00ooo
003oooooooooo`0]ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`0]ooooo`03ool00?oooooooooo02Gooooo00?o0000ooooooooool0;Oooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool07oooool0
0ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo
02gooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
02gooooo00?oo`00ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`;o00001Oooool2o`00
023ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
023ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool07_ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo02Ko
oooo00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`0Uooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool07oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Oooooo`03o`000?oooooooooo00_o
oooo000Vooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0;Oooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0;Oooool00ooo003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool07oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0Pooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00_ooooo000Vooooo`;o00009oooool00ooo003ooooooooo
o`0]ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`0]ooooo`03ool00?oooooooooo02Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Oooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0Pooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo01oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000
ooooooooool09_ooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo02Gooooo00?o0000
ooooooooool0=Oooool2o`0001oooooo0_oo0004ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool08?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00?ooooo00Coo`00
oooooooooooooooo0_oo000Pooooo`;o00003Oooool002Kooooo00?o0000ooooooooool09_ooool0
0ooo003oooooooooo`0]ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool0
0ooo003oooooooooo`0]ooooo`03ool00?oooooooooo02Gooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0Nooooo`;oo`001?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo023ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`03ooooo`04ool00?oooooo
ooooooooo`;oo`008Oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0V
ooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09
ooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool09Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool00_ooool2ool002;ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool07oooool2ool000Gooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0;
ooooo`009_ooool2o`0002Kooooo0ooo000^ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`0/ooooo`?oo`009_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool00_ooool2ool002;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool07oooool2ool000Gooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`0;oooo
o`009_ooool00ol0003oooooooooo`0Uooooo`?oo`00;_ooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo00Wooooo00?oo`00ooooooooool0;?ooool3ool002Kooooo00?o0000oooooooo
ool0=Oooool2o`0002Cooooo0_oo000Xooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo02Gooooo0_oo000Uooooo`;o
00003Oooool002Kooooo00?o0000ooooooooool09Oooool3ool002kooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02cooooo0ooo000Vooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool08oooool2ool002Sooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
9Oooool2ool002Kooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0E_oo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0EOoo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo04gooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COoo
ool00ol0003oooooooooo`0;ooooo`009_ooool2o`0005Oooooo00?oo`00ooooooooool02Oooool0
0ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool2
o`0004kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool0C?ooool2o`0000gooooo000Dooooo`;o00001?ooool00ol0
003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`1Fooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo
00_ooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`1Eooooo`03o`000?oooooooooo01cooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`?o00001Oooool00ol0003oooooooooo`1=ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
04gooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04gooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool00ol0003ooooo
ooooo`0;ooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo
0ol0001Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`1Dooooo`;o00007Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool00_ooool2o`0004kooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0C?ooool2o`00
00gooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`1Eooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COoo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?oooooo
ooooo`0000Sooooo0_l00005ooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool06ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`03
o`000?oooooooooo04gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0;ooooo`00
5?ooool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Fooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1Eooooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003ooooo
o`0000Sooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooo
oooo00_ooooo000Vooooo`;o0000Eoooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0Looooo`;o00002_ooool2o`00
00;ooooo1Ol00004ooooo`;o0000C_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1<ooooo`;o00003Oooool002Ko
oooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo04go
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003ooooo
ooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0COooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`1=ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo05Kooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`1=ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o
0000ooooooooool02oooool002Kooooo0_l0001Gooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo0_l0001>
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo04cooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`1Foooo
o`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1Eoooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=oooo
o`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo05Kooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`1<ooooo`;oo`001Oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo0_oo001?ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`00
0?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1<ooooo`;oo`00
1Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo0_oo001?ooooo`03o`00
0?oooooooooo00_ooooo000Vooooo`;o0000Eoooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`;o0000E?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05;ooooo0_l0000=ooooo`009_ooool0
0ol0003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool0
0ooo003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Doooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool02oooool0
02Kooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
05?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo
00_ooooo000Vooooo`;o0000Eoooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`;o0000E?ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo05;ooooo0_l0000=ooooo`009_ooool00ol0003ooooo
ooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Doooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool02oooool001Cooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00000oooool00ol0003oooooooooo`1Fooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1Eooooo`03o`00
0?oooooooooo02;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`00
0?oooooooooo05?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Cooooo`03o`00
0?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo027ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo000Cooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool3o`0005Kooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Cooooo0_l0000Soooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`0005Cooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`1Booooo`;o00003Oooool001?ooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Kooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000
ooooooooool08Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Doooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o
0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0Qooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`00
4oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`1Eooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00002?ooool2
o`0000Kooooo00?o0000ooooooooool0Doooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo05?ooooo00?o0000ooooooooool02oooool001Cooooo0_l00009ooooo`?o00001?ooool2o`00
05Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
05Gooooo00?o0000ooooooooool08_ooool2o`0000[ooooo00?o0000ooooooooool01?ooool2o`00
05Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Booooo`;o00003Oooool002Ko
oooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00_o
oooo000Vooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`1Cooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003ooooo
ooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0Doooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o
0000ooooooooool02oooool002Kooooo0_l0001Gooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo0_l0001D
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0D_ooool2o`0000gooooo000Voooo
o`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Coooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;oooo
o`009_ooool00ol0003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0Doooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o0000oooooooo
ool02oooool002Kooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo05?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Cooooo`03o`00
0?oooooooooo00_ooooo000Vooooo`;o0000Eoooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`;o0000E?oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05;ooooo0_l0000=ooooo`009_ooool0
0ol0003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool0
0ooo003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Doooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool02oooool0
02Kooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
05?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo
00_ooooo000Vooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003o
ooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool2o`0005Co
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Booooo`;o00003Oooool002Kooooo
0_l0001Gooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Doooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool02oooool001Cooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo05Kooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o
0000ooooooooool07?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol0
0005ooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`1Cooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`00
00_ooooo00Go0000ooooooooooooooooo`00001Hooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo01_ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l0
001Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0D_ooool2o`0000gooooo000C
ooooo`04o`000?ooooooooooo`0000Wooooo0_l00004ooooo`?o0000E_ooool00ooo003ooooooooo
o`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0E?ooool2o`0001gooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0Doooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo
00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002oooool01Ol0003ooooo
oooooooooooo000005Sooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo05Gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00009oooo
o`04o`000?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`004oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`1Eooooo`?oo`002_ooool00ooo003oooooooooo`08ooooo`?oo`00E_ooool00ol0003ooooooooo
o`0Kooooo`04o`000?ooooooooooo`0000Sooooo0_l00003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0Doooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo
00?o0000ooooooooool02oooool001Cooooo0_l00009ooooo`?o00001?ooool00ol0003ooooooooo
o`1Eooooo`?oo`002_ooool00ooo003oooooooooo`08ooooo`?oo`00E_ooool00ol0003ooooooooo
o`0Looooo`;o00002_ooool01?l0003oooooooooooooool5o`0000Cooooo0_l0001Cooooo`;oo`00
1Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0_ooool2ool005Cooooo0_l0000=ooooo`009_ooool2o`0005Kooooo0ooo000:ooooo`03ool00?oo
oooooooo00Sooooo0ooo001Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0D_oo
ool2ool000Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00;ooooo0_oo001Eooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo05Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo05Wooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0H_ooool00ooo
003oooooooooo`1Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0FOooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0FOooool00ol0
003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo067o
oooo00?o0000ooooooooool0=Oooool2o`0005[ooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo05Sooooo0_l0000=ooooo`009_ooool2o`0006?ooooo
00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05Wooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05Wooooo
00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0H_ooool00ooo003ooooooooo
o`1Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0FOooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0FOooool00ol0003ooooooooo
o`0;ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00;ooooo00?oo`00
ooooooooool00oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Voooo
o`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0eoooo
o`;o0000F_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0F?ooool2o`0000gooooo000Vooooo`;o0000Hoooool00ooo003oooooooooo`1Qooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0;ooooo`00
9_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oo
oooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0eooooo`;o0000F_oo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0F?oo
ool2o`0000gooooo000Vooooo`;o0000Hoooool00ooo003oooooooooo`1Qooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0
003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool08_ooool2o`00
00Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo05Wooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05Wooooo00?o0000
ooooooooool02oooool001Cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00003oooo
o`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0Qoooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`1Iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`1Iooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o
0000ooooooooool08Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo
0_l0001Jooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`1Hooooo`;o00003Oooool001?ooooo00Co0000oooooooooooo00001oooool5o`0000?ooooo
0ol0001Rooooo`03ool00?oooooooooo063ooooo0_l0000Sooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00_o
oooo000Cooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool08Oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1Iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`1Iooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool000001?ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o
0000ooooooooool08Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`00
0?ooooooooooo`0000Wooooo0_l00004ooooo`03o`000?oooooooooo06;ooooo00?oo`00oooooooo
ool0HOooool00ol0003oooooooooo`0Rooooo`;o00002Oooool3o`0000Gooooo0_l0001Jooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Hooooo`;o
00003Oooool001Cooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo0_l0001Sooooo`03ool0
0?oooooooooo067ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Iooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Iooooo`03o`00
0?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOoo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool02ooo
ool002Kooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`1Qooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0
003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool0=Oooool2o`00
05[ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
05Sooooo0_l0000=ooooo`009_ooool2o`0006?ooooo00?oo`00ooooooooool0HOooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool00_ooool00ooo003o
ooooooooo`03ooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool02oooool002Kooooo
00?o0000ooooooooool0H_ooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0F?ooool2ool000Cooooo00?oo`00ooooooooool00_ooool2ool005_ooooo
00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0H_ooool00ooo003ooooooooo
o`1Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0F?ooool2ool000Cooooo00?o
o`00ooooooooool00_ooool2ool005_ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000
ooooooooool0H_ooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo03Gooooo0_l0001O
ooooo`03ool00?oooooooooo05kooooo0_l0000=ooooo`009_ooool2o`0006?ooooo00?oo`00oooo
ooooool0HOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05kooooo00?oo`00oooo
ooooool0Goooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03
ool00?oooooooooo067ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Nooooo`03
ool00?oooooooooo05oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0
H_ooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo03Gooooo0_l0001Oooooo`03ool0
0?oooooooooo05kooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03ool00?oo
oooooooo067ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Nooooo`03ool00?oo
oooooooo05oooooo00?o0000ooooooooool02oooool002Kooooo0_l0001Sooooo`03ool00?oooooo
oooo067ooooo00?o0000ooooooooool07?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0
0002ooooo`?o00001Oooool00ol0003oooooooooo`1Nooooo`03ool00?oooooooooo05oooooo00?o
0000ooooooooool02oooool001Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004
ooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0K
ooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0G_ooool00ooo003oooooooooo`1Oooooo`03
o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0
003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`;o0000Goooool2ool005oooooo0_l0000=ooooo`004oooool01?l0
003oooooooooool0000;ooooo`05o`000?ooooooooooooooool00000Hoooool3ool006;ooooo00?o
0000ooooooooool06oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Nooooo`;oo`00H?ooool00ol0003ooooo
ooooo`0;ooooo`004oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`?o
0000HOooool3ool0067ooooo0_l0000Mooooo`04o`000?ooooooooooo`0000Oooooo00Ko0000oooo
ooooooooooooo`000?ooool4o`0000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo0000
1oooool4o`0000Cooooo00?o0000ooooooooool0HOooool3ool006;ooooo00?o0000ooooooooool0
6oooool01?l0003oooooooooool00007ooooo`07o`000?ooooooooooooooool0003oooooo`000008
ooooolCo00003Oooool001?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000001kooooo0_l00009ooooo`?o00000_ooool5o`000=Gooooo000Dooooo`;o00002?ooool5
o`0000?ooooob_l0003oooooo`Wooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo003oooooooWooooo
003oooooooWooooo003oooooooWooooo0000\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-5.82174, \
-0.0769837, 0.0417682, 0.00170675}, {{262.875, 490.688}, {303, 162.25}} -> \
{-16.9053, -0.0611584, 0.0430227, 0.00132033}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-5.82174, -1.02, 0.0417682, 0.00512026}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-16.9053, -0.528066, 0.0430227, 0.00263702}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Pulse (T -> infinity)", "Subsection"],

Cell[CellGroupData[{

Cell["Define and plot single pulse", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Pulse1[
          t_] := \((UnitStep[t + 1/2]\  - 
            UnitStep[t - 1/2])\);\)\), "\[IndentingNewLine]", 
    \(\(g5 = 
        Plot[Pulse1[t], {t, \(-10\), 10}, \ PlotPoints \[Rule] 100, 
          PlotStyle \[Rule] {Blue}, 
          PlotRange \[Rule] {\(-1.01\), 3.01}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.155277 0.15374 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .00154 -12 -4.5 ]
[-0.0125 .00154 0 4.5 ]
[-0.0125 .15528 -6 -4.5 ]
[-0.0125 .15528 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .46276 -6 -4.5 ]
[-0.0125 .46276 0 4.5 ]
[-0.0125 .6165 -6 -4.5 ]
[-0.0125 .6165 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .00154 m
.00625 .00154 L
s
[(-1)] -0.0125 .00154 1 0 Mshowa
0 .15528 m
.00625 .15528 L
s
[(0)] -0.0125 .15528 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .46276 m
.00625 .46276 L
s
[(2)] -0.0125 .46276 1 0 Mshowa
0 .6165 m
.00625 .6165 L
s
[(3)] -0.0125 .6165 1 0 Mshowa
.125 Mabswid
0 .03229 m
.00375 .03229 L
s
0 .06303 m
.00375 .06303 L
s
0 .09378 m
.00375 .09378 L
s
0 .12453 m
.00375 .12453 L
s
0 .18603 m
.00375 .18603 L
s
0 .21677 m
.00375 .21677 L
s
0 .24752 m
.00375 .24752 L
s
0 .27827 m
.00375 .27827 L
s
0 .33976 m
.00375 .33976 L
s
0 .37051 m
.00375 .37051 L
s
0 .40126 m
.00375 .40126 L
s
0 .43201 m
.00375 .43201 L
s
0 .4935 m
.00375 .4935 L
s
0 .52425 m
.00375 .52425 L
s
0 .555 m
.00375 .555 L
s
0 .58575 m
.00375 .58575 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .00154 m
1 .00154 L
s
.99375 .15528 m
1 .15528 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .46276 m
1 .46276 L
s
.99375 .6165 m
1 .6165 L
s
.125 Mabswid
.99625 .03229 m
1 .03229 L
s
.99625 .06303 m
1 .06303 L
s
.99625 .09378 m
1 .09378 L
s
.99625 .12453 m
1 .12453 L
s
.99625 .18603 m
1 .18603 L
s
.99625 .21677 m
1 .21677 L
s
.99625 .24752 m
1 .24752 L
s
.99625 .27827 m
1 .27827 L
s
.99625 .33976 m
1 .33976 L
s
.99625 .37051 m
1 .37051 L
s
.99625 .40126 m
1 .40126 L
s
.99625 .43201 m
1 .43201 L
s
.99625 .4935 m
1 .4935 L
s
.99625 .52425 m
1 .52425 L
s
.99625 .555 m
1 .555 L
s
.99625 .58575 m
1 .58575 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .15528 m
1 .15528 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .15528 m
.03318 .15528 L
.04339 .15528 L
.05298 .15528 L
.06221 .15528 L
.07203 .15528 L
.08148 .15528 L
.09153 .15528 L
.10121 .15528 L
.11052 .15528 L
.12043 .15528 L
.12997 .15528 L
.13914 .15528 L
.14891 .15528 L
.15831 .15528 L
.1683 .15528 L
.17793 .15528 L
.18719 .15528 L
.19704 .15528 L
.20653 .15528 L
.21661 .15528 L
.22632 .15528 L
.23566 .15528 L
.2456 .15528 L
.25518 .15528 L
.26438 .15528 L
.27418 .15528 L
.28361 .15528 L
.29364 .15528 L
.3033 .15528 L
.31259 .15528 L
.32248 .15528 L
.332 .15528 L
.34115 .15528 L
.3509 .15528 L
.36028 .15528 L
.37025 .15528 L
.37985 .15528 L
.38909 .15528 L
.39893 .15528 L
.40839 .15528 L
.41845 .15528 L
.42814 .15528 L
.43747 .15528 L
.44739 .15528 L
.45694 .15528 L
.46613 .15528 L
.47124 .15528 L
.47366 .15528 L
.47484 .15528 L
Mistroke
.47535 .15528 L
.47562 .15528 L
.47591 .15528 L
.47621 .30902 L
.47648 .30902 L
.47702 .30902 L
.47822 .30902 L
.48073 .30902 L
.48532 .30902 L
.49454 .30902 L
.50435 .30902 L
.51379 .30902 L
.51627 .30902 L
.51895 .30902 L
.52018 .30902 L
.52149 .30902 L
.5226 .30902 L
.52291 .30902 L
.52324 .30902 L
.52355 .30902 L
.52383 .15528 L
.52414 .15528 L
.52444 .15528 L
.52499 .15528 L
.52622 .15528 L
.52843 .15528 L
.53345 .15528 L
.54279 .15528 L
.55272 .15528 L
.56229 .15528 L
.57148 .15528 L
.58128 .15528 L
.5907 .15528 L
.60072 .15528 L
.61037 .15528 L
.61966 .15528 L
.62953 .15528 L
.63905 .15528 L
.64819 .15528 L
.65793 .15528 L
.6673 .15528 L
.67726 .15528 L
.68686 .15528 L
.69609 .15528 L
.70592 .15528 L
.71538 .15528 L
.72543 .15528 L
.73511 .15528 L
.74443 .15528 L
.75434 .15528 L
Mistroke
.76389 .15528 L
.77306 .15528 L
.78283 .15528 L
.79224 .15528 L
.80224 .15528 L
.81187 .15528 L
.82113 .15528 L
.83099 .15528 L
.84048 .15528 L
.85057 .15528 L
.86028 .15528 L
.86963 .15528 L
.87958 .15528 L
.88916 .15528 L
.89837 .15528 L
.90817 .15528 L
.91761 .15528 L
.92764 .15528 L
.93731 .15528 L
.9466 .15528 L
.95649 .15528 L
.96602 .15528 L
.97517 .15528 L
.97619 .15528 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003[ooooo0ol0000hoooo
o`?o00001?ooool2o`0000[ooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=_ooool01Ol0003ooooooooooooooooo000003Oooooo00Co0000oooooooooooo0000>?oo
ool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00009ooooo`004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`00
03cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Wooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>_ooool0
0ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Wooooo000Jooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=_ooool4o`0003Sooooo00Co0000oooooooooooo
0000>?ooool4o`0003Wooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00009oooo
o`006Oooool2o`0000Cooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`0ioooo
o`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0>Oooool2o`0000Cooooo00Co0000
oooooooooooo00002Oooool001[ooooo00?o0000ooooooooool00oooool2o`0003Oooooo1Ol0000h
ooooo`;o0000>Oooool5o`0003Sooooo00?o0000ooooooooool00oooool2o`0000[ooooo003ooooo
ob7ooooo003oooooob7ooooo000<ooooo`?o0000oooooolBooooo`003Oooool00ol0003ooooooooo
o`3ooooooa7ooooo0005ooooo`Go00000oooool00ol0003oooooooooo`05oooooooo00001Ol00007
ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool000gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo0_l00007ooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00083ooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`00
5Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000=ooooo`;o00001_ooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool000cooooo00Co0000oooooooooooo00001Oooool6o`0007Ko003o
3?l0001fo`00o`Ko00001oooool000cooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`1hooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`1hooooo`03o`000?oooooooooo00Gooooo000<ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool0N?ooool00ol0003oooooooooo`05ooooo`003?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool01Oooool000gooooo0_l0
0006ooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0N?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool0N?ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1hoooo
o`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1hoooo
o`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07Sooooo00?o003ooooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo07Sooooo00?o0000oooooooo
ool01Oooool001Gooooo0_l0001iooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oo
oooooooo07Sooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooo
oooooooo07Sooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0N?ooool0
0ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0N?ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1hooooo`03o`00oooooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo
00Gooooo000Eooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool01Oooool001Gooooo
00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool0N?ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1hooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooooooo
o`1hooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07Sooooo00?o003o
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo07Sooooo00?o0000
ooooooooool01Oooool001Gooooo0_l0001iooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo00Gooooo000Eooooo`03
o`000?oooooooooo07Sooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo07Sooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0
N?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
N?ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1hooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1hooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool01Oooool0
01Gooooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool0N?ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003o
ooooooooo`1hooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oo
ooooooooo`1hooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07Sooooo
00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo07Sooooo
00?o0000ooooooooool01Oooool001Gooooo0_l0001iooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo00Gooooo000E
ooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooo
ooooool0N?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003ooooo
ooooool0N?ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1hooooo`03
o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1hooooo`03
o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool0
1Oooool001Gooooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o003oooooooooool0N?ooool00ol0003oooooooooo`05ooooo`005Oooool0
0ol0003oooooooooo`1hooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol00?ooooooooooo`1hooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo
07Sooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo
07Sooooo00?o0000ooooooooool01Oooool001Gooooo0_l0001iooooo`03o`00oooooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1hooooo`03o`000?oooooooooo00Go
oooo000Eooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool01Oooool001Gooooo00?o
0000ooooooooool0N?ooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
003oooooooooool0N?ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1h
ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`1h
ooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07Sooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo07Sooooo00?o0000oooo
ooooool01Oooool001Gooooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool0N?ooool00ol0003oooooooooo`05ooooo`00
3?ooool3o`0000Kooooo00?o0000ooooooooool0N?ooool00ol00?ooooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o003oooooooooool0N?ooool00ol0003oooooooooo`05ooooo`003Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07Sooooo00?o003oooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo07Sooooo00?o0000ooooooooool01Ooo
ool000gooooo00?o0000ooooooooool01Oooool2o`0007Wooooo3_l00?miooooo`;o00001oooool0
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool000gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000cooooo
0_l00007ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003ooooo
ooooo`05ooooo`003Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooo
ooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03
o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`00
5Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o
0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020oooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07ko
oooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
ooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Ooo
ool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0
003oooooooooo`05ooooo`005Oooool2o`00083ooooo00?o0000ooooooooool0O_ooool00ol0003o
ooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo
00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003ooooooooo
o`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000;ooooo`Go0000
1Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool0
1Oooool000cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1oooooo`03o`00
0?oooooooooo07kooooo00?o0000ooooooooool01Oooool000gooooo00?o0000ooooooooool01Ooo
ool2o`00083ooooo00?o0000ooooooooool0OOooool2o`0000Oooooo000>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooo
oooo00Gooooo000;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`1o
ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool000_ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`003?ooool3o`0000Kooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooo
ooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000E
ooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0
003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oo
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool2o`00083ooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool01Oooool001Gooooo0_l00020ooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000
ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eoooo
o`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05oooo
o`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00Gooooo000Eooooo`;o0000P?ooool00ol0003oooooooooo`1nooooo`03o`000?oo
oooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0O_ooool0
0ol0003oooooooooo`05ooooo`005Oooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo
07kooooo00?o0000ooooooooool01Oooool001Gooooo00?o0000ooooooooool0Ooooool00ol0003o
ooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000Eooooo`03o`000?oooooooooo07oooooo
00?o0000ooooooooool0O_ooool00ol0003oooooooooo`05ooooo`003?ooool3o`0000Kooooo00?o
0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Gooooo000;
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`1oooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooooooool01Oooool000oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000=ooooo`;o00001_ooooooo`00
00Go00001oooool000oooooo00?o0000ooooooooool0ooooool?ooooo`002oooool01Ol0003ooooo
oooooooooooo00000?oooooo4Oooool000cooooo0ol0003ooooooa;ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.2089, -1.31662, \
0.0808208, 0.0250332}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Frequency spectrum", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(spectrum = \ 
        FourierTransform[Pulse1[t], \ t, \ f]\  // \ 
          FullSimplify;\)\), "\[IndentingNewLine]", 
    \(spectrum\  // \ TraditionalForm\)}], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(sin(f\ \[Pi])\)\/\(f\ \[Pi]\)\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ge = 
        Plot[spectrum, {f, \(-4\), 4}, PlotStyle \[Rule] Red, \ 
          PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.119759 0.48356 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02305 -24 -4.5 ]
[-0.0125 .02305 0 4.5 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .21647 -18 -4.5 ]
[-0.0125 .21647 0 4.5 ]
[-0.0125 .31318 -18 -4.5 ]
[-0.0125 .31318 0 4.5 ]
[-0.0125 .40989 -18 -4.5 ]
[-0.0125 .40989 0 4.5 ]
[-0.0125 .50661 -18 -4.5 ]
[-0.0125 .50661 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02305 m
.00625 .02305 L
s
[(-0.2)] -0.0125 .02305 1 0 Mshowa
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .21647 m
.00625 .21647 L
s
[(0.2)] -0.0125 .21647 1 0 Mshowa
0 .31318 m
.00625 .31318 L
s
[(0.4)] -0.0125 .31318 1 0 Mshowa
0 .40989 m
.00625 .40989 L
s
[(0.6)] -0.0125 .40989 1 0 Mshowa
0 .50661 m
.00625 .50661 L
s
[(0.8)] -0.0125 .50661 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04722 m
.00375 .04722 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16811 m
.00375 .16811 L
s
0 .19229 m
.00375 .19229 L
s
0 .24065 m
.00375 .24065 L
s
0 .26483 m
.00375 .26483 L
s
0 .289 m
.00375 .289 L
s
0 .33736 m
.00375 .33736 L
s
0 .36154 m
.00375 .36154 L
s
0 .38572 m
.00375 .38572 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .48243 m
.00375 .48243 L
s
0 .53078 m
.00375 .53078 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02305 m
1 .02305 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .21647 m
1 .21647 L
s
.99375 .31318 m
1 .31318 L
s
.99375 .40989 m
1 .40989 L
s
.99375 .50661 m
1 .50661 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04722 m
1 .04722 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16811 m
1 .16811 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .24065 m
1 .24065 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .289 m
1 .289 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .36154 m
1 .36154 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .48243 m
1 .48243 L
s
.99625 .53078 m
1 .53078 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .11976 m
.04262 .10068 L
.0522 .09189 L
.06244 .08408 L
.0679 .08082 L
.07286 .07849 L
.07525 .0776 L
.07784 .07681 L
.07903 .07651 L
.08029 .07624 L
.08145 .07603 L
.08255 .07587 L
.0832 .07579 L
.08392 .07572 L
.08516 .07564 L
.08586 .07561 L
.08662 .0756 L
.08732 .0756 L
.08797 .07562 L
.08922 .07569 L
.08993 .07575 L
.09058 .07582 L
.09177 .07598 L
.09304 .0762 L
.09588 .07688 L
.09854 .07774 L
.10458 .08051 L
.10959 .08364 L
.11503 .08786 L
.12493 .0975 L
.14349 .12061 L
.16287 .14715 L
.17317 .15998 L
.17858 .16589 L
.18427 .17129 L
.18932 .17527 L
.19198 .17702 L
.19484 .17862 L
.19747 .17982 L
.19985 .18067 L
.20101 .181 L
.20226 .1813 L
.20344 .18152 L
.20452 .18167 L
.20562 .18178 L
.2068 .18183 L
.20791 .18183 L
.20892 .18178 L
.21011 .18166 L
.2114 .18146 L
Mistroke
.21263 .18121 L
.21376 .18091 L
.21624 .18006 L
.21849 .17905 L
.22354 .17598 L
.22843 .17191 L
.23359 .16651 L
.24282 .15414 L
.26366 .11618 L
.28356 .07397 L
.30168 .03963 L
.30649 .03232 L
.31172 .02561 L
.31666 .0206 L
.31886 .01883 L
.32123 .01726 L
.32253 .01655 L
.32372 .016 L
.32493 .01554 L
.32606 .0152 L
.3273 .01493 L
.32795 .01483 L
.32865 .01476 L
.32939 .01472 L
.33008 .01472 L
.33138 .01481 L
.33269 .01504 L
.33335 .0152 L
.33408 .01542 L
.33656 .01646 L
.33795 .01726 L
.33945 .01829 L
.34216 .02061 L
.34743 .02684 L
.35231 .03466 L
.36337 .05974 L
.37312 .09012 L
.38348 .13026 L
.4212 .32287 L
.44215 .43621 L
.45133 .48091 L
.46137 .52383 L
.47047 .55584 L
.4802 .58161 L
.48557 .59172 L
.48812 .59544 L
.49047 .59823 L
.49282 .60043 L
.49404 .60133 L
.49538 .60212 L
Mistroke
.49655 .60265 L
.49764 .60301 L
.49879 .60324 L
.50003 .60332 L
.50072 .60329 L
.50136 .60321 L
.50257 .60295 L
.50387 .60248 L
.50528 .60176 L
.50651 .60094 L
.50781 .5999 L
.51014 .59756 L
.51541 .59011 L
.52118 .57853 L
.53157 .54928 L
.54127 .51322 L
.5802 .31505 L
.60003 .20789 L
.61048 .15693 L
.62158 .10968 L
.63143 .07501 L
.63666 .05966 L
.64229 .04562 L
.64745 .03509 L
.65218 .02739 L
.65669 .02177 L
.65897 .01958 L
.66145 .01765 L
.66399 .01619 L
.66542 .01559 L
.66674 .01518 L
.6679 .01492 L
.66917 .01476 L
.66981 .01472 L
.67049 .01472 L
.67173 .01479 L
.67293 .01497 L
.67424 .01528 L
.67547 .01568 L
.67661 .01615 L
.67877 .01726 L
.68107 .01878 L
.68674 .02391 L
.69207 .03035 L
.70203 .04589 L
.74065 .12489 L
.751 .14414 L
.76064 .15917 L
.7707 .17108 L
.77603 .17566 L
Mistroke
.77879 .17754 L
.78173 .17916 L
.78425 .18025 L
.78559 .18072 L
.78704 .18112 L
.78836 .18142 L
.78957 .18162 L
.79078 .18175 L
.79194 .18182 L
.79263 .18184 L
.79327 .18183 L
.794 .1818 L
.79468 .18175 L
.79591 .18162 L
.7966 .18152 L
.79724 .1814 L
.80005 .1807 L
.80147 .18023 L
.80302 .17962 L
.80805 .177 L
.81344 .1732 L
.82316 .16406 L
.84296 .13929 L
.86451 .11005 L
.87454 .09808 L
.8852 .08767 L
.8943 .08115 L
.89679 .07979 L
.89948 .07853 L
.90203 .07754 L
.90434 .07682 L
.90674 .07625 L
.90805 .07601 L
.9093 .07583 L
.91045 .07571 L
.91151 .07564 L
.91267 .0756 L
.91391 .07561 L
.91515 .07566 L
.91584 .0757 L
.91648 .07576 L
.91772 .07591 L
.91889 .07609 L
.92151 .07664 L
.92437 .07747 L
.92967 .0796 L
.93532 .08266 L
.94547 .08995 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`008oooool3o`0003Wooooo1Ol0000hooooo`;o0000>Oooool5o`0003_o
oooo0ol00006ooooo`009?ooool00ol0003oooooooooo`0iooooo`04o`000?ooooooooooo`0003Oo
oooo00Co0000oooooooooooo0000>Oooool01?l0003oooooooooool0000looooo`03o`000?oooooo
oooo00Gooooo000Kooooo`Go000000?oooooo`000?l000000ol0000cooooo`Go00000oooool00ol0
003oooooooooo`0gooooo`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>Oooool5
o`0000Kooooo000Qooooo`04o`000?ooooooooooo`0003gooooo00?o0000ooooooooool0=_ooool0
1?l0003oooooooooool0000kooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo0000
1oooool002;ooooo00?o0000ooooool00000>_ooool01Ol0003ooooooooooooooooo000003Oooooo
00Co0000oooooooooooo0000>?ooool01Ol0003ooooooooooooooooo000003[ooooo00?o0000oooo
ool000001oooool002?ooooo0_l0000jooooo`05o`000?ooooooooooooooool00000=oooool01?l0
003oooooooooool0000hooooo`05o`000?ooooooooooooooool00000>oooool2o`0000Oooooo000T
ooooo`03o`000?oooooooooo03Wooooo0ol0000iooooo`;o0000>_ooool3o`0003gooooo00?o0000
ooooooooool01Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Ooo
ool00?oooooo8Oooool001_oooooool00005o`00007ooooo000Kooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool000Sooooo0_l0
0004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`1Booooo`;oo`00
:oooool00ol0003oooooooooo`0Xooooo`;oo`00E?ooool1o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1@ooooo`;o
o`0000Coooooool00?oo003oo`00:Oooool00ol0003oooooooooo`0Vooooo`?oo`0000Coooooool0
0?oo003oo`00DOooool1o`00007ooooo0005o`0000;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04oooooo00?oo`00ooooooooool01?ooool0
0ooo003oooooooooo`0Vooooo`03o`000?oooooooooo02Gooooo0_oo0005ooooo`03ool00?oooooo
oooo04oooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00?ooooo0_l0001?ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool09_ooool0
0ol0003oooooooooo`0Uooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0COooool2
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo04gooooo00?oo`00ooooooooool01oooool00ooo003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool01oooool00ooo003ooooooooo
o`1=ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`08ooooo`03ool0
0?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ooo003oooooooooo`07ooooo`03ool0
0?oooooooooo04gooooo0Ol00001ooooo`002?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oo
oooooooo04cooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Tooooo`03o`000?oo
oooooooo02?ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1<ooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo02Cooooo00?o0000ooooooooool08oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooo
oooo04_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo
00_ooooo00?oo`00ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03ool00?oooooooooo
00cooooo00?oo`00ooooooooool0B_ooool1o`00007ooooo000Kooooo`;o0000Boooool00ooo003o
ooooooooo`0<ooooo`03ool00?oooooooooo02?ooooo00?o0000ooooooooool08_ooool00ooo003o
ooooooooo`0<ooooo`03ool00?oooooooooo04Wooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`1:ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool08_ooool00ol0003ooooo
ooooo`0Qooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0BOooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo04Wooooo00?oo`00ooooooooool03_ooool00ooo003ooooooooo
o`0Rooooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool03_ooool00ooo003ooooooooo
o`19ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0B?ooool00ooo003oooooooooo`0@
ooooo`03ool00?oooooooooo027ooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`0@
ooooo`03ool00?oooooooooo04Sooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`18oooo
o`03ool00?oooooooooo013ooooo00?oo`00ooooooooool08Oooool00ol0003oooooooooo`0Poooo
o`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0B?ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo04Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0Pooooo`03
o`000?oooooooooo023ooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`17ooooo`7o
00000Oooool001_ooooo0_l00018ooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
8?ooool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool0
A_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo017ooooo1Ooo000`ooooo`03ool00?oo
oooooooo01?ooooo00?oo`00ooooooooool08?ooool00ol0003oooooooooo`0Oooooo`03ool00?oo
oooooooo01?ooooo00?oo`00ooooooooool0;_ooool5ool001?ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`0?ooooo`?oo`001?ooool3ool002gooooo00?oo`00ooooooooool05?ooool0
0ooo003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool04oooool0
0ooo003oooooooooo`0/ooooo`?oo`001?ooool3ool0013ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0<ooooo`?oo`002_ooool2ool002[ooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0Yooooo`;oo`002_ooool00ooo003oooooooooo`0=ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo02Oo
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Oooooo`03o`000?oooooooooo01ko
oooo00?oo`00ooooooooool05Oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooooooo00_o
oooo00?oo`00ooooooooool03?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00[ooooo
00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Vooooo`03ool00?oooooooooo01Oooooo
00?oo`00ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo01Gooooo
00?oo`00ooooooooool09oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00_ooooo
0Ol00001ooooo`006oooool2o`0000_ooooo00?oo`00ooooooooool03oooool00ooo003ooooooooo
o`0Uooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool07_ooool00ol0003ooooooooo
o`0Mooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool09Oooool00ooo003ooooooooo
o`0?ooooo`03ool00?oooooooooo00Wooooo0_l00001ooooo`006oooool00ol0003oooooooooo`09
ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool08oooool00ooo003oooooooooo`0H
ooooo`03ool00?oooooooooo01kooooo00?o0000ooooooooool07Oooool00ooo003oooooooooo`0G
ooooo`03ool00?oooooooooo02Cooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`09
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0Boooo
o`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`0Moooo
o`03o`000?oooooooooo01gooooo00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0Roooo
o`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool02?ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0Rooooo`03
ool00?oooooooooo01Wooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03
ool00?oooooooooo01Wooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0Eooooo`03
ool00?oooooooooo00Oooooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool0
1_ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool0
6_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0
6_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool0
1_ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1Oooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool0
6_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0
6_ooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0
1Oooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1?ooool00ooo003oooooooooo`0Jooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool0
6oooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0
6oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0
1?ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo1_l000000ooo003o0000
o`00000Lo`000003ool00?l0003o000001co000000?oo`00o`000?l000007?l000000ooo003o0000
o`00000jo`000003ool00?l0003o000001co000000?oo`00o`000?l000007?l000000ooo003o0000
o`00000Lo`000003ool00?l0003o000000Co00000Oooool001?ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0Rooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool0
7Oooool00ooo003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool0
7Oooool00ooo003oooooooooo`0Kooooo`03ool00?oooooooooo02;ooooo0Ol00001ooooo`004ooo
ool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02?ooooo00?oo`00ooooooooool0
6_ooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo01cooooo00?o0000ooooooooool0
6oooool00ooo003oooooooooo`0Mooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool0
8oooool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003oooooooooo`0Tooooo`03ool00?oo
oooooooo01Sooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`0Looooo`03o`000?oo
oooooooo01_ooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`0Iooooo`03ool00?oo
oooooooo02?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Uooooo`03ool00?oooooo
oooo01Oooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`0Looooo`03o`000?oooooo
oooo01[ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooo
oooo02Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Uooooo`03ool00?oooooooooo
01Kooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo
01[ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo
02Gooooo0Ol00001ooooo`006oooool2o`0002Oooooo00?oo`00ooooooooool05Oooool00ooo003o
ooooooooo`0Pooooo`03ool00?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ooo003o
ooooooooo`0Qooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool09Oooool2o`00007o
oooo000Kooooo`03o`000?oooooooooo02Oooooo00?oo`00ooooooooool04oooool00ooo003ooooo
ooooo`0Qooooo`03ool00?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ooo003ooooo
ooooo`0Qooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool09oooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo02Sooooo00?oo`00ooooooooool04_ooool00ooo003ooooooooo
o`0Qooooo`03ool00?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ooo003ooooooooo
o`0Sooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0:?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo02Wooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0R
ooooo`03ool00?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0S
ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0:Oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Toooo
o`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0:_ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo02[ooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Uooooo`03
ool00?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ooo003oooooooooo`0Uooooo`03
ool00?oooooooooo00cooooo00?oo`00ooooooooool0:oooool1o`00007ooooo000Kooooo`;o0000
;?ooool2ool000cooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?oo`00ooooooooool09_ooool00ooo003oooooooooo`0;ooooo`03ool0
0?oooooooooo02[ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`0]ooooo`03ool00?oo
oooooooo00Sooooo00?oo`00ooooooooool09oooool00ooo003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Sooooo00?oo`00ooooooooool0:?ooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo02cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0^ooooo`03ool00?oooooo
oooo00Gooooo0_oo000Zooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool06?ooool0
0ooo003oooooooooo`0Yooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0;Oooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo02oooooo0ooo0003ooooo`03ool00?oooooooooo
02_ooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03ool00?oooooooooo
02[ooooo0_oo0003ooooo`Coo`00<?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo037o
oooo1?oo000^ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ooo003o
ooooooooo`0/ooooo`Coo`00<oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06?ooooo
00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03ool00?oooooooooo06?ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1Sooooo`03ool00?oooooooooo01Wooooo00?o
0000ooooooooool06?ooool00ooo003oooooooooo`1Sooooo`7o00000Oooool001_ooooo0_l0001T
ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`1R
ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0I?ooool00ooo003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0I?ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo06Cooooo00?oo`00ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03
ool00?oooooooooo06Cooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooo
oooo1Ol00004ooooo`03o`000?oooooooooo06Cooooo00?oo`00ooooooooool06?ooool00ol0003o
ooooooooo`0Gooooo`03ool00?oooooooooo06Cooooo0Ol00001ooooo`001oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0I?ooool00ooo
003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?oo`00ooooooooool0I?ooool1o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Tooooo`03ool00?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ooo
003oooooooooo`1Tooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0
003oooooooooo`03ooooo`;o0000I_ooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo
01Oooooo00?oo`00ooooooooool0Hoooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06Gooooo00?oo`00
ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo06Gooooo0Ol00001
ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`1Uooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05_oo
ool00ooo003oooooooooo`1Uooooo`7o00000Oooool000Sooooo0_l00009ooooo`?o00001Oooool0
0ol0003oooooooooo`1Uooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool05_ooool0
0ooo003oooooooooo`1Uooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0IOooool00ooo
003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool0IOooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo06Kooooo00?oo`00ooooooooool05_ooool00ol0003o
ooooooooo`0Fooooo`03ool00?oooooooooo06Gooooo0Ol00001ooooo`006oooool2o`0006Oooooo
00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo06Gooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`1Vooooo`03ool00?oooooooooo01Kooooo00?o
0000ooooooooool05Oooool00ooo003oooooooooo`1Vooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0I_ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00
ooooooooool0I_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Kooooo00?oo`00oooo
ooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo06Kooooo0Ol00001oooo
o`006oooool00ol0003oooooooooo`1Wooooo`03ool00?oooooooooo01Gooooo00?o0000oooooooo
ool05?ooool00ooo003oooooooooo`1Wooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
Ioooool00ooo003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?oo`00ooooooooool0
Ioooool1o`00007ooooo000Kooooo`;o0000J?ooool00ooo003oooooooooo`0Eooooo`03o`000?oo
oooooooo01Cooooo00?oo`00ooooooooool0I_ooool2o`00007ooooo000Kooooo`03o`000?oooooo
oooo06Oooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooo
oooo06Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Wooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`1Wooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0J?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo01?o
oooo00?oo`00ooooooooool0J?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Sooooo
00?oo`00ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo06Sooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1Xooooo`03ool00?oooooooooo01Cooooo00?o
0000ooooooooool04oooool00ooo003oooooooooo`1Xooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0J?ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?oo`00
ooooooooool0J?ooool1o`00007ooooo000Kooooo`;o0000JOooool00ooo003oooooooooo`0Doooo
o`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0J?ooool2o`00007ooooo000Kooooo`03
o`000?oooooooooo06Wooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0Booooo`03
ool00?oooooooooo06Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Yooooo`03ool0
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1Yooooo`7o0000
0Oooool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oo
oooooooo06Wooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0Booooo`03ool00?oo
oooooooo06Wooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`0Cooooo`03o`000?oo
oooooooo01;ooooo00?oo`00ooooooooool0JOooool1o`00007ooooo0007ooooo`04o`000?oooooo
ooooo`0000Oooooo1Ol00004ooooo`03o`000?oooooooooo06Wooooo00?oo`00ooooooooool04ooo
ool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo06[ooooo0Ol00001ooooo`001oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo0_l0001[ooooo`03ool0
0?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1Yooooo`;o0000
0Oooool000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo06[ooooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03ool0
0?oooooooooo06[ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`;o0000
1Oooool00ol0003oooooooooo`1Zooooo`03ool00?oooooooooo01;ooooo00?o0000ooooooooool0
4Oooool00ooo003oooooooooo`1Zooooo`7o00000Oooool000Sooooo0_l0000;ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0J_ooool00ooo003oooooooooo`0Booooo`03o`000?oo
oooooooo017ooooo00?oo`00ooooooooool0J_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo06[ooooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
oooo06_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1[ooooo`03ool00?oooooooooo
017ooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`1[ooooo`7o00000Oooool001_o
oooo0_l0001/ooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ooo003o
ooooooooo`1Zooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Joooool00ooo003ooooo
ooooo`0Aooooo`03o`000?oooooooooo013ooooo00?oo`00ooooooooool0Joooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo06_ooooo00?oo`00ooooooooool04Oooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo06_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1[
ooooo`03ool00?oooooooooo017ooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`1/
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0K?ooool00ooo003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo00?oo`00ooooooooool0K?ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo06cooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03
ool00?oooooooooo06cooooo0Ol00001ooooo`006oooool2o`0006gooooo00?oo`00ooooooooool0
4?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo06_ooooo0_l00001ooooo`006ooo
ool00ol0003oooooooooo`1/ooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool03ooo
ool00ooo003oooooooooo`1/ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0K?ooool0
0ooo003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0KOooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo06gooooo00?oo`00ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03ool00?oooooooooo06gooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1]ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ooo003o
ooooooooo`1]ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0KOooool00ooo003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0KOooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo06gooooo00?oo`00ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`03ool00?oooooooooo06gooooo0Ol00001ooooo`006oooool2o`0006kooooo00?oo`00
ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo06gooooo0_l00001
ooooo`006oooool00ol0003oooooooooo`1^ooooo`03ool00?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ooo003oooooooooo`1^ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0K_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?oo`00oooooooo
ool0K_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo06kooooo0Ol00001ooooo`002?oo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0K_oo
ool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0K_oo
ool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo06kooooo00?oo`00ooooooooool03_ooool00ol0003ooooo
ooooo`0<ooooo`03ool00?oooooooooo06oooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001?ooool2o`00073ooooo00?oo`00oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo06kooooo0_l00001ooooo`00
1oooool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`1_ooooo`03
ool00?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`1_ooooo`7o
00000Oooool000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo06oooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
ool00?oooooooooo06oooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007ooooo0008ooooo`;o0000
2_ooool2o`0000Gooooo00?o0000ooooooooool0Koooool00ooo003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?oo`00ooooooooool0Koooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo073ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03ool00?oo
oooooooo073ooooo0Ol00001ooooo`006oooool2o`00077ooooo00?oo`00ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03ool00?oooooooooo06oooooo0_l00001ooooo`006oooool00ol0
003oooooooooo`1`ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool02oooool00ooo
003oooooooooo`1`ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0L?ooool00ooo003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0L?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo073ooooo00?oo`00ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03ool00?oooooooooo073ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1`ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ooo003ooooooooo
o`1aooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0LOooool00ooo003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0LOooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo077ooooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo077ooooo0Ol00001ooooo`006oooool2o`0007;ooooo00?oo`00oooooooo
ool02oooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo073ooooo0_l00001ooooo`00
6oooool00ol0003oooooooooo`1aooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool0
2_ooool00ooo003oooooooooo`1aooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0LOoo
ool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0L_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo07;ooooo00?oo`00ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo07;ooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1booooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ooo
003oooooooooo`1booooo`7o00000Oooool001_ooooo00?o0000ooooooooool0L_ooool00ooo003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0L_ooool1o`00007o
oooo000Kooooo`;o0000Loooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?oo`00ooooooooool0LOooool2o`00007ooooo000Kooooo`03o`000?oooooooooo07;ooooo00?o
o`00ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo07?ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1cooooo`03ool00?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ooo003oooooooooo`1cooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0Loooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?oo`00oooo
ooooool0Loooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00001Oooool00ol0003oooooooooo`1cooooo`03ool00?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ooo003oooooooooo`1cooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Loooool00ooo
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0Loooool1o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`;o0000MOooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?oo`00
ooooooooool0Loooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo0ol00005
ooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1dooooo`03ool00?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1dooooo`7o00000Ooo
ool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0M?ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?oo`00ooooooooool0M?ooool1o`00007ooooo0008ooooo`;o00002Oooool3o`0000Gooooo00?o
0000ooooooooool0MOooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
o`00ooooooooool0M?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Gooooo00?oo`00
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo07Gooooo0Ol00001
ooooo`006oooool2o`0007Kooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03ool00?oooooooooo07Cooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1eooooo`03
ool00?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`1eooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0M_ooool00ooo003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?oo`00ooooooooool0MOooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo07Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03ool00?oo
oooooooo07Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1fooooo`03ool00?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1fooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0M_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?oo`00ooooooooool0M_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Oo
oooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo07Ko
oooo0Ol00001ooooo`006oooool2o`0007Sooooo00?oo`00ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo07Kooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`1gooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ooo003ooooooooo
o`1gooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool00ooo003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0Moooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03ool00?oooooooooo07Sooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1hooooo`03
ool00?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1hooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0N?ooool00ooo003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0N?ooool1o`00007ooooo000Kooooo`;o0000N_oo
ool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0N?oo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03ool00?oooooooooo07Wooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`1jooooo`03ool00?oooooooooo00;ooooo00Go0000ooooooooooooooooool0001l
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Noooool01Ooo003ooooooooooooooooo
000000?ooooo00?oo`00ooooooooool0N_ooool1o`00007ooooo000Cooooo`?o00001Oooool00ol0
003oooooooooo`1kooooo`05ool00?ooooooooooooooool000000_ooool00ooo003oooooooooo`1k
ooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1loooo
o`;oo`0000Coooooo`000?ooooooo`00O_ooool1o`00007ooooo000Dooooo`03o`000?oooooooooo
00Cooooo0_l0001nooooo`Coo`00O_ooool2o`00007ooooo000Dooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Oooool001Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool00oooool1o`00007ooooo000Cooooo`;o00001_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool1o`00007ooooo000D
ooooo`03o`000?oooooooooo00Coooooool00005o`00007ooooo003oooooob7ooooo003oooooob7o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-5.08152, -0.359353, \
0.032354, 0.00796526}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compare FS and FT", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{ga, gb}, {gd, ge}}], 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 504 311.489 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.477324 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.118423 3.87917 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04084 -30 -4.5 ]
[-0.0125 .04084 0 4.5 ]
[-0.0125 .11842 -6 -4.5 ]
[-0.0125 .11842 0 4.5 ]
[-0.0125 .19601 -24 -4.5 ]
[-0.0125 .19601 0 4.5 ]
[-0.0125 .27359 -24 -4.5 ]
[-0.0125 .27359 0 4.5 ]
[-0.0125 .35117 -24 -4.5 ]
[-0.0125 .35117 0 4.5 ]
[-0.0125 .42876 -24 -4.5 ]
[-0.0125 .42876 0 4.5 ]
[-0.0125 .50634 -18 -4.5 ]
[-0.0125 .50634 0 4.5 ]
[-0.0125 .58392 -24 -4.5 ]
[-0.0125 .58392 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04084 m
.00625 .04084 L
s
[(-0.02)] -0.0125 .04084 1 0 Mshowa
0 .11842 m
.00625 .11842 L
s
[(0)] -0.0125 .11842 1 0 Mshowa
0 .19601 m
.00625 .19601 L
s
[(0.02)] -0.0125 .19601 1 0 Mshowa
0 .27359 m
.00625 .27359 L
s
[(0.04)] -0.0125 .27359 1 0 Mshowa
0 .35117 m
.00625 .35117 L
s
[(0.06)] -0.0125 .35117 1 0 Mshowa
0 .42876 m
.00625 .42876 L
s
[(0.08)] -0.0125 .42876 1 0 Mshowa
0 .50634 m
.00625 .50634 L
s
[(0.1)] -0.0125 .50634 1 0 Mshowa
0 .58392 m
.00625 .58392 L
s
[(0.12)] -0.0125 .58392 1 0 Mshowa
.125 Mabswid
0 .06024 m
.00375 .06024 L
s
0 .07963 m
.00375 .07963 L
s
0 .09903 m
.00375 .09903 L
s
0 .13782 m
.00375 .13782 L
s
0 .15721 m
.00375 .15721 L
s
0 .17661 m
.00375 .17661 L
s
0 .2154 m
.00375 .2154 L
s
0 .2348 m
.00375 .2348 L
s
0 .25419 m
.00375 .25419 L
s
0 .29299 m
.00375 .29299 L
s
0 .31238 m
.00375 .31238 L
s
0 .33178 m
.00375 .33178 L
s
0 .37057 m
.00375 .37057 L
s
0 .38996 m
.00375 .38996 L
s
0 .40936 m
.00375 .40936 L
s
0 .44815 m
.00375 .44815 L
s
0 .46755 m
.00375 .46755 L
s
0 .48694 m
.00375 .48694 L
s
0 .52574 m
.00375 .52574 L
s
0 .54513 m
.00375 .54513 L
s
0 .56453 m
.00375 .56453 L
s
0 .02144 m
.00375 .02144 L
s
0 .00205 m
.00375 .00205 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04084 m
1 .04084 L
s
.99375 .11842 m
1 .11842 L
s
.99375 .19601 m
1 .19601 L
s
.99375 .27359 m
1 .27359 L
s
.99375 .35117 m
1 .35117 L
s
.99375 .42876 m
1 .42876 L
s
.99375 .50634 m
1 .50634 L
s
.99375 .58392 m
1 .58392 L
s
.125 Mabswid
.99625 .06024 m
1 .06024 L
s
.99625 .07963 m
1 .07963 L
s
.99625 .09903 m
1 .09903 L
s
.99625 .13782 m
1 .13782 L
s
.99625 .15721 m
1 .15721 L
s
.99625 .17661 m
1 .17661 L
s
.99625 .2154 m
1 .2154 L
s
.99625 .2348 m
1 .2348 L
s
.99625 .25419 m
1 .25419 L
s
.99625 .29299 m
1 .29299 L
s
.99625 .31238 m
1 .31238 L
s
.99625 .33178 m
1 .33178 L
s
.99625 .37057 m
1 .37057 L
s
.99625 .38996 m
1 .38996 L
s
.99625 .40936 m
1 .40936 L
s
.99625 .44815 m
1 .44815 L
s
.99625 .46755 m
1 .46755 L
s
.99625 .48694 m
1 .48694 L
s
.99625 .52574 m
1 .52574 L
s
.99625 .54513 m
1 .54513 L
s
.99625 .56453 m
1 .56453 L
s
.99625 .02144 m
1 .02144 L
s
.99625 .00205 m
1 .00205 L
s
.99625 .60332 m
1 .60332 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11842 m
1 .11842 L
s
1 0 0 r
.5 Mabswid
.02381 .11842 m
.02381 .11842 L
s
.03869 .11842 m
.03869 .10318 L
s
.05357 .11842 m
.05357 .08932 L
s
.06845 .11842 m
.06845 .07909 L
s
.08333 .11842 m
.08333 .07432 L
s
.09821 .11842 m
.09821 .07617 L
s
.1131 .11842 m
.1131 .08484 L
s
.12798 .11842 m
.12798 .09952 L
s
.14286 .11842 m
.14286 .11842 L
s
.15774 .11842 m
.15774 .13897 L
s
.17262 .11842 m
.17262 .15811 L
s
.1875 .11842 m
.1875 .17275 L
s
.20238 .11842 m
.20238 .18016 L
s
.21726 .11842 m
.21726 .17846 L
s
.23214 .11842 m
.23214 .16693 L
s
.24702 .11842 m
.24702 .14622 L
s
.2619 .11842 m
.2619 .11842 L
s
.27679 .11842 m
.27679 .08692 L
s
.29167 .11842 m
.29167 .05606 L
s
.30655 .11842 m
.30655 .03067 L
s
.32143 .11842 m
.32143 .01552 L
s
.33631 .11842 m
.33631 .01472 L
s
.35119 .11842 m
.35119 .03111 L
s
.36607 .11842 m
.36607 .06592 L
s
.38095 .11842 m
.38095 .11842 L
s
.39583 .11842 m
.39583 .18593 L
s
.41071 .11842 m
.41071 .26394 L
s
.4256 .11842 m
.4256 .34658 L
s
.44048 .11842 m
.44048 .42712 L
s
.45536 .11842 m
.45536 .49868 L
s
.47024 .11842 m
.47024 .55498 L
s
.48512 .11842 m
.48512 .59095 L
s
.5 .11842 m
.5 .60332 L
s
.51488 .11842 m
.51488 .59095 L
s
.52976 .11842 m
.52976 .55498 L
s
.54464 .11842 m
.54464 .49868 L
s
.55952 .11842 m
.55952 .42712 L
s
.5744 .11842 m
.5744 .34658 L
s
.58929 .11842 m
.58929 .26394 L
s
.60417 .11842 m
.60417 .18593 L
s
.61905 .11842 m
.61905 .11842 L
s
.63393 .11842 m
.63393 .06592 L
s
.64881 .11842 m
.64881 .03111 L
s
.66369 .11842 m
.66369 .01472 L
s
.67857 .11842 m
.67857 .01552 L
s
.69345 .11842 m
.69345 .03067 L
s
.70833 .11842 m
.70833 .05606 L
s
.72321 .11842 m
.72321 .08692 L
s
.7381 .11842 m
.7381 .11842 L
s
.75298 .11842 m
.75298 .14622 L
s
.76786 .11842 m
.76786 .16693 L
s
.78274 .11842 m
.78274 .17846 L
s
.79762 .11842 m
.79762 .18016 L
s
.8125 .11842 m
.8125 .17275 L
s
.82738 .11842 m
.82738 .15811 L
s
.84226 .11842 m
.84226 .13897 L
s
.85714 .11842 m
.85714 .11842 L
s
.87202 .11842 m
.87202 .09952 L
s
.8869 .11842 m
.8869 .08484 L
s
.90179 .11842 m
.90179 .07617 L
s
.91667 .11842 m
.91667 .07432 L
s
.93155 .11842 m
.93155 .07909 L
s
.94643 .11842 m
.94643 .08932 L
s
.96131 .11842 m
.96131 .10318 L
s
.97619 .11842 m
.97619 .11842 L
s
.015 w
.02381 .11842 Mdot
.03869 .10318 Mdot
.05357 .08932 Mdot
.06845 .07909 Mdot
.08333 .07432 Mdot
.09821 .07617 Mdot
.1131 .08484 Mdot
.12798 .09952 Mdot
.14286 .11842 Mdot
.15774 .13897 Mdot
.17262 .15811 Mdot
.1875 .17275 Mdot
.20238 .18016 Mdot
.21726 .17846 Mdot
.23214 .16693 Mdot
.24702 .14622 Mdot
.2619 .11842 Mdot
.27679 .08692 Mdot
.29167 .05606 Mdot
.30655 .03067 Mdot
.32143 .01552 Mdot
.33631 .01472 Mdot
.35119 .03111 Mdot
.36607 .06592 Mdot
.38095 .11842 Mdot
.39583 .18593 Mdot
.41071 .26394 Mdot
.4256 .34658 Mdot
.44048 .42712 Mdot
.45536 .49868 Mdot
.47024 .55498 Mdot
.48512 .59095 Mdot
.5 .60332 Mdot
.51488 .59095 Mdot
.52976 .55498 Mdot
.54464 .49868 Mdot
.55952 .42712 Mdot
.5744 .34658 Mdot
.58929 .26394 Mdot
.60417 .18593 Mdot
.61905 .11842 Mdot
.63393 .06592 Mdot
.64881 .03111 Mdot
.66369 .01472 Mdot
.67857 .01552 Mdot
.69345 .03067 Mdot
.70833 .05606 Mdot
.72321 .08692 Mdot
.7381 .11842 Mdot
.75298 .14622 Mdot
.76786 .16693 Mdot
.78274 .17846 Mdot
.79762 .18016 Mdot
.8125 .17275 Mdot
.82738 .15811 Mdot
.84226 .13897 Mdot
.85714 .11842 Mdot
.87202 .09952 Mdot
.8869 .08484 Mdot
.90179 .07617 Mdot
.91667 .07432 Mdot
.93155 .07909 Mdot
.94643 .08932 Mdot
.96131 .10318 Mdot
.97619 .11842 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.0147151 0.97619 0.295003 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.119759 0.48356 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02305 -24 -4.5 ]
[-0.0125 .02305 0 4.5 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .21647 -18 -4.5 ]
[-0.0125 .21647 0 4.5 ]
[-0.0125 .31318 -18 -4.5 ]
[-0.0125 .31318 0 4.5 ]
[-0.0125 .40989 -18 -4.5 ]
[-0.0125 .40989 0 4.5 ]
[-0.0125 .50661 -18 -4.5 ]
[-0.0125 .50661 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02305 m
.00625 .02305 L
s
[(-0.2)] -0.0125 .02305 1 0 Mshowa
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .21647 m
.00625 .21647 L
s
[(0.2)] -0.0125 .21647 1 0 Mshowa
0 .31318 m
.00625 .31318 L
s
[(0.4)] -0.0125 .31318 1 0 Mshowa
0 .40989 m
.00625 .40989 L
s
[(0.6)] -0.0125 .40989 1 0 Mshowa
0 .50661 m
.00625 .50661 L
s
[(0.8)] -0.0125 .50661 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04722 m
.00375 .04722 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16811 m
.00375 .16811 L
s
0 .19229 m
.00375 .19229 L
s
0 .24065 m
.00375 .24065 L
s
0 .26483 m
.00375 .26483 L
s
0 .289 m
.00375 .289 L
s
0 .33736 m
.00375 .33736 L
s
0 .36154 m
.00375 .36154 L
s
0 .38572 m
.00375 .38572 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .48243 m
.00375 .48243 L
s
0 .53078 m
.00375 .53078 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02305 m
1 .02305 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .21647 m
1 .21647 L
s
.99375 .31318 m
1 .31318 L
s
.99375 .40989 m
1 .40989 L
s
.99375 .50661 m
1 .50661 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04722 m
1 .04722 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16811 m
1 .16811 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .24065 m
1 .24065 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .289 m
1 .289 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .36154 m
1 .36154 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .48243 m
1 .48243 L
s
.99625 .53078 m
1 .53078 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .11976 m
.04262 .10068 L
.0522 .09189 L
.06244 .08408 L
.0679 .08082 L
.07286 .07849 L
.07525 .0776 L
.07784 .07681 L
.07903 .07651 L
.08029 .07624 L
.08145 .07603 L
.08255 .07587 L
.0832 .07579 L
.08392 .07572 L
.08516 .07564 L
.08586 .07561 L
.08662 .0756 L
.08732 .0756 L
.08797 .07562 L
.08922 .07569 L
.08993 .07575 L
.09058 .07582 L
.09177 .07598 L
.09304 .0762 L
.09588 .07688 L
.09854 .07774 L
.10458 .08051 L
.10959 .08364 L
.11503 .08786 L
.12493 .0975 L
.14349 .12061 L
.16287 .14715 L
.17317 .15998 L
.17858 .16589 L
.18427 .17129 L
.18932 .17527 L
.19198 .17702 L
.19484 .17862 L
.19747 .17982 L
.19985 .18067 L
.20101 .181 L
.20226 .1813 L
.20344 .18152 L
.20452 .18167 L
.20562 .18178 L
.2068 .18183 L
.20791 .18183 L
.20892 .18178 L
.21011 .18166 L
.2114 .18146 L
Mistroke
.21263 .18121 L
.21376 .18091 L
.21624 .18006 L
.21849 .17905 L
.22354 .17598 L
.22843 .17191 L
.23359 .16651 L
.24282 .15414 L
.26366 .11618 L
.28356 .07397 L
.30168 .03963 L
.30649 .03232 L
.31172 .02561 L
.31666 .0206 L
.31886 .01883 L
.32123 .01726 L
.32253 .01655 L
.32372 .016 L
.32493 .01554 L
.32606 .0152 L
.3273 .01493 L
.32795 .01483 L
.32865 .01476 L
.32939 .01472 L
.33008 .01472 L
.33138 .01481 L
.33269 .01504 L
.33335 .0152 L
.33408 .01542 L
.33656 .01646 L
.33795 .01726 L
.33945 .01829 L
.34216 .02061 L
.34743 .02684 L
.35231 .03466 L
.36337 .05974 L
.37312 .09012 L
.38348 .13026 L
.4212 .32287 L
.44215 .43621 L
.45133 .48091 L
.46137 .52383 L
.47047 .55584 L
.4802 .58161 L
.48557 .59172 L
.48812 .59544 L
.49047 .59823 L
.49282 .60043 L
.49404 .60133 L
.49538 .60212 L
Mistroke
.49655 .60265 L
.49764 .60301 L
.49879 .60324 L
.50003 .60332 L
.50072 .60329 L
.50136 .60321 L
.50257 .60295 L
.50387 .60248 L
.50528 .60176 L
.50651 .60094 L
.50781 .5999 L
.51014 .59756 L
.51541 .59011 L
.52118 .57853 L
.53157 .54928 L
.54127 .51322 L
.5802 .31505 L
.60003 .20789 L
.61048 .15693 L
.62158 .10968 L
.63143 .07501 L
.63666 .05966 L
.64229 .04562 L
.64745 .03509 L
.65218 .02739 L
.65669 .02177 L
.65897 .01958 L
.66145 .01765 L
.66399 .01619 L
.66542 .01559 L
.66674 .01518 L
.6679 .01492 L
.66917 .01476 L
.66981 .01472 L
.67049 .01472 L
.67173 .01479 L
.67293 .01497 L
.67424 .01528 L
.67547 .01568 L
.67661 .01615 L
.67877 .01726 L
.68107 .01878 L
.68674 .02391 L
.69207 .03035 L
.70203 .04589 L
.74065 .12489 L
.751 .14414 L
.76064 .15917 L
.7707 .17108 L
.77603 .17566 L
Mistroke
.77879 .17754 L
.78173 .17916 L
.78425 .18025 L
.78559 .18072 L
.78704 .18112 L
.78836 .18142 L
.78957 .18162 L
.79078 .18175 L
.79194 .18182 L
.79263 .18184 L
.79327 .18183 L
.794 .1818 L
.79468 .18175 L
.79591 .18162 L
.7966 .18152 L
.79724 .1814 L
.80005 .1807 L
.80147 .18023 L
.80302 .17962 L
.80805 .177 L
.81344 .1732 L
.82316 .16406 L
.84296 .13929 L
.86451 .11005 L
.87454 .09808 L
.8852 .08767 L
.8943 .08115 L
.89679 .07979 L
.89948 .07853 L
.90203 .07754 L
.90434 .07682 L
.90674 .07625 L
.90805 .07601 L
.9093 .07583 L
.91045 .07571 L
.91151 .07564 L
.91267 .0756 L
.91391 .07561 L
.91515 .07566 L
.91584 .0757 L
.91648 .07576 L
.91772 .07591 L
.91889 .07609 L
.92151 .07664 L
.92437 .07747 L
.92967 .0796 L
.93532 .08266 L
.94547 .08995 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.323031 0.477324 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.117755 0.971128 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02064 -24 -4.5 ]
[-0.0125 .02064 0 4.5 ]
[-0.0125 .11775 -6 -4.5 ]
[-0.0125 .11775 0 4.5 ]
[-0.0125 .21487 -18 -4.5 ]
[-0.0125 .21487 0 4.5 ]
[-0.0125 .31198 -18 -4.5 ]
[-0.0125 .31198 0 4.5 ]
[-0.0125 .40909 -18 -4.5 ]
[-0.0125 .40909 0 4.5 ]
[-0.0125 .50621 -18 -4.5 ]
[-0.0125 .50621 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02064 m
.00625 .02064 L
s
[(-0.1)] -0.0125 .02064 1 0 Mshowa
0 .11775 m
.00625 .11775 L
s
[(0)] -0.0125 .11775 1 0 Mshowa
0 .21487 m
.00625 .21487 L
s
[(0.1)] -0.0125 .21487 1 0 Mshowa
0 .31198 m
.00625 .31198 L
s
[(0.2)] -0.0125 .31198 1 0 Mshowa
0 .40909 m
.00625 .40909 L
s
[(0.3)] -0.0125 .40909 1 0 Mshowa
0 .50621 m
.00625 .50621 L
s
[(0.4)] -0.0125 .50621 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.5)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04006 m
.00375 .04006 L
s
0 .05949 m
.00375 .05949 L
s
0 .07891 m
.00375 .07891 L
s
0 .09833 m
.00375 .09833 L
s
0 .13718 m
.00375 .13718 L
s
0 .1566 m
.00375 .1566 L
s
0 .17602 m
.00375 .17602 L
s
0 .19545 m
.00375 .19545 L
s
0 .23429 m
.00375 .23429 L
s
0 .25371 m
.00375 .25371 L
s
0 .27314 m
.00375 .27314 L
s
0 .29256 m
.00375 .29256 L
s
0 .3314 m
.00375 .3314 L
s
0 .35083 m
.00375 .35083 L
s
0 .37025 m
.00375 .37025 L
s
0 .38967 m
.00375 .38967 L
s
0 .42852 m
.00375 .42852 L
s
0 .44794 m
.00375 .44794 L
s
0 .46736 m
.00375 .46736 L
s
0 .48678 m
.00375 .48678 L
s
0 .52563 m
.00375 .52563 L
s
0 .54505 m
.00375 .54505 L
s
0 .56447 m
.00375 .56447 L
s
0 .5839 m
.00375 .5839 L
s
0 .00122 m
.00375 .00122 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02064 m
1 .02064 L
s
.99375 .11775 m
1 .11775 L
s
.99375 .21487 m
1 .21487 L
s
.99375 .31198 m
1 .31198 L
s
.99375 .40909 m
1 .40909 L
s
.99375 .50621 m
1 .50621 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04006 m
1 .04006 L
s
.99625 .05949 m
1 .05949 L
s
.99625 .07891 m
1 .07891 L
s
.99625 .09833 m
1 .09833 L
s
.99625 .13718 m
1 .13718 L
s
.99625 .1566 m
1 .1566 L
s
.99625 .17602 m
1 .17602 L
s
.99625 .19545 m
1 .19545 L
s
.99625 .23429 m
1 .23429 L
s
.99625 .25371 m
1 .25371 L
s
.99625 .27314 m
1 .27314 L
s
.99625 .29256 m
1 .29256 L
s
.99625 .3314 m
1 .3314 L
s
.99625 .35083 m
1 .35083 L
s
.99625 .37025 m
1 .37025 L
s
.99625 .38967 m
1 .38967 L
s
.99625 .42852 m
1 .42852 L
s
.99625 .44794 m
1 .44794 L
s
.99625 .46736 m
1 .46736 L
s
.99625 .48678 m
1 .48678 L
s
.99625 .52563 m
1 .52563 L
s
.99625 .54505 m
1 .54505 L
s
.99625 .56447 m
1 .56447 L
s
.99625 .5839 m
1 .5839 L
s
.99625 .00122 m
1 .00122 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11775 m
1 .11775 L
s
1 0 0 r
.5 Mabswid
.02381 .11775 m
.02381 .11775 L
s
.08333 .11775 m
.08333 .0736 L
s
.14286 .11775 m
.14286 .11775 L
s
.20238 .11775 m
.20238 .17958 L
s
.2619 .11775 m
.2619 .11775 L
s
.32143 .11775 m
.32143 .01472 L
s
.38095 .11775 m
.38095 .11775 L
s
.44048 .11775 m
.44048 .42687 L
s
.5 .11775 m
.5 .60332 L
s
.55952 .11775 m
.55952 .42687 L
s
.61905 .11775 m
.61905 .11775 L
s
.67857 .11775 m
.67857 .01472 L
s
.7381 .11775 m
.7381 .11775 L
s
.79762 .11775 m
.79762 .17958 L
s
.85714 .11775 m
.85714 .11775 L
s
.91667 .11775 m
.91667 .0736 L
s
.97619 .11775 m
.97619 .11775 L
s
.015 w
.02381 .11775 Mdot
.08333 .0736 Mdot
.14286 .11775 Mdot
.20238 .17958 Mdot
.2619 .11775 Mdot
.32143 .01472 Mdot
.38095 .11775 Mdot
.44048 .42687 Mdot
.5 .60332 Mdot
.55952 .42687 Mdot
.61905 .11775 Mdot
.67857 .01472 Mdot
.7381 .11775 Mdot
.79762 .17958 Mdot
.85714 .11775 Mdot
.91667 .0736 Mdot
.97619 .11775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.323031 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.117755 1.94226 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02064 -30 -4.5 ]
[-0.0125 .02064 0 4.5 ]
[-0.0125 .11775 -6 -4.5 ]
[-0.0125 .11775 0 4.5 ]
[-0.0125 .21487 -24 -4.5 ]
[-0.0125 .21487 0 4.5 ]
[-0.0125 .31198 -18 -4.5 ]
[-0.0125 .31198 0 4.5 ]
[-0.0125 .40909 -24 -4.5 ]
[-0.0125 .40909 0 4.5 ]
[-0.0125 .50621 -18 -4.5 ]
[-0.0125 .50621 0 4.5 ]
[-0.0125 .60332 -24 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-4)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-2)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(2)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.08333 0 m
.08333 .00375 L
s
.14286 0 m
.14286 .00375 L
s
.20238 0 m
.20238 .00375 L
s
.32143 0 m
.32143 .00375 L
s
.38095 0 m
.38095 .00375 L
s
.44048 0 m
.44048 .00375 L
s
.55952 0 m
.55952 .00375 L
s
.61905 0 m
.61905 .00375 L
s
.67857 0 m
.67857 .00375 L
s
.79762 0 m
.79762 .00375 L
s
.85714 0 m
.85714 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02064 m
.00625 .02064 L
s
[(-0.05)] -0.0125 .02064 1 0 Mshowa
0 .11775 m
.00625 .11775 L
s
[(0)] -0.0125 .11775 1 0 Mshowa
0 .21487 m
.00625 .21487 L
s
[(0.05)] -0.0125 .21487 1 0 Mshowa
0 .31198 m
.00625 .31198 L
s
[(0.1)] -0.0125 .31198 1 0 Mshowa
0 .40909 m
.00625 .40909 L
s
[(0.15)] -0.0125 .40909 1 0 Mshowa
0 .50621 m
.00625 .50621 L
s
[(0.2)] -0.0125 .50621 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.25)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04006 m
.00375 .04006 L
s
0 .05949 m
.00375 .05949 L
s
0 .07891 m
.00375 .07891 L
s
0 .09833 m
.00375 .09833 L
s
0 .13718 m
.00375 .13718 L
s
0 .1566 m
.00375 .1566 L
s
0 .17602 m
.00375 .17602 L
s
0 .19545 m
.00375 .19545 L
s
0 .23429 m
.00375 .23429 L
s
0 .25371 m
.00375 .25371 L
s
0 .27314 m
.00375 .27314 L
s
0 .29256 m
.00375 .29256 L
s
0 .3314 m
.00375 .3314 L
s
0 .35083 m
.00375 .35083 L
s
0 .37025 m
.00375 .37025 L
s
0 .38967 m
.00375 .38967 L
s
0 .42852 m
.00375 .42852 L
s
0 .44794 m
.00375 .44794 L
s
0 .46736 m
.00375 .46736 L
s
0 .48678 m
.00375 .48678 L
s
0 .52563 m
.00375 .52563 L
s
0 .54505 m
.00375 .54505 L
s
0 .56447 m
.00375 .56447 L
s
0 .5839 m
.00375 .5839 L
s
0 .00122 m
.00375 .00122 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.08333 .61428 m
.08333 .61803 L
s
.14286 .61428 m
.14286 .61803 L
s
.20238 .61428 m
.20238 .61803 L
s
.32143 .61428 m
.32143 .61803 L
s
.38095 .61428 m
.38095 .61803 L
s
.44048 .61428 m
.44048 .61803 L
s
.55952 .61428 m
.55952 .61803 L
s
.61905 .61428 m
.61905 .61803 L
s
.67857 .61428 m
.67857 .61803 L
s
.79762 .61428 m
.79762 .61803 L
s
.85714 .61428 m
.85714 .61803 L
s
.91667 .61428 m
.91667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02064 m
1 .02064 L
s
.99375 .11775 m
1 .11775 L
s
.99375 .21487 m
1 .21487 L
s
.99375 .31198 m
1 .31198 L
s
.99375 .40909 m
1 .40909 L
s
.99375 .50621 m
1 .50621 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04006 m
1 .04006 L
s
.99625 .05949 m
1 .05949 L
s
.99625 .07891 m
1 .07891 L
s
.99625 .09833 m
1 .09833 L
s
.99625 .13718 m
1 .13718 L
s
.99625 .1566 m
1 .1566 L
s
.99625 .17602 m
1 .17602 L
s
.99625 .19545 m
1 .19545 L
s
.99625 .23429 m
1 .23429 L
s
.99625 .25371 m
1 .25371 L
s
.99625 .27314 m
1 .27314 L
s
.99625 .29256 m
1 .29256 L
s
.99625 .3314 m
1 .3314 L
s
.99625 .35083 m
1 .35083 L
s
.99625 .37025 m
1 .37025 L
s
.99625 .38967 m
1 .38967 L
s
.99625 .42852 m
1 .42852 L
s
.99625 .44794 m
1 .44794 L
s
.99625 .46736 m
1 .46736 L
s
.99625 .48678 m
1 .48678 L
s
.99625 .52563 m
1 .52563 L
s
.99625 .54505 m
1 .54505 L
s
.99625 .56447 m
1 .56447 L
s
.99625 .5839 m
1 .5839 L
s
.99625 .00122 m
1 .00122 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11775 m
1 .11775 L
s
1 0 0 r
.5 Mabswid
.02381 .11775 m
.02381 .11775 L
s
.05357 .11775 m
.05357 .08861 L
s
.08333 .11775 m
.08333 .0736 L
s
.1131 .11775 m
.1131 .08413 L
s
.14286 .11775 m
.14286 .11775 L
s
.17262 .11775 m
.17262 .1575 L
s
.20238 .11775 m
.20238 .17958 L
s
.23214 .11775 m
.23214 .16633 L
s
.2619 .11775 m
.2619 .11775 L
s
.29167 .11775 m
.29167 .0553 L
s
.32143 .11775 m
.32143 .01472 L
s
.35119 .11775 m
.35119 .03032 L
s
.38095 .11775 m
.38095 .11775 L
s
.41071 .11775 m
.41071 .26348 L
s
.44048 .11775 m
.44048 .42687 L
s
.47024 .11775 m
.47024 .55492 L
s
.5 .11775 m
.5 .60332 L
s
.52976 .11775 m
.52976 .55492 L
s
.55952 .11775 m
.55952 .42687 L
s
.58929 .11775 m
.58929 .26348 L
s
.61905 .11775 m
.61905 .11775 L
s
.64881 .11775 m
.64881 .03032 L
s
.67857 .11775 m
.67857 .01472 L
s
.70833 .11775 m
.70833 .0553 L
s
.7381 .11775 m
.7381 .11775 L
s
.76786 .11775 m
.76786 .16633 L
s
.79762 .11775 m
.79762 .17958 L
s
.82738 .11775 m
.82738 .1575 L
s
.85714 .11775 m
.85714 .11775 L
s
.8869 .11775 m
.8869 .08413 L
s
.91667 .11775 m
.91667 .0736 L
s
.94643 .11775 m
.94643 .08861 L
s
.97619 .11775 m
.97619 .11775 L
s
.015 w
.02381 .11775 Mdot
.05357 .08861 Mdot
.08333 .0736 Mdot
.1131 .08413 Mdot
.14286 .11775 Mdot
.17262 .1575 Mdot
.20238 .17958 Mdot
.23214 .16633 Mdot
.2619 .11775 Mdot
.29167 .0553 Mdot
.32143 .01472 Mdot
.35119 .03032 Mdot
.38095 .11775 Mdot
.41071 .26348 Mdot
.44048 .42687 Mdot
.47024 .55492 Mdot
.5 .60332 Mdot
.52976 .55492 Mdot
.55952 .42687 Mdot
.58929 .26348 Mdot
.61905 .11775 Mdot
.64881 .03032 Mdot
.67857 .01472 Mdot
.70833 .0553 Mdot
.7381 .11775 Mdot
.76786 .16633 Mdot
.79762 .17958 Mdot
.82738 .1575 Mdot
.85714 .11775 Mdot
.8869 .08413 Mdot
.91667 .0736 Mdot
.94643 .08861 Mdot
.97619 .11775 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 311.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooolY
ooooo`?o0000:oooool5o`0002Wooooo0_l0000/ooooo`Go0000;Oooool3o`00017ooooo003ooooo
ob[ooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool0000Xooooo`04o`000?oooooo
ooooo`0002cooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0@ooooo`00oooo
oolQooooo`Go000000?oooooo`000?l000000ol0000Uooooo`Go00000oooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool0:oooool5o`00017ooooo
000cooooo`?o0000:Oooool5o`0002Wooooo0_l0000Zooooo`Go0000;?ooool3o`0003Wooooo00Co
0000oooooooooooo0000;oooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0002ko
oooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000Booooo`00=?ooool00ol0003o
ooooooooo`0Yooooo`04o`000?ooooooooooo`0002Sooooo00Co0000oooooooooooo0000:_ooool0
1?l0003oooooooooool0000]ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool00000;?oo
ool01Ol0003ooooooooooooooooo000002Sooooo00Co0000oooooooooooo0000:oooool01Ol0003o
oooooooooooooooo000002cooooo00?o0000ooooool000004_ooool002_ooooo1Ol000000ooooooo
0000o`000003o`0002?ooooo1Ol00003ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooo
oooo0000:oooool00ol0003oooooooooo`0Zooooo`Go0000>oooool2o`0002cooooo00Go0000oooo
ooooooooooooo`00000Xooooo`04o`000?ooooooooooo`0002_ooooo00Go0000oooooooooooooooo
o`00000]ooooo`;o00004_ooool0037ooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooo
ooooo`0Wooooo`04o`000?ooooooooooo`0002cooooo00?o0000ooooooooool0:Oooool01?l0003o
ooooooooool0000mooooo`03o`000?oooooooooo02_ooooo0ol0000Zooooo`;o0000;Oooool3o`00
02oooooo00?o0000ooooooooool04?ooool003;ooooo00?o0000ooooool00000:_ooool01Ol0003o
oooooooooooooooo000002Sooooo00Co0000oooooooooooo0000:Oooool01Ol0003ooooooooooooo
oooo000002_ooooo00?o0000ooooool00000ooooool=ooooo`00<oooool2o`0002[ooooo00Go0000
ooooooooooooooooo`00000Xooooo`04o`000?ooooooooooo`0002Wooooo00Go0000oooooooooooo
ooooo`00000/ooooo`;o0000ooooool=ooooo`00=?ooool00ol0003oooooooooo`0Yooooo`?o0000
:_ooool2o`0002_ooooo0ol0000^ooooo`03o`000?oooooooooo0?oooooo2oooool00?oooooonOoo
ool00?oooooo8_ooooo:o`0000gooooo003oooooob;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool002co
ooooa?l0000Nooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00_ooooo000/ooooo`;o
00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000007Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0?Ooo
ool5ool001oooooo00?o0000ooooooooool07_ooool5ool003oooooo00?o0000ooooooooool02ooo
ool002cooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`0Dooooo`Go00000_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0000nooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool0??ooool2o`0000gooooo000/ooooo`03o`000?oooooo
oooo03_ooooo0_oo00000oooooooo`00ool0000nooooo`;oo`0000?oooooool00?oo0000?Oooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0looooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool06ooo
ool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool0??oo
ool00ol0003oooooooooo`0;ooooo`00;?ooool2o`0003cooooo0_oo00000oooooooo`00ool0000n
ooooo`;oo`0000?oooooool00?oo0000?Oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo03_ooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo00_ooooo
000/ooooo`03o`000?oooooooooo03cooooo00Coo`00ooooooooooooo`00?oooool01?oo003ooooo
oooooooo000mooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0>oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo03_ooooo00?o0000ooooooooool02oooool001Cooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000oooool00ol0003oooooooooo`0hoooo
o`;oo`000_ooool01Ooo003ooooooooooooo003ooooo00;oo`00>?ooool2ool000;ooooo00Goo`00
ooooooooooooo`00ooooo`02ool003[ooooo00?o0000ooooooooool07?ooool2o`0000Wooooo0ol0
0005ooooo`03o`000?oooooooooo03[ooooo00?oo`00ooooooooool01oooool00ooo003ooooooooo
o`0Jooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool01oooool00ooo003ooooooooo
o`0jooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo03So
oooo0_oo0002ooooo`05ool00?ooooooooooool00?ooool00_oo000hooooo`;oo`000_ooool01Ooo
003ooooooooooooo003ooooo00;oo`00>_ooool00ol0003oooooooooo`0_ooooo`;o0000>oooool0
0ooo003oooooooooo`08ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool06_ooool0
0ooo003oooooooooo`09ooooo`03ool00?oooooooooo03Sooooo0_l0000=ooooo`003?ooool5o`00
00;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00?ooooo0_l0000jooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`00>Oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool003Wooooo0_l0000a
ooooo`03o`000?oooooooooo03Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0I
ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0i
ooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo000iooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`00>_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo03Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Wooooo00?oo`00ooooooooool02oooool00ooo003oooooooooo`0hooooo`03o`000?oooooo
oooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00003ooooo`05o`000?ooooooooooooooool00000>oooool01?oo003ooooooooooooo0002oooo
o`04ool00?ooooooooooool003Wooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo000jooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0>?ooool00ooo003ooooo
ooooo`0;ooooo`03ool00?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ooo003ooooo
ooooo`0;ooooo`03ool00?oooooooooo03Sooooo00?o0000ooooooooool02oooool001?ooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000oooo
ooooooooooooo`00000gooooo`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool003Wooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooo003ooooo
00;oo`00=oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Oooooo00?oo`00oooo
ooooool03?ooool00ooo003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?oo`00oooo
ooooool03?ooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o
00002_ooool2o`0000?ooooo0ol00004ooooo`;o0000=_ooool2ool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo000iooooo`04ool00?ooooooooooool000;ooooo00Go
o`00ooooooooooooo`00ooooo`02ool003Oooooo00?o0000ooooooooool0;oooool2o`0003Sooooo
00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo
00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0fooooo`;o00003Oooool002cooooo00?o
0000ooooooooool0=_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00oooooooo003oo`00<_ooool2ool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo03Gooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0<ooooo`Koo`009?ooool00ooo003oooooooooo`0>ooooo`03ool00?oo
oooooooo01Oooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0>ooooo`03ool00?oo
oooooooo02;ooooo1_oo000>ooooo`03o`000?oooooooooo00_ooooo000/ooooo`03o`000?oooooo
oooo03Kooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooo`00ool003;ooooo0_oo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool00ooo003oooooooooo`0eooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool02_ooool2ool000Kooooo00?oo`00ooooooooool08Oooool00ooo003oooooooooo`0>
ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`0>
ooooo`03ool00?oooooooooo023ooooo0_oo0006ooooo`;oo`003?ooool00ol0003oooooooooo`0;
ooooo`00;?ooool00ol0003oooooooooo`0=ooooo`Coo`009Oooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00<oooool01?oo003ooooo
oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`008oooool2
ool00003oooooooo003oo`0000oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08
ooooo`;oo`002Oooool2ool0023ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0F
ooooo`03o`000?oooooooooo01Sooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0N
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0;
ooooo`00;?ooool2o`0000_ooooo0_oo00000oooooooo`00ool00002ool002Gooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool003?ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool002?ooooo0_oo00001?ooooooo`00ool00?ooool2ool000cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool07Ooo
ool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05ooo
ool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool02_oo
ool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo000/ooooo`03o`000?oooooo
oooo00[ooooo0_oo0002ooooo`04ool00?ooooooo`00ooooo`;oo`007_ooool2ool000;ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
03?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oo
oooooooo00?oo`007_ooool2ool000;ooooo00Goo`00ooooooooooooo`00ooooo`02ool000cooooo
00?o0000ooooooooool0;oooool2o`0000Oooooo00?oo`00ooooooooool03Oooool00ooo003ooooo
ooooo`0Kooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool05_ooool00ol0003ooooo
ooooo`0Gooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool06oooool00ooo003ooooo
ooooo`0<ooooo`03ool00?oooooooooo00Kooooo0_l0000=ooooo`00;?ooool00ol0003ooooooooo
o`07ooooo`;oo`000_ooool01ooo003ooooooooooooo003oooooool00?ooool00_oo000Nooooo`;o
o`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00
ooooooooooooo`00<oooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00?oo`00ooooooooool00ooo000Nooooo`;oo`000_ooool01?oo003ooooooooooooo0002oooo
o`04ool00?ooooooo`00ool000Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05
ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`0A
ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05oooool00ooo003oooooooooo`0A
ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`06
ooooo`03o`000?oooooooooo00_ooooo000/ooooo`03o`000?oooooooooo00Oooooo0_oo0002oooo
o`06ool00?ooooooooooool00?ooooooo`000_ooool00ooo003oooooooooo`0Mooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`03ool00?oooooooooo037ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo
0002ooooo`06ool00?ooooooooooool00?ooooooo`007oooool01?oo003ooooooooooooo0002oooo
o`05ool00?ooooooooooool00?ooool00_oo0009ooooo`03o`000?oooooooooo02Sooooo0_l00005
ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0I
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`0F
ooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`0?
ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool02oooool002cooooo0_l00005oooo
o`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00
oooooooo003oo`007?ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`0aooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooool001co
oooo0_oo00001Oooooooo`00ooooooooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003oooooool00?oo0006ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo017ooooo00?oo`00ooooooooool0
6?ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0
5_ooool00ooo003oooooooooo`0Cooooo`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool0
4Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo000Vooooo`;o00001?oo
ool00ol0003oooooooooo`04ooooo`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool0
0?ooooooo`0000;ooooo00Coo`00oooooooo003oo`007?ooool01?oo003ooooooooooooo0002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooooooo
o`0aooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003o
oooooooooooo003oooooool001cooooo0_oo00001Oooooooo`00ooooooooooooo`0000;ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003oooooool00?oo0006ooooo`03o`000?oooooooooo02Oo
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo
01?ooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool05_ooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo
01Oooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo
00_ooooo000Uooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01?oo
003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooo
oooooooo000Looooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo037ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?ooooooo`007?ooool0
1?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooo
oooo00001?ooool5o`000003ool00?l0003o000001Go000000?oo`00o`000?l000005Ol000000ooo
003o0000o`00000Do`000003ool00?l0003o000002ko000000?oo`00o`000?l000005?l000000ooo
003o0000o`00000Fo`000003ool00?l0003o000001Co000000?oo`00o`000?l000000ol0000=oooo
o`009Oooool01?l0003oooooooooool00003ooooo`Co00000_oo0002o`000004ool00?l0003o0000
ool000;o000000Koo`00o`000?l0003oo`00o`000?oo0002o`000005ool00?l0003o0000ool00?l0
00000_oo0002o`000004ool00?l0003o0000ool000;o000000Coo`00o`000?l0003oo`000_l00000
1ooo003o0000o`000?oo003o0000ool00?l000000ooo00001Ol0003oo`00o`000?l0003oo`0000;o
000000Coo`00o`000?l0003oo`000_l000001?oo003o0000o`000?oo0002o`000004ool00?l0003o
o`00ool000;o000000?oo`00o`000?oo00000_l000001?oo003o0000o`000?oo0002o`000004ool0
0?l0003o0000ool000;o000000Coo`00o`000?l0003oo`000_l000001?oo003o0000o`000?oo0002
o`000003ool00?l0003oo`0000;o000000Coo`00o`000?l0003oo`000_l000001?oo003o0000ool0
0?oo0002o`000004ool00?l0003o0000ool000;o000000Coo`00o`000?l0003oo`000_l000001ooo
003o0000o`000?oo003o0000ool00?l000000ooo00001Ol0003oo`00o`000?l0003oo`0000;o0000
00Coo`00o`000?l0003oo`000_l000001?oo003o0000o`000?oo0002o`000006ool00?l0003oo`00
ool00?l0003oo`000_l000001?oo003o0000o`000?oo0002o`000004ool00?l0003o0000ool000;o
000000Goo`00o`000?l0003oo`00o`000002ool000Co0000:Oooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0F
ooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`0F
ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool06_ooool00ol0003oooooooooo`0;
ooooo`009Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`;oo`005Ooo
ool2ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`07
ool00?ooooooooooool00?ooooooo`00ooooo`02ool001Kooooo0_oo0002ooooo`03ool00?oooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo003oo`005Oooool2ool000;ooooo00Co
o`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00oooooooo003oo`005Oooool2ool000?ooooo00?o0000ooooooooool09oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo01_ooooo00?oo`00ooooooooool04ooo
ool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool05Ooo
ool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01?ooooo00?oo`00ooooooooool06ooo
ool00ol0003oooooooooo`0;ooooo`009Oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo01cooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06
ool00?ooooooooooool00?ooooooo`007Oooool00ooo003oooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002
ooooo`03ool00?oooooooooo01[ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool06oooool00ol0003o
ooooooooo`0Xooooo`;o00001Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo017o
oooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo01Go
oooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Aooooo`03ool00?oooooooooo01co
oooo00?o0000ooooooooool02oooool002Gooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`0Looooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1_oo003ooooooooooooo003oooooool001gooooo00?oo`00oooooooo00000_ooool01?oo003ooooo
oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`00
0_ooool00ooo003oooooooooo`0Jooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo01_ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0Mooooo`03ool00?oooooooooo013ooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?oo`00
ooooooooool05oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo01gooooo00?o0000
ooooooooool02oooool002Kooooo0_l00004ooooo`;o00007?ooool2ool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0001gooooo00?o
o`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooo
o`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`0Jooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooo003ooooo
00;oo`007Oooool00ol0003oooooooooo`0_ooooo`;o00007oooool00ooo003oooooooooo`0>oooo
o`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0Eoooo
o`03ool00?oooooooooo01Sooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Loooo
o`;o00003Oooool002cooooo00?o0000ooooooooool06oooool2ool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0001gooooo00?oo`00
oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`00
00;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`0Jooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooooooo003ooooo00;o
o`007Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01kooooo00?oo`00oooooooo
ool03_ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo01?ooooo00?o0000oooooooo
ool05?ooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo
ool07_ooool00ol0003oooooooooo`0;ooooo`00;?ooool00ol0003oooooooooo`0Oooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003oooooool00?oo000L
ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool06Oooool2
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool0
0?oooooooooo01kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Oooooo`03ool0
0?oooooooooo00cooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Cooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0<ooooo`03ool0
0?oooooooooo01oooooo00?o0000ooooooooool02oooool002cooooo00?o0000ooooooooool07ooo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
003oo`007?ooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00
ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo
01Wooooo0_oo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooooooo`0Nooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08?oo
ool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool04ooo
ool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool02_oo
ool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo000/ooooo`;o00007oooool2
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo000Oooooo`03ool0
0?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool0
0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool07Oooool01?oo003ooooo
oooooooo0002ooooo`05ool00?ooooooooooool00?ooool00_oo000Pooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo
01cooooo00?oo`00ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo
01cooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Qooooo`03o`000?oooooooooo
00_ooooo000/ooooo`03o`000?oooooooooo01kooooo0_oo0002ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`007oooool00ooo003oooooool00002ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002
ooooo`03ool00?oooooooooo01gooooo00Coo`00ooooooooooooo`000_ooool01Ooo003ooooooooo
oooo003ooooo00;oo`008?ooool00ol0003oooooooooo`0_ooooo`;o00008oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo01kooooo00?oo`00ooooooooool04_ooool00ol0003ooooo
ooooo`0Dooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool01oooool00ooo003ooooo
ooooo`0Pooooo`;o00003Oooool002cooooo00?o0000ooooooooool08_ooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooo`00ool001oooooo00?oo`00oooooooo00000_ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`0Looooo`;oo`000_ooool01?oo003ooooooooooooo0002oooo
o`03ool00?oooooooooo027ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Soooo
o`;oo`001Oooool00ooo003oooooooooo`0Oooooo`03ool00?oooooooooo01;ooooo00?o0000oooo
ooooool04oooool00ooo003oooooooooo`0Oooooo`;oo`001?ooool3ool002Cooooo00?o0000oooo
ooooool02oooool002cooooo00?o0000ooooooooool08Oooool2ool000;ooooo00Goo`00oooooooo
ooooo`00ooooo`02ool001oooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo
003oooooooooo`0Looooo`;oo`000_ooool01Ooo003ooooooooooooo003ooooo00;oo`008oooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Cooooo1_oo000Rooooo`03ool00?oooooo
oooo01;ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Pooooo`Goo`009oooool0
0ol0003oooooooooo`0;ooooo`00;?ooool2o`0002;ooooo0_oo00001?ooooooo`00ool00?ooool2
ool002;ooooo00?oo`00oooooooo00000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`0O
ooooo`;oo`0000Coooooool00?oo003ooooo0_oo000Sooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0C?ooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o
o`00ooooooooool0C?ooool00ol0003oooooooooo`0;ooooo`005?ooool2o`0000Cooooo00?o0000
ooooooooool00oooool2o`0000;ooooo1Ol00003ooooo`03o`000?oooooooooo02Cooooo0_oo0000
0oooooooo`00ool0000Rooooo`03ool00?ooooooo`0000;ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000_ooool00ooo003oooooool00002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00
ooooooooool07oooool2ool00003oooooooo003oo`0002Kooooo00?o0000ooooooooool0;oooool2
o`0004gooooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooo
oooo04_ooooo0_l0000=ooooo`004oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1:ooooo`;oo`00
00Goooooool00?ooooooooooool00002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?oooooo
o`000_ooool01Ooo003ooooooooooooo003ooooo00;oo`00C?ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo04gooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0Coooo
o`03ool00?oooooooooo04cooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0B_ooool2ool00005oooooooo003ooooooooooooo00000_ooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo
003ooooooooooooo003oooooool000;ooooo00Goo`00ooooooooooooo`00ooooo`02ool004cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1=ooooo`03ool00?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo00_ooooo
000Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`02ooooo`;o0000C_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool0
0?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo001>ooooo`;o00007_ooool2
o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo04gooooo00?o
o`00ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo04gooooo00?o
0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002?ooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Go0000ooooooooooooooooo`00001?ooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`04ool00?oooooo
ooooool004oooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0;ooooo`00
4oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
1Ol0003ooooooooooooooooo000004oooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1_oo003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`00Coooool00ol0003o
ooooooooo`0Kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`00
04kooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo
04cooooo0_l0000=ooooo`005?ooool2o`0000[ooooo0_l00003ooooo`?o00001?ooool2o`0004ko
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003oooooool0
00;ooooo00Coo`00ooooooooooooo`00Coooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1>ooooo`03ool00?oo
oooooooo013ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`1=ooooo`03o`000?oo
oooooooo00_ooooo000/ooooo`03o`000?oooooooooo04gooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01_oo003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`00
Coooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool04?ooool00ol0
003oooooooooo`0Booooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool02oooool002co
oooo00?o0000ooooooooool0COooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool0
0?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo001?ooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0C_ooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo
00?oo`00ooooooooool0C_ooool00ol0003oooooooooo`0;ooooo`00;?ooool00ol0003ooooooooo
o`1=ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00oooo
oooo0002ooooo`04ool00?ooooooooooool004oooooo00?o0000ooooooooool07?ooool2o`0000Wo
oooo0ol00005ooooo`03o`000?oooooooooo04kooooo00?oo`00ooooooooool04?ooool00ol0003o
ooooooooo`0Aooooo`03ool00?oooooooooo04kooooo00?o0000ooooooooool02oooool002cooooo
0_l0001>ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00
oooooooo0002ooooo`04ool00?ooooooooooool004oooooo00?o0000ooooooooool0;oooool2o`00
04oooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo
04gooooo0_l0000=ooooo`00;?ooool00ol0003oooooooooo`1=ooooo`04ool00?ooooooooooool0
00;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`04ool00?oooooooooo
ool004oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1?ooooo`03ool00?oooooo
oooo00oooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`1>ooooo`03o`000?oooooo
oooo00_ooooo000/ooooo`03o`000?oooooooooo04gooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooooooo
o`000_ooool01_oo003ooooooooooooo003oooooool000;ooooo00Coo`00ooooooooooooo`00Cooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04oooooo00?oo`00ooooooooool03ooo
ool00ol0003oooooooooo`0Aooooo`03ool00?oooooooooo04kooooo00?o0000ooooooooool02ooo
ool002cooooo00?o0000ooooooooool0COooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`06ool00?ooooooooooool00?ooooooo`000_ooool01?oo003ooooooooooooo001?ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0Coooool00ooo003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?oo`00ooooooooool0Coooool00ol0003oooooooooo`0;ooooo`00;?oo
ool2o`0004kooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo
003oooooool000;ooooo00Coo`00ooooooooooooo`00Coooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo04oooooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
ool00?oooooooooo04oooooo00?o0000ooooooooool02oooool001Cooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`?o00000oooool00ol0003oooooooooo`1=ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00oooooooo0002ooooo`04
ool00?ooooooooooool004oooooo00?o0000ooooooooool0;oooool2o`00053ooooo00?oo`00oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo04kooooo0_l0000=oooo
o`004oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1<ooooo`;oo`000_ooool01?oo003ooooooooooooo
0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00Coo`00oooooooo003oo`00Coooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo053ooooo00?oo`00ooooooooool03_ooool0
0ol0003oooooooooo`0@ooooo`03ool00?oooooooooo04oooooo00?o0000ooooooooool02oooool0
01?ooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Go00000ooo
ool00ol0003oooooooooo`1<ooooo`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002
ooooo`03ool00?ooooooo`0000;ooooo00Coo`00oooooooo003oo`00Coooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo053ooooo00?oo`00ooooooooool03_ooool00ol0003ooooooooo
o`0@ooooo`03ool00?oooooooooo04oooooo00?o0000ooooooooool02oooool001?ooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000oooooooo
ool00_ooool2o`00057ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ool00002ooooo`03ool00?oooooooooo04oooooo0_l0000aooooo`03o`000?oooooooooo053ooooo
00?oo`00ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo053ooooo
00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0D?ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool0
D?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo053ooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool0
2oooool001?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`;o
00001?ooool00ol0003oooooooooo`1@ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00?oo`00oooooooo00000_ooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02oooooo
0_l0001Aooooo`03ool00?oooooooooo00kooooo00?o0000ooooooooool03oooool00ooo003ooooo
ooooo`1?ooooo`;o00003Oooool001Cooooo0_l0000:ooooo`;o00001Oooool00ol0003ooooooooo
o`02ooooo`;o0000DOooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo057ooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooo
oooo053ooooo00?o0000ooooooooool02oooool002cooooo00?o0000ooooooooool0D?ooool01?oo
003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00oooooooo
ool0D?ooool00ol0003oooooooooo`0Looooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o
00001?ooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo00gooooo00?o0000oooooooo
ool03oooool00ooo003oooooooooo`1@ooooo`03o`000?oooooooooo00_ooooo000/ooooo`03o`00
0?oooooooooo053ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002oooo
o`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool0
0002ooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool06oooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0DOooool00ooo003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0DOooool00ol0003ooooo
ooooo`0;ooooo`00;?ooool00ol0003oooooooooo`1@ooooo`04ool00?ooooooooooool000;ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oooooooooo
ool000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`1@ooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo00?o0000ooooooooool0DOoo
ool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0DOoo
ool00ol0003oooooooooo`0;ooooo`00;?ooool2o`00057ooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000_ooool00ooo003oooooool00002ooooo`03ool00?oooooooooo053ooooo00?o0000oooo
ooooool06oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo0_l0
001Booooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ooo003ooooooooo
o`1@ooooo`;o00003Oooool002cooooo00?o0000ooooooooool0D?ooool01?oo003ooooooooooooo
0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`03ool00?ooooooo`0000;ooooo00?oo`00ooooooooool0D?ooool00ol0
003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`1Booooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03_ooool0
0ooo003oooooooooo`1Aooooo`03o`000?oooooooooo00_ooooo000/ooooo`03o`000?oooooooooo
053ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooool00002ooooo`03
ool00?oooooooooo053ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00009oooo
o`;o00001Oooool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo00cooooo00?o0000oooo
ooooool03_ooool00ooo003oooooooooo`1Aooooo`03o`000?oooooooooo00_ooooo000/ooooo`03
o`000?oooooooooo053ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ool00002ooooo`03ool00?oooooooooo053ooooo00?o0000ooooooooool07?ooool2o`0000_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Booooo`03ool00?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ooo003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo
000/ooooo`;o0000DOooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooo
o`0000;ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo05;ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooo
oooo05;ooooo00?o0000ooooooooool02oooool001Cooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0_l00003ooooo`?o00001?ooool00ol0003oooooooooo`1@ooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool00ooo003oooooooooo`1@ooooo`03
o`000?oooooooooo02oooooo0_l0001Cooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ooo003oooooooooo`1Aooooo`;o00003Oooool001?ooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00Go0000ooooooooooooooooo`00
001Booooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00oooooooo00000_ooool0
0ooo003oooooooooo`1@ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Doooool0
0ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0D_ooool0
0ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00008ooooo`06o`000?oooooo
ooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo0000057ooooo0_oo0002ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo
0002ooooo`07ool00?ooooooooooool00?ooooooo`00ooooo`02ool005;ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo00_ooooo00?o0000oooooooo
ool03Oooool00ooo003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Cooooo0_l0001@oooo
o`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Co
o`00ooooooooooooo`000_ooool01ooo003ooooooooooooo003oooooool00?ooool00_oo001Aoooo
o`;o0000<Oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo000Cooooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00007ooooo`03o`000?oo
oooooooo05?ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00oooooooo001Eooooo`03o`000?oo
oooooooo02oooooo0_l0001Dooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ooo003oooooooooo`1Booooo`;o00003Oooool001?ooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Doooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01_oo003ooooooooooooo003oooooool005Gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00002_oo
ool2o`0000Cooooo0_l00004ooooo`03o`000?oooooooooo05?ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00oooo
ooooooooo`00oooooooo001Eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0E?oo
ool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0Dooo
ool00ol0003oooooooooo`0;ooooo`00;?ooool2o`0005Cooooo00Coo`00ooooooooooooo`000_oo
ool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00oooooooo
ooooo`00oooooooo001Eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0E?ooool0
0ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0Doooool0
0ol0003oooooooooo`0;ooooo`00;?ooool00ol0003oooooooooo`1Cooooo`04ool00?oooooooooo
ool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool0
0?ooooooooooool00?ooooooo`00EOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
05Cooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo
05Cooooo00?o0000ooooooooool02oooool002cooooo00?o0000ooooooooool0Doooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_oo
ool01_oo003ooooooooooooo003oooooool005Gooooo00?o0000ooooooooool0;oooool2o`0005Go
oooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05?o
oooo0_l0000=ooooo`00;?ooool2o`0005Cooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00oooo
oooo001Eooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0E?ooool00ooo003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0E?ooool00ol0003ooooo
ooooo`0;ooooo`00;?ooool00ol0003oooooooooo`1Cooooo`04ool00?ooooooooooool000;ooooo
00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool00?oooooooooo
ool00?ooooooo`00EOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05Cooooo00?o
o`00ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo05Cooooo00?o
0000ooooooooool02oooool002cooooo00?o0000ooooooooool0Doooool01?oo003ooooooooooooo
0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003o
oooooooooooo003oooooool005Gooooo00?o0000ooooooooool07?ooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0EOooool00ooo003oooooooooo`09
ooooo`03o`000?oooooooooo00_ooooo00?oo`00ooooooooool0E?ooool00ol0003oooooooooo`0;
ooooo`00;?ooool00ol0003oooooooooo`1Cooooo`04ool00?ooooooooooool000;ooooo00Coo`00
ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?oo
ooooo`00EOooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05Gooooo00?oo`00ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool02ooo
ool002cooooo0_l0001Dooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`00
0_ooool01?oo003ooooooooooooo0002ooooo`06ool00?ooooooooooool00?ooooooo`00EOooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000004ooooo`;o0000E_ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?oo`00ooooooooool0E?ooool2o`0000gooooo000Dooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`;o00000oooool3o`0000Cooooo00?o0000ooooooooool0Doooool01?oo003ooooooooo
oooo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo
003ooooooooooooo003oooooool005Gooooo00?o0000ooooooooool06oooool01?l0003ooooooooo
ool00007ooooo`Co00001Oooool00ol0003oooooooooo`1Eooooo`03ool00?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo00_ooooo
000Cooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003oooo
o`05o`000?ooooooooooooooool00000EOooool01?oo003ooooooooooooo0002ooooo`04ool00?oo
ooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01_oo003ooooooooooooo003ooooo
ool005Gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0EOooool00ooo003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0;ooooo`004oooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01Ol0003o
oooooooooooooooo000005Gooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo
0002ooooo`04ool00?ooooooooooool000;ooooo00Koo`00ooooooooooooo`00oooooooo001Eoooo
o`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00002ooooo`?o00001?ooool2o`0005?ooooo0_oo
0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooo`00ool005?ooooo0_l0000Nooooo`;o00002_ooool2
o`0000Gooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?oo`00ooooooooool0E_ooool00ol0003oooooooooo`0;ooooo`004oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01Ol0003ooooo
oooooooooooo000005Cooooo0_oo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooo
ooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooo`00ool005Cooooo
00?o0000ooooooooool0;oooool2o`0005Oooooo00?oo`00ooooooooool02?ooool00ol0003ooooo
ooooo`09ooooo`03ool00?oooooooooo05Gooooo0_l0000=ooooo`004oooool01?l0003ooooooooo
ool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01Ol0003ooooooooooooooooo
000005Sooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooooooool000;ooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo05Kooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
ool00?oooooooooo05Kooooo00?o0000ooooooooool02oooool001Cooooo0_l0000:ooooo`;o0000
0oooool3o`0000Cooooo00?o0000ooooooooool0E_ooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1E
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0E_ooool00ol0003oooooooooo`0;
ooooo`00;?ooool2o`0005Oooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo
0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0EOooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo05Oooooo00?oo`00ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03ool00?oooooooooo05Kooooo00?o0000ooooooooool02oooool002cooooo00?o
0000ooooooooool0E_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;o
oooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0Eoooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?oo`00ooooooooool0Eoooool00ol0003oooooooooo`0;ooooo`00;?ooool00ol0003o
ooooooooo`1Fooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0;ooo
ool2o`0005Sooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`08ooooo`03ool00?oo
oooooooo05Kooooo0_l0000=ooooo`00;?ooool00ol0003oooooooooo`1Fooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03
ool00?oooooooooo05Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Gooooo`03
ool00?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`1Gooooo`03
o`000?oooooooooo00_ooooo000/ooooo`;o0000Eoooool01?oo003ooooooooooooo0002ooooo`04
ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1E
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Eoooool00ooo003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0Eoooool00ol0003oooooooooo`0;
ooooo`00;?ooool00ol0003oooooooooo`1Fooooo`04ool00?ooooooooooool000;ooooo00Coo`00
ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo05Gooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Hooooo`03ool00?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool00ooo003oooooooooo`1Gooooo`03o`000?oooooooooo00_ooooo
000/ooooo`03o`000?oooooooooo05Kooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
oooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0EOooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo05Sooooo00?oo`00ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03ool00?oooooooooo05Sooooo00?o0000ooooooooool02oooool002co
oooo0_l0001Gooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool0
1?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0;ooo
ool2o`0005Wooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03ool00?oo
oooooooo05Oooooo0_l0000=ooooo`00;?ooool00ol0003oooooooooo`1Fooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03
ool00?oooooooooo05Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Hooooo`03
ool00?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1Hooooo`03
o`000?oooooooooo00_ooooo000Jooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1?ooool00ol0003oooooooooo`1Fooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
ooooo`000_ooool01?oo003ooooooooooooo0002ooooo`03ool00?oooooooooo05Gooooo00?o0000
ooooooooool07?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool0FOooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?oo`00
ooooooooool0F?ooool00ol0003oooooooooo`0;ooooo`006Oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0EOooool2ool000;ooooo00Coo`00
ooooooooooooo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooo`00ool005Oo
oooo00?o0000ooooooooool06oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ooo003oooooooooo`1Hooooo`03o`000?oooooooooo00_ooooo000Ioooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool2o`0005Kooooo0_oo0002
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool01?oo003ooooo
ool00?oo001Fooooo`;o00007Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Ioooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1I
ooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003ooooo
ooooo`1Hooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool3o`0000Go
oooo0_l0001Jooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`1Hooooo`;o00003Oooool001Wooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo05Wooooo00Coo`00ooooooooooooo`000_ooool01?oo
003ooooooooooooo0002ooooo`03ool00?oooooooooo05Sooooo00?o0000ooooooooool06oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ooo003ooooo
ooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Iooooo`04o`000?ooooooooooo`0000Sooooo
0_l00005ooooo`03o`000?oooooooooo05Wooooo00Coo`00ooooooooooooo`000_ooool01?oo003o
oooooooooooo0002ooooo`03ool00?oooooooooo05Sooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`1Jooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ooo003ooooooooo
o`1Iooooo`03o`000?oooooooooo00_ooooo000Jooooo`;o00002_ooool00ol0003oooooooooo`03
ooooo`;o0000F_ooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo
00?oo`00ooooooooool0F?ooool00ol0003oooooooooo`0Looooo`;o00002Oooool3o`0000Gooooo
00?o0000ooooooooool0F_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo
00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0;ooooo`00;?ooool00ol0003ooooooooo
o`1Iooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003o
ooooooooo`1Hooooo`03o`000?oooooooooo02oooooo0_l0001Kooooo`03ool00?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1Iooooo`;o00003Oooool002cooooo
00?o0000ooooooooool0FOooool01?oo003ooooooooooooo0002ooooo`04ool00?ooooooooooool0
00;ooooo00?oo`00ooooooooool0F?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
05[ooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
05[ooooo00?o0000ooooooooool02oooool002cooooo00?o0000ooooooooool0FOooool01?oo003o
oooooooooooo0002ooooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0F?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo05[ooooo00?o0000ooooooooool02oooool0
02cooooo0_l0001Jooooo`04ool00?ooooooooooool000;ooooo00Coo`00ooooooooooooo`000_oo
ool00ooo003oooooooooo`1Hooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Fooo
ool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0Fooo
ool00ol0003oooooooooo`0;ooooo`00;?ooool00ol0003oooooooooo`1Iooooo`04ool00?oooooo
ooooool000;ooooo00Coo`00ooooooooooooo`000_ooool00ooo003oooooooooo`1Hooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0Foooool00ooo003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0;ooooo`00;?oo
ool00ol0003oooooooooo`1Hooooo`;oo`000_ooool01?oo003ooooooooooooo0002ooooo`04ool0
0?ooooooo`00ool005[ooooo00?o0000ooooooooool0;oooool2o`0005gooooo00?oo`00oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05[ooooo0_l0000=ooooo`00
;?ooool2o`0005Wooooo0_oo0002ooooo`04ool00?ooooooooooool000;ooooo00Coo`00oooooooo
003oo`00F_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05cooooo00?oo`00oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05cooooo00?o0000oooo
ooooool02oooool002cooooo00?o0000ooooooooool0G?ooool01?oo003ooooooooooooo0002oooo
o`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Loooo
o`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Loooo
o`03o`000?oooooooooo00_ooooo000Dooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o
00000_ooool5o`0000?ooooo00?o0000ooooooooool0G?ooool01?oo003ooooooooooooo0002oooo
o`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Loooo
o`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Loooo
o`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo05cooooo00Coo`00
ooooooooooooo`000_ooool00ooo003oooooooooo`1Kooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0GOooool01Ooo003ooooooooooooooooo000000Cooooo00?oo`00ooooooooool0
GOooool00ol0003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0005gooooo00Coo`00oooooooooooo
o`000_ooool00ooo003oooooooooo`1Jooooo`;o0000<Oooool2o`0005kooooo00Goo`00oooooooo
ooooooooo`000004ooooo`03ool00?oooooooooo05cooooo0_l0000=ooooo`004oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Looooo`04ool00?ooooooooooool000;ooooo00?oo`00ooooooooool0Foooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05gooooo00Goo`00ooooooooooooooooo`00
0004ooooo`03ool00?oooooooooo05gooooo00?o0000ooooooooool02oooool001?ooooo00Co0000
oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`00001Mooooo`;oo`000_ooool01?oo003oooooool00?oo001Mooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0G_ooool01?oo003oooooooooool00003ooooo`03ool00?oooooo
oooo05kooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002?ooool2
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo05_ooooo0_oo
0002ooooo`04ool00?ooooooo`00ool005gooooo00?o0000ooooooooool09oooool3o`0000Gooooo
00?o0000ooooooooool0Goooool00ooo003oooooo`000003ooooo`03ool00?oooooooooo05kooooo
00?o0000ooooooooool02oooool001Cooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`;o0000Goooool2ool0063ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo063ooooo00?oo`00o`000?ooool00_oo001Qooooo`03o`000?oo
oooooooo00_ooooo000/ooooo`03o`000?oooooooooo05kooooo0_oo001Pooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool01?ooool2o`00067ooooo1?oo001Qooooo`;o00003Oooool0
02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool00000:_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0;ooooo`00;?ooooo4o`0002[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`00oooooolJooooo`;o00001_ooooo:o`0000go
oooo003ooooooa_ooooo00?o0000ooooooooool0foooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool0
0?oooooonOooool002gooooo0ol0000[ooooo`Go0000:_ooool2o`0002cooooo1Ol0000]ooooo`?o
0000ooooool<ooooo`00;_ooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002Wo
oooo00Co0000oooooooooooo0000;?ooool01?l0003oooooooooool0000^ooooo`03o`000?oooooo
oooo0?oooooo2oooool002Gooooo1Ol000000ooooooo0000o`000003o`0002Gooooo1Ol00003oooo
o`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo0000;Oooool00ol0003oooooooooo`0[
ooooo`Go0000@?ooool3o`0002[ooooo1Ol0000Xooooo`;o0000:oooool5o`0002_ooooo0ol0000A
ooooo`00:oooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo02Sooooo00Co0000
oooooooooooo0000;_ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0004;ooooo
00?o0000ooooooooool0:_ooool01?l0003oooooooooool0000Wooooo`04o`000?ooooooooooo`00
02_ooooo00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0@ooooo`00;?ooool00ol0
003oooooo`00000/ooooo`05o`000?ooooooooooooooool00000:Oooool01?l0003oooooooooool0
000[ooooo`05o`000?ooooooooooooooool00000;?ooool00ol0003oooooo`00000iooooo`Go0000
00?oooooo`000?l000000ol0000Tooooo`Go00000oooool00ol0003oooooooooo`0Wooooo`04o`00
0?ooooooooooo`0002cooooo00?o0000ooooooooool0:Oooool5o`00017ooooo000]ooooo`;o0000
;?ooool01Ol0003ooooooooooooooooo000002Wooooo00Co0000oooooooooooo0000:oooool01Ol0
003ooooooooooooooooo000002gooooo0_l0000oooooo`04o`000?ooooooooooo`0002kooooo00?o
0000ooooooooool09_ooool01?l0003oooooooooool0000]ooooo`03o`000?oooooooooo02Sooooo
00Co0000oooooooooooo00004_ooool002kooooo00?o0000ooooooooool0:oooool3o`0002_ooooo
0_l0000]ooooo`?o0000;oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo000002_ooooo
00Go0000ooooooooooooooooo`00000Wooooo`04o`000?ooooooooooo`0002[ooooo00Go0000oooo
ooooooooooooo`00000Zooooo`03o`000?oooooo000001;ooooo003oooooobkooooo0_l0000[oooo
o`05o`000?ooooooooooooooool000009oooool01?l0003oooooooooool0000Zooooo`05o`000?oo
ooooooooooooool00000:oooool2o`0001;ooooo003ooooooboooooo00?o0000ooooooooool0:_oo
ool3o`0002Wooooo0_l0000/ooooo`?o0000;Oooool00ol0003oooooooooo`0@ooooo`00oooooooi
ooooo`00oooooooiooooo`009_ooooo:o`000?oooooo2Oooool001Cooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
;Oooool01Ol0003ooooooooooooooooo000003Ooooooa?l0000=ooooo`004oooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool3ool004Go
oooo0ooo000nooooo`03o`000?oooooooooo03Gooooo0_l00002ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooooooo0_l0000=ooooo`003?ooool5o`0000;ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo0ooo0015oooo
o`?oo`00?_ooool00ol0003oooooooooo`0Looooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool3o`0000Gooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`03ooooo`?o0000?Oooool3ool004Gooooo0ooo000mooooo`;o00007Oooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03_ooooo0_oo0013ooooo`;oo`00?_ooool00ol0003o
ooooooooo`0;ooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0?_ooool00ooo003oooooooooo`15ooooo`03ool00?oooooooooo03go
oooo00?o0000ooooooooool05?ooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00;ooooo0_l0000looooo`;oo`00@oooool2
ool003gooooo0_l0000=ooooo`004oooool01?l0003oooooooooool00008ooooo`;o00001Oooool0
0ol0003oooooooooo`0nooooo`03ool00?oooooooooo04Gooooo00?oo`00ooooooooool0?Oooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03cooooo00?oo`00ooooooooool0
@_ooool00ooo003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool0AOoo
ool00ooo003oooooooooo`0mooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000
2?ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`0looooo`04
ool00?ooooooooooooooo`;oo`00>Oooool2ool000Cooooo00?oo`00ooooooooool0??ooool00ol0
003oooooooooo`0;ooooo`009_ooool2o`0003oooooo00?oo`00ooooooooool0AOooool00ooo003o
ooooooooo`0mooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool01_l0
003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0??ooool01?oo003ooooooooo
ooooool2ool003Wooooo0_oo0004ooooo`03ool00?oooooooooo03cooooo00?o0000ooooooooool0
2oooool002Kooooo00?o0000ooooooooool0?_ooool00ooo003oooooooooo`15ooooo`03ool00?oo
oooooooo03gooooo00?o0000ooooooooool07?ooool2o`0000[ooooo0_l00002ooooo`Go00001?oo
ool2o`0003gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0gooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool0>oooool2o`0000gooooo000Vooooo`03o`000?oooooo
oooo03kooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`0mooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0??ooool00ooo003oooooooooo`02ooooo`03ool00?oooooo
oooo03Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0looooo`03o`000?oooooo
oooo00_ooooo000Vooooo`03o`000?oooooooooo03kooooo00?oo`00ooooooooool0AOooool00ooo
003oooooooooo`0mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0??ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo000Vooooo`;o0000?oooool00ooo003o
ooooooooo`15ooooo`03ool00?oooooooooo03gooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0eooooo`;oo`001Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03Oo
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`;oo`00>?ooool00ol0003o
ooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0=ooooo`?oo`00;_ooool00ooo003ooooo
ooooo`15ooooo`03ool00?oooooooooo02cooooo0ooo000>ooooo`03o`000?oooooooooo03Gooooo
0_l0000fooooo`;oo`001Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo03Oooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`;oo`00=oooool2o`0000gooooo
000Vooooo`03o`000?oooooooooo00gooooo0ooo000^ooooo`03ool00?oooooooooo04Gooooo00?o
o`00ooooooooool0;?ooool3ool000kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0fooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0gooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0fooooo`03o`000?oooooooooo00_ooooo000Vooooo`;o00003_ooool3ool002kooooo00?oo`00
ooooooooool0AOooool00ooo003oooooooooo`0/ooooo`?oo`003_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo03Kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo03Kooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooo
ooooool03_ooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo04Gooooo00?oo`00oooo
ooooool0;Oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool03?ooool2ool002Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo02Gooooo0_oo000?ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03
o`000?oooooooooo00kooooo00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`15ooooo`03
ool00?oooooooooo02gooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0eooooo`;o
00003Oooool2ool002Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03
ool00?oooooooooo03Oooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo02Gooooo0_oo000>ooooo`;o00003Oooool002Kooooo00?o0000ooooooooool0
3_ooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo04Gooooo00?oo`00ooooooooool0
;Oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
3Oooool00ooo003oooooooooo`02ooooo`;oo`008_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool0=oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool07oooool2ool000Gooooo00?oo`00ooooooooool0
3Oooool00ol0003oooooooooo`0;ooooo`009_ooool2o`0000oooooo00?oo`00ooooooooool0;Ooo
ool00ooo003oooooooooo`15ooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool03Ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo0_oo0005ooooo`03ool00?oo
oooooooo00;ooooo0_oo000Rooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_oo
ool00ooo003oooooooooo`0gooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`0Oooooo`;oo`001Oooool00ooo003oooooooooo`02ooooo`;oo`002Ooo
ool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooo
oooo02gooooo00?oo`00ooooooooool0AOooool00ooo003oooooooooo`0]ooooo`03ool00?oooooo
oooo00gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`;oo`001Oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo03Oooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`02ooooo`;oo`002Oooool00ol0003oooooooooo`0;ooooo`008?ooool2o`00
00Cooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo
04Gooooo00?oo`00ooooooooool0;Oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo
03Gooooo0_l00008ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0Pooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`0gooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`0Pooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`06ooooo`;o00003Oooool001oooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooooooool3ool000[ooooo00?oo`00ooooooooool02?ooool3ool001Gooooo0ooo000:
ooooo`03ool00?oooooooooo00Sooooo0ooo000]ooooo`?oo`002_ooool00ooo003oooooooooo`08
ooooo`?oo`005Oooool3ool000[ooooo00?oo`00ooooooooool02?ooool3ool000;ooooo00?o0000
ooooooooool0;_ooool2o`0000Gooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0=oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0;
ooooo`007oooool01?l0003oooooooooool00003ooooo`Co00000ooo000:o`000003ool00?l0003o
000000So00000ooo000:o`000003ool00?l0003o000000So00000ooo000:o`000003ool00?l0003o
000000So00000ooo000:o`000003ool00?l0003o000000Wo000000?oo`00o`000?l000002Ol00000
0ooo003o0000o`000008o`0000?oo`002_l000000ooo003o0000o`000008o`0000?oo`002_l00000
0ooo003o0000o`000008o`0000?oo`002_l000000ooo003o0000o`000008o`0000?oo`000ol0000_
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0=oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool01oooool00ol0003ooooooooo
o`0;ooooo`007oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?oo`00
5Oooool3ool000[ooooo00?oo`00ooooooooool02?ooool3ool001Gooooo0ooo000:ooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`08ooooo`?oo`00
5Oooool3ool000[ooooo00?oo`00ooooooooool02?ooool3ool001Gooooo0ooo0002ooooo`03o`00
0?oooooooooo02gooooo00Co0000oooooooooooo00001?ooool4o`0000;oo`001?l000000ooo003o
0000o`000003o`000003ool00?l0003o000000?o000000?oo`00o`000?l000000_l00002ool000Go
000000?oo`00o`000?l000000_l000000ooo003o0000o`000003o`000003ool00?l0003o000000;o
00000_oo0005o`000003ool00?l0003o000000?o000000?oo`00o`000?l000000_l000000ooo003o
0000o`000002o`0000;oo`001Ol000000ooo003o0000o`000003o`000003ool00?l0003o000000?o
000000?oo`00o`000?l000000_l000000ooo003o0000o`000003o`000003ool00?l0003o000000?o
000000?oo`00o`000?l000000ol000000ooo003o0000o`000002o`0000;oo`001?l000000ooo003o
0000o`000003o`000003ool00?l0003o000000?o000000?oo`00o`000?l000000_l00002ool000Go
000000?oo`00o`000?l000000ol000000ooo003o0000o`000002o`000003ool00?l0003o000000;o
00000_oo0005o`000003ool00?l0003o000000?o000000?oo`00o`000?l000000ol000001?oo003o
0000o`000?l00003ool000Co00003Oooool001oooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`0Vooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo02gooooo00?oo`00ooooooooool09Oooool00ol0
003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0_oo
000Eooooo`;oo`001Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00_ooool2ool001Gooooo0_oo0005ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo0_oo
000Eooooo`;oo`001Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00_ooool2ool001Gooooo0_oo0004ooooo`03o`000?oooooooooo00_ooooo000O
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool09_ooool00ooo003ooooooooo
o`0]ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`0]ooooo`03ool00?oooooooooo02Gooooo00?o0000ooooooooool0;Oooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo01oooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool07oooool00ol0003ooooo
ooooo`0;ooooo`008?ooool2o`0000Cooooo0_l0000Wooooo`03ool00?oooooooooo02gooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02gooooo00?o
o`00ooooooooool09Oooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool07oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool08?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo
000Vooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0;Oooool00ooo003ooooooooo
o`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0;Oooool00ooo003ooooooooo
o`0Uooooo`03o`000?oooooooooo02kooooo0_l00005ooooo`;o00008?ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`0Pooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0Nooooo`;o00003Oooool002Kooooo00?o0000ooooooooool09_ooool00ooo003oooooooooo`0]
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0]
ooooo`03ool00?oooooooooo02Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0O
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0P
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo023ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo01oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooo
ooooool09_ooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`0]ooooo`03ool00?oooooooooo02Gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0Pooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo023ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01oooooo00?o0000oooo
ooooool02oooool002Kooooo0_l0000Wooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02gooooo00?oo`00oooooooo
ool09Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01oooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo023ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool08?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool07oooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`0Vooooo`03ool0
0?oooooooooo02gooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo02gooooo00?oo`00ooooooooool09Oooool00ol0003oooooooooo`0eooooo`;o0000
7oooool2ool000Cooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Pooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo023ooooo00?oo`00ooooooooool00oooool01?oo003oooooooooooooool2ool0023o
oooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`0Vooooo`03ool00?oooooooooo02gooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02gooooo
00?oo`00ooooooooool09Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01kooooo
0_oo0004ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool08?ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0Pooooo`03ool00?oooooooooo00?ooooo00Coo`00oooooooooooooooo0_oo000Qooooo`03
o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo02Kooooo00?oo`00ooooooooool0
;Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0
;Oooool00ooo003oooooooooo`0Uooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
9?ooool00ooo003oooooooooo`02ooooo`;oo`008_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Oooooo`;oo`00
1Oooool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo000Vooooo`;o00009_oo
ool3ool002kooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo02cooooo0ooo000Vooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09?oo
ool00ooo003oooooooooo`02ooooo`;oo`008_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Oooooo`;oo`001Ooo
ool00ooo003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo02Gooooo0ooo000^ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool0
0ooo003oooooooooo`0/ooooo`?oo`009_ooool00ol0003oooooooooo`0eooooo`;o00009?ooool2
ool002Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool09Oooool2ool002Gooooo0_l0000=ooooo`009_ooool00ol0
003oooooooooo`0Uooooo`?oo`00;_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool0;?ooool3ool002Kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Sooooo`;oo`00:?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Uooooo`;oo`009_ooool00ol0
003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Fooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1Eooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0COooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo00_o
oooo000Vooooo`;o0000Eoooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo
00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`;o0000C_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`1<ooooo`;o00003Oooool001Cooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0
0004ooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`1=ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool02oooool001?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o
0000ooooooooool07?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol0
0005ooooo`03o`000?oooooooooo04gooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool00ol0003ooooooooo
o`0;ooooo`004oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?o
o`00ooooooooool0EOooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0COooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`1=ooooo`03o`000?oooooooooo00_ooooo000Cooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool3o`0005Kooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Cooooo0_l0000Moooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`02ooooo`;o0000C_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`1<ooooo`;o00003Oooool001?ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o
0000ooooooooool06oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04go
oooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002?ooool2o`0000Go
oooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Gooooo00?o0000ooooooooool0COooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1=ooooo`03o`000?oooooooooo00_ooooo000Dooooo`;o00002_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool06oooool01?l0
003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003ooooo
ooooo`1=ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool02oooool002Kooooo0_l0
001Gooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`1Eooooo`03o`000?oooooooooo01cooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo0_l0
001>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo04cooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`1F
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1E
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0COooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1=
ooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo05Kooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`1=ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000oooo
ooooool02oooool002Kooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo04gooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0COooool00ol0003oooooooooo`0;ooooo`00
9_ooool2o`0005Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool2o`0004kooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
C?ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Ooo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`1=ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04gooooo00?o0000ooooooooool02ooo
ool002Kooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooo
oooo00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo04cooooo0_oo0005ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool2
ool004oooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0E_ooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo04cooooo0_oo0005ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool00_ooool2ool004oooooo00?o0000ooooooooool02oooool002Ko
oooo0_l0001Gooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003o
ooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo0_l0001Dooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool0D_ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo05Kooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003ooooooooo
o`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Doooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool02oooool002Kooooo0_l0001G
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1E
ooooo`03o`000?oooooooooo03Gooooo0_l0001Dooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool0D_ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo05Kooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0Doooool00ol0003oooooooooo`0;ooooo`005?ooool2o`0000Cooooo00Co0000oooooooo
oooooooo1Ol00003ooooo`03o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000ooooooooool08_ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0Doooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool02oooool001?o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooo
oooo05Gooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Doooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo05?ooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`03ooooo`?o0000E_ooool00ooo003oooooooooo`09ooooo`03ool00?oo
oooooooo00Wooooo00?oo`00ooooooooool0E?ooool2o`0002?ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`04ooooo`;o0000E?ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo05;ooooo0_l0000=ooooo`004oooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0Qooooo`04o`00
0?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`00
4oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`1Eooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo05Kooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o
0000ooooooooool08Oooool01?l0003oooooooooool00008ooooo`;o00001_ooool00ol0003ooooo
ooooo`1Cooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003ooooo
ooooo`0;ooooo`005?ooool2o`0000Wooooo0ol00004ooooo`;o0000Eoooool00ooo003ooooooooo
o`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool00ol0003ooooooooo
o`0Rooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`;o0000E?ooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo05;ooooo0_l0000=ooooo`009_ooool00ol0003oooooooooo`1F
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`1E
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Doooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000oooo
ooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool0EOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo000Vooooo`03
o`000?oooooooooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Cooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`00
9_ooool2o`0005Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo05Gooooo00?o0000ooooooooool0=Oooool2o`0005Cooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
0oooool00ooo003oooooooooo`1Booooo`;o00003Oooool002Kooooo00?o0000ooooooooool0E_oo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0EOoo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00ooo
ool00ooo003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooo
oooo05Kooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooo
oooo05Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0
003oooooooooo`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo
003oooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Doooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool02oooool002Ko
oooo0_l0001Gooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003o
ooooooooo`1Eooooo`03o`000?oooooooooo03Gooooo0_l0001Dooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool0D_ooool2o`0000gooooo000Vooooo`03o`000?oooooooooo05Kooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo
00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003ooooooooo
o`1Fooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`1Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0Doooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooooooo
o`03ooooo`03ool00?oooooooooo05?ooooo00?o0000ooooooooool02oooool002Kooooo00?o0000
ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00
ooooooooool0EOooool00ol0003oooooooooo`0eooooo`;o0000E?ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo05;ooooo0_l0000=ooooo`009_ooool2o`0005Oooooo00?oo`00oooo
ooooool02Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo05Gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`1Cooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooo
ooooool0Doooool00ol0003oooooooooo`0;ooooo`005?ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Cooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0Looooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Gooooo00?o0000oooooooo
ool0Doooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o0000oooooooo
ool02oooool001?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool0E_ooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo
00Wooooo00?oo`00ooooooooool0EOooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0Doooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05?ooooo00?o
0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooo
oooooooo000005Sooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo05Gooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`0005Cooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`1Booooo`;o00003Oooool001?ooooo00Co0000oooooooooooo
00002Oooool2o`0000Cooooo0ol0001Fooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`1Dooooo`;o00007Oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Coooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;oooo
o`004oooool01?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool00000F?ooool0
0ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0EOooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooooooo
1?l00005ooooo`03o`000?oooooooooo05?ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00_ooooo000Cooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo05Gooooo0ooo000:ooooo`03
ool00?oooooooooo00Sooooo0ooo001Fooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo00002?ooool2o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Coooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0;oooo
o`005?ooool2o`0000Wooooo0ol00004ooooo`03o`000?oooooooooo05Gooooo0ooo000:ooooo`03
ool00?oooooooooo00Sooooo0ooo001Fooooo`03o`000?oooooooooo01cooooo0_l0000:ooooo`04
o`000?ooooooooooooooo`Go00001?ooool2o`0005?ooooo0_oo0005ooooo`03ool00?oooooooooo
00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`02ooooo`;oo`00E?ooool2o`00
00gooooo000Vooooo`;o0000E_ooool3ool000[ooooo00?oo`00ooooooooool02?ooool3ool005Ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Booooo`;oo`001Oooool00ooo003o
ooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool00_ooool2ool005Go
oooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0H_ooool00ooo003ooooo
ooooo`1Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0FOooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0FOooool00ol0003ooooo
ooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool00oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00_ooooo000V
ooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0e
ooooo`;o0000F_ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool0F?ooool2o`0000gooooo000Vooooo`;o0000Hoooool00ooo003oooooooooo`1Qoooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`02oooo
o`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0;oooo
o`009_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`00
0?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo05Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool0
0?oooooooooo05Wooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0H_oo
ool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo03Gooooo0_l0001Jooooo`03ool00?oo
oooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Hooooo`;o00003Ooo
ool002Kooooo0_l0001Sooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo
06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
05Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo
05Wooooo00?o0000ooooooooool02oooool002Kooooo00?o0000ooooooooool0H_ooool00ooo003o
ooooooooo`1Qooooo`03o`000?oooooooooo03Gooooo0_l0001Jooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Hooooo`;o00003Oooool002Kooooo
0_l0001Sooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`1Iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo06;ooooo00?o
o`00ooooooooool0HOooool00ol0003oooooooooo`0Rooooo`;o00001?ooool01?l0003ooooooooo
ooooool5o`0000Cooooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0;ooooo`005?oo
ool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool0H_oo
ool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Wooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05Wooooo00?o0000oooooooo
ool02oooool001?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0Qooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`0005[ooooo00?oo`00oooo
ooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05Sooooo0_l0000=oooo
o`004oooool01?l0003oooooooooool00007ooooo`Go00000oooool3o`0006;ooooo00?oo`00oooo
ooooool0H?ooool2o`0002?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06;ooooo00?o
o`00ooooooooool0HOooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05Wooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo05Wooooo00?o0000oooooooo
ool02oooool001?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000004ooooo`03
o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`0Qooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo05Wooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooo
oooo05Wooooo00?o0000ooooooooool02oooool001?ooooo00Co0000oooooooooooo00002Oooool2
o`0000Cooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`1Qooooo`03o`000?oooooo
oooo02;ooooo0_l00009ooooo`?o00001Oooool2o`0005[ooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`03ooooo`03ool00?oooooooooo05Sooooo0_l0000=ooooo`005?ooool2o`00
00_ooooo00?o0000ooooooooool00_ooool2o`0006?ooooo00?oo`00ooooooooool0HOooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool00_ooool00ooo
003oooooooooo`03ooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool02oooool002Ko
oooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003ooooo
ooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`1Iooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`1Iooooo`03o`000?oooooooooo00_ooooo000Vooooo`03o`000?oooooooooo06;ooooo00?o
o`00ooooooooool0HOooool00ol0003oooooooooo`0eooooo`;o0000F_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0F?ooool2o`0000gooooo000V
ooooo`;o0000Hoooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0FOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00?ooooo00?oo`00
ooooooooool0FOooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Roooo
o`03ool00?oooooooooo067ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Hoooo
o`;oo`001?ooool00ooo003oooooooooo`02ooooo`;oo`00Foooool00ol0003oooooooooo`0;oooo
o`009_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo067ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`1Hooooo`;oo`001?ooool00ooo003oooooooooo`02ooooo`;o
o`00Foooool00ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03ool0
0?oooooooooo067ooooo00?o0000ooooooooool0=Oooool2o`0005oooooo00?oo`00ooooooooool0
G_ooool2o`0000gooooo000Vooooo`;o0000Hoooool00ooo003oooooooooo`1Qooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0G_ooool00ooo003oooooooooo`1Oooooo`03o`000?oo
oooooooo00_ooooo000Vooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo05kooooo00?oo`00ooooooooool0Goooool0
0ol0003oooooooooo`0;ooooo`009_ooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo
067ooooo00?o0000ooooooooool0=Oooool2o`0005oooooo00?oo`00ooooooooool0G_ooool2o`00
00gooooo000Vooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool0HOooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo05kooooo00?oo`00ooooooooool0Goooool00ol0003o
ooooooooo`0;ooooo`009_ooool2o`0006?ooooo00?oo`00ooooooooool0HOooool00ol0003ooooo
ooooo`0Looooo`;o00001?ooool01?l0003oooooooooooooool5o`0000;ooooo0ol00005ooooo`03
o`000?oooooooooo05kooooo00?oo`00ooooooooool0Goooool00ol0003oooooooooo`0;ooooo`00
5?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0
H_ooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1Nooooo`03ool00?oooooooooo05oooooo00?o0000ooooooooool02oooool0
01?ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool0H_ooool00ooo003oooooooooo`1Qooooo`03o`000?oooooooooo01_ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
0_l0001Oooooo`;oo`00Goooool2o`0000gooooo000Cooooo`04o`000?ooooooooooo`0000_ooooo
00Go0000ooooooooooooooooo`00001Sooooo`?oo`00H_ooool00ol0003oooooooooo`0Kooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05kooooo0_oo001Pooooo`03o`000?oooooooooo00_ooooo000Cooooo`04
o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo0ol0001Qooooo`?oo`00HOooool2
o`0001gooooo00Co0000oooooooooooo00001oooool01_l0003ooooooooooooooooo0000ooooo`Co
00001Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`004oooool01?l0003oooooooooool00007ooooo`Co00001?ooool00ol0
003oooooooooo`1Qooooo`?oo`00H_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0000Oooooo00Oo0000ooooooooooooooooo`000?oooooo000000Soooooa?l0000=ooooo`004ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000007_ooool2o`0000Wo
oooo0ol00002ooooo`Go0000eOooool001Cooooo0_l00008ooooo`Go00000oooooo:o`000?oooooo
2Oooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooo
nOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooonOooool00?oooooo
nOooool00001\
\>"],
  ImageRangeCache->{{{0, 503}, {310.438, 0}} -> {-0.0514703, -0.0309082, \
0.0041808, 0.0041808}, {{12.3125, 240.062}, {303, 162.25}} -> {-6.126, \
-0.0611928, 0.0430363, 0.00132074}, {{262.875, 490.688}, {303, 162.25}} -> \
{-16.2836, -0.459781, 0.0417554, 0.0102798}, {{12.3125, 240.062}, {148.125, \
7.375}} -> {-5.82174, -1.02, 0.0417682, 0.00512026}, {{262.875, 490.688}, \
{148.125, 7.375}} -> {-16.9053, -0.528066, 0.0430227, 0.00263702}}]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuous-time Fourier transform (CTFT) example", "Section"],

Cell[CellGroupData[{

Cell["Widest pulse", "Subsection"],

Cell[BoxData[
    \(\(x[t_] := u[t + 1]\  - \ u[t - 1];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X[f_] = 
        FourierTransform[x[t], t, 
              f]\  /. {\[Delta][b_\ a_ + f\ a_] \[Rule] \[Delta][b + f]/
                  a, \[Delta][\(-b_\)\ a_ + 
                    f_\ a_] \[Rule] \[Delta][\(-b\) + f]/a}\  // \ 
          ComplexExpand;\)\), "\[IndentingNewLine]", 
    \(\({{x[t]}, {X[f]}}\  // FullSimplify\)\  // \ 
      TraditionalForm\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{
                RowBox[{
                  InterpretationBox["\[Theta]",
                    UnitStep,
                    Editable->False,
                    Selectable->False], "(", \(t + 1\), ")"}], "-", 
                RowBox[{
                  InterpretationBox["\[Theta]",
                    UnitStep,
                    Editable->False,
                    Selectable->False], "(", \(t - 1\), ")"}]}]},
            {\(\(sin(2\ f\ \[Pi])\)\/\(f\ \[Pi]\)\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gx1 = 
      Plot[Evaluate[x[t]], {t, \(-2\), 2}, PlotStyle \[Rule] {Blue}, \ 
        PlotPoints \[Rule] 500, \ PlotRange \[Rule] {\(- .1\), 2.1}]; 
    gX1 = Plot[Evaluate[X[f]], {f, \(-10\), 10}, PlotStyle \[Rule] {Blue}, \ 
        PlotPoints \[Rule] 500, \ PlotRange \[Rule] All];\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0280925 0.280925 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44948 -18 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.5)] -0.0125 .16855 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(1.5)] -0.0125 .44948 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(2)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .02809 m
.02567 .02809 L
.02769 .02809 L
.0296 .02809 L
.03143 .02809 L
.03338 .02809 L
.03525 .02809 L
.03724 .02809 L
.03917 .02809 L
.04101 .02809 L
.04298 .02809 L
.04487 .02809 L
.04669 .02809 L
.04863 .02809 L
.05049 .02809 L
.05248 .02809 L
.05439 .02809 L
.05622 .02809 L
.05818 .02809 L
.06006 .02809 L
.06206 .02809 L
.06399 .02809 L
.06584 .02809 L
.06781 .02809 L
.06971 .02809 L
.07154 .02809 L
.07348 .02809 L
.07535 .02809 L
.07734 .02809 L
.07926 .02809 L
.0811 .02809 L
.08306 .02809 L
.08495 .02809 L
.08677 .02809 L
.0887 .02809 L
.09056 .02809 L
.09254 .02809 L
.09445 .02809 L
.09628 .02809 L
.09823 .02809 L
.10011 .02809 L
.10211 .02809 L
.10403 .02809 L
.10588 .02809 L
.10785 .02809 L
.10974 .02809 L
.11156 .02809 L
.1135 .02809 L
.11537 .02809 L
.11736 .02809 L
Mistroke
.11927 .02809 L
.12111 .02809 L
.12307 .02809 L
.12495 .02809 L
.12695 .02809 L
.12888 .02809 L
.13074 .02809 L
.13271 .02809 L
.13462 .02809 L
.13644 .02809 L
.13839 .02809 L
.14026 .02809 L
.14226 .02809 L
.14418 .02809 L
.14602 .02809 L
.14799 .02809 L
.14988 .02809 L
.15169 .02809 L
.15363 .02809 L
.15549 .02809 L
.15748 .02809 L
.15938 .02809 L
.16122 .02809 L
.16317 .02809 L
.16505 .02809 L
.16705 .02809 L
.16898 .02809 L
.17083 .02809 L
.1728 .02809 L
.1747 .02809 L
.17652 .02809 L
.17846 .02809 L
.18033 .02809 L
.18232 .02809 L
.18424 .02809 L
.18608 .02809 L
.18804 .02809 L
.18993 .02809 L
.19174 .02809 L
.19367 .02809 L
.19553 .02809 L
.19751 .02809 L
.19941 .02809 L
.20124 .02809 L
.20319 .02809 L
.20507 .02809 L
.20706 .02809 L
.20899 .02809 L
.21083 .02809 L
.2128 .02809 L
Mistroke
.21469 .02809 L
.21651 .02809 L
.21845 .02809 L
.22032 .02809 L
.2223 .02809 L
.22421 .02809 L
.22605 .02809 L
.22801 .02809 L
.22989 .02809 L
.23189 .02809 L
.23382 .02809 L
.23567 .02809 L
.23765 .02809 L
.23955 .02809 L
.24137 .02809 L
.24332 .02809 L
.24519 .02809 L
.24718 .02809 L
.2491 .02809 L
.25094 .02809 L
.25291 .02809 L
.2548 .02809 L
.25661 .02809 L
.25855 .02809 L
.26041 .02809 L
.26137 .02809 L
.26161 .02809 L
.26174 .02809 L
.2618 .02809 L
.26186 .02809 L
.26189 .02809 L
.26193 .30902 L
.26196 .30902 L
.262 .30902 L
.26213 .30902 L
.26239 .30902 L
.26433 .30902 L
.2662 .30902 L
.26818 .30902 L
.2701 .30902 L
.27194 .30902 L
.2739 .30902 L
.27578 .30902 L
.27779 .30902 L
.27972 .30902 L
.28157 .30902 L
.28355 .30902 L
.28545 .30902 L
.28728 .30902 L
.28923 .30902 L
Mistroke
.2911 .30902 L
.2931 .30902 L
.29502 .30902 L
.29686 .30902 L
.29883 .30902 L
.30072 .30902 L
.30254 .30902 L
.30448 .30902 L
.30634 .30902 L
.30832 .30902 L
.31023 .30902 L
.31207 .30902 L
.31402 .30902 L
.3159 .30902 L
.3179 .30902 L
.31983 .30902 L
.32168 .30902 L
.32366 .30902 L
.32555 .30902 L
.32738 .30902 L
.32932 .30902 L
.33119 .30902 L
.33318 .30902 L
.3351 .30902 L
.33694 .30902 L
.3389 .30902 L
.34079 .30902 L
.34261 .30902 L
.34454 .30902 L
.3464 .30902 L
.34838 .30902 L
.35028 .30902 L
.35211 .30902 L
.35406 .30902 L
.35594 .30902 L
.35794 .30902 L
.35986 .30902 L
.36171 .30902 L
.36368 .30902 L
.36557 .30902 L
.36739 .30902 L
.36933 .30902 L
.3712 .30902 L
.37318 .30902 L
.3751 .30902 L
.37693 .30902 L
.37889 .30902 L
.38077 .30902 L
.38278 .30902 L
.38471 .30902 L
Mistroke
.38656 .30902 L
.38854 .30902 L
.39044 .30902 L
.39226 .30902 L
.39421 .30902 L
.39608 .30902 L
.39808 .30902 L
.39999 .30902 L
.40184 .30902 L
.4038 .30902 L
.40569 .30902 L
.40751 .30902 L
.40945 .30902 L
.41131 .30902 L
.41329 .30902 L
.4152 .30902 L
.41703 .30902 L
.41898 .30902 L
.42086 .30902 L
.42286 .30902 L
.42479 .30902 L
.42664 .30902 L
.42861 .30902 L
.43051 .30902 L
.43233 .30902 L
.43427 .30902 L
.43614 .30902 L
.43813 .30902 L
.44004 .30902 L
.44188 .30902 L
.44384 .30902 L
.44573 .30902 L
.44754 .30902 L
.44948 .30902 L
.45133 .30902 L
.45331 .30902 L
.45521 .30902 L
.45704 .30902 L
.45899 .30902 L
.46087 .30902 L
.46286 .30902 L
.46478 .30902 L
.46663 .30902 L
.4686 .30902 L
.47049 .30902 L
.47231 .30902 L
.47425 .30902 L
.47611 .30902 L
.4781 .30902 L
.48001 .30902 L
Mistroke
.48184 .30902 L
.4838 .30902 L
.48568 .30902 L
.48768 .30902 L
.48961 .30902 L
.49146 .30902 L
.49344 .30902 L
.49534 .30902 L
.49716 .30902 L
.49911 .30902 L
.50098 .30902 L
.50297 .30902 L
.50489 .30902 L
.50673 .30902 L
.50869 .30902 L
.51058 .30902 L
.5124 .30902 L
.51433 .30902 L
.51619 .30902 L
.51817 .30902 L
.52008 .30902 L
.52191 .30902 L
.52386 .30902 L
.52574 .30902 L
.52774 .30902 L
.52966 .30902 L
.53151 .30902 L
.53348 .30902 L
.53537 .30902 L
.5372 .30902 L
.53914 .30902 L
.541 .30902 L
.54299 .30902 L
.5449 .30902 L
.54674 .30902 L
.5487 .30902 L
.55058 .30902 L
.55259 .30902 L
.55452 .30902 L
.55637 .30902 L
.55835 .30902 L
.56025 .30902 L
.56208 .30902 L
.56403 .30902 L
.5659 .30902 L
.56789 .30902 L
.56981 .30902 L
.57166 .30902 L
.57362 .30902 L
.57552 .30902 L
Mistroke
.57733 .30902 L
.57927 .30902 L
.58113 .30902 L
.58312 .30902 L
.58502 .30902 L
.58686 .30902 L
.58881 .30902 L
.5907 .30902 L
.59269 .30902 L
.59462 .30902 L
.59647 .30902 L
.59844 .30902 L
.60034 .30902 L
.60217 .30902 L
.60411 .30902 L
.60598 .30902 L
.60797 .30902 L
.60988 .30902 L
.61173 .30902 L
.61369 .30902 L
.61557 .30902 L
.61739 .30902 L
.61932 .30902 L
.62118 .30902 L
.62316 .30902 L
.62506 .30902 L
.62689 .30902 L
.62884 .30902 L
.63072 .30902 L
.63271 .30902 L
.63464 .30902 L
.63649 .30902 L
.63845 .30902 L
.64035 .30902 L
.64217 .30902 L
.64411 .30902 L
.64597 .30902 L
.64796 .30902 L
.64987 .30902 L
.65171 .30902 L
.65366 .30902 L
.65555 .30902 L
.65755 .30902 L
.65947 .30902 L
.66133 .30902 L
.6633 .30902 L
.6652 .30902 L
.66703 .30902 L
.66898 .30902 L
.67085 .30902 L
Mistroke
.67284 .30902 L
.67476 .30902 L
.6766 .30902 L
.67857 .30902 L
.68046 .30902 L
.68227 .30902 L
.68421 .30902 L
.68607 .30902 L
.68805 .30902 L
.68996 .30902 L
.69179 .30902 L
.69374 .30902 L
.69562 .30902 L
.69762 .30902 L
.69954 .30902 L
.7014 .30902 L
.70336 .30902 L
.70526 .30902 L
.70708 .30902 L
.70903 .30902 L
.7109 .30902 L
.71288 .30902 L
.7148 .30902 L
.71664 .30902 L
.71859 .30902 L
.72048 .30902 L
.72248 .30902 L
.72442 .30902 L
.72627 .30902 L
.72825 .30902 L
.73015 .30902 L
.73198 .30902 L
.73393 .30902 L
.73581 .30902 L
.73676 .30902 L
.73726 .30902 L
.73754 .30902 L
.7378 .30902 L
.73792 .30902 L
.73803 .30902 L
.73809 .30902 L
.73812 .02809 L
.73816 .02809 L
.73827 .02809 L
.7388 .02809 L
.73972 .02809 L
.7416 .02809 L
.7436 .02809 L
.74553 .02809 L
.74738 .02809 L
Mistroke
.74935 .02809 L
.75125 .02809 L
.75308 .02809 L
.75502 .02809 L
.75689 .02809 L
.75888 .02809 L
.7608 .02809 L
.76264 .02809 L
.7646 .02809 L
.76649 .02809 L
.76831 .02809 L
.77024 .02809 L
.7721 .02809 L
.77408 .02809 L
.77598 .02809 L
.77782 .02809 L
.77977 .02809 L
.78165 .02809 L
.78364 .02809 L
.78556 .02809 L
.78741 .02809 L
.78938 .02809 L
.79128 .02809 L
.7931 .02809 L
.79504 .02809 L
.79691 .02809 L
.79889 .02809 L
.8008 .02809 L
.80264 .02809 L
.8046 .02809 L
.80648 .02809 L
.80849 .02809 L
.81042 .02809 L
.81227 .02809 L
.81425 .02809 L
.81615 .02809 L
.81798 .02809 L
.81992 .02809 L
.8218 .02809 L
.82379 .02809 L
.82571 .02809 L
.82755 .02809 L
.82952 .02809 L
.83141 .02809 L
.83322 .02809 L
.83516 .02809 L
.83702 .02809 L
.839 .02809 L
.84091 .02809 L
.84275 .02809 L
Mistroke
.8447 .02809 L
.84658 .02809 L
.84858 .02809 L
.8505 .02809 L
.85236 .02809 L
.85433 .02809 L
.85622 .02809 L
.85805 .02809 L
.85999 .02809 L
.86186 .02809 L
.86385 .02809 L
.86576 .02809 L
.86761 .02809 L
.86956 .02809 L
.87145 .02809 L
.87327 .02809 L
.8752 .02809 L
.87706 .02809 L
.87903 .02809 L
.88094 .02809 L
.88277 .02809 L
.88472 .02809 L
.88659 .02809 L
.88859 .02809 L
.89051 .02809 L
.89236 .02809 L
.89432 .02809 L
.89622 .02809 L
.89804 .02809 L
.89998 .02809 L
.90184 .02809 L
.90382 .02809 L
.90574 .02809 L
.90757 .02809 L
.90953 .02809 L
.91141 .02809 L
.91341 .02809 L
.91534 .02809 L
.91719 .02809 L
.91917 .02809 L
.92107 .02809 L
.92289 .02809 L
.92484 .02809 L
.92671 .02809 L
.9287 .02809 L
.93062 .02809 L
.93246 .02809 L
.93442 .02809 L
.93631 .02809 L
.93813 .02809 L
Mistroke
.94006 .02809 L
.94193 .02809 L
.94391 .02809 L
.94581 .02809 L
.94765 .02809 L
.9496 .02809 L
.95148 .02809 L
.95347 .02809 L
.9554 .02809 L
.95725 .02809 L
.95922 .02809 L
.96111 .02809 L
.96293 .02809 L
.96488 .02809 L
.96674 .02809 L
.96873 .02809 L
.97064 .02809 L
.97248 .02809 L
.97444 .02809 L
.97619 .02809 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006oooool5o`0003_ooooo0ol0000kooooo`;o0000??ooool3o`0003_ooooo1Ol00006oooo
o`007?ooool01?l0003oooooooooool0000looooo`03o`000?oooooooooo03Wooooo00Co0000oooo
oooooooo0000??ooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000Kooooo000E
ooooo`Go00000oooool00ol0003oooooooooo`0dooooo`Go00000oooool00ol0003oooooooooo`0i
ooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`06ooooo`007_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Wooooo00Co0000
oooooooooooo0000??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo000K
ooooo`05o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`0iooooo`04o`000?oo
ooooooooo`0003cooooo00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000000Ko
oooo000Kooooo`05o`000?ooooooooooooooool00000>oooool2o`0003_ooooo00Co0000oooooooo
oooo0000>oooool2o`0003cooooo00Go0000ooooooooooooooooo`000006ooooo`007?ooool3o`00
03gooooo00?o0000ooooooooool0>_ooool2o`0003gooooo00?o0000ooooooooool0>oooool3o`00
00Oooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooo
oooo00002ol00001ooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo04?ooooo00?o003oooooooooool0??ooool00ol0003oooooooooo`0loooo
o`03o`00oooooooooooo04;ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`;o00001?oooom0o`00ocoooooo00?o0000ooooooooool0??oooom0o`00o`Cooooo0_l00001oooo
o`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04;ooooo00?o003ooooo
ooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001oooo
o`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04;ooooo00?o003ooooo
ooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001oooo
o`003_ooool2o`0000Gooooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`0mooooo`03
o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00
oooooooooooo04;ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`12ooooo`03o`00oooo
oooooooo03gooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`12ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`0mooooo`03o`000?oooooo
oooo03cooooo00?o003oooooooooool0@_ooool1o`00007ooooo000Eooooo`;o0000@oooool00ol0
0?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@Oooool2o`00
007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003o
ooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool00ol00?oooooo
ooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0@_ooool00ol00?oooooooooo
o`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`0l
ooooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`12oooo
o`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`12oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`0mooooo`03
o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00
oooooooooooo04;ooooo0Ol00001ooooo`005Oooool2o`0004?ooooo00?o003oooooooooool0?Ooo
ool00ol0003oooooooooo`0looooo`03o`00oooooooooooo047ooooo0_l00001ooooo`005Oooool0
0ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool0
0ol00?ooooooooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0@_ooool00ol0
0?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003o
ooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool00ol00?oooooo
ooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0@_ooool00ol00?oooooooooo
o`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`0l
ooooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool2o`0004?ooooo00?o003ooooo
ooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo047ooooo0_l00001oooo
o`005Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000oooooooo
ool0??ooool00ol00?ooooooooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
@_ooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0
@_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Ooo
ool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool0
0ol00?ooooooooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0@_ooool00ol0
0?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003o
ooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool2o`0004?ooooo
00?o003oooooooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo047ooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o
0000ooooooooool0??ooool00ol00?ooooooooooo`12ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0@_ooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003o
ooooooooool0@_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003ooooo
ooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000oooooooo
ool0??ooool00ol00?ooooooooooo`12ooooo`7o00000Oooool000;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0
?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`0000Go
ooooo`000?ooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool00ol00?oo
ooooooooo`12ooooo`7o00000Oooool00005ooooool0003oooooooooool000002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003o
ooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`0000Goooooo`000?oooooo
ooooo`00000;ooooo`03o`000?oooooooooo00;ooooo0_l00013ooooo`03o`00oooooooooooo03go
oooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`11ooooo`;o00000Oooool00005oooo
ool0003oooooooooool000001oooool4o`0000Gooooo00?o0000ooooooooool0@_ooool00ol00?oo
ooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00007o
oooo00001Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool00ol00?oo
ooooooooo`12ooooo`7o00000Oooool000;ooooo0_l00008ooooo`Go00001?ooool00ol0003ooooo
ooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool00ol00?oooooo
ooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0@_ooool00ol00?oooooooooo
o`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`0l
ooooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`12oooo
o`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`12oooo
o`7o00000Oooool001Gooooo0_l00013ooooo`03o`00oooooooooooo03gooooo00?o0000oooooooo
ool0??ooool00ol00?ooooooooooo`11ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0
@_ooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0
@_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Ooo
ool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool0
0ol00?ooooooooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0@_ooool00ol0
0?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003o
ooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool00ol00?oooooo
ooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0@_ooool00ol00?oooooooooo
o`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00007ooooo000E
ooooo`;o0000@oooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003o
ooooooooool0@Oooool2o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003ooooo
ooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000oooooooo
ool0??ooool00ol00?ooooooooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
@_ooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0
@_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Ooo
ool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000ooooooooool0??ooool0
0ol00?ooooooooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0@_ooool00ol0
0?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0@_ooool1o`00
007ooooo000Eooooo`;o0000@oooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo03co
oooo00?o003oooooooooool0@Oooool2o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo
00?o003oooooooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o
0000ooooooooool0??ooool00ol00?ooooooooooo`12ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0@_ooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003o
ooooooooool0@_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003ooooo
ooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o0000oooooooo
ool0??ooool00ol00?ooooooooooo`12ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
@_ooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo03cooooo00?o003oooooooooool0
@_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Ooo
ool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`005Oooool2
o`0004?ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooo
oooo047ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo
03gooooo00?o0000ooooooooool0??ooool00ol00?ooooooooooo`12ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0@_ooool00ol00?ooooooooooo`0mooooo`03o`000?oooooooooo03co
oooo00?o003oooooooooool0@_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo04;ooooo
00?o003oooooooooool0?Oooool00ol0003oooooooooo`0looooo`03o`00oooooooooooo04;ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`12ooooo`03o`00oooooooooooo03gooooo00?o
0000ooooooooool0??ooool00ol00?ooooooooooo`12ooooo`7o00000Oooool000gooooo0ol00005
ooooo`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`0l
ooooo`03o`00oooooooooooo04;ooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo04;ooooo00?o003oooooooooool0?Oooool00ol0003oooooooooo`0loooo
o`03o`00oooooooooooo04;ooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`;o
0000@ooooon0o`00od?ooooo0_l00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000>ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool000gooooo0_l00006ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1
o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?o
oooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POoo
ool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03
o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
087ooooo0Ol00001ooooo`0000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`02oooo
o`?o00001Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`000_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`000_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo0_l00023ooooo`03o`000?oooooooooo083o
oooo0_l00001ooooo`000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000;ooooo00?o
0000ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool00003ooooool0003o000000Wooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`000_ooool00ol0
003oooooooooo`07ooooo`Go00001?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003o
ooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o0000oooooooo
ool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo000<ooooo`Go00001?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087o
oooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0POooool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000oooooo00?o
0000ooooooooool00oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000<
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`003?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000gooooo0ol00005
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00?ooooo0Ol00001ooooo`005Oooooooo`0000_o00000Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.43721, -0.268479, \
0.0158161, 0.0134047}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.11976 0.24178 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .24065 -18 -4.5 ]
[-0.0125 .24065 0 4.5 ]
[-0.0125 .36154 -6 -4.5 ]
[-0.0125 .36154 0 4.5 ]
[-0.0125 .48243 -18 -4.5 ]
[-0.0125 .48243 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .24065 m
.00625 .24065 L
s
[(0.5)] -0.0125 .24065 1 0 Mshowa
0 .36154 m
.00625 .36154 L
s
[(1)] -0.0125 .36154 1 0 Mshowa
0 .48243 m
.00625 .48243 L
s
[(1.5)] -0.0125 .48243 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .02305 m
.00375 .02305 L
s
0 .04723 m
.00375 .04723 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16812 m
.00375 .16812 L
s
0 .19229 m
.00375 .19229 L
s
0 .21647 m
.00375 .21647 L
s
0 .26483 m
.00375 .26483 L
s
0 .28901 m
.00375 .28901 L
s
0 .31318 m
.00375 .31318 L
s
0 .33736 m
.00375 .33736 L
s
0 .38572 m
.00375 .38572 L
s
0 .4099 m
.00375 .4099 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .50661 m
.00375 .50661 L
s
0 .53079 m
.00375 .53079 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .24065 m
1 .24065 L
s
.99375 .36154 m
1 .36154 L
s
.99375 .48243 m
1 .48243 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .02305 m
1 .02305 L
s
.99625 .04723 m
1 .04723 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16812 m
1 .16812 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .21647 m
1 .21647 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .28901 m
1 .28901 L
s
.99625 .31318 m
1 .31318 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .4099 m
1 .4099 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .50661 m
1 .50661 L
s
.99625 .53079 m
1 .53079 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .11976 m
.02567 .11788 L
.02769 .11595 L
.0296 .11437 L
.03143 .11316 L
.03237 .11267 L
.03338 .11228 L
.03387 .11213 L
.03413 .11207 L
.0344 .11201 L
.03464 .11196 L
.0349 .11193 L
.03514 .1119 L
.03525 .11189 L
.03537 .11188 L
.03549 .11187 L
.03555 .11187 L
.03561 .11187 L
.03564 .11187 L
.03568 .11187 L
.03571 .11187 L
.03574 .11187 L
.03581 .11187 L
.03584 .11187 L
.03587 .11187 L
.03593 .11187 L
.03599 .11187 L
.03604 .11187 L
.0361 .11187 L
.03623 .11188 L
.03634 .11188 L
.03655 .1119 L
.03678 .11193 L
.03723 .112 L
.03772 .11211 L
.03816 .11224 L
.03917 .11262 L
.04008 .11308 L
.04107 .11369 L
.04302 .11519 L
.0449 .11694 L
.0469 .11899 L
.04882 .12104 L
.05067 .12296 L
.05264 .1248 L
.05453 .12627 L
.05549 .12686 L
.05636 .12731 L
.05729 .12768 L
.05781 .12784 L
Mistroke
.0583 .12795 L
.05854 .12799 L
.05876 .12802 L
.05888 .12804 L
.05902 .12805 L
.05913 .12806 L
.05925 .12807 L
.05931 .12807 L
.05937 .12808 L
.05942 .12808 L
.05948 .12808 L
.05951 .12808 L
.05954 .12808 L
.0596 .12808 L
.05965 .12808 L
.05971 .12808 L
.05976 .12808 L
.05982 .12808 L
.05987 .12808 L
.05991 .12808 L
.06002 .12807 L
.06014 .12806 L
.06038 .12804 L
.0606 .12802 L
.06085 .12798 L
.06109 .12793 L
.06197 .12769 L
.06244 .12752 L
.06294 .12731 L
.06382 .12685 L
.06565 .12559 L
.06759 .12387 L
.06946 .12194 L
.07145 .11974 L
.07336 .11759 L
.07521 .11564 L
.07717 .11381 L
.07814 .11303 L
.07905 .11241 L
.07994 .1119 L
.08087 .11148 L
.08133 .11131 L
.08184 .11117 L
.08206 .11112 L
.0823 .11107 L
.08251 .11103 L
.08273 .11101 L
.08285 .11099 L
.08298 .11098 L
.0831 .11097 L
Mistroke
.08322 .11097 L
.08325 .11097 L
.08329 .11097 L
.08332 .11097 L
.08335 .11096 L
.08339 .11096 L
.08342 .11096 L
.08348 .11096 L
.08351 .11096 L
.08354 .11096 L
.08358 .11096 L
.08362 .11096 L
.08368 .11097 L
.08375 .11097 L
.08388 .11098 L
.08399 .11098 L
.08425 .11101 L
.08449 .11104 L
.08472 .11108 L
.08519 .11119 L
.08568 .11134 L
.08657 .11169 L
.0875 .11219 L
.08838 .11276 L
.09024 .11428 L
.09222 .11628 L
.09413 .11844 L
.09596 .12063 L
.09792 .12291 L
.09979 .12494 L
.10179 .12676 L
.10279 .12751 L
.10372 .12808 L
.10461 .12852 L
.10507 .1287 L
.10557 .12885 L
.10582 .12892 L
.10606 .12897 L
.10629 .12901 L
.10651 .12904 L
.10671 .12906 L
.10683 .12907 L
.10693 .12908 L
.10704 .12909 L
.10711 .12909 L
.10717 .12909 L
.10722 .12909 L
.10728 .12909 L
.10733 .12909 L
.10739 .12909 L
Mistroke
.10745 .12909 L
.10748 .12909 L
.10752 .12909 L
.10763 .12908 L
.1077 .12908 L
.10777 .12907 L
.10789 .12906 L
.10814 .12903 L
.10837 .129 L
.10883 .1289 L
.10926 .12877 L
.11022 .1284 L
.1111 .12793 L
.11298 .12656 L
.11498 .12463 L
.11691 .12243 L
.11876 .12012 L
.12073 .11763 L
.12263 .11534 L
.12446 .11337 L
.1264 .11167 L
.1273 .11105 L
.12827 .11051 L
.1288 .11028 L
.12929 .11011 L
.12976 .10998 L
.13 .10993 L
.13026 .10989 L
.1305 .10986 L
.13062 .10985 L
.13075 .10984 L
.13086 .10983 L
.13092 .10983 L
.13098 .10983 L
.13103 .10983 L
.13109 .10983 L
.13114 .10983 L
.13119 .10983 L
.13125 .10983 L
.13131 .10983 L
.13137 .10983 L
.13142 .10984 L
.13155 .10984 L
.13168 .10986 L
.13192 .10989 L
.13219 .10993 L
.13269 .11004 L
.13314 .11018 L
.13415 .11062 L
.13508 .11117 L
Mistroke
.13608 .11191 L
.13805 .11376 L
.13995 .11596 L
.14178 .11831 L
.14373 .12094 L
.1456 .12342 L
.14759 .12584 L
.14951 .12781 L
.15136 .12923 L
.15231 .12975 L
.15279 .12996 L
.15332 .13014 L
.15356 .13021 L
.15381 .13026 L
.15402 .1303 L
.15425 .13034 L
.15438 .13035 L
.1545 .13036 L
.15456 .13037 L
.15462 .13037 L
.15468 .13037 L
.15473 .13037 L
.15479 .13038 L
.15483 .13038 L
.15486 .13038 L
.1549 .13038 L
.15494 .13038 L
.15497 .13038 L
.155 .13038 L
.15507 .13038 L
.1551 .13038 L
.15513 .13037 L
.1552 .13037 L
.15526 .13037 L
.15537 .13036 L
.15549 .13035 L
.15574 .13032 L
.15595 .13028 L
.15618 .13023 L
.15671 .13009 L
.15719 .12991 L
.15811 .12945 L
.15911 .12879 L
.16107 .12703 L
.16297 .12486 L
.16479 .12244 L
.16673 .11968 L
.16859 .11698 L
.17057 .11428 L
.17248 .11199 L
Mistroke
.17432 .11023 L
.17527 .10953 L
.17628 .10895 L
.17677 .10874 L
.17703 .10865 L
.17731 .10856 L
.17755 .1085 L
.17781 .10844 L
.17805 .1084 L
.17816 .10839 L
.17828 .10838 L
.1784 .10837 L
.17846 .10836 L
.17852 .10836 L
.17855 .10836 L
.17858 .10836 L
.17864 .10836 L
.17867 .10836 L
.17871 .10836 L
.17875 .10836 L
.17878 .10836 L
.17884 .10836 L
.1789 .10836 L
.17895 .10836 L
.17901 .10836 L
.17914 .10837 L
.17926 .10838 L
.17946 .10841 L
.17969 .10844 L
.18015 .10855 L
.18064 .10871 L
.18108 .10889 L
.18209 .10945 L
.183 .11012 L
.184 .11101 L
.18596 .11321 L
.18784 .11576 L
.18985 .11878 L
.19178 .12179 L
.19363 .1246 L
.19561 .1273 L
.19751 .12946 L
.19847 .13033 L
.19934 .13098 L
.20028 .13152 L
.2008 .13174 L
.20103 .13182 L
.20129 .1319 L
.20151 .13196 L
.20175 .13201 L
Mistroke
.20189 .13203 L
.20201 .13204 L
.20213 .13206 L
.20225 .13207 L
.2023 .13207 L
.20235 .13207 L
.20241 .13208 L
.20246 .13208 L
.20252 .13208 L
.20258 .13208 L
.20264 .13208 L
.2027 .13208 L
.20275 .13207 L
.20281 .13207 L
.20291 .13207 L
.20303 .13206 L
.20313 .13204 L
.20336 .13201 L
.20361 .13196 L
.20405 .13184 L
.20452 .13167 L
.20505 .13142 L
.20598 .13085 L
.20698 .13003 L
.20896 .1279 L
.21086 .12529 L
.21269 .12242 L
.21464 .11915 L
.21652 .116 L
.21852 .11286 L
.22044 .11025 L
.22229 .10828 L
.22324 .10751 L
.22373 .10719 L
.22425 .1069 L
.22474 .10669 L
.22519 .10654 L
.22541 .10648 L
.22565 .10644 L
.22575 .10642 L
.22587 .1064 L
.22597 .10639 L
.22607 .10638 L
.22614 .10638 L
.2262 .10638 L
.22623 .10637 L
.22626 .10637 L
.2263 .10637 L
.22633 .10637 L
.22639 .10637 L
Mistroke
.22645 .10637 L
.22651 .10637 L
.22654 .10637 L
.22657 .10637 L
.22664 .10638 L
.2267 .10638 L
.22685 .10639 L
.22697 .10641 L
.22711 .10643 L
.22735 .10647 L
.22757 .10653 L
.22808 .1067 L
.22858 .10692 L
.22906 .10719 L
.22996 .10783 L
.23181 .10968 L
.23378 .11233 L
.23567 .1154 L
.2375 .11866 L
.23944 .12224 L
.24131 .12558 L
.24329 .1288 L
.24521 .13136 L
.24617 .1324 L
.24705 .13316 L
.248 .1338 L
.24852 .13405 L
.24875 .13415 L
.24901 .13424 L
.24923 .1343 L
.24948 .13435 L
.24961 .13438 L
.24973 .13439 L
.24986 .13441 L
.24991 .13441 L
.24997 .13442 L
.25003 .13442 L
.25008 .13442 L
.25014 .13443 L
.2502 .13443 L
.25025 .13443 L
.2503 .13443 L
.25035 .13442 L
.2504 .13442 L
.25046 .13442 L
.25052 .13442 L
.25064 .1344 L
.25076 .13439 L
.25086 .13437 L
.25109 .13433 L
Mistroke
.25133 .13427 L
.25183 .1341 L
.25229 .13389 L
.25272 .13364 L
.2537 .1329 L
.25459 .13204 L
.25651 .1296 L
.25835 .12662 L
.26031 .12295 L
.2622 .11916 L
.26401 .1155 L
.26595 .1118 L
.26781 .10867 L
.26875 .10731 L
.26979 .10603 L
.27078 .10503 L
.27169 .10433 L
.27218 .10405 L
.27263 .10384 L
.27287 .10375 L
.27312 .10367 L
.27325 .10364 L
.27339 .10361 L
.27351 .10359 L
.27364 .10357 L
.2737 .10357 L
.27377 .10356 L
.27383 .10356 L
.27389 .10355 L
.27393 .10355 L
.27396 .10355 L
.27402 .10355 L
.27407 .10355 L
.27413 .10355 L
.27418 .10355 L
.27424 .10355 L
.27429 .10356 L
.27434 .10356 L
.27446 .10357 L
.27458 .10359 L
.27483 .10363 L
.27506 .10369 L
.27531 .10377 L
.27558 .10387 L
.27603 .1041 L
.27652 .1044 L
.2774 .10511 L
.27837 .10612 L
.27938 .10744 L
.28122 .11039 L
Mistroke
.28317 .11419 L
.28505 .11827 L
.28705 .12277 L
.28897 .127 L
.29082 .1307 L
.2928 .13398 L
.29378 .1353 L
.29469 .1363 L
.29557 .13704 L
.29607 .13736 L
.29652 .13758 L
.29675 .13767 L
.29699 .13775 L
.2972 .1378 L
.29732 .13783 L
.29743 .13785 L
.2975 .13786 L
.29756 .13786 L
.29762 .13787 L
.29768 .13787 L
.29775 .13788 L
.29778 .13788 L
.29782 .13788 L
.29788 .13788 L
.29792 .13788 L
.29795 .13788 L
.29801 .13788 L
.29806 .13788 L
.29812 .13787 L
.29818 .13787 L
.29831 .13785 L
.29843 .13784 L
.29866 .13779 L
.29891 .13772 L
.29935 .13755 L
.29987 .13727 L
.30034 .13694 L
.30127 .1361 L
.30227 .13491 L
.30424 .13177 L
.30614 .12792 L
.30797 .12365 L
.30991 .11877 L
.31179 .11403 L
.31378 .10929 L
.31569 .1053 L
.31754 .10226 L
.31849 .10107 L
.31898 .10057 L
.3195 .10011 L
Mistroke
.31999 .09977 L
.32044 .09952 L
.32087 .09936 L
.32108 .0993 L
.3212 .09927 L
.32132 .09925 L
.32144 .09924 L
.3215 .09923 L
.32154 .09923 L
.32157 .09922 L
.32163 .09922 L
.32169 .09922 L
.32172 .09922 L
.32175 .09922 L
.32181 .09922 L
.32187 .09922 L
.32192 .09922 L
.32198 .09923 L
.32203 .09923 L
.32215 .09925 L
.32226 .09927 L
.32251 .09932 L
.32275 .0994 L
.323 .0995 L
.32327 .09963 L
.32373 .09992 L
.32422 .10031 L
.3251 .10122 L
.32612 .1026 L
.32709 .10421 L
.32894 .10802 L
.3309 .11293 L
.33279 .1182 L
.33461 .12348 L
.33655 .12899 L
.33841 .13385 L
.3404 .13819 L
.34139 .13994 L
.3423 .14128 L
.34319 .14229 L
.34369 .14272 L
.34414 .14303 L
.34437 .14316 L
.34462 .14327 L
.34483 .14335 L
.34507 .14341 L
.3452 .14343 L
.34532 .14345 L
.34538 .14346 L
.34542 .14346 L
Mistroke
.34545 .14346 L
.34549 .14347 L
.34552 .14347 L
.34558 .14347 L
.34565 .14347 L
.3457 .14347 L
.34577 .14346 L
.3458 .14346 L
.34583 .14346 L
.34595 .14344 L
.34607 .14343 L
.34619 .1434 L
.34631 .14337 L
.34657 .14328 L
.3468 .14317 L
.34705 .14304 L
.34748 .14275 L
.34794 .14234 L
.34888 .14127 L
.34988 .13973 L
.35187 .13562 L
.35378 .13052 L
.35562 .12483 L
.35757 .1183 L
.35946 .11192 L
.36146 .10549 L
.36339 .10007 L
.36524 .09592 L
.3662 .09427 L
.36669 .09358 L
.36722 .09296 L
.36771 .09249 L
.36816 .09215 L
.36838 .09202 L
.36862 .09191 L
.36884 .09183 L
.36905 .09177 L
.36916 .09175 L
.36922 .09175 L
.36927 .09174 L
.36933 .09173 L
.36939 .09173 L
.36945 .09173 L
.36948 .09173 L
.36951 .09173 L
.36957 .09173 L
.36962 .09173 L
.36967 .09174 L
.36973 .09174 L
.36983 .09176 L
Mistroke
.36995 .09178 L
.37007 .09181 L
.37019 .09185 L
.37046 .09196 L
.3707 .09209 L
.37094 .09224 L
.3714 .09262 L
.37189 .09314 L
.37278 .09437 L
.37371 .09607 L
.37459 .09801 L
.37645 .10315 L
.37843 .1099 L
.38033 .11724 L
.38216 .12469 L
.38411 .13255 L
.38598 .13956 L
.38798 .14592 L
.38898 .14853 L
.3899 .15054 L
.39079 .15208 L
.39125 .15271 L
.39175 .15325 L
.392 .15347 L
.39224 .15365 L
.39247 .1538 L
.39268 .1539 L
.39289 .15397 L
.393 .15401 L
.39311 .15403 L
.39317 .15404 L
.39322 .15404 L
.39328 .15405 L
.39334 .15405 L
.3934 .15405 L
.39345 .15405 L
.3935 .15405 L
.39357 .15404 L
.39362 .15404 L
.39369 .15403 L
.39382 .154 L
.39394 .15396 L
.39405 .15392 L
.39431 .1538 L
.39459 .15362 L
.39509 .15319 L
.39555 .15265 L
.39646 .15122 L
.39746 .14911 L
.39941 .1434 L
Mistroke
.40129 .13618 L
.40329 .12709 L
.40521 .11748 L
.40706 .10799 L
.40903 .09827 L
.41092 .08988 L
.41274 .08326 L
.41376 .08036 L
.41469 .07826 L
.41514 .07744 L
.41564 .07671 L
.41587 .07644 L
.41612 .07619 L
.41633 .076 L
.41655 .07585 L
.41668 .07578 L
.41681 .07571 L
.41693 .07567 L
.41705 .07564 L
.41712 .07562 L
.41715 .07562 L
.41718 .07561 L
.41724 .0756 L
.41727 .0756 L
.41731 .0756 L
.41734 .0756 L
.41738 .0756 L
.41741 .0756 L
.41744 .0756 L
.41747 .0756 L
.41751 .07561 L
.41755 .07561 L
.41758 .07562 L
.41765 .07563 L
.41771 .07565 L
.41783 .07568 L
.41805 .07579 L
.41831 .07595 L
.41856 .07615 L
.41902 .07667 L
.41946 .07731 L
.42045 .07932 L
.42143 .08203 L
.42232 .08512 L
.42424 .09358 L
.42608 .10375 L
.42804 .11619 L
.42993 .12907 L
.43174 .14157 L
.43367 .15421 L
Mistroke
.43553 .16494 L
.43648 .1696 L
.43751 .17397 L
.43851 .17736 L
.43941 .17966 L
.4399 .18056 L
.44036 .1812 L
.44061 .18146 L
.44084 .18164 L
.44096 .18171 L
.44109 .18177 L
.44116 .18179 L
.44123 .18181 L
.44127 .18182 L
.4413 .18182 L
.44136 .18183 L
.44142 .18184 L
.44146 .18184 L
.44149 .18184 L
.44155 .18183 L
.44161 .18182 L
.44166 .18181 L
.44171 .1818 L
.44183 .18176 L
.44195 .1817 L
.44206 .18163 L
.44232 .18143 L
.44254 .1812 L
.44277 .18088 L
.4432 .18016 L
.44365 .17917 L
.44415 .17781 L
.44516 .17421 L
.4461 .1699 L
.4471 .16423 L
.44908 .15013 L
.45099 .13345 L
.45282 .11526 L
.45477 .09462 L
.45665 .07461 L
.45865 .05455 L
.46057 .03775 L
.46242 .02516 L
.46338 .0204 L
.46386 .01851 L
.46439 .01685 L
.46464 .01622 L
.46488 .01573 L
.4651 .01536 L
.46533 .01506 L
Mistroke
.46546 .01493 L
.46558 .01484 L
.46564 .0148 L
.4657 .01477 L
.46576 .01475 L
.46581 .01473 L
.46587 .01472 L
.46593 .01472 L
.46596 .01472 L
.466 .01472 L
.46603 .01472 L
.46606 .01473 L
.4661 .01474 L
.46613 .01475 L
.46619 .01477 L
.46626 .01481 L
.46633 .01485 L
.46645 .01495 L
.46658 .01509 L
.46682 .01543 L
.46705 .01586 L
.46727 .01635 L
.46775 .0178 L
.46827 .01986 L
.4693 .02558 L
.47027 .03297 L
.47212 .05256 L
.4741 .08115 L
.47599 .11581 L
.47782 .15502 L
.47976 .20202 L
.48163 .2511 L
.48362 .30571 L
.48554 .35893 L
.48738 .40894 L
.48934 .45901 L
.49123 .50244 L
.49305 .53829 L
.49498 .56873 L
.49587 .57972 L
.49684 .58943 L
.4978 .59658 L
.49833 .59941 L
.49882 .60136 L
.49906 .60208 L
.49919 .6024 L
.49932 .60268 L
.49944 .60288 L
.49957 .60306 L
.49963 .60313 L
Mistroke
.49969 .60319 L
.49975 .60323 L
.4998 .60326 L
.49986 .60329 L
.49992 .60331 L
.49995 .60332 L
.49998 .60332 L
.50004 .60332 L
.5001 .60331 L
.50015 .60329 L
.50021 .60326 L
.50027 .60322 L
.50037 .60312 L
.50047 .60301 L
.5007 .60264 L
.50094 .60209 L
.5012 .6013 L
.50168 .59938 L
.50214 .59692 L
.50257 .59411 L
.50347 .58661 L
.50446 .57589 L
.5064 .54793 L
.50826 .51314 L
.51024 .46907 L
.51215 .4213 L
.51398 .37208 L
.51594 .31798 L
.51782 .26603 L
.51981 .21284 L
.52174 .16527 L
.52359 .12426 L
.52556 .08693 L
.52746 .05797 L
.52928 .03704 L
.53022 .029 L
.53122 .02239 L
.53171 .01994 L
.53224 .01781 L
.53249 .01703 L
.53275 .01632 L
.53299 .01577 L
.53321 .01538 L
.53343 .01508 L
.53354 .01496 L
.53366 .01486 L
.53378 .01478 L
.53385 .01475 L
.53391 .01473 L
.53397 .01472 L
Mistroke
.53403 .01472 L
.53409 .01472 L
.53415 .01472 L
.5342 .01473 L
.53425 .01475 L
.5343 .01477 L
.53435 .01479 L
.53446 .01487 L
.53457 .01496 L
.53479 .0152 L
.53502 .01556 L
.53552 .01662 L
.53597 .01794 L
.53698 .02204 L
.53791 .0271 L
.53891 .03381 L
.54088 .05015 L
.54278 .06871 L
.54461 .08796 L
.54655 .10871 L
.54842 .12778 L
.55041 .14596 L
.55233 .16054 L
.55417 .17124 L
.55513 .17536 L
.55561 .17708 L
.55614 .17863 L
.55663 .1798 L
.55707 .18064 L
.5575 .18124 L
.55772 .18146 L
.55795 .18164 L
.55807 .18172 L
.55814 .18175 L
.55821 .18177 L
.55827 .18179 L
.55833 .18181 L
.55839 .18182 L
.55845 .18183 L
.5585 .18184 L
.55856 .18184 L
.55861 .18183 L
.55866 .18183 L
.55872 .18182 L
.55878 .18181 L
.55884 .18179 L
.5589 .18177 L
.55903 .18171 L
.55915 .18165 L
.55942 .18143 L
Mistroke
.55965 .18119 L
.5599 .18086 L
.56036 .1801 L
.56085 .17907 L
.56173 .17662 L
.56276 .17292 L
.56373 .16866 L
.56557 .15878 L
.56754 .14642 L
.56943 .13353 L
.57125 .12099 L
.57318 .10827 L
.57505 .09732 L
.57703 .08772 L
.57802 .08387 L
.57894 .08093 L
.57983 .07868 L
.58032 .07769 L
.58077 .07695 L
.58127 .07633 L
.58153 .07608 L
.5818 .07587 L
.58192 .0758 L
.58204 .07574 L
.58215 .07569 L
.58226 .07565 L
.58234 .07563 L
.5824 .07562 L
.58246 .07561 L
.5825 .07561 L
.58253 .0756 L
.58259 .0756 L
.58262 .0756 L
.58266 .0756 L
.58271 .0756 L
.58277 .07561 L
.58283 .07561 L
.5829 .07562 L
.58301 .07565 L
.58313 .07569 L
.58323 .07573 L
.58347 .07586 L
.58372 .07604 L
.58414 .07645 L
.5846 .07705 L
.58554 .07872 L
.58654 .08116 L
.58853 .08771 L
.59044 .09578 L
.59228 .10464 L
Mistroke
.59423 .11462 L
.59612 .12417 L
.59812 .13362 L
.60005 .14147 L
.6019 .14746 L
.60286 .14986 L
.60335 .15088 L
.60388 .15181 L
.60437 .15255 L
.60482 .1531 L
.60527 .15352 L
.6057 .15381 L
.60593 .15391 L
.60605 .15396 L
.60617 .15399 L
.60629 .15402 L
.60636 .15403 L
.60642 .15404 L
.60648 .15405 L
.60654 .15405 L
.6066 .15405 L
.60663 .15405 L
.60666 .15405 L
.60672 .15405 L
.60678 .15404 L
.60683 .15404 L
.60688 .15403 L
.607 .154 L
.60712 .15397 L
.60733 .1539 L
.60755 .15379 L
.60804 .15345 L
.60857 .15292 L
.60954 .15156 L
.61048 .14976 L
.61149 .14736 L
.6135 .14135 L
.61543 .13435 L
.61729 .12695 L
.61926 .11888 L
.62117 .11141 L
.623 .10493 L
.62495 .09917 L
.62584 .09701 L
.62682 .09505 L
.62735 .09417 L
.62785 .09347 L
.62835 .09288 L
.62881 .09243 L
.62925 .09212 L
Mistroke
.62949 .09198 L
.62971 .09188 L
.62996 .0918 L
.6301 .09177 L
.63016 .09176 L
.63022 .09175 L
.63028 .09174 L
.63031 .09174 L
.63035 .09173 L
.6304 .09173 L
.63046 .09173 L
.63052 .09173 L
.63058 .09173 L
.63064 .09173 L
.63067 .09173 L
.63071 .09174 L
.63082 .09175 L
.63088 .09176 L
.63094 .09177 L
.63118 .09184 L
.6314 .09192 L
.63162 .09203 L
.63215 .09237 L
.63262 .0928 L
.63353 .09389 L
.63453 .0955 L
.63648 .09974 L
.63836 .10494 L
.64035 .11129 L
.64228 .11779 L
.64413 .124 L
.64609 .13015 L
.64799 .13528 L
.64981 .13919 L
.65075 .14074 L
.65175 .14203 L
.65224 .14251 L
.65277 .14292 L
.65301 .14308 L
.65327 .14321 L
.6535 .1433 L
.65374 .14338 L
.65386 .14341 L
.65399 .14344 L
.65405 .14345 L
.65412 .14345 L
.65418 .14346 L
.65423 .14346 L
.65427 .14347 L
.6543 .14347 L
Mistroke
.65434 .14347 L
.65438 .14347 L
.65441 .14347 L
.65445 .14347 L
.65448 .14347 L
.65451 .14347 L
.65457 .14346 L
.65464 .14346 L
.6547 .14345 L
.65477 .14344 L
.65489 .14342 L
.65501 .14339 L
.65524 .14332 L
.65548 .14323 L
.65574 .1431 L
.65619 .14281 L
.6567 .14239 L
.65771 .14126 L
.65865 .13989 L
.65965 .1381 L
.66164 .13372 L
.66355 .12871 L
.6654 .12346 L
.66736 .11777 L
.66924 .11254 L
.67106 .10803 L
.67299 .10407 L
.67388 .1026 L
.67485 .10128 L
.67581 .10028 L
.67634 .09987 L
.67682 .09958 L
.67707 .09947 L
.67733 .09937 L
.67745 .09933 L
.67758 .0993 L
.67769 .09928 L
.67781 .09925 L
.67792 .09924 L
.67803 .09923 L
.67808 .09922 L
.67813 .09922 L
.67818 .09922 L
.67823 .09922 L
.67829 .09922 L
.67835 .09922 L
.6784 .09922 L
.67846 .09923 L
.67852 .09923 L
.67859 .09924 L
Mistroke
.6787 .09926 L
.67882 .09928 L
.67894 .0993 L
.67916 .09937 L
.67939 .09945 L
.67965 .09956 L
.6801 .09983 L
.68053 .10013 L
.68143 .10098 L
.68242 .1022 L
.68435 .10539 L
.68621 .10927 L
.68819 .11398 L
.6901 .1188 L
.69193 .12341 L
.69389 .12798 L
.69576 .13179 L
.69672 .13343 L
.69776 .13495 L
.69868 .13605 L
.6992 .13656 L
.69968 .13696 L
.70018 .1373 L
.70064 .13755 L
.70087 .13765 L
.70113 .13773 L
.70127 .13777 L
.7014 .1378 L
.70153 .13783 L
.70165 .13785 L
.70177 .13786 L
.70183 .13787 L
.7019 .13788 L
.70193 .13788 L
.70197 .13788 L
.702 .13788 L
.70204 .13788 L
.7021 .13788 L
.70213 .13788 L
.70216 .13788 L
.70222 .13788 L
.70227 .13788 L
.70233 .13787 L
.7024 .13787 L
.70253 .13785 L
.70264 .13783 L
.70286 .13779 L
.7031 .13772 L
.70354 .13756 L
.70403 .1373 L
Mistroke
.70448 .137 L
.70549 .13611 L
.70642 .13505 L
.70742 .13367 L
.70939 .13029 L
.71129 .12644 L
.71312 .12241 L
.71506 .11803 L
.71693 .11399 L
.71892 .11015 L
.72083 .10714 L
.72171 .10604 L
.72268 .10504 L
.72363 .1043 L
.72415 .104 L
.72438 .10389 L
.72464 .10379 L
.72487 .10371 L
.72511 .10365 L
.72524 .10362 L
.72537 .10359 L
.72549 .10358 L
.72561 .10356 L
.72571 .10356 L
.72577 .10355 L
.72583 .10355 L
.72589 .10355 L
.72592 .10355 L
.72595 .10355 L
.72601 .10355 L
.72607 .10355 L
.72612 .10355 L
.72617 .10356 L
.72627 .10356 L
.72639 .10358 L
.7265 .10359 L
.72673 .10364 L
.72698 .1037 L
.72742 .10386 L
.7279 .10409 L
.72843 .10441 L
.72937 .10516 L
.73037 .10621 L
.73236 .10894 L
.73428 .11222 L
.73613 .11577 L
.73809 .11975 L
.73998 .12352 L
.7418 .12687 L
.74373 .12994 L
Mistroke
.7456 .13223 L
.74656 .13312 L
.74705 .13349 L
.74758 .13381 L
.74808 .13406 L
.74853 .13423 L
.74875 .13429 L
.74898 .13435 L
.74909 .13437 L
.74921 .13439 L
.7493 .1344 L
.74941 .13441 L
.74947 .13442 L
.74953 .13442 L
.74959 .13442 L
.74965 .13442 L
.7497 .13443 L
.74975 .13443 L
.74981 .13443 L
.74987 .13442 L
.74993 .13442 L
.74996 .13442 L
.74999 .13442 L
.75006 .13442 L
.75012 .13441 L
.75023 .1344 L
.75035 .13438 L
.75057 .13434 L
.75081 .13429 L
.75124 .13415 L
.75169 .13396 L
.75219 .13369 L
.7532 .13296 L
.75414 .13209 L
.75514 .13095 L
.75712 .12817 L
.75903 .12499 L
.76087 .12167 L
.76282 .11807 L
.76471 .11476 L
.76671 .11162 L
.76863 .10918 L
.76952 .10828 L
.77049 .10749 L
.77145 .10691 L
.77197 .10668 L
.77246 .10652 L
.7727 .10646 L
.77283 .10644 L
.77296 .10642 L
Mistroke
.77308 .1064 L
.77321 .10639 L
.77327 .10638 L
.77333 .10638 L
.77339 .10638 L
.77344 .10637 L
.77349 .10637 L
.77355 .10637 L
.77361 .10637 L
.77367 .10637 L
.77373 .10637 L
.77376 .10637 L
.77379 .10637 L
.77385 .10638 L
.77391 .10638 L
.774 .10639 L
.77411 .1064 L
.77433 .10643 L
.77457 .10648 L
.77483 .10655 L
.77531 .10671 L
.77577 .10691 L
.7762 .10715 L
.77719 .10783 L
.77809 .10862 L
.78002 .11082 L
.78187 .11345 L
.78385 .11661 L
.78575 .11982 L
.78758 .12286 L
.78953 .12586 L
.7914 .12833 L
.79235 .12939 L
.79339 .13036 L
.79439 .1311 L
.79486 .13138 L
.79531 .1316 L
.79578 .13179 L
.79621 .13192 L
.79644 .13197 L
.79669 .13202 L
.79681 .13204 L
.79693 .13205 L
.79701 .13206 L
.79707 .13206 L
.79714 .13207 L
.7972 .13207 L
.79726 .13207 L
.79731 .13208 L
.79735 .13208 L
Mistroke
.79738 .13208 L
.79744 .13208 L
.7975 .13208 L
.79755 .13208 L
.79762 .13207 L
.79768 .13207 L
.79779 .13206 L
.79789 .13205 L
.79813 .13203 L
.79838 .13198 L
.79861 .13193 L
.79913 .13177 L
.7996 .13158 L
.80004 .13136 L
.80103 .13072 L
.80291 .12903 L
.8049 .12664 L
.80683 .12392 L
.80867 .12109 L
.81064 .11803 L
.81253 .11522 L
.81436 .11282 L
.81629 .11073 L
.81719 .10997 L
.81816 .1093 L
.81869 .109 L
.81918 .10878 L
.81965 .10861 L
.81991 .10853 L
.82014 .10848 L
.82039 .10843 L
.82064 .10839 L
.82077 .10838 L
.8209 .10837 L
.82097 .10836 L
.82103 .10836 L
.82107 .10836 L
.8211 .10836 L
.82114 .10836 L
.82118 .10836 L
.82123 .10836 L
.82129 .10836 L
.82135 .10836 L
.8214 .10836 L
.82146 .10836 L
.82152 .10836 L
.82165 .10837 L
.82177 .10838 L
.8219 .1084 L
.82215 .10843 L
Mistroke
.8224 .10849 L
.82264 .10855 L
.82317 .10872 L
.82364 .10892 L
.82414 .10917 L
.82597 .11047 L
.82791 .11243 L
.82978 .11473 L
.83176 .11749 L
.83368 .12026 L
.83552 .12286 L
.83748 .1254 L
.83936 .12747 L
.84032 .12834 L
.84137 .12912 L
.84237 .12971 L
.84285 .12992 L
.8433 .13009 L
.84373 .13021 L
.84396 .13026 L
.8442 .13031 L
.84434 .13033 L
.84447 .13034 L
.84459 .13036 L
.84466 .13036 L
.84472 .13037 L
.84479 .13037 L
.84484 .13037 L
.8449 .13038 L
.84495 .13038 L
.84502 .13038 L
.84507 .13038 L
.84513 .13038 L
.84517 .13038 L
.8452 .13038 L
.84526 .13037 L
.84531 .13037 L
.84543 .13037 L
.84555 .13036 L
.84568 .13034 L
.84591 .13031 L
.84612 .13028 L
.84664 .13015 L
.84713 .12999 L
.84808 .12956 L
.84897 .12902 L
.85086 .12746 L
.85267 .12554 L
.85461 .12316 L
.85647 .12068 L
Mistroke
.85844 .11801 L
.86035 .11558 L
.86218 .11352 L
.8632 .11252 L
.86413 .11174 L
.86511 .11105 L
.86601 .11054 L
.86693 .11016 L
.86742 .11002 L
.86769 .10995 L
.86793 .10991 L
.86817 .10987 L
.86839 .10985 L
.86851 .10984 L
.86862 .10983 L
.86868 .10983 L
.86874 .10983 L
.86878 .10983 L
.86881 .10983 L
.86887 .10983 L
.86893 .10983 L
.86898 .10983 L
.86904 .10983 L
.8691 .10983 L
.86916 .10983 L
.86922 .10984 L
.86933 .10984 L
.86954 .10986 L
.86976 .10989 L
.86999 .10993 L
.87021 .10998 L
.87071 .11011 L
.87119 .11028 L
.87172 .11051 L
.87268 .11104 L
.8737 .11174 L
.87553 .11336 L
.87749 .11548 L
.87937 .11776 L
.88137 .12028 L
.88329 .12266 L
.88514 .12476 L
.88711 .12664 L
.88809 .1274 L
.88901 .12799 L
.88989 .12845 L
.89038 .12865 L
.89084 .12881 L
.89132 .12893 L
.89158 .12899 L
Mistroke
.89186 .12903 L
.89197 .12905 L
.89209 .12906 L
.8922 .12907 L
.89232 .12908 L
.89238 .12908 L
.89244 .12908 L
.89251 .12909 L
.89255 .12909 L
.89258 .12909 L
.89261 .12909 L
.89265 .12909 L
.89271 .12909 L
.89276 .12909 L
.89282 .12909 L
.89288 .12909 L
.89294 .12909 L
.893 .12908 L
.89306 .12908 L
.89328 .12906 L
.8934 .12905 L
.89351 .12904 L
.89376 .129 L
.89422 .12891 L
.89464 .12879 L
.89561 .12842 L
.8965 .12796 L
.8984 .12661 L
.90022 .12492 L
.90217 .12282 L
.90404 .12062 L
.90603 .11826 L
.90795 .11609 L
.90979 .11425 L
.91073 .11344 L
.91176 .11266 L
.91274 .11205 L
.91364 .1116 L
.91458 .11125 L
.91506 .11113 L
.91533 .11107 L
.91558 .11103 L
.91581 .111 L
.91604 .11098 L
.91616 .11097 L
.91627 .11097 L
.91633 .11097 L
.91637 .11097 L
.9164 .11096 L
.91643 .11096 L
Mistroke
.91647 .11096 L
.91653 .11096 L
.91658 .11096 L
.91664 .11096 L
.9167 .11097 L
.91675 .11097 L
.9168 .11097 L
.91687 .11097 L
.91698 .11098 L
.91709 .11099 L
.91721 .111 L
.91741 .11102 L
.91787 .1111 L
.91836 .11122 L
.91924 .11152 L
.92027 .112 L
.92123 .11259 L
.92308 .11402 L
.92505 .11589 L
.92694 .11792 L
.92876 .11997 L
.93069 .12211 L
.93256 .12401 L
.93454 .12574 L
.93553 .12644 L
.93645 .127 L
.93734 .12743 L
.93828 .12777 L
.93878 .1279 L
.93904 .12796 L
.93931 .128 L
.93955 .12804 L
.93968 .12805 L
.93982 .12806 L
.93994 .12807 L
.94006 .12808 L
.94011 .12808 L
.94017 .12808 L
.94023 .12808 L
.94028 .12808 L
.94034 .12808 L
.9404 .12808 L
.94045 .12808 L
.9405 .12808 L
.94056 .12808 L
.94063 .12808 L
.94074 .12807 L
.94086 .12806 L
.94097 .12805 L
.94118 .12803 L
Mistroke
.94143 .128 L
.94165 .12796 L
.94217 .12784 L
.94264 .12771 L
.94307 .12755 L
.94406 .12711 L
.94593 .12594 L
.94791 .12431 L
.94983 .12245 L
.95166 .12053 L
.95362 .11844 L
.9555 .11654 L
.95751 .11475 L
.95851 .11398 L
.95944 .11336 L
.9604 .11283 L
.96129 .11243 L
.9622 .11213 L
.96268 .11202 L
.96294 .11197 L
.96319 .11193 L
.96343 .1119 L
.96355 .11189 L
.96368 .11188 L
.96375 .11188 L
.96381 .11187 L
.96388 .11187 L
.96394 .11187 L
.964 .11187 L
.96403 .11187 L
.96407 .11187 L
.96411 .11187 L
.96415 .11187 L
.96418 .11187 L
.96421 .11187 L
.96427 .11187 L
.96433 .11187 L
.96439 .11187 L
.96446 .11187 L
.96459 .11188 L
.96472 .11189 L
.96496 .11191 L
.96518 .11194 L
.96565 .11202 L
.96614 .11213 L
.96702 .11242 L
.96796 .11283 L
.96884 .11331 L
.9707 .1146 L
.97267 .11629 L
Mistroke
.97457 .11813 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006Oooool3o`0000Cooooo0_l0000iooooo`?o0000>oooool2o`0003cooooo0ol0000ioooo
o`?o00001?ooool2o`0000Cooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000=oooool01Ol0003ooooooooooooooooo000003Wooooo00Co0000oooooooooooo0000>_oo
ool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`004_ooool5o`0000?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool0000aooooo`Go00001Oooool00ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`00
03kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000?ooooo000Jooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000>oooool0
0ol0003oooooooooo`0gooooo`04o`000?ooooooooooo`0003kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000Jooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000=oooool4o`0003[ooooo00Co0000oooooooooooo
0000>_ooool4o`0003[ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`006Oooool2o`0000Cooooo00Co0000oooooooooooo0000=oooool00ol0003oooooooooo`0koooo
o`04o`000?ooooooooooo`0003[ooooo00?o0000ooooooooool0>_ooool2o`0000Cooooo00Co0000
oooooooooooo00000oooool001[ooooo00?o0000ooooooooool00oooool2o`0003Sooooo1Ol0000j
ooooo`;o0000>oooool5o`0003Wooooo00?o0000ooooooooool00oooool2o`0000Cooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooooooo00002ol00001
ooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`1hooooo`;o003o2?ooool00ol0003oooooooooo`05ooooo`;o003oN_oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Sooooo0_l00?l8ooooo`03o`000?oooooo
oooo00Gooooo0_l00?mjooooo`7o00000Oooool001Gooooo0_l0001iooooo`;o003o2?ooool00ol0
003oooooooooo`05ooooo`;o003oNOooool2o`00007ooooo000Eooooo`03o`000?oooooooooo07So
oooo0_l00?l8ooooo`03o`000?oooooooooo00Gooooo00?o003oooooool00?l0NOooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo07Sooooo0_l00?l8ooooo`03o`000?oooooooooo00Gooooo
00?o003oooooool00?l0NOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Oooooo00Co
003ooooooooooooo003o1oooool00ol0003oooooooooo`05ooooo`03o`00oooooooo003o07Wooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`1gooooo`04o`00ooooooooooooo`00o`Oooooo
00?o0000ooooooooool01?ooool01?l00?ooooooooooool00?miooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0Moooool01?l00?ooooooooooool00?l7ooooo`03o`000?oooooooooo00Co
oooo00Co003ooooooooooooo003oNOooool1o`00007ooooo000Eooooo`;o0000N?ooool01?l00?oo
ooooooooool00?l7ooooo`03o`000?oooooooooo00Cooooo00Co003ooooooooooooo003oN?ooool2
o`00007ooooo000Eooooo`03o`000?oooooooooo07Oooooo00Co003ooooooooooooo003o1oooool0
0ol0003oooooooooo`04ooooo`04o`00ooooooooooooo`00ogWooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1gooooo`04o`00ooooooooooooo`00o`Oooooo00?o0000ooooooooool01?oo
ool01?l00?ooooooooooool00?miooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0Mooo
ool01?l00?ooooooooooool00?l7ooooo`03o`000?oooooooooo00Cooooo00Co003ooooooooooooo
003oNOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07Oooooo00Co003ooooooooooooo
003o1oooool00ol0003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l0N?ooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo07Oooooo00Co003ooooooooooooo003o1oooool00ol0
003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l0N?ooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo07Kooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00Go003oooooooooooooooooo`00o`1hooooo`7o00000Oooool0
01Gooooo0_l0001gooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol0
003oooooooooo`04ooooo`05o`00ooooooooooooooooool00?l0Moooool2o`00007ooooo000Eoooo
o`03o`000?oooooooooo06_ooooo0_l00?l9ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01oooool2o`00ofgooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1[ooooo`;o
003o2Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Oooooo0ol00?m/ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0J_ooool01?l00?ooooooooooool00?l8ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?m/oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0J_ooool01?l00?ooooooooooool00?l8oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`00oooooooooooo00;ooooo00?o003oooooooooool01_ooool01?l00?ooooooooooool00?m/
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0G_ooool2o`00o`[ooooo00Co003ooooo
oooooooo003o2?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Kooooo00Co003o
oooooooooooo003o2_ooool2o`00of3ooooo0Ol00001ooooo`005Oooool2o`0005oooooo00?o003o
ooooool00?l02Oooool01?l00?ooooooooooool00?l8ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01_ooool01Ol00?oooooooooooooooooo003o00Sooooo0ol00?mOooooo`;o0000
0Oooool001Gooooo00?o0000ooooooooool0D_ooool2o`00o`Wooooo00Co003ooooooooooooo003o
2?ooool01Ol00?oooooooooooooooooo003o00Sooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`06ooooo`05o`00ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l9
ooooo`?o003oDoooool1o`00007ooooo000Eooooo`03o`000?oooooooooo04Gooooo0_l00?l:oooo
o`?o003o2Oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01Oooool0
1Ol00?oooooooooooooooooo003o00Sooooo00Co003ooooooooooooo003o2Oooool00ol00?oooooo
o`00o`0:ooooo`;o003oAoooool1o`00007ooooo000Eooooo`03o`000?oooooooooo02cooooo0_l0
0?l:ooooo`?o003o2Oooool4o`00o`Wooooo00Co003ooooooooooooo003o2?ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03
o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`09ooooo`04o`00oooooooooooo
o`00o`Sooooo1?l00?l9ooooo`?o003o2oooool00ol00?ooooooooooo`0/ooooo`7o00000Oooool0
00kooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool02?ooool3o`00
o`[ooooo0ol00?l9ooooo`Co003o2?ooool2o`00o`03ooooool00?oooooo00Sooooo00Go003ooooo
ooooooooooooo`00o`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol00?oooooooooo
oooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00
oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00
ooooooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l9ooooo`04o`00oooooooo003o
o`00o`Wooooo0ol00?l9ooooo`Co003o2Oooool3o`00o`_ooooo00?o003oooooooooool01_ooool1
o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01Oooool4
o`00o`Sooooo0_l00?l00ooooooo003oo`00o`07ooooo`;o003o0_ooool2o`00o`Oooooo0_l00?l2
ooooo`03o`00oooooooooooo00Kooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooo
oooooooo00;ooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02ooooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00oooo
ooooooooooooool00?l02?ooool01Ol00?oooooooooooooooooo003o00Sooooo00Co003ooooooooo
oooo003o2?ooool2o`00o`03ooooool00?oo003o00Sooooo1Ol00?l6ooooo`7o00000Oooool000go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01?ooool2o`00o`?ooooo0_l00?l6ooooo`03o`00oooooooooooo
00;ooooo0_l00?l6ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol0
0?ooooooooooo`02ooooo`;o003o1_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo
00Cooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01?ooool2o`00o`?ooooo0_l00?l6ooooo`03o`00oooooooooooo
00;ooooo0_l00?l5ooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool6o`00
0003o`00ool0003o000000Co000000?o003oo`000?l000000_l00002o`00o`Go00000_l00?l4o`00
0003o`00ool0003o000000Co000000?o003oo`000?l000000ol000000ol00?oo0000o`000004o`00
0003o`00ool0003o000000;o00000_l00?l5o`000003o`00ool0003o000000?o000000?o003oo`00
0?l000001?l000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o000000?o003oo`00
0?l000001?l000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o000000?o003oo`00
0?l000001?l000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o000000?o003oo`00
0?l000002_l000000ol00?oo0000o`000003o`000003o`00ool0003o000000Co000000?o003oo`00
0?l000000ol000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o000000?o003oo`00
0?l000001?l000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o000000?o003oo`00
0?l000001?l000000ol00?oo0000o`000003o`000003o`00ool0003o000000?o00000_l00?l5o`00
0003o`00ool0003o000000?o00000_l00?l4o`000003o`00ool0003o000000Co000000?o003oo`00
0?l000000_l00002o`00o`Go00000_l00?l4o`000003o`00ool0003o000000Co000000?o003oo`00
0?l000001?l00001ooooo`003Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
00[ooooo0_l00?l2ooooo`;o003o1oooool01Ol00?oooooooooooooooooo003o00Sooooo00Go003o
ooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Ooo
ool01?l00?ooooooooooooooool2o`00o`Kooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o0000ooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`05ooooo`04o`00ooooooooooooooooo`;o003o1oooool00ol00?ooooooooooo`02o`00o`Oo
oooo0_l00?l2ooooo`03o`00oooooooooooo00_ooooo0Ol00001ooooo`003Oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00cooooo0ol00?l9ooooo`?o003o2_ooool4o`00o`So
oooo0_l00?l00ooooooo003oooooo`07ooooo`05o`00ooooooooooooooooool00?l02?ooool01Ol0
0?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04
ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00Gooooo00Go003oooooooooooooooooo`00o`08ooooo`05o`00oooo
ooooooooooooool00?l02?ooool01?l00?ooooooooooool00?l9ooooo`Co003o2Oooool3o`00o`Wo
oooo0ol00?l>ooooo`7o00000Oooool000kooooo0_l00005ooooo`03o`000?oooooooooo03;ooooo
0ol00?l9ooooo`?o003o2Oooool2o`00o`;ooooo00?o003oooooooooool01_ooool01Ol00?oooooo
oooooooooooo003o00Oooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`03
o`00oooooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Gooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`04ooooo`05
o`00ooooooooooooooooool00?l02Oooool01?l00?ooooooooooool00?l9ooooo`?o003o2_ooool2
o`00ocCooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`0oooooo`;o003o2_ooool3o`00
o`Wooooo00Co003ooooooooooooo003o2?ooool01Ol00?oooooooooooooooooo003o00Oooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00?ooooo00?o
003oooooooooool01Oooool01Ol00?oooooooooooooooooo003o00Sooooo00Co003ooooooooooooo
003o2Oooool3o`00o`_ooooo00?o003oooooooooool0?oooool1o`00007ooooo000Eooooo`03o`00
0?oooooooooo05Oooooo1?l00?l8ooooo`05o`00ooooooooooooooooool00?l01oooool00ol00?oo
ooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`05ooooo`05o`00ooooooooooooooooool00?l02?ooool4o`00oeWooooo0Ol00001oooo
o`005Oooool2o`0005Wooooo0_l00?l9ooooo`05o`00ooooooooooooooooool00?l01oooool00ol0
0?ooooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool00_ooool00ol0
0?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l02Oooool2o`00oeWooooo0_l00001
ooooo`005Oooool00ol0003oooooooooo`1Tooooo`03o`00oooooooo003o00Sooooo00?o003ooooo
ooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooo`00o`1Vooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0I?ooool3o`00o`Wooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00;ooooo00?o003oooooooooool01_ooool3o`00ofKooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1Uooooo`;o003o2Oooool01Ol00?oooooooooooooooooo003o00Oooooo00?o003ooooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo00Gooooo00Go003ooooo
ooooooooooooo`00o`09ooooo`;o003oIoooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
073ooooo00Go003oooooooooooooooooo`00o`07ooooo`03o`00oooooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l0L_oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo073ooooo00Go003oooooooooooooooooo`00
o`07ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol00?oooooooooo
o`05ooooo`05o`00ooooooooooooooooool00?l0L_ooool1o`00007ooooo000Eooooo`;o0000LOoo
ool01Ol00?oooooooooooooooooo003o00Oooooo00?o003oooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`00oooooooooooo00Kooooo00Co003ooooooooooooo003oLOooool2o`00007o
oooo000Eooooo`03o`000?oooooooooo077ooooo00?o003oooooool00?l02?ooool00ol00?oooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool01_ooool01?l00?oooooo
ooooool00?mbooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0LOooool00ol00?oooooo
o`00o`08ooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`06ooooo`03o`00oooooooo003o07?ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1aooooo`03o`00oooooooo003o00Sooooo00?o003oooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`00oooooooooooo00Kooooo00?o003oooooool00?l0Loooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo07;ooooo0_l00?l8ooooo`03o`00oooooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`07ooooo`;o003oLoooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo07cooooo00?o003oooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`00oooooooooooo07cooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1looooo`03
o`00oooooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`1looooo`7o
00000Oooool001Gooooo0_l0001mooooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol00?ooooooooooo`1kooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0O?oo
ool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0O?oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07cooooo00?o003oooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`00oooooooooooo07cooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1looooo`03o`00oooooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
0?ooooooooooo`1looooo`7o00000Oooool001Gooooo00?o0000ooooooooool0O?ooool00ol00?oo
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0O?ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo07cooooo00?o003oooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`00oooooooooooo07cooooo0Ol00001ooooo`005Oooool2o`0007gooooo00?o
003oooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo07_ooooo0_l0
0001ooooo`005Oooool00ol0003oooooooooo`1looooo`03o`00oooooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol00?ooooooooooo`1looooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0O?ooool00ol00?ooooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o003ooooo
ooooool0O?ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07cooooo00?o003ooooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`00oooooooooooo07cooooo0Ol00001ooooo`00
0_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0
OOooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0
O?ooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo07gooooo00?o003oooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`00oooooooooooo07cooooo0Ol00001ooooo`0000Goooooo`000?oooooo
ooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0OOooool00ol00?oo
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool0O?ooool1o`00007o
oooo00001Ooooooo0000oooooooooooo000000_ooooo00?o0000ooooooooool00_ooool3o`0007go
oooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo003o07kooooo0_l00001oooo
o`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool00ol0003oooooooooo`1moooo
o`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`1oooooo`7o00000Oooool0
0005ooooool0003oooooooooool000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo07gooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo003o07oooooo0Ol0
0001ooooo`000_ooool2o`0000Sooooo1Ol00004ooooo`03o`000?oooooooooo07gooooo00?o003o
ooooooooool00_ooool01Ol0003ooooooooooooooooo003o07oooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1mooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00
o`1oooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0OOooool00ol00?ooooooooooo`02
ooooo`05o`000?ooooooooooooooool00?l0Ooooool1o`00007ooooo000Eooooo`;o0000O_ooool0
0ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l0O_ooool2o`00007ooooo000E
ooooo`03o`000?oooooooooo07gooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooo
oooo003o07oooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1mooooo`03o`00oooooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00o`1oooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0OOooool00ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l0Oooo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07gooooo00?o003oooooooooool00_ooool0
1Ol0003ooooooooooooooooo003o07oooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1m
ooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`1oooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0OOooool00ol00?ooooooooooo`02ooooo`05o`000?oooooo
ooooooooool00?l0Ooooool1o`00007ooooo000Eooooo`;o0000O_ooool00ol00?ooooooooooo`02
ooooo`05o`000?ooooooooooooooool00?l0O_ooool2o`00007ooooo000Eooooo`03o`000?oooooo
oooo07gooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo003o07oooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1mooooo`03o`00oooooooooooo00;ooooo00Go0000
ooooooooooooooooo`00o`1oooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0OOooool0
0ol00?ooooooooooo`02ooooo`05o`000?ooooooooooooooool00?l0Ooooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo07gooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooo
oooo003o07oooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1mooooo`03o`00oooooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00o`1oooooo`7o00000Oooool001Gooooo0_l0001n
ooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00o`1nooooo`;o00000Ooo
ool001Gooooo00?o0000ooooooooool0OOooool00ol00?ooooooooooo`02ooooo`05o`000?oooooo
ooooooooool00?l0Ooooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07gooooo00?o003o
ooooooooool00_ooool01Ol0003ooooooooooooooooo003o07oooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1mooooo`03o`00oooooooooooo00;ooooo00Go0000ooooooooooooooooo`00
o`1oooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0OOooool00ol00?ooooooooooo`02
ooooo`05o`000?ooooooooooooooool00?l0Ooooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo07gooooo00?o003oooooooooool00_ooool01Ol0003ooooooooooooooooo003o07oooooo0Ol0
0001ooooo`005Oooool2o`0007oooooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooo
oooooooo07cooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`1nooooo`05o`00oooooooo
ooooooooool000000oooool00ol00?ooooooooooo`1mooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0O_ooool01Ol00?oooooooooooooooooo000000?ooooo00?o003oooooooooool0OOoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07kooooo00Go003oooooooooooooooooo`00
0002ooooo`03o`00oooooooooooo07kooooo0Ol00001ooooo`003Oooool3o`0000Gooooo00?o0000
ooooooooool0O_ooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool0O_oo
ool1o`00007ooooo000>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0O_ooool0
1Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool0O_ooool1o`00007ooooo000>
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0O_ooool01Ol00?oooooooooooooo
oooo000000;ooooo00?o003oooooooooool0O_ooool1o`00007ooooo000>ooooo`03o`000?oooooo
oooo00Cooooo0ol0001nooooo`05o`00ooooooooooooooooool000000_ooool00ol00?oooooooooo
o`1mooooo`;o00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1n
ooooo`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`1nooooo`7o00000Ooo
ool000gooooo0_l00006ooooo`03o`000?oooooooooo07kooooo00Go003oooooooooooooooooo`00
0002ooooo`03o`00oooooooooooo07kooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo07kooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooo
oooooooo07kooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1nooooo`05o`00oooooooo
ooooooooool000000_ooool00ol00?ooooooooooo`1nooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0O_ooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool0O_oo
ool1o`00007ooooo000Eooooo`;o0000Ooooool01Ol00?oooooooooooooooooo000000;ooooo00?o
003oooooooooool0OOooool2o`00007ooooo000Eooooo`03o`000?oooooooooo07kooooo00Go003o
ooooooooooooooooo`000002ooooo`03o`00oooooooooooo07kooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1nooooo`05o`00ooooooooooooooooool000000_ooool00ol00?oooooooooo
o`1nooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0O_ooool01Ol00?oooooooooooooo
oooo000000;ooooo00?o003oooooooooool0O_ooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo07kooooo00Go003oooooooooooooooooo`000002ooooo`03o`00oooooooooooo07kooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1nooooo`05o`00ooooooooooooooooool000000_oo
ool00ol00?ooooooooooo`1nooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0O_ooool0
1Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool0O_ooool1o`00007ooooo000E
ooooo`;o0000Ooooool01Ol00?oooooooooooooooooo000000;ooooo00?o003oooooooooool0OOoo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo07kooooo00Go003oooooooooooooooooo`00
0002ooooo`03o`00oooooooooooo07kooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1n
ooooo`05o`00ooooooooooooooooool000000_ooool00ol00?ooooooooooo`1nooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0O_ooool01Ol00?oooooooooooooooooo000000;ooooo00?o
003oooooooooool0O_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07kooooo00Go003o
ooooooooooooooooo`000002ooooo`03o`00oooooooooooo07kooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1nooooo`05o`00ooooooooooooooooool000000_ooool00ol00?oooooooooo
o`1nooooo`7o00000Oooool001Gooooo0_l0001oooooo`05o`00ooooooooooooooooool000000_oo
ool00ol00?ooooooooooo`1mooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0Ooooool0
1?l00?ooooooooooool00002ooooo`03o`00oooooooooooo07kooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1oooooo`04o`00ooooooooooooo`0000;ooooo00?o003oooooooooool0O_oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07oooooo00Co003ooooooooooooo00000_oo
ool00ol00?ooooooooooo`1nooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0Ooooool0
1_l00?ooooooooooool0003oooooo`00oh7ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1oooooo`06o`00ooooooooooooo`000?oooooo003oPOooool1o`00007ooooo000Eooooo`;o0000
P?ooool01_l00?ooooooooooool0003oooooo`00oh3ooooo0_l00001ooooo`005Oooool00ol0003o
ooooooooo`1oooooo`06o`00ooooooooooooo`000?oooooo003oPOooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo07oooooo00Ko003ooooooooooooo0000ooooool00?n1ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0Ooooool01_l00?ooooooooooool0003oooooo`00oh7ooooo
0Ol00001ooooo`0000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`1oooooo`06o`00ooooooooooooo`000?oooooo003oPOooool1o`00
007ooooo0002ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo07oooooo00Ko003ooooooooooooo0000ooooool00?n1ooooo`7o00000Ooo
ool000;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07oooooo00Ko003ooooooooooooo0000ooooool00?n1ooooo`7o00000Oooool000;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`?o0000Ooooool01_l00?oooooooooo
ool0003oooooo`00oh3ooooo0_l00001ooooo`000_ooool00ol0003oooooooooo`07ooooo`Co0000
1Oooool00ol0003oooooooooo`1oooooo`06o`00ooooooooooooo`000?oooooo003oPOooool1o`00
007ooooo00000ooooooo0000o`000009ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0Ooooool01_l00?ooooooooooool0003oooooo`00oh7ooooo0Ol00001ooooo`000_ooool00ol0
003oooooooooo`07ooooo`Go00001?ooool00ol0003oooooooooo`1oooooo`06o`00oooooooooooo
o`000?oooooo003oPOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07oooooo00Ko003o
oooooooooooo0000ooooool00?n1ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0Oooo
ool01_l00?ooooooooooool0003oooooo`00oh7ooooo0Ol00001ooooo`005Oooool2o`00083ooooo
00Ko003ooooooooooooo0000ooooool00?n0ooooo`;o00000Oooool001Gooooo00?o0000oooooooo
ool0Ooooool01_l00?ooooooooooool0003oooooo`00oh7ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1oooooo`06o`00ooooooooooooo`000?oooooo003oPOooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo07oooooo00Ko003ooooooooooooo0000ooooool00?n1ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0Ooooool01_l00?ooooooooooool0003oooooo`00oh7o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`20ooooo`05o`00oooooooo0000ooooool0
0?l0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo083ooooo00Go003oooooool0003o
ooooo`00o`21ooooo`7o00000Oooool001Gooooo0_l00021ooooo`04o`00oooooooo0000o`00oh7o
oooo0_l00001ooooo`005Oooool00ol0003oooooooooo`20ooooo`04o`00oooooooo0000o`00oh;o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`20ooooo`04o`00oooooooo0000o`00oh;o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`20ooooo`04o`00oooooooo0000o`00oh;o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`20ooooo`04o`00oooooooo0000o`00oh;o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`20ooooo`04o`00oooooooo0000o`00oh;o
oooo0Ol00001ooooo`005Oooool2o`00087ooooo00Co003oooooool0003o003oPOooool2o`00007o
oooo000Eooooo`03o`000?oooooooooo083ooooo00Co003oooooool0003o003oP_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo083ooooo00Co003oooooool0003o003oP_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo083ooooo00Co003oooooool0003o003oP_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo083ooooo00Co003oooooool0003o003oP_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo083ooooo00Co003oooooool0003o003oP_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo087ooooo00?o003oo`000?l00?l0P_ooool1o`00007ooooo
000Eooooo`;o0000P_ooool00ol00?oo0000o`00o`21ooooo`;o00000Oooool001Gooooo00?o0000
ooooooooool0POooool00ol00?oo0000o`00o`22ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0POooool00ol00?oo0000o`00o`22ooooo`7o00000Oooool000cooooo1Ol00004ooooo`03
o`000?oooooooooo087ooooo00?o003oo`000?l00?l0P_ooool1o`00007ooooo000=ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0POooool2o`00oh?ooooo0Ol00001ooooo`00
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo087ooooo0_l00?n3ooooo`7o0000
0Oooool000oooooo00?o0000ooooooooool00oooool3o`00087ooooo0_l00?n2ooooo`;o00000Ooo
ool000cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000<ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo000=ooooo`?o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool0
01Goooooool0000;o`00007ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.1932, -0.687297, \
0.0791273, 0.0155843}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Narrower pulse", "Subsection"],

Cell[BoxData[
    \(\(x[t_] := u[t + 1/2]\  - \ u[t - 1/2];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X[f_] = 
        FourierTransform[x[t], t, 
              f]\  /. {\[Delta][b_\ a_ + f\ a_] \[Rule] \[Delta][b + f]/
                  a, \[Delta][\(-b_\)\ a_ + 
                    f_\ a_] \[Rule] \[Delta][\(-b\) + f]/a}\  // \ 
          ComplexExpand;\)\), "\[IndentingNewLine]", 
    \(\({{x[t]}, {X[f]}}\  // FullSimplify\)\  // \ 
      TraditionalForm\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{
                RowBox[{
                  InterpretationBox["\[Theta]",
                    UnitStep,
                    Editable->False,
                    Selectable->False], "(", \(t + 1\/2\), ")"}], "-", 
                RowBox[{
                  InterpretationBox["\[Theta]",
                    UnitStep,
                    Editable->False,
                    Selectable->False], "(", \(t - 1\/2\), ")"}]}]},
            {\(\(sin(f\ \[Pi])\)\/\(f\ \[Pi]\)\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gx2 = 
      Plot[Evaluate[x[t]], {t, \(-2\), 2}, PlotStyle \[Rule] {Red}, \ 
        PlotPoints \[Rule] 500, \ PlotRange \[Rule] {\(- .1\), 2.1}]; 
    gX2 = Plot[Evaluate[X[f]], {f, \(-10\), 10}, PlotStyle \[Rule] {Red}, \ 
        PlotPoints \[Rule] 500, \ PlotRange \[Rule] All];\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0280925 0.280925 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44948 -18 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.5)] -0.0125 .16855 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(1.5)] -0.0125 .44948 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(2)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .02809 m
.02567 .02809 L
.02769 .02809 L
.0296 .02809 L
.03143 .02809 L
.03338 .02809 L
.03525 .02809 L
.03724 .02809 L
.03917 .02809 L
.04101 .02809 L
.04298 .02809 L
.04487 .02809 L
.04669 .02809 L
.04863 .02809 L
.05049 .02809 L
.05248 .02809 L
.05439 .02809 L
.05622 .02809 L
.05818 .02809 L
.06006 .02809 L
.06206 .02809 L
.06399 .02809 L
.06584 .02809 L
.06781 .02809 L
.06971 .02809 L
.07154 .02809 L
.07348 .02809 L
.07535 .02809 L
.07734 .02809 L
.07926 .02809 L
.0811 .02809 L
.08306 .02809 L
.08495 .02809 L
.08677 .02809 L
.0887 .02809 L
.09056 .02809 L
.09254 .02809 L
.09445 .02809 L
.09628 .02809 L
.09823 .02809 L
.10011 .02809 L
.10211 .02809 L
.10403 .02809 L
.10588 .02809 L
.10785 .02809 L
.10974 .02809 L
.11156 .02809 L
.1135 .02809 L
.11537 .02809 L
.11736 .02809 L
Mistroke
.11927 .02809 L
.12111 .02809 L
.12307 .02809 L
.12495 .02809 L
.12695 .02809 L
.12888 .02809 L
.13074 .02809 L
.13271 .02809 L
.13462 .02809 L
.13644 .02809 L
.13839 .02809 L
.14026 .02809 L
.14226 .02809 L
.14418 .02809 L
.14602 .02809 L
.14799 .02809 L
.14988 .02809 L
.15169 .02809 L
.15363 .02809 L
.15549 .02809 L
.15748 .02809 L
.15938 .02809 L
.16122 .02809 L
.16317 .02809 L
.16505 .02809 L
.16705 .02809 L
.16898 .02809 L
.17083 .02809 L
.1728 .02809 L
.1747 .02809 L
.17652 .02809 L
.17846 .02809 L
.18033 .02809 L
.18232 .02809 L
.18424 .02809 L
.18608 .02809 L
.18804 .02809 L
.18993 .02809 L
.19174 .02809 L
.19367 .02809 L
.19553 .02809 L
.19751 .02809 L
.19941 .02809 L
.20124 .02809 L
.20319 .02809 L
.20507 .02809 L
.20706 .02809 L
.20899 .02809 L
.21083 .02809 L
.2128 .02809 L
Mistroke
.21469 .02809 L
.21651 .02809 L
.21845 .02809 L
.22032 .02809 L
.2223 .02809 L
.22421 .02809 L
.22605 .02809 L
.22801 .02809 L
.22989 .02809 L
.23189 .02809 L
.23382 .02809 L
.23567 .02809 L
.23765 .02809 L
.23955 .02809 L
.24137 .02809 L
.24332 .02809 L
.24519 .02809 L
.24718 .02809 L
.2491 .02809 L
.25094 .02809 L
.25291 .02809 L
.2548 .02809 L
.25661 .02809 L
.25855 .02809 L
.26041 .02809 L
.26239 .02809 L
.2643 .02809 L
.26613 .02809 L
.26808 .02809 L
.26996 .02809 L
.27196 .02809 L
.27388 .02809 L
.27573 .02809 L
.2777 .02809 L
.2796 .02809 L
.28142 .02809 L
.28336 .02809 L
.28523 .02809 L
.28722 .02809 L
.28913 .02809 L
.29097 .02809 L
.29293 .02809 L
.29481 .02809 L
.29682 .02809 L
.29875 .02809 L
.3006 .02809 L
.30258 .02809 L
.30448 .02809 L
.30631 .02809 L
.30826 .02809 L
Mistroke
.31014 .02809 L
.31213 .02809 L
.31405 .02809 L
.31589 .02809 L
.31786 .02809 L
.31975 .02809 L
.32157 .02809 L
.32351 .02809 L
.32537 .02809 L
.32735 .02809 L
.32926 .02809 L
.3311 .02809 L
.33305 .02809 L
.33494 .02809 L
.33694 .02809 L
.33886 .02809 L
.34072 .02809 L
.34269 .02809 L
.34459 .02809 L
.34641 .02809 L
.34835 .02809 L
.35023 .02809 L
.35221 .02809 L
.35413 .02809 L
.35597 .02809 L
.35793 .02809 L
.35982 .02809 L
.36164 .02809 L
.36357 .02809 L
.36543 .02809 L
.36741 .02809 L
.36931 .02809 L
.37115 .02809 L
.3731 .02809 L
.37497 .02809 L
.37697 .02809 L
.37889 .02809 L
.37977 .02809 L
.38027 .02809 L
.38052 .02809 L
.38074 .02809 L
.38085 .02809 L
.38088 .02809 L
.38092 .02809 L
.38098 .30902 L
.38104 .30902 L
.38109 .30902 L
.3812 .30902 L
.3817 .30902 L
.38271 .30902 L
Mistroke
.38456 .30902 L
.38654 .30902 L
.38844 .30902 L
.39027 .30902 L
.39221 .30902 L
.39409 .30902 L
.39608 .30902 L
.398 .30902 L
.39984 .30902 L
.4018 .30902 L
.4037 .30902 L
.40551 .30902 L
.40745 .30902 L
.40931 .30902 L
.41129 .30902 L
.4132 .30902 L
.41503 .30902 L
.41699 .30902 L
.41887 .30902 L
.42086 .30902 L
.42279 .30902 L
.42464 .30902 L
.42661 .30902 L
.42851 .30902 L
.43033 .30902 L
.43227 .30902 L
.43414 .30902 L
.43613 .30902 L
.43805 .30902 L
.43989 .30902 L
.44185 .30902 L
.44373 .30902 L
.44555 .30902 L
.44748 .30902 L
.44934 .30902 L
.45131 .30902 L
.45322 .30902 L
.45505 .30902 L
.457 .30902 L
.45887 .30902 L
.46086 .30902 L
.46279 .30902 L
.46463 .30902 L
.4666 .30902 L
.46849 .30902 L
.47031 .30902 L
.47225 .30902 L
.47412 .30902 L
.4761 .30902 L
.47801 .30902 L
Mistroke
.47985 .30902 L
.4818 .30902 L
.48368 .30902 L
.48568 .30902 L
.48761 .30902 L
.48947 .30902 L
.49144 .30902 L
.49334 .30902 L
.49517 .30902 L
.49711 .30902 L
.49898 .30902 L
.50097 .30902 L
.50289 .30902 L
.50473 .30902 L
.50669 .30902 L
.50858 .30902 L
.5104 .30902 L
.51233 .30902 L
.51419 .30902 L
.51617 .30902 L
.51808 .30902 L
.51991 .30902 L
.52186 .30902 L
.52374 .30902 L
.52574 .30902 L
.52766 .30902 L
.52951 .30902 L
.53148 .30902 L
.53338 .30902 L
.5352 .30902 L
.53714 .30902 L
.53901 .30902 L
.54099 .30902 L
.5429 .30902 L
.54474 .30902 L
.5467 .30902 L
.54859 .30902 L
.55059 .30902 L
.55252 .30902 L
.55438 .30902 L
.55635 .30902 L
.55825 .30902 L
.56008 .30902 L
.56203 .30902 L
.5639 .30902 L
.5659 .30902 L
.56782 .30902 L
.56966 .30902 L
.57163 .30902 L
.57352 .30902 L
Mistroke
.57534 .30902 L
.57727 .30902 L
.57914 .30902 L
.58112 .30902 L
.58303 .30902 L
.58486 .30902 L
.58682 .30902 L
.5887 .30902 L
.5907 .30902 L
.59262 .30902 L
.59447 .30902 L
.59645 .30902 L
.59834 .30902 L
.60017 .30902 L
.60211 .30902 L
.60398 .30902 L
.60597 .30902 L
.60789 .30902 L
.60973 .30902 L
.61169 .30902 L
.61358 .30902 L
.61539 .30902 L
.6164 .30902 L
.61732 .30902 L
.61823 .30902 L
.61868 .30902 L
.61881 .30902 L
.61888 .30902 L
.61894 .30902 L
.619 .30902 L
.61904 .30902 L
.61907 .02809 L
.61912 .02809 L
.61918 .02809 L
.621 .02809 L
.62294 .02809 L
.62481 .02809 L
.62679 .02809 L
.6287 .02809 L
.63054 .02809 L
.6325 .02809 L
.63438 .02809 L
.63638 .02809 L
.63831 .02809 L
.64017 .02809 L
.64214 .02809 L
.64404 .02809 L
.64587 .02809 L
.64781 .02809 L
.64969 .02809 L
Mistroke
.65168 .02809 L
.65359 .02809 L
.65544 .02809 L
.6574 .02809 L
.65929 .02809 L
.66111 .02809 L
.66304 .02809 L
.66491 .02809 L
.66689 .02809 L
.66879 .02809 L
.67063 .02809 L
.67258 .02809 L
.67446 .02809 L
.67646 .02809 L
.67838 .02809 L
.68023 .02809 L
.6822 .02809 L
.6841 .02809 L
.68592 .02809 L
.68786 .02809 L
.68973 .02809 L
.69172 .02809 L
.69363 .02809 L
.69547 .02809 L
.69743 .02809 L
.69932 .02809 L
.70132 .02809 L
.70325 .02809 L
.70511 .02809 L
.70708 .02809 L
.70899 .02809 L
.71082 .02809 L
.71277 .02809 L
.71464 .02809 L
.71663 .02809 L
.71855 .02809 L
.7204 .02809 L
.72237 .02809 L
.72426 .02809 L
.72608 .02809 L
.72802 .02809 L
.72988 .02809 L
.73186 .02809 L
.73377 .02809 L
.73561 .02809 L
.73756 .02809 L
.73945 .02809 L
.74145 .02809 L
.74337 .02809 L
.74523 .02809 L
Mistroke
.7472 .02809 L
.7491 .02809 L
.75092 .02809 L
.75287 .02809 L
.75474 .02809 L
.75673 .02809 L
.75864 .02809 L
.76049 .02809 L
.76245 .02809 L
.76434 .02809 L
.76615 .02809 L
.76809 .02809 L
.76995 .02809 L
.77192 .02809 L
.77383 .02809 L
.77566 .02809 L
.77761 .02809 L
.77949 .02809 L
.78149 .02809 L
.78341 .02809 L
.78526 .02809 L
.78723 .02809 L
.78912 .02809 L
.79094 .02809 L
.79288 .02809 L
.79475 .02809 L
.79674 .02809 L
.79865 .02809 L
.80049 .02809 L
.80245 .02809 L
.80433 .02809 L
.80633 .02809 L
.80826 .02809 L
.81012 .02809 L
.81209 .02809 L
.81399 .02809 L
.81582 .02809 L
.81777 .02809 L
.81964 .02809 L
.82163 .02809 L
.82355 .02809 L
.8254 .02809 L
.82736 .02809 L
.82925 .02809 L
.83107 .02809 L
.83301 .02809 L
.83487 .02809 L
.83685 .02809 L
.83876 .02809 L
.84059 .02809 L
Mistroke
.84255 .02809 L
.84443 .02809 L
.84643 .02809 L
.84835 .02809 L
.8502 .02809 L
.85217 .02809 L
.85407 .02809 L
.85589 .02809 L
.85784 .02809 L
.85971 .02809 L
.86169 .02809 L
.86361 .02809 L
.86545 .02809 L
.86741 .02809 L
.8693 .02809 L
.87111 .02809 L
.87304 .02809 L
.8749 .02809 L
.87688 .02809 L
.87878 .02809 L
.88061 .02809 L
.88256 .02809 L
.88444 .02809 L
.88643 .02809 L
.88835 .02809 L
.8902 .02809 L
.89217 .02809 L
.89406 .02809 L
.89588 .02809 L
.89782 .02809 L
.89969 .02809 L
.90167 .02809 L
.90358 .02809 L
.90542 .02809 L
.90737 .02809 L
.90926 .02809 L
.91126 .02809 L
.91319 .02809 L
.91504 .02809 L
.91701 .02809 L
.91891 .02809 L
.92074 .02809 L
.92268 .02809 L
.92456 .02809 L
.92655 .02809 L
.92846 .02809 L
.93031 .02809 L
.93227 .02809 L
.93416 .02809 L
.93598 .02809 L
Mistroke
.93791 .02809 L
.93977 .02809 L
.94175 .02809 L
.94366 .02809 L
.94549 .02809 L
.94744 .02809 L
.94932 .02809 L
.95132 .02809 L
.95324 .02809 L
.95509 .02809 L
.95706 .02809 L
.95896 .02809 L
.96078 .02809 L
.96272 .02809 L
.96459 .02809 L
.96658 .02809 L
.96849 .02809 L
.97033 .02809 L
.97229 .02809 L
.97417 .02809 L
.97618 .02809 L
.97619 .02809 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006oooool5o`0003_ooooo0ol0000kooooo`;o0000??ooool3o`0003_ooooo1Ol00006oooo
o`007?ooool01?l0003oooooooooool0000looooo`03o`000?oooooooooo03Wooooo00Co0000oooo
oooooooo0000??ooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000Kooooo000E
ooooo`Go00000oooool00ol0003oooooooooo`0dooooo`Go00000oooool00ol0003oooooooooo`0i
ooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`06ooooo`007_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Wooooo00Co0000
oooooooooooo0000??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo000K
ooooo`05o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`0iooooo`04o`000?oo
ooooooooo`0003cooooo00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000000Ko
oooo000Kooooo`05o`000?ooooooooooooooool00000>oooool2o`0003_ooooo00Co0000oooooooo
oooo0000>oooool2o`0003cooooo00Go0000ooooooooooooooooo`000006ooooo`007?ooool3o`00
03gooooo00?o0000ooooooooool0>_ooool2o`0003gooooo00?o0000ooooooooool0>oooool3o`00
00Oooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooo
oooo00002ol00001ooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`0Loooo
o`03ool00?oooooooooo05cooooo00?oo`00ooooooooool00oooool1o`00007ooooo000=ooooo`04
o`000?ooooooooooo`0000Cooooo0_l00004ooooof3oo`007oooool00ol0003oooooooooo`0Loooo
of3oo`001?ooool2o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0H_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00oooo
ooooool0H_ooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0H_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00oooo
ooooool0H_ooool1o`00007ooooo000>ooooo`;o00001Oooool00ol0003oooooooooo`1Rooooo`03
ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`1Rooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0Mooooo`03o`00
0?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oo
oooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooo
oooo01gooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`1Rooooo`7o00000Oooool0
01Gooooo0_l0001Sooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo
003oooooooooo`1Qooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0H_ooool00ooo003o
ooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003ooooo
ooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo003ooooooooo
o`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0M
ooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`0Loooo
o`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Rooooo`03
ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`1Rooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0Mooooo`03o`00
0?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007ooooo000Eooooo`;o0000Hooo
ool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0HOoo
ool2o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool0
0ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo
003oooooooooo`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_ooool00ooo003o
ooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003ooooo
ooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo003ooooooooo
o`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0M
ooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007ooooo000Eoooo
o`;o0000Hoooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00oooo
ooooool0HOooool2o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00oooooooo
ool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool0
7?ooool00ooo003oooooooooo`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_oo
ool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool0
0ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo
003oooooooooo`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_ooool00ooo003o
ooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007o
oooo000Eooooo`;o0000Hoooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo
00?oo`00ooooooooool0HOooool2o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?o
o`00ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000
ooooooooool07?ooool00ooo003oooooooooo`1Rooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0H_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00oooo
ooooool0H_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00oooooooo
ool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`00
0_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0
H_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0
H_ooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003o
ooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`0000Goooooo`000?oooooo
ooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0H_ooool00ooo003o
ooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007o
oooo00001Ooooooo0000oooooooooooo000000_ooooo00?o0000ooooooooool00_ooool2o`0006?o
oooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo067o
oooo0_l00001ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool00ol0003o
ooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo003o
ooooooooo`1Rooooo`7o00000Oooool00005ooooool0003oooooooooool000001oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003o
ooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`000_ooool2o`0000Sooooo
1Ol00004ooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003ooooo
ooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo003ooooooooo
o`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0M
ooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`0Loooo
o`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool2o`0006?ooooo00?oo`00oooooooo
ool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo067ooooo0_l00001ooooo`00
5Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool0
7?ooool00ooo003oooooooooo`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_oo
ool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool0
0ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo
003oooooooooo`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_ooool00ooo003o
ooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool00ol0003ooooo
ooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo003ooooooooo
o`1Rooooo`7o00000Oooool001Gooooo0_l0001Sooooo`03ool00?oooooooooo01gooooo00?o0000
ooooooooool07?ooool00ooo003oooooooooo`1Qooooo`;o00000Oooool001Gooooo00?o0000oooo
ooooool0H_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00oooo
ooooool0H_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00oooooooo
ool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool0
7?ooool00ooo003oooooooooo`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_oo
ool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_oo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00ooooooooool07Oooool0
0ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ooo
003oooooooooo`1Rooooo`7o00000Oooool001Gooooo0_l0001Sooooo`03ool00?oooooooooo01go
oooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`1Qooooo`;o00000Oooool001Gooooo
00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo
00?oo`00ooooooooool0H_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?o
o`00ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000
ooooooooool07?ooool00ooo003oooooooooo`1Rooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0H_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00oooo
ooooool0H_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?oo`00oooooooo
ool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo01gooooo00?o0000ooooooooool0
7?ooool00ooo003oooooooooo`1Rooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0H_oo
ool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_oo
ool1o`00007ooooo000Eooooo`;o0000Hoooool00ooo003oooooooooo`0Mooooo`03o`000?oooooo
oooo01cooooo00?oo`00ooooooooool0HOooool2o`00007ooooo000Eooooo`03o`000?oooooooooo
06;ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo
06;ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1Rooooo`03ool00?oooooooooo01go
oooo00?o0000ooooooooool07?ooool00ooo003oooooooooo`1Rooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo
00?oo`00ooooooooool0H_ooool1o`00007ooooo000Eooooo`03o`000?oooooooooo06;ooooo00?o
o`00ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo06;ooooo0Ol0
0001ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0M
ooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007ooooo000>oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool00ooo003oooooooooo`0Moooo
o`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0H_ooool1o`00007ooooo000>ooooo`03
o`000?oooooooooo00Cooooo0_l0001Soooood3oo`00Hoooool2o`00007ooooo000>ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o0000
0Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`003Oooool2o`0000Kooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o0000
ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool001Gooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooo
oooo083ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087o
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`00
0?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooo
oooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo00001?oooooo0000o`000?l00004oooo
o`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo0002ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo0002ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool2o`0008?o
oooo00?o0000ooooooooool0P?ooool2o`00007ooooo0002ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`000_ooool00ol0003oooooooooo`07ooooo`Co00001Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`0000?oooooo`000?l000002Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1
o`00007ooooo0002ooooo`03o`000?oooooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20
ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Go
oooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2
o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o
0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool000cooooo1Ol00004ooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0POooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo
0Ol00001ooooo`003oooool00ol0003oooooooooo`03ooooo`;o0000Poooool00ol0003ooooooooo
o`20ooooo`;o00000Oooool000cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000<ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`003Oooool3o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool1o`00007ooooo000Eoooooooo00002ol0
0001ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.43721, -0.268479, \
0.0158161, 0.0134047}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.11976 0.483559 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02305 -24 -4.5 ]
[-0.0125 .02305 0 4.5 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .21647 -18 -4.5 ]
[-0.0125 .21647 0 4.5 ]
[-0.0125 .31318 -18 -4.5 ]
[-0.0125 .31318 0 4.5 ]
[-0.0125 .4099 -18 -4.5 ]
[-0.0125 .4099 0 4.5 ]
[-0.0125 .50661 -18 -4.5 ]
[-0.0125 .50661 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02305 m
.00625 .02305 L
s
[(-0.2)] -0.0125 .02305 1 0 Mshowa
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .21647 m
.00625 .21647 L
s
[(0.2)] -0.0125 .21647 1 0 Mshowa
0 .31318 m
.00625 .31318 L
s
[(0.4)] -0.0125 .31318 1 0 Mshowa
0 .4099 m
.00625 .4099 L
s
[(0.6)] -0.0125 .4099 1 0 Mshowa
0 .50661 m
.00625 .50661 L
s
[(0.8)] -0.0125 .50661 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04723 m
.00375 .04723 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16812 m
.00375 .16812 L
s
0 .19229 m
.00375 .19229 L
s
0 .24065 m
.00375 .24065 L
s
0 .26483 m
.00375 .26483 L
s
0 .28901 m
.00375 .28901 L
s
0 .33736 m
.00375 .33736 L
s
0 .36154 m
.00375 .36154 L
s
0 .38572 m
.00375 .38572 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .48243 m
.00375 .48243 L
s
0 .53079 m
.00375 .53079 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02305 m
1 .02305 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .21647 m
1 .21647 L
s
.99375 .31318 m
1 .31318 L
s
.99375 .4099 m
1 .4099 L
s
.99375 .50661 m
1 .50661 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04723 m
1 .04723 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16812 m
1 .16812 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .24065 m
1 .24065 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .28901 m
1 .28901 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .36154 m
1 .36154 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .48243 m
1 .48243 L
s
.99625 .53079 m
1 .53079 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .11976 m
.02567 .11787 L
.02769 .11583 L
.0296 .11395 L
.03143 .11223 L
.03338 .11049 L
.03525 .10895 L
.03724 .10749 L
.03917 .10627 L
.04101 .10528 L
.04195 .10487 L
.04298 .10447 L
.04397 .10415 L
.04487 .10392 L
.0458 .10374 L
.04632 .10366 L
.04658 .10363 L
.04681 .10361 L
.04703 .10359 L
.04727 .10357 L
.0474 .10357 L
.04752 .10356 L
.04765 .10356 L
.04776 .10355 L
.04786 .10355 L
.04792 .10355 L
.04797 .10355 L
.04802 .10355 L
.04808 .10355 L
.04814 .10355 L
.04819 .10355 L
.04825 .10355 L
.0483 .10355 L
.04835 .10355 L
.04841 .10355 L
.04853 .10355 L
.04865 .10356 L
.04887 .10357 L
.04912 .10358 L
.04956 .10362 L
.05008 .10368 L
.05055 .10376 L
.05147 .10394 L
.05247 .10422 L
.05444 .10495 L
.05634 .1059 L
.05816 .10702 L
.0601 .10843 L
.06197 .10998 L
.06395 .1118 L
Mistroke
.06587 .1137 L
.0677 .11564 L
.06966 .11778 L
.07155 .11989 L
.07355 .12216 L
.07548 .12432 L
.07734 .12635 L
.07931 .12842 L
.08121 .13029 L
.08304 .13195 L
.08499 .13353 L
.08686 .13486 L
.08885 .13603 L
.08985 .13651 L
.09077 .1369 L
.09172 .13723 L
.09262 .13748 L
.09352 .13768 L
.09399 .13775 L
.09426 .13779 L
.09451 .13782 L
.09475 .13784 L
.09497 .13785 L
.09521 .13787 L
.09535 .13787 L
.09541 .13788 L
.09547 .13788 L
.09553 .13788 L
.0956 .13788 L
.09563 .13788 L
.09567 .13788 L
.09573 .13788 L
.09579 .13788 L
.09585 .13788 L
.09591 .13788 L
.09596 .13788 L
.09602 .13788 L
.09608 .13788 L
.09622 .13787 L
.09635 .13787 L
.09649 .13786 L
.09673 .13785 L
.09695 .13783 L
.09745 .13777 L
.09794 .1377 L
.09847 .1376 L
.09949 .13734 L
.10046 .13703 L
.10231 .13622 L
.10428 .13509 L
Mistroke
.10617 .13374 L
.10799 .13222 L
.10993 .13039 L
.11179 .12845 L
.11378 .12623 L
.11569 .12395 L
.11753 .12168 L
.11948 .11921 L
.12137 .11681 L
.12337 .11429 L
.1253 .11192 L
.12715 .10975 L
.12912 .10757 L
.13102 .10565 L
.13285 .10399 L
.1348 .10246 L
.13667 .10125 L
.13762 .10073 L
.13866 .10025 L
.13957 .0999 L
.14058 .0996 L
.14103 .09949 L
.14153 .09939 L
.14205 .09931 L
.1423 .09928 L
.14254 .09926 L
.14276 .09924 L
.14288 .09924 L
.143 .09923 L
.14307 .09923 L
.14313 .09922 L
.1432 .09922 L
.14326 .09922 L
.14332 .09922 L
.14338 .09922 L
.14344 .09922 L
.14347 .09922 L
.1435 .09922 L
.14357 .09922 L
.1436 .09922 L
.14363 .09922 L
.14369 .09922 L
.14375 .09922 L
.14382 .09922 L
.14388 .09923 L
.14402 .09923 L
.14414 .09924 L
.14426 .09924 L
.14452 .09927 L
.14501 .09932 L
Mistroke
.14546 .09939 L
.14647 .09961 L
.14739 .09989 L
.14839 .10029 L
.15035 .10131 L
.15224 .1026 L
.15406 .1041 L
.156 .10597 L
.15786 .10801 L
.15984 .11039 L
.16175 .11286 L
.16359 .11537 L
.16554 .11814 L
.16743 .12086 L
.16943 .12377 L
.17135 .12654 L
.17321 .12914 L
.17518 .13177 L
.17708 .13415 L
.1789 .13625 L
.18085 .13824 L
.18272 .1399 L
.1847 .14134 L
.1857 .14193 L
.18662 .1424 L
.18757 .14279 L
.18846 .14308 L
.18936 .14329 L
.18984 .14337 L
.19011 .14341 L
.19035 .14343 L
.19058 .14345 L
.19071 .14346 L
.19082 .14346 L
.19093 .14346 L
.19099 .14347 L
.19105 .14347 L
.1911 .14347 L
.19115 .14347 L
.19121 .14347 L
.19126 .14347 L
.19132 .14347 L
.19136 .14347 L
.19139 .14347 L
.19145 .14347 L
.19151 .14346 L
.19163 .14346 L
.19174 .14345 L
.19201 .14344 L
.19226 .14341 L
Mistroke
.19273 .14335 L
.19322 .14326 L
.19411 .14304 L
.19506 .14271 L
.19594 .14232 L
.19781 .14123 L
.19981 .1397 L
.20172 .13787 L
.20357 .13582 L
.20553 .13335 L
.20742 .13072 L
.20924 .128 L
.21118 .12493 L
.21304 .12186 L
.21502 .11852 L
.21693 .11527 L
.21876 .11218 L
.22071 .10896 L
.22259 .10599 L
.22459 .10303 L
.22652 .10041 L
.22837 .09814 L
.23034 .09606 L
.23224 .09441 L
.23406 .09317 L
.235 .09268 L
.236 .09226 L
.23649 .0921 L
.23702 .09196 L
.23752 .09186 L
.23775 .09182 L
.23799 .09179 L
.23823 .09176 L
.23834 .09175 L
.23845 .09174 L
.23855 .09174 L
.23866 .09173 L
.23872 .09173 L
.23878 .09173 L
.23883 .09173 L
.23889 .09173 L
.23894 .09173 L
.23901 .09173 L
.23904 .09173 L
.23907 .09173 L
.23913 .09173 L
.23919 .09173 L
.23925 .09173 L
.23936 .09174 L
.23949 .09174 L
Mistroke
.23961 .09175 L
.23988 .09178 L
.24012 .09181 L
.24038 .09185 L
.24086 .09195 L
.24176 .0922 L
.24272 .09259 L
.24373 .09311 L
.24556 .09437 L
.2475 .09614 L
.24937 .09824 L
.25136 .10087 L
.25328 .10375 L
.25512 .10681 L
.25709 .11033 L
.25897 .11392 L
.26079 .11751 L
.26272 .12143 L
.26459 .12524 L
.26656 .12926 L
.26847 .13305 L
.2703 .13655 L
.27226 .14007 L
.27413 .14319 L
.27613 .14617 L
.27805 .14866 L
.2799 .15064 L
.28084 .15149 L
.28187 .15229 L
.28286 .15292 L
.28377 .15338 L
.2847 .15373 L
.28522 .15387 L
.28548 .15392 L
.28571 .15396 L
.28593 .154 L
.28617 .15402 L
.2863 .15403 L
.28642 .15404 L
.28654 .15405 L
.2866 .15405 L
.28663 .15405 L
.28666 .15405 L
.28672 .15405 L
.28678 .15405 L
.28683 .15405 L
.28688 .15405 L
.28694 .15405 L
.287 .15405 L
.28706 .15405 L
Mistroke
.28712 .15404 L
.28723 .15404 L
.28733 .15403 L
.28755 .15401 L
.28778 .15398 L
.28802 .15394 L
.28846 .15384 L
.28898 .15369 L
.28946 .15352 L
.29038 .15308 L
.29138 .15247 L
.29335 .15082 L
.29525 .1487 L
.29708 .1462 L
.29902 .14306 L
.30089 .13961 L
.30288 .13555 L
.30479 .13129 L
.30664 .12694 L
.3086 .1221 L
.31048 .11731 L
.3123 .11265 L
.31423 .10771 L
.31609 .10303 L
.31807 .09824 L
.31997 .09387 L
.3218 .08997 L
.32375 .08621 L
.32563 .08304 L
.32762 .08022 L
.32955 .0781 L
.33043 .07733 L
.3314 .07664 L
.33235 .07613 L
.33287 .07592 L
.33336 .07578 L
.3336 .07572 L
.33386 .07567 L
.33398 .07565 L
.33411 .07564 L
.33423 .07562 L
.33434 .07561 L
.33445 .07561 L
.33451 .0756 L
.33454 .0756 L
.33458 .0756 L
.33463 .0756 L
.33469 .0756 L
.33475 .0756 L
.3348 .0756 L
Mistroke
.33486 .0756 L
.33491 .0756 L
.33496 .0756 L
.33502 .07561 L
.33512 .07561 L
.33523 .07562 L
.33546 .07565 L
.33571 .07569 L
.33616 .0758 L
.33664 .07596 L
.33716 .07618 L
.33811 .07671 L
.33912 .07748 L
.34111 .07957 L
.34304 .08231 L
.34489 .08558 L
.34686 .08972 L
.34875 .09429 L
.35058 .09917 L
.35252 .10483 L
.35439 .11066 L
.35637 .11717 L
.35829 .12366 L
.36013 .13002 L
.36209 .13679 L
.36397 .14323 L
.36598 .14986 L
.36791 .15594 L
.36977 .1614 L
.37174 .16668 L
.37364 .17116 L
.37547 .17482 L
.37742 .17794 L
.37832 .17909 L
.3793 .18012 L
.37983 .18059 L
.38032 .18095 L
.38082 .18126 L
.38129 .18149 L
.38173 .18165 L
.38197 .18172 L
.38219 .18177 L
.38231 .18179 L
.38243 .18181 L
.38251 .18182 L
.38257 .18182 L
.38264 .18183 L
.3827 .18183 L
.38276 .18183 L
.38282 .18184 L
Mistroke
.38288 .18184 L
.38292 .18184 L
.38295 .18184 L
.38301 .18184 L
.38306 .18183 L
.38312 .18183 L
.38318 .18183 L
.3833 .18182 L
.3834 .1818 L
.38365 .18176 L
.38389 .18171 L
.38414 .18163 L
.3846 .18144 L
.38503 .18122 L
.38594 .18058 L
.38693 .17961 L
.38788 .17843 L
.38888 .1769 L
.39088 .17303 L
.3928 .16829 L
.39465 .1628 L
.39662 .15604 L
.39851 .14869 L
.40034 .14093 L
.40228 .13201 L
.40414 .12288 L
.40613 .11273 L
.40804 .10266 L
.40988 .09282 L
.41184 .08235 L
.41372 .07242 L
.41572 .06221 L
.41765 .05286 L
.41951 .0445 L
.42148 .03643 L
.42338 .02964 L
.42521 .02415 L
.42623 .02158 L
.42716 .01957 L
.42813 .01781 L
.42903 .01653 L
.42995 .01556 L
.43044 .01519 L
.43071 .01503 L
.43095 .01491 L
.43117 .01483 L
.4314 .01477 L
.43152 .01475 L
.43164 .01473 L
.4317 .01472 L
Mistroke
.43176 .01472 L
.43179 .01472 L
.43183 .01472 L
.43186 .01472 L
.43189 .01472 L
.43194 .01472 L
.432 .01472 L
.43205 .01472 L
.43209 .01472 L
.43215 .01473 L
.43221 .01474 L
.43232 .01476 L
.43243 .01478 L
.43255 .01482 L
.43277 .01489 L
.433 .015 L
.43322 .01512 L
.43371 .01548 L
.43413 .01589 L
.43458 .01641 L
.43553 .01785 L
.43642 .01958 L
.43829 .02458 L
.44029 .03188 L
.44221 .04088 L
.44405 .05136 L
.44602 .06444 L
.44791 .07889 L
.44973 .09443 L
.45167 .11268 L
.45354 .1318 L
.45552 .15367 L
.45743 .17609 L
.45927 .19877 L
.46123 .22392 L
.46311 .24893 L
.46511 .27616 L
.46704 .3028 L
.46889 .32859 L
.47087 .35597 L
.47276 .38204 L
.47459 .40663 L
.47654 .43207 L
.47841 .45561 L
.4804 .47938 L
.48232 .50085 L
.48416 .51999 L
.48612 .53854 L
.48801 .55446 L
.48983 .56784 L
Mistroke
.49176 .57987 L
.49362 .58919 L
.49457 .59304 L
.4956 .59657 L
.4966 .59928 L
.49751 .60115 L
.498 .60191 L
.49845 .60248 L
.49894 .60292 L
.49921 .6031 L
.49934 .60317 L
.49946 .60322 L
.49957 .60325 L
.49969 .60328 L
.49975 .6033 L
.49981 .60331 L
.49987 .60331 L
.49993 .60332 L
.49999 .60332 L
.50005 .60332 L
.5001 .60332 L
.50016 .60331 L
.50021 .6033 L
.50026 .6033 L
.50036 .60327 L
.50049 .60323 L
.50061 .60319 L
.50088 .60305 L
.50112 .60288 L
.50136 .60267 L
.50182 .60215 L
.50232 .60144 L
.5032 .59973 L
.50414 .59732 L
.50502 .59452 L
.50689 .58685 L
.50887 .57619 L
.51078 .56359 L
.51261 .5494 L
.51457 .53224 L
.51645 .51384 L
.51845 .49247 L
.52037 .4703 L
.52223 .44771 L
.5242 .42254 L
.5261 .39742 L
.52792 .37264 L
.52987 .34584 L
.53174 .31983 L
.53373 .29222 L
Mistroke
.53564 .26587 L
.53748 .24098 L
.53944 .21518 L
.54133 .19122 L
.54315 .16915 L
.54508 .14687 L
.54694 .12675 L
.54892 .10694 L
.55082 .08951 L
.55265 .07436 L
.5546 .06006 L
.55648 .04813 L
.55848 .03746 L
.5604 .02914 L
.56225 .02296 L
.56318 .0205 L
.56422 .0183 L
.56519 .01671 L
.56611 .01565 L
.56661 .01524 L
.56686 .01508 L
.56709 .01496 L
.56731 .01486 L
.56751 .0148 L
.56763 .01477 L
.56774 .01475 L
.56785 .01473 L
.56792 .01472 L
.56798 .01472 L
.56804 .01472 L
.56809 .01472 L
.56815 .01472 L
.5682 .01472 L
.56826 .01472 L
.56829 .01472 L
.56833 .01473 L
.56845 .01474 L
.56855 .01476 L
.56867 .01479 L
.56888 .01485 L
.56914 .01495 L
.5694 .01509 L
.56988 .01542 L
.57034 .01582 L
.57083 .01636 L
.57171 .01757 L
.57371 .02144 L
.57563 .02656 L
.57749 .03262 L
.57946 .04015 L
Mistroke
.58135 .04829 L
.58318 .05681 L
.58512 .06645 L
.58699 .07613 L
.58897 .08668 L
.59089 .09693 L
.59273 .10674 L
.59469 .11695 L
.59657 .12644 L
.59839 .13513 L
.60032 .1438 L
.60218 .15147 L
.60415 .15881 L
.60606 .16501 L
.60789 .1701 L
.60984 .17454 L
.61171 .17784 L
.61274 .17922 L
.61371 .18026 L
.61417 .18067 L
.61467 .18103 L
.61513 .18131 L
.61555 .18151 L
.61601 .18168 L
.61626 .18174 L
.61637 .18177 L
.61649 .18179 L
.61661 .1818 L
.61671 .18182 L
.61676 .18182 L
.61682 .18183 L
.61687 .18183 L
.61691 .18183 L
.61697 .18183 L
.61703 .18184 L
.61709 .18184 L
.61715 .18184 L
.61721 .18184 L
.61727 .18183 L
.61732 .18183 L
.61737 .18183 L
.61749 .18182 L
.61761 .1818 L
.61782 .18177 L
.61809 .18171 L
.61832 .18163 L
.61882 .18144 L
.61933 .18117 L
.62028 .18049 L
.62117 .17966 L
Mistroke
.62305 .17727 L
.62504 .17385 L
.62696 .16979 L
.62881 .16525 L
.63078 .15983 L
.63268 .15413 L
.6345 .1483 L
.63644 .14183 L
.63831 .13543 L
.64029 .12855 L
.64221 .12197 L
.64405 .11577 L
.646 .10941 L
.64789 .10361 L
.64989 .09788 L
.65182 .09285 L
.65368 .08853 L
.65565 .08457 L
.65755 .0814 L
.65938 .07898 L
.6604 .07791 L
.66133 .07712 L
.66229 .07646 L
.6632 .07602 L
.66367 .07585 L
.66392 .07578 L
.66416 .07572 L
.66438 .07568 L
.66458 .07565 L
.66481 .07562 L
.66493 .07561 L
.66499 .07561 L
.66505 .0756 L
.66511 .0756 L
.66514 .0756 L
.66517 .0756 L
.66523 .0756 L
.66529 .0756 L
.66535 .0756 L
.6654 .0756 L
.66546 .0756 L
.66551 .0756 L
.66563 .07561 L
.6657 .07562 L
.66576 .07562 L
.666 .07565 L
.6662 .07568 L
.66643 .07573 L
.66689 .07584 L
.66737 .07601 L
Mistroke
.66781 .07621 L
.66882 .07678 L
.66973 .07745 L
.67072 .07835 L
.67267 .0806 L
.67455 .08332 L
.67654 .08675 L
.67846 .09051 L
.68031 .0945 L
.68228 .09906 L
.68417 .10368 L
.68599 .10828 L
.68793 .11325 L
.6898 .11803 L
.69178 .12305 L
.69369 .12773 L
.69553 .13203 L
.69749 .13632 L
.69937 .14012 L
.70137 .14373 L
.7033 .14675 L
.70515 .1492 L
.70713 .15127 L
.70811 .1521 L
.70903 .15274 L
.70997 .15326 L
.71086 .15364 L
.71132 .15378 L
.71157 .15385 L
.71184 .15391 L
.71206 .15395 L
.7123 .15399 L
.71252 .15402 L
.71273 .15403 L
.71285 .15404 L
.71295 .15405 L
.71302 .15405 L
.71307 .15405 L
.71311 .15405 L
.71314 .15405 L
.7132 .15405 L
.71326 .15405 L
.7133 .15405 L
.71333 .15405 L
.71336 .15405 L
.71339 .15405 L
.71346 .15405 L
.71352 .15404 L
.71358 .15404 L
.7137 .15403 L
Mistroke
.71392 .15401 L
.71416 .15398 L
.71459 .15391 L
.71509 .15379 L
.71562 .15362 L
.71659 .15321 L
.71755 .15267 L
.71857 .15196 L
.7204 .15035 L
.72235 .14817 L
.72422 .14567 L
.72621 .14263 L
.72813 .13939 L
.72998 .13602 L
.73195 .13223 L
.73384 .12845 L
.73566 .12474 L
.7376 .12078 L
.73946 .11701 L
.74144 .11311 L
.74335 .10952 L
.74519 .10628 L
.74714 .10309 L
.74902 .10033 L
.75102 .09777 L
.75295 .0957 L
.7548 .09409 L
.75574 .09344 L
.75678 .09283 L
.75776 .09238 L
.75867 .09207 L
.75918 .09194 L
.75965 .09184 L
.76008 .09178 L
.76032 .09176 L
.76044 .09175 L
.76055 .09174 L
.76065 .09174 L
.76077 .09173 L
.76083 .09173 L
.76088 .09173 L
.76094 .09173 L
.76098 .09173 L
.76101 .09173 L
.76106 .09173 L
.76112 .09173 L
.76117 .09173 L
.76123 .09173 L
.76128 .09173 L
.76133 .09173 L
Mistroke
.76144 .09174 L
.76157 .09175 L
.76169 .09175 L
.76192 .09178 L
.76217 .09181 L
.76243 .09185 L
.76293 .09195 L
.76338 .09206 L
.76439 .09241 L
.76532 .09283 L
.76632 .0934 L
.76829 .09483 L
.77019 .09659 L
.77202 .0986 L
.77397 .10104 L
.77584 .10365 L
.77783 .10665 L
.77975 .10972 L
.7816 .11278 L
.78356 .1161 L
.78545 .11932 L
.78727 .12237 L
.78921 .12555 L
.79107 .12847 L
.79305 .1314 L
.79496 .13399 L
.79679 .13624 L
.79874 .13835 L
.80062 .14006 L
.80262 .14151 L
.80362 .1421 L
.80455 .14254 L
.80551 .14291 L
.8064 .14318 L
.80684 .14327 L
.8073 .14336 L
.80757 .14339 L
.80782 .14342 L
.80805 .14344 L
.80817 .14345 L
.8083 .14346 L
.80842 .14346 L
.80847 .14346 L
.80853 .14347 L
.80858 .14347 L
.80864 .14347 L
.80869 .14347 L
.80875 .14347 L
.80878 .14347 L
.80881 .14347 L
Mistroke
.80885 .14347 L
.80888 .14347 L
.80894 .14347 L
.80898 .14347 L
.80901 .14347 L
.80912 .14346 L
.80925 .14346 L
.80938 .14345 L
.80952 .14344 L
.80977 .14342 L
.81002 .14339 L
.81026 .14336 L
.81077 .14327 L
.81124 .14316 L
.81214 .14289 L
.81311 .14252 L
.81399 .1421 L
.81589 .14094 L
.81772 .13954 L
.81966 .13775 L
.82154 .13576 L
.82353 .13342 L
.82544 .13096 L
.82729 .12846 L
.82925 .12569 L
.83114 .12295 L
.83295 .12031 L
.83489 .11752 L
.83675 .1149 L
.83873 .11222 L
.84064 .10979 L
.84247 .10763 L
.84442 .10555 L
.8463 .10378 L
.8483 .1022 L
.85022 .10098 L
.85207 .1001 L
.85303 .09976 L
.85351 .09962 L
.85404 .09949 L
.85453 .09939 L
.85498 .09932 L
.8552 .09929 L
.85543 .09927 L
.85564 .09925 L
.85586 .09924 L
.85599 .09923 L
.85612 .09923 L
.85623 .09922 L
.85629 .09922 L
Mistroke
.85633 .09922 L
.85636 .09922 L
.85642 .09922 L
.85647 .09922 L
.85653 .09922 L
.85659 .09922 L
.85665 .09922 L
.8567 .09922 L
.85675 .09922 L
.85681 .09922 L
.85694 .09923 L
.85706 .09923 L
.85733 .09925 L
.85758 .09927 L
.85782 .0993 L
.85828 .09936 L
.85877 .09945 L
.85965 .09966 L
.86068 .09999 L
.86165 .10038 L
.86351 .10135 L
.86548 .10266 L
.86738 .10419 L
.8692 .10586 L
.87114 .10785 L
.87301 .10993 L
.875 .11228 L
.87692 .11465 L
.87876 .11697 L
.88072 .11947 L
.88261 .12185 L
.88442 .12409 L
.88636 .12638 L
.88822 .12846 L
.89019 .13052 L
.8921 .1323 L
.89393 .13381 L
.89588 .13519 L
.89776 .13625 L
.89871 .1367 L
.89975 .1371 L
.90067 .13739 L
.90119 .13752 L
.90167 .13763 L
.90217 .13772 L
.90263 .13778 L
.90312 .13784 L
.90338 .13786 L
.90352 .13786 L
.90364 .13787 L
Mistroke
.90376 .13787 L
.90382 .13788 L
.90388 .13788 L
.90394 .13788 L
.904 .13788 L
.90405 .13788 L
.9041 .13788 L
.90413 .13788 L
.90417 .13788 L
.90423 .13788 L
.90428 .13788 L
.90434 .13788 L
.9044 .13788 L
.90446 .13788 L
.90459 .13788 L
.90471 .13787 L
.90481 .13787 L
.90505 .13785 L
.90526 .13784 L
.90548 .13782 L
.90594 .13776 L
.90643 .13769 L
.90731 .1375 L
.90834 .13721 L
.90931 .13687 L
.91116 .13602 L
.91313 .13487 L
.91503 .13352 L
.91685 .13204 L
.91879 .13028 L
.92066 .12845 L
.92265 .12637 L
.92456 .12427 L
.9264 .12221 L
.92836 .12 L
.93025 .11788 L
.93225 .11568 L
.93418 .11365 L
.93604 .11181 L
.93802 .10999 L
.93992 .10842 L
.94175 .10708 L
.9437 .10588 L
.94557 .10494 L
.94653 .10455 L
.94757 .1042 L
.94857 .10394 L
.94904 .10383 L
.94949 .10375 L
.94996 .10368 L
Mistroke
.95039 .10363 L
.95062 .1036 L
.95087 .10358 L
.95113 .10357 L
.95126 .10356 L
.95138 .10356 L
.9515 .10355 L
.95157 .10355 L
.95164 .10355 L
.9517 .10355 L
.95175 .10355 L
.95181 .10355 L
.95185 .10355 L
.95188 .10355 L
.95193 .10355 L
.95199 .10355 L
.95205 .10355 L
.95211 .10355 L
.95221 .10355 L
.95233 .10356 L
.95246 .10356 L
.95258 .10357 L
.95285 .10358 L
.95308 .1036 L
.95333 .10362 L
.95379 .10368 L
.95428 .10375 L
.95517 .10393 L
.95619 .1042 L
.95716 .10452 L
.95901 .1053 L
.96098 .10635 L
.96288 .10757 L
.9647 .10892 L
.96664 .1105 L
.96851 .11216 L
.97049 .11404 L
.9724 .11592 L
.97424 .11778 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`007oooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003[o
oooo0ol0000hooooo`?o00001?ooool2o`0000Cooooo000Pooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000=_ooool01Ol0003ooooooooooooooooo000003Oooooo00Co0000oooo
oooooooo0000>?ooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`006?ooool5o`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`00
0?ooooooooooo`0003cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo000Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000>_ooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003cooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000P
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=_ooool4o`0003Sooooo00Co
0000oooooooooooo0000>?ooool4o`0003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`007oooool2o`0000Cooooo00Co0000oooooooooooo0000=_ooool00ol0003o
ooooooooo`0iooooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0>Oooool2o`00
00Cooooo00Co0000oooooooooooo00000oooool0023ooooo00?o0000ooooooooool00oooool2o`00
03Oooooo1Ol0000hooooo`;o0000>Oooool5o`0003Sooooo00?o0000ooooooooool00oooool2o`00
00Cooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo000Koooooooo00001Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Ooo
ool000Sooooo0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003ooooooooo
o`1]ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool03_ooool2ool006kooooo0Ol0
0001ooooo`001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0K?ooool3ool0013ooooo00?o0000ooooooooool03Oooool3ool006kooooo
0Ol00001ooooo`001Ol00002ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1[ooooo`;oo`0000?oooooool00?ooool03oooool00ol0003ooooo
ooooo`0=ooooo`04ool00?ooooooooooool006gooooo0Ol00001ooooo`001oooool01?l0003ooooo
ooooool0000:ooooo`03o`000?oooooooooo00?ooooo0_l0001/ooooo`05ool00?oooooooooooooo
oooo00003oooool00ol0003oooooooooo`0=ooooo`04ool00?ooooooooooool006cooooo0_l00001
ooooo`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`1[ooooo`05ool00?oooooooooooooooooo00003oooool00ol0003ooooo
ooooo`0<ooooo`05ool00?oooooooooooooooooo0000KOooool1o`00007ooooo0007ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
06_ooooo00Goo`00ooooooooooooooooool0000?ooooo`03o`000?oooooooooo00cooooo00?oo`00
ooooooooool00_ooool00ooo003oooooooooo`1Zooooo`7o00000Oooool000Sooooo0_l00009oooo
o`?o00001Oooool00ol0003oooooooooo`1Zooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool03Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0J_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06[ooooo00?oo`00oooooooo
ool00oooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`1Zooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
J_ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo06[ooooo0Ol00001ooooo`006ooo
ool2o`0006_ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1Xooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool0JOooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`04ooooo`03ool00?oooooo
oooo06Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Yooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo
00Cooooo00?oo`00ooooooooool0JOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Wo
oooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00_o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1Yooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0JOooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo06Sooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1Yooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Gooooo00?o
o`00ooooooooool0J?ooool1o`00007ooooo000Kooooo`;o0000JOooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo06Oooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1Coooo
o`?oo`004_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo017ooooo0_oo001Eoooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0D_ooool2ool00003oooooooo003ooooo017o
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00[o
oooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0@ooooo`04ool00?ooooooo`00ool0
05Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo00;o
oooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00ko
oooo00Coo`00oooooooooooooooo0_oo001Cooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0DOooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00oooooo00?oo`00oooooooo
ool01_ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?oo`00oooooooo
ool01oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooooooo
ool0DOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo03[ooooo0_oo000Dooooo`03ool0
0?oooooooooo00Cooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`08ooooo`03ool0
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`07ooooo`03ool0
0?oooooooooo00gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Booooo`;oo`00
??ooool1o`00007ooooo000Kooooo`;o0000>_ooool2ool00003oooooooo003oo`0001;ooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00Sooooo00?o
o`00ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo00Oooooo00?o
o`00ooooooooool03Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo013ooooo0_oo
00000oooooooo`00ool0000jooooo`;o00000Oooool001_ooooo00?o0000ooooooooool08Oooool3
ool001Cooooo0_oo0003ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool03?ooool0
0ooo003oooooooooo`06ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`0Booooo`?oo`008oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
00Wooooo0_oo000Eooooo`;oo`0000?oooooool00?oo00004_ooool2ool000Gooooo00?oo`00oooo
ooooool03_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00cooooo00?oo`00oooo
ooooool02?ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?oo`00oooo
ooooool02?ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00Kooooo00?oo`00oooo
ooooool03_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo013ooooo0_oo00000ooo
ooooo`00ool0000Eooooo`;oo`002oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Ko
oooo1ooo000Booooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03oooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`0<ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01_ooool00ooo003o
ooooooooo`0>ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool04?ooool6ool000Wo
oooo0Ol00001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool01Oooool2ool000Gooooo
0_oo000@ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03Oooool00ooo003ooooo
ooooo`06ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool02?ooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`08ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool01_ooool00ooo003ooooo
ooooo`0=ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03_ooool2ool000Gooooo
0_oo0007ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`04ooooo`;oo`001oooool2ool000kooooo00?oo`00ooooooooool01oooool00ooo003ooooo
ooooo`0<ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02oooool00ooo003ooooo
ooooo`08ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02oooool00ooo003ooooo
ooooo`08ooooo`03ool00?oooooooooo00_ooooo0_oo0008ooooo`03ool00?oooooooooo00cooooo
0_oo0007ooooo`;oo`001_ooool1o`00007ooooo000Cooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool00oooool2ool000Wooooo0_oo000<ooooo`03ool00?oooooooooo00Sooooo
0_oo000<ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool02Oooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`08ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool02?ooool00ooo003ooooo
ooooo`0:ooooo`;oo`002Oooool2ool000Gooooo0Ol00001ooooo`004oooool01?l0003ooooooooo
ool00004ooooo`Ko000000?oo`00o`000?l000002Ol00002ool000[o00000_oo000;o`000003ool0
0?l0003o000000Wo000000?oo`00o`000?l000002_l000000ooo003o0000o`000009o`000003ool0
0?l0003o000000Wo000000?oo`00o`000?l000002_l000000ooo003o0000o`000009o`000003ool0
0?l0003o000001Ko000000?oo`00o`000?l000002Ol000000ooo003o0000o`000009o`000003ool0
0?l0003o000000[o000000?oo`00o`000?l000002Ol000000ooo003o0000o`00000:o`000003ool0
0?l0003o000000Wo000000?oo`00o`000?l000002Ol00002ool000[o00000_oo000;o`000003ool0
0?l0003o000000Co00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`0@ooooo`;oo`002?ooool2ool000gooooo00?oo`00ooooooooool02?ooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02_ooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02?ooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool02oooool00ooo003ooooo
ooooo`07ooooo`;oo`003?ooool2ool000Sooooo0_oo000Booooo`7o00000Oooool001?ooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`0Aooooo`;oo`001_ooool2ool000oooooo
00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00Oooooo
00?oo`00ooooooooool02oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Oooooo
00?oo`00ooooooooool03?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00cooooo
0_oo0006ooooo`;oo`004oooool1o`00007ooooo000Dooooo`;o00001Oooool00ol0003ooooooooo
o`0Booooo`;oo`001?ooool2ool0013ooooo0_oo0006ooooo`;oo`003_ooool00ooo003ooooooooo
o`07ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool02?ooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool02oooool00ooo003ooooooooo
o`07ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool01Oooool00ooo003ooooooooo
o`0>ooooo`;oo`001?ooool2ool001Cooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0C
ooooo`Koo`004_ooool2ool000Cooooo0_oo000@ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool03Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00Gooooo00?oo`00
ooooooooool03oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo1_oo000E
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0;?ooool2ool000;ooooo0_oo000Aoooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`07oooo
o`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0=oooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03oooool2ool000;ooooo0_oo000^oooo
o`7o00000Oooool001_ooooo0_l0000^ooooo`Coo`004oooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo00kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0<ooooo`03
ool00?oooooooooo00Kooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`03ooooo`03
ool00?oooooooooo01;ooooo0ooo000^ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0
A?ooool2ool000?ooooo0_oo000Aooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool0
3?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00oooooo0_oo0003ooooo`03ool0
0?oooooooooo04Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`15ooooo`Goo`004_oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool01Ooo
ool00ooo003oooooooooo`0@ooooo`Goo`00Aoooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo04Oooooo0_oo000Cooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool03?ooool0
0ooo003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool03?ooool0
0ooo003oooooooooo`05ooooo`03ool00?oooooooooo017ooooo0_oo0019ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo
00cooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo
00gooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`1Looooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0GOooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00go
oooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00go
oooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`1Mooooo`7o00000Oooool001_ooooo
0_l0001Nooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool03_ooool00ooo003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool03Oooool00ooo003ooooo
ooooo`03ooooo`03ool00?oooooooooo05cooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`1Nooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03_ooool00ooo003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool03_ooool00ooo003ooooooooo
o`02ooooo`03ool00?oooooooooo05gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1N
ooooo`05ool00?oooooooooooooooooo00004Oooool00ooo003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?oo`00ooooooooool03_ooool01Ooo003oooooooooooooooooo`00063ooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`1Oooooo`04ool00?ooooooo`00ool0017ooooo
00?oo`00ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00oooooo
00Coo`00oooooooo003oo`00H?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05oooooo
0ooo000Booooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ooo003ooooo
ooooo`0@ooooo`?oo`00HOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Cooooo00?o
o`00ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo07Cooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1dooooo`03ool00?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ooo003oooooooooo`1dooooo`7o00000Oooool001_ooooo0_l0001eoooo
o`03ool00?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1coooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool0M?ooool00ooo003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?oo`00ooooooooool0M?ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07Cooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03ool0
0?oooooooooo07Cooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00Co0000oooooooooooooooo
1Ol00004ooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03ool00?oooooooooo07Cooooo0Ol00001ooooo`001oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0M?ooool00ooo003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0M?ooool1o`00007o
oooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`1dooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ooo003o
ooooooooo`1dooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`03ooooo`;o0000MOooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0Loooool2o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07Cooooo00?oo`00oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo07Cooooo0Ol00001oooo
o`001oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`1dooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ooo003oooooooooo`1dooooo`7o00000Oooool000Sooooo0_l00009ooooo`?o00001Oooool00ol0
003oooooooooo`1dooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ooo
003oooooooooo`1eooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0M?ooool00ooo003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0MOooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo07Cooooo00?oo`00ooooooooool02?ooool00ol0003ooooo
ooooo`06ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`006oooool2o`0007Kooooo00?o
o`00ooooooooool01oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo07Cooooo0_l0
0001ooooo`006oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ooo003oooooooooo`1eooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0MOooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?oo`00oooo
ooooool0MOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Gooooo00?oo`00oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo07Gooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1eooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ooo003oooooooooo`1eooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0MOoo
ool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0MOoo
ool1o`00007ooooo000Kooooo`;o0000Moooool00ooo003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?oo`00ooooooooool0M?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo
07Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo
07Gooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1fooooo`03ool00?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`1eooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0M_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?oo`00ooooooooool0MOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Kooooo00?o
o`00ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo07Gooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1fooooo`03ool00?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`1fooooo`7o00000Oooool001_ooooo00?o0000oooo
ooooool0M_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?oo`00oooo
ooooool0M_ooool1o`00007ooooo000Kooooo`;o0000Moooool00ooo003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?oo`00ooooooooool0MOooool2o`00007ooooo000Kooooo`03o`00
0?oooooooooo07Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03ool0
0?oooooooooo07Kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1fooooo`03ool00?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1fooooo`7o00000Ooo
ool000Sooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooo
oooo07Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooo
oooo07Kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0M_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0M_ooool1o`00007ooooo0007ooooo`04o`000?oooooooooo
o`0000Oooooo1Ol00004ooooo`03o`000?oooooooooo07Kooooo00?oo`00ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo07Kooooo0Ol00001ooooo`001oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo0_l0001gooooo`03ool00?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1eooooo`;o00000Ooo
ool000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo07Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo07Kooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`;o00001Ooo
ool00ol0003oooooooooo`1fooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ooo003oooooooooo`1fooooo`7o00000Oooool000Sooooo0_l0000;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0M_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?oo`00ooooooooool0M_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
07Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo
07Kooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1fooooo`03ool00?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1fooooo`7o00000Oooool001_ooooo
0_l0001gooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`1fooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0M_ooool00ooo003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0Moooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03ool00?oooooooooo07Oooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1goooo
o`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`1goooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool00ooo003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?oo`00ooooooooool0Moooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07Oooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo07Oooooo0Ol00001ooooo`006oooool2o`0007Sooooo00?oo`00ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo07Kooooo0_l00001ooooo`006oooool0
0ol0003oooooooooo`1gooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`1gooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool00ooo
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0Moooool1o`00
007ooooo000Kooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03ool00?oooooooooo07Oooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1gooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ooo003ooooo
ooooo`1gooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Moooool00ooo003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0Moooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo07Oooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03ool00?oooooooooo07Oooooo0Ol00001ooooo`006oooool2o`0007Sooooo00?oo`00oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo07Oooooo0_l00001oooo
o`006oooool00ol0003oooooooooo`1gooooo`03ool00?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ooo003oooooooooo`1hooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
Moooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0
N?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo07Sooooo0Ol00001ooooo`002?ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0N?ooool0
0ooo003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0N?ooool1
o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo07Sooooo0Ol00001ooooo`001oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001?ooool2o`0007Wooooo00?oo`00ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo07Oooooo0_l00001ooooo`001ooo
ool01?l0003oooooooooool00007ooooo`Co00001Oooool00ol0003oooooooooo`1hooooo`03ool0
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1hooooo`7o0000
0Oooool000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo07Sooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03ool0
0?oooooooooo07Sooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0N?ooool00ooo003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0N?ooool1o`00007ooooo0008ooooo`;o00002_oo
ool2o`0000Gooooo00?o0000ooooooooool0N?ooool00ooo003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?oo`00ooooooooool0N?ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo07Sooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooo
oooo07Sooooo0Ol00001ooooo`006oooool2o`0007Wooooo00?oo`00ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo07Oooooo0_l00001ooooo`006oooool00ol0003o
ooooooooo`1hooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ooo003o
ooooooooo`1iooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0N?ooool00ooo003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo07Sooooo00?oo`00ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03ool00?oooooooooo07Wooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1i
ooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1i
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0NOooool00ooo003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo07Wooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
ool00?oooooooooo07Wooooo0Ol00001ooooo`006oooool2o`0007[ooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo07Sooooo0_l00001ooooo`006ooo
ool00ol0003oooooooooo`1iooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ooo003oooooooooo`1iooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0NOooool0
0ooo003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03ool00?oooooooooo07Wooooo0Ol00001ooooo`006oooool00ol0003o
ooooooooo`1iooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ooo003o
ooooooooo`1iooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0NOooool00ooo003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0NOooool1o`00007ooooo
000Kooooo`;o0000N_ooool00ooo003oooooooooo`03ooooo`05o`000?oooooooooooooooooo0000
Noooool2o`00007ooooo000Kooooo`03o`000?oooooooooo07Wooooo00?oo`00ooooooooool00ooo
ool01Ol0003oooooooooooooooooo`0007cooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1iooooo`03ool00?oooooooooo00?ooooo00Go0000ooooooooooooooooool0001looooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0N_ooool00ooo003oooooooooo`02ooooo`05o`000?oo
oooooooooooooooo0000O?ooool1o`00007ooooo0008ooooo`;o00001?ooool00ol0003ooooooooo
o`02ooooo`?o00001Oooool00ol0003oooooooooo`1jooooo`03ool00?oooooooooo00;ooooo00Go
0000ooooooooooooooooool0001looooo`7o00000Oooool000Oooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0N_ooool00ooo003o
ooooooooo`02ooooo`05o`000?oooooooooooooooooo0000O?ooool1o`00007ooooo0007ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`;o0000Noooool0
0ooo003oooooooooo`02ooooo`05o`000?oooooooooooooooooo0000Noooool2o`00007ooooo0007
ooooo`04o`000?ooooooooooo`0000Sooooo0ol00005ooooo`03o`000?oooooooooo07[ooooo00?o
o`00ooooooooool00_ooool01Ol0003oooooooooooooooooo`0007cooooo0Ol00001ooooo`001ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`1jooooo`03ool00?oooooooooo00;ooooo00Go0000ooooooooooooooooool0001loooo
o`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0N_ooool00ooo003oooooooooo`02ooooo`05o`000?oooooo
oooooooooooo0000O?ooool1o`00007ooooo0008ooooo`;o00002Oooool3o`0000Gooooo00?o0000
ooooooooool0N_ooool00ooo003oooooooooo`02ooooo`05o`000?oooooooooooooooooo0000O?oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo07[ooooo00?oo`00ooooooooool00_ooool0
1?l0003ooooooooooooo001mooooo`7o00000Oooool001_ooooo0_l0001kooooo`03ool00?oooooo
oooo00;ooooo00Co0000ooooooooooooo`00O?ooool2o`00007ooooo000Kooooo`03o`000?oooooo
oooo07_ooooo00Goo`00ooooooooooooooooo`000002ooooo`03ool00?oooooooooo07_ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1kooooo`05ool00?ooooooooooooooool000000_oo
ool00ooo003oooooooooo`1kooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Noooool0
1Ooo003ooooooooooooooooo000000;ooooo00?oo`00ooooooooool0Noooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo07_ooooo00Goo`00ooooooooooooooooo`000002ooooo`03ool00?oo
oooooooo07_ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1kooooo`05ool00?oooooo
ooooooooool000000_ooool00ooo003oooooooooo`1kooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0Noooool01Ooo003ooooooooooooooooo000000;ooooo00?oo`00ooooooooool0Nooo
ool1o`00007ooooo000Kooooo`;o0000O?ooool01Ooo003ooooooooooooooooo000000;ooooo00?o
o`00ooooooooool0N_ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo07_ooooo00Ooo`00
ooooooooooooooooo`000?ooooooo`0007kooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`1looooo`06ool00?ooooooooooo`000?ooooooo`00O_ooool1o`00007ooooo000Kooooo`03o`00
0?oooooooooo07cooooo00Koo`00oooooooooooo0000oooooooo001nooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0O?ooool01_oo003oooooooooool0003oooooool007kooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1looooo`06ool00?ooooooooooo`000?ooooooo`00O_oo
ool1o`00007ooooo000Kooooo`;o0000OOooool01_oo003oooooooooool0003oooooool007gooooo
0_l00001ooooo`006oooool00ol0003oooooooooo`1looooo`05ool00?ooooooooooo`000?oo0000
Ooooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07gooooo00Coo`00ooooool0003oo`00
Ooooool1o`00007ooooo000Kooooo`03o`000?oooooooooo07gooooo00Coo`00ooooool0003oo`00
Ooooool1o`00007ooooo000Cooooo`?o00001Oooool00ol0003oooooooooo`1mooooo`04ool00?oo
oooo0000ool007oooooo0Ol00001ooooo`005?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07kooooo0ooo001oooooo`7o00000Oooool001Cooooo00?o0000ooooooooool01?ooool2
o`0007oooooo0_oo001oooooo`;o00000Oooool001Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo07kooooo0Ol00001ooooo`005?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool001?ooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`005?ooool00ol0003oooooooooo`04oooooooo00001Ol00001ooooo`00oooooolQ
ooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.7039, -0.359355, \
0.0808853, 0.00796527}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Narrowest pulse", "Subsection"],

Cell[BoxData[
    \(\(x[t_] := u[t + 1/10]\  - \ u[t - 1/10];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(X[f_] = 
        FourierTransform[x[t], t, 
              f]\  /. {\[Delta][b_\ a_ + f\ a_] \[Rule] \[Delta][b + f]/
                  a, \[Delta][\(-b_\)\ a_ + 
                    f_\ a_] \[Rule] \[Delta][\(-b\) + f]/a}\  // \ 
          ComplexExpand;\)\), "\[IndentingNewLine]", 
    \(\({{x[t]}, {X[f]}}\  // FullSimplify\)\  // \ 
      TraditionalForm\)}], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{
                RowBox[{
                  InterpretationBox["\[Theta]",
                    UnitStep,
                    Editable->False,
                    Selectable->False], "(", \(t + 1\/10\), ")"}], "-", 
                RowBox[{
                  InterpretationBox["\[Theta]",
                    UnitStep,
                    Editable->False,
                    Selectable->False], "(", \(t - 1\/10\), ")"}]}]},
            {\(\(sin(\(f\ \[Pi]\)\/5)\)\/\(f\ \[Pi]\)\)}
            }], "\[NoBreak]", ")"}], TraditionalForm]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(gx3 = 
      Plot[Evaluate[x[t]], {t, \(-2\), 2}, 
        PlotStyle \[Rule] {Magenta, \ Thickness[ .01]}, \ 
        PlotPoints \[Rule] 500, \ PlotRange \[Rule] {\(- .1\), 2.1}]; 
    gX3 = Plot[Evaluate[X[f]], {f, \(-10\), 10}, 
        PlotStyle \[Rule] {Magenta, Thickness[ .01]}, \ 
        PlotPoints \[Rule] 500, \ PlotRange \[Rule] All];\)], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0280925 0.280925 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44948 -18 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.5)] -0.0125 .16855 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(1.5)] -0.0125 .44948 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(2)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.01 w
.02381 .02809 m
.02567 .02809 L
.02769 .02809 L
.0296 .02809 L
.03143 .02809 L
.03338 .02809 L
.03525 .02809 L
.03724 .02809 L
.03917 .02809 L
.04101 .02809 L
.04298 .02809 L
.04487 .02809 L
.04669 .02809 L
.04863 .02809 L
.05049 .02809 L
.05248 .02809 L
.05439 .02809 L
.05622 .02809 L
.05818 .02809 L
.06006 .02809 L
.06206 .02809 L
.06399 .02809 L
.06584 .02809 L
.06781 .02809 L
.06971 .02809 L
.07154 .02809 L
.07348 .02809 L
.07535 .02809 L
.07734 .02809 L
.07926 .02809 L
.0811 .02809 L
.08306 .02809 L
.08495 .02809 L
.08677 .02809 L
.0887 .02809 L
.09056 .02809 L
.09254 .02809 L
.09445 .02809 L
.09628 .02809 L
.09823 .02809 L
.10011 .02809 L
.10211 .02809 L
.10403 .02809 L
.10588 .02809 L
.10785 .02809 L
.10974 .02809 L
.11156 .02809 L
.1135 .02809 L
.11537 .02809 L
.11736 .02809 L
Mistroke
.11927 .02809 L
.12111 .02809 L
.12307 .02809 L
.12495 .02809 L
.12695 .02809 L
.12888 .02809 L
.13074 .02809 L
.13271 .02809 L
.13462 .02809 L
.13644 .02809 L
.13839 .02809 L
.14026 .02809 L
.14226 .02809 L
.14418 .02809 L
.14602 .02809 L
.14799 .02809 L
.14988 .02809 L
.15169 .02809 L
.15363 .02809 L
.15549 .02809 L
.15748 .02809 L
.15938 .02809 L
.16122 .02809 L
.16317 .02809 L
.16505 .02809 L
.16705 .02809 L
.16898 .02809 L
.17083 .02809 L
.1728 .02809 L
.1747 .02809 L
.17652 .02809 L
.17846 .02809 L
.18033 .02809 L
.18232 .02809 L
.18424 .02809 L
.18608 .02809 L
.18804 .02809 L
.18993 .02809 L
.19174 .02809 L
.19367 .02809 L
.19553 .02809 L
.19751 .02809 L
.19941 .02809 L
.20124 .02809 L
.20319 .02809 L
.20507 .02809 L
.20706 .02809 L
.20899 .02809 L
.21083 .02809 L
.2128 .02809 L
Mistroke
.21469 .02809 L
.21651 .02809 L
.21845 .02809 L
.22032 .02809 L
.2223 .02809 L
.22421 .02809 L
.22605 .02809 L
.22801 .02809 L
.22989 .02809 L
.23189 .02809 L
.23382 .02809 L
.23567 .02809 L
.23765 .02809 L
.23955 .02809 L
.24137 .02809 L
.24332 .02809 L
.24519 .02809 L
.24718 .02809 L
.2491 .02809 L
.25094 .02809 L
.25291 .02809 L
.2548 .02809 L
.25661 .02809 L
.25855 .02809 L
.26041 .02809 L
.26239 .02809 L
.2643 .02809 L
.26613 .02809 L
.26808 .02809 L
.26996 .02809 L
.27196 .02809 L
.27388 .02809 L
.27573 .02809 L
.2777 .02809 L
.2796 .02809 L
.28142 .02809 L
.28336 .02809 L
.28523 .02809 L
.28722 .02809 L
.28913 .02809 L
.29097 .02809 L
.29293 .02809 L
.29481 .02809 L
.29682 .02809 L
.29875 .02809 L
.3006 .02809 L
.30258 .02809 L
.30448 .02809 L
.30631 .02809 L
.30826 .02809 L
Mistroke
.31014 .02809 L
.31213 .02809 L
.31405 .02809 L
.31589 .02809 L
.31786 .02809 L
.31975 .02809 L
.32157 .02809 L
.32351 .02809 L
.32537 .02809 L
.32735 .02809 L
.32926 .02809 L
.3311 .02809 L
.33305 .02809 L
.33494 .02809 L
.33694 .02809 L
.33886 .02809 L
.34072 .02809 L
.34269 .02809 L
.34459 .02809 L
.34641 .02809 L
.34835 .02809 L
.35023 .02809 L
.35221 .02809 L
.35413 .02809 L
.35597 .02809 L
.35793 .02809 L
.35982 .02809 L
.36164 .02809 L
.36357 .02809 L
.36543 .02809 L
.36741 .02809 L
.36931 .02809 L
.37115 .02809 L
.3731 .02809 L
.37497 .02809 L
.37697 .02809 L
.37889 .02809 L
.38074 .02809 L
.38271 .02809 L
.3846 .02809 L
.38642 .02809 L
.38836 .02809 L
.39023 .02809 L
.39221 .02809 L
.39413 .02809 L
.39597 .02809 L
.39792 .02809 L
.39981 .02809 L
.40181 .02809 L
.40374 .02809 L
Mistroke
.40559 .02809 L
.40757 .02809 L
.40947 .02809 L
.4113 .02809 L
.41324 .02809 L
.41512 .02809 L
.41711 .02809 L
.41903 .02809 L
.42087 .02809 L
.42283 .02809 L
.42472 .02809 L
.42654 .02809 L
.42848 .02809 L
.43034 .02809 L
.43232 .02809 L
.43423 .02809 L
.43606 .02809 L
.43802 .02809 L
.4399 .02809 L
.44189 .02809 L
.44382 .02809 L
.44567 .02809 L
.44764 .02809 L
.44954 .02809 L
.45136 .02809 L
.4533 .02809 L
.45517 .02809 L
.45716 .02809 L
.45907 .02809 L
.46092 .02809 L
.46288 .02809 L
.46476 .02809 L
.46658 .02809 L
.46851 .02809 L
.47037 .02809 L
.47234 .02809 L
.47425 .02809 L
.4752 .02809 L
.47562 .02809 L
.47584 .02809 L
.47596 .02809 L
.47608 .02809 L
.47613 .02809 L
.4762 .30902 L
.47623 .30902 L
.47626 .30902 L
.47633 .30902 L
.47656 .30902 L
.47702 .30902 L
.47802 .30902 L
Mistroke
.47986 .30902 L
.48182 .30902 L
.4837 .30902 L
.4857 .30902 L
.48763 .30902 L
.48948 .30902 L
.49145 .30902 L
.49335 .30902 L
.49518 .30902 L
.49713 .30902 L
.499 .30902 L
.50099 .30902 L
.5029 .30902 L
.50475 .30902 L
.50671 .30902 L
.5086 .30902 L
.51041 .30902 L
.51235 .30902 L
.51421 .30902 L
.51619 .30902 L
.51809 .30902 L
.51993 .30902 L
.52188 .30902 L
.52278 .30902 L
.52325 .30902 L
.52351 .30902 L
.52364 .30902 L
.5237 .30902 L
.52376 .30902 L
.52382 .02809 L
.52388 .02809 L
.52401 .02809 L
.52429 .02809 L
.52478 .02809 L
.52575 .02809 L
.52771 .02809 L
.5296 .02809 L
.5316 .02809 L
.53353 .02809 L
.53539 .02809 L
.53736 .02809 L
.53926 .02809 L
.54109 .02809 L
.54304 .02809 L
.54491 .02809 L
.54691 .02809 L
.54882 .02809 L
.55067 .02809 L
.55264 .02809 L
.55453 .02809 L
Mistroke
.55635 .02809 L
.55828 .02809 L
.56015 .02809 L
.56213 .02809 L
.56404 .02809 L
.56587 .02809 L
.56783 .02809 L
.56971 .02809 L
.5717 .02809 L
.57363 .02809 L
.57548 .02809 L
.57745 .02809 L
.57935 .02809 L
.58118 .02809 L
.58312 .02809 L
.58499 .02809 L
.58698 .02809 L
.58889 .02809 L
.59074 .02809 L
.5927 .02809 L
.59458 .02809 L
.5964 .02809 L
.59833 .02809 L
.60019 .02809 L
.60217 .02809 L
.60407 .02809 L
.6059 .02809 L
.60785 .02809 L
.60973 .02809 L
.61173 .02809 L
.61365 .02809 L
.6155 .02809 L
.61746 .02809 L
.61936 .02809 L
.62118 .02809 L
.62312 .02809 L
.62498 .02809 L
.62697 .02809 L
.62888 .02809 L
.63072 .02809 L
.63267 .02809 L
.63456 .02809 L
.63656 .02809 L
.63849 .02809 L
.64034 .02809 L
.64231 .02809 L
.64422 .02809 L
.64604 .02809 L
.64799 .02809 L
.64986 .02809 L
Mistroke
.65185 .02809 L
.65377 .02809 L
.65561 .02809 L
.65758 .02809 L
.65947 .02809 L
.66128 .02809 L
.66322 .02809 L
.66508 .02809 L
.66706 .02809 L
.66897 .02809 L
.6708 .02809 L
.67275 .02809 L
.67463 .02809 L
.67663 .02809 L
.67856 .02809 L
.68041 .02809 L
.68238 .02809 L
.68427 .02809 L
.6861 .02809 L
.68804 .02809 L
.68991 .02809 L
.69189 .02809 L
.69381 .02809 L
.69565 .02809 L
.69761 .02809 L
.69949 .02809 L
.7015 .02809 L
.70343 .02809 L
.70528 .02809 L
.70726 .02809 L
.70916 .02809 L
.71099 .02809 L
.71294 .02809 L
.71482 .02809 L
.71681 .02809 L
.71873 .02809 L
.72058 .02809 L
.72254 .02809 L
.72444 .02809 L
.72625 .02809 L
.72819 .02809 L
.73006 .02809 L
.73204 .02809 L
.73395 .02809 L
.73579 .02809 L
.73774 .02809 L
.73962 .02809 L
.74162 .02809 L
.74355 .02809 L
.7454 .02809 L
Mistroke
.74737 .02809 L
.74927 .02809 L
.7511 .02809 L
.75304 .02809 L
.75491 .02809 L
.7569 .02809 L
.75882 .02809 L
.76066 .02809 L
.76262 .02809 L
.76451 .02809 L
.76633 .02809 L
.76826 .02809 L
.77012 .02809 L
.7721 .02809 L
.77401 .02809 L
.77584 .02809 L
.77779 .02809 L
.77967 .02809 L
.78166 .02809 L
.78359 .02809 L
.78543 .02809 L
.7874 .02809 L
.7893 .02809 L
.79112 .02809 L
.79306 .02809 L
.79493 .02809 L
.79691 .02809 L
.79882 .02809 L
.80066 .02809 L
.80262 .02809 L
.8045 .02809 L
.80651 .02809 L
.80844 .02809 L
.81029 .02809 L
.81227 .02809 L
.81417 .02809 L
.816 .02809 L
.81794 .02809 L
.81982 .02809 L
.82181 .02809 L
.82373 .02809 L
.82557 .02809 L
.82754 .02809 L
.82943 .02809 L
.83125 .02809 L
.83318 .02809 L
.83504 .02809 L
.83703 .02809 L
.83893 .02809 L
.84077 .02809 L
Mistroke
.84272 .02809 L
.8446 .02809 L
.8466 .02809 L
.84853 .02809 L
.85038 .02809 L
.85235 .02809 L
.85425 .02809 L
.85607 .02809 L
.85801 .02809 L
.85988 .02809 L
.86187 .02809 L
.86378 .02809 L
.86563 .02809 L
.86759 .02809 L
.86947 .02809 L
.87129 .02809 L
.87322 .02809 L
.87508 .02809 L
.87705 .02809 L
.87896 .02809 L
.88079 .02809 L
.88274 .02809 L
.88461 .02809 L
.88661 .02809 L
.88853 .02809 L
.89038 .02809 L
.89234 .02809 L
.89424 .02809 L
.89606 .02809 L
.898 .02809 L
.89986 .02809 L
.90185 .02809 L
.90376 .02809 L
.90559 .02809 L
.90755 .02809 L
.90943 .02809 L
.91143 .02809 L
.91336 .02809 L
.91522 .02809 L
.91719 .02809 L
.91909 .02809 L
.92092 .02809 L
.92286 .02809 L
.92473 .02809 L
.92672 .02809 L
.92864 .02809 L
.93048 .02809 L
.93245 .02809 L
.93434 .02809 L
.93615 .02809 L
Mistroke
.93809 .02809 L
.93995 .02809 L
.94193 .02809 L
.94383 .02809 L
.94567 .02809 L
.94762 .02809 L
.9495 .02809 L
.95149 .02809 L
.95342 .02809 L
.95527 .02809 L
.95724 .02809 L
.95913 .02809 L
.96096 .02809 L
.9629 .02809 L
.96476 .02809 L
.96675 .02809 L
.96866 .02809 L
.9705 .02809 L
.97246 .02809 L
.97435 .02809 L
.97619 .02809 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`006oooool5o`0003_ooooo0ol0000kooooo`;o0000??ooool3o`0003_ooooo1Ol00006oooo
o`007?ooool01?l0003oooooooooool0000looooo`03o`000?oooooooooo03Wooooo00Co0000oooo
oooooooo0000??ooool00ol0003oooooooooo`0kooooo`04o`000?ooooooooooo`0000Kooooo000E
ooooo`Go00000oooool00ol0003oooooooooo`0dooooo`Go00000oooool00ol0003oooooooooo`0i
ooooo`04o`000?ooooooooooo`0003cooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`06ooooo`007_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Wooooo00Co0000
oooooooooooo0000??ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Gooooo000K
ooooo`05o`000?ooooooooooooooool00000??ooool00ol0003oooooooooo`0iooooo`04o`000?oo
ooooooooo`0003cooooo00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo000000Ko
oooo000Kooooo`05o`000?ooooooooooooooool00000>oooool2o`0003_ooooo00Co0000oooooooo
oooo0000>oooool2o`0003cooooo00Go0000ooooooooooooooooo`000006ooooo`007?ooool3o`00
03gooooo00?o0000ooooooooool0>_ooool2o`0003gooooo00?o0000ooooooooool0>oooool3o`00
00Oooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Eoooo
oooo00002ol00001ooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`003_ooool2o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`003Oooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo0?mmoooo
o`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool2o`0000?oooooN_oo0?l6oooo
o`03o`000?oooooooooo00;oooooN_oo0?l4ooooo`;o00000Oooool000gooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`02ooooog[oo`3o1_ooool00ol0003oooooooooo`02oooo
og[oo`3o1Oooool1o`00007ooooo000=ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0N_ooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001oooo
o`003_ooool2o`0000Gooooo00?o0000ooooooooool0N_ooool2ool0o`Kooooo00?o0000oooooooo
ool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1jooooo`;oo`3o
1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007ooooo000Eooooo`03o`000?oo
oooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo0?mmooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0N_ooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2
ool0oggooooo0Ol00001ooooo`005Oooool2o`0007_ooooo0_oo0?l6ooooo`03o`000?oooooooooo
00;ooooo0_oo0?mlooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0N_ooool2ool0o`Ko
oooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool00ol0003ooooo
ooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo
0?mmooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0N_ooool2ool0o`Kooooo00?o0000
ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1joooo
o`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007ooooo000Eooooo`03
o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo0?mmooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0N_ooool2ool0o`Kooooo00?o0000ooooooooool0
0_ooool2ool0oggooooo0Ol00001ooooo`005Oooool2o`0007_ooooo0_oo0?l6ooooo`03o`000?oo
oooooooo00;ooooo0_oo0?mlooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0N_ooool2
ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;o
oooo0_oo0?mmooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0N_ooool2ool0o`Kooooo
00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo0?mm
ooooo`7o00000Oooool001Gooooo0_l0001kooooo`;oo`3o1_ooool00ol0003oooooooooo`02oooo
o`;oo`3oO?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03
o`000?oooooooooo00;ooooo0_oo0?mmooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0
N_ooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooo
oooo00;ooooo0_oo0?mmooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0N_ooool2ool0
o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007o
oooo000Eooooo`;o0000Noooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0ogcooooo
0_l00001ooooo`005Oooool00ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003ooooooooo
o`02ooooo`;oo`3oOOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6
ooooo`03o`000?oooooooooo00;ooooo0_oo0?mmooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0N_ooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;o
o`3oOOooool1o`00007ooooo0002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3o
OOooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;o
oooo0_oo0?mmooooo`7o00000Oooool00005ooooool0003oooooooooool000002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;o
oooo0_oo0?mmooooo`7o00000Oooool00005ooooool0003oooooooooool000002oooool00ol0003o
ooooooooo`02ooooo`;o0000Noooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0ogco
oooo0_l00001ooooo`0000Goooooo`000?ooooooooooo`000007ooooo`Co00001Oooool00ol0003o
ooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007o
oooo00001Ooooooo0000oooooooooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007o
oooo0002ooooo`;o00002?ooool5o`0000Cooooo00?o0000ooooooooool0N_ooool2ool0o`Kooooo
00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo0?mm
ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0N_ooool2ool0o`Kooooo00?o0000oooo
ooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool2o`0007_ooooo0_oo0?l6ooooo`03
o`000?oooooooooo00;ooooo0_oo0?mlooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0
N_ooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOoo
ool1o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooo
oooo00;ooooo0_oo0?mmooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0N_ooool2ool0
o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool00ol0003o
ooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo
0_oo0?mmooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0N_ooool2ool0o`Kooooo00?o
0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool2o`0007_ooooo0_oo0?l6
ooooo`03o`000?oooooooooo00;ooooo0_oo0?mlooooo`;o00000Oooool001Gooooo00?o0000oooo
ooooool0N_ooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;o
o`3oOOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`00
0?oooooooooo00;ooooo0_oo0?mmooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0N_oo
ool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1
o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo
00;ooooo0_oo0?mmooooo`7o00000Oooool001Gooooo0_l0001kooooo`;oo`3o1_ooool00ol0003o
ooooooooo`02ooooo`;oo`3oO?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo
0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo0?mmooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool0N_ooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol0
0001ooooo`005Oooool00ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02
ooooo`;oo`3oOOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6oooo
o`03o`000?oooooooooo00;ooooo0_oo0?mmooooo`7o00000Oooool001Gooooo00?o0000oooooooo
ool0N_ooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3o
OOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oo
oooooooo00;ooooo0_oo0?mmooooo`7o00000Oooool001Gooooo0_l0001kooooo`;oo`3o1_ooool0
0ol0003oooooooooo`02ooooo`;oo`3oO?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo
07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo0?mmooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0N_ooool2ool0o`Kooooo00?o0000ooooooooool00_ooool2ool0oggo
oooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`1jooooo`;oo`3o1_ooool00ol0003ooooo
ooooo`02ooooo`;oo`3oOOooool1o`00007ooooo000Eooooo`03o`000?oooooooooo07[ooooo0_oo
0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo0?mmooooo`7o00000Oooool000gooooo0ol00005
ooooo`03o`000?oooooooooo07[ooooo0_oo0?l6ooooo`03o`000?oooooooooo00;ooooo0_oo0?mm
ooooo`7o00000Oooool000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1joooo
o`;oo`3o1_ooool00ol0003oooooooooo`02ooooo`;oo`3oOOooool1o`00007ooooo000>ooooo`03
o`000?oooooooooo00Cooooo0_l0001kooooo`ooo`3oO?ooool2o`00007ooooo000>ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0N_ooool?ool0oggooooo0Ol00001ooooo`003_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POoo
ool1o`00007ooooo000=ooooo`;o00001_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo087ooooo0Ol00001ooooo`003_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;o
oooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20
ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o
00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o0000
0Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Ooo
ool001Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Go
oooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03
o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?ooooo00?o0000ooooooooool0P?ooool2
o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00
007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007o
oooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo
000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000E
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eoooo
o`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`;o
0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool001Gooooo00?o0000ooooooooool0
P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool0
0ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool00004ooooool0003o0000o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21oooo
o`7o00000Oooool000;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool000;o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`;o0000Poooool00ol0003o
ooooooooo`20ooooo`;o00000Oooool000;ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo
0002ooooo`03o`000?oooooooooo00Oooooo1?l00005ooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo00000ooooooo0000o`000009ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool0
00;ooooo00?o0000ooooooooool01oooool5o`0000Cooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`21ooooo`7o00000Oooool001Gooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0
003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`005Oooool2o`0008?o
oooo00?o0000ooooooooool0P?ooool2o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000
ooooooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000oooooooo
ool0POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
POooool1o`00007ooooo000Eooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POoo
ool1o`00007ooooo000Eooooo`;o0000Poooool00ol0003oooooooooo`20ooooo`;o00000Oooool0
01Gooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Go
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000
ooooooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`21ooooo`7o00000Oooool001Gooooo0_l00023ooooo`03
o`000?oooooooooo083ooooo0_l00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oo
oooooooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooo
oooo087ooooo0Ol00001ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
087ooooo0Ol00001ooooo`003?ooool5o`0000Cooooo00?o0000ooooooooool0P_ooool00ol0003o
ooooooooo`21ooooo`7o00000Oooool000gooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`003_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo
000?ooooo`03o`000?oooooooooo00?ooooo0_l00023ooooo`03o`000?oooooooooo083ooooo0_l0
0001ooooo`003?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`21ooooo`7o00000Oooool000cooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0POooool1o`00007ooooo000=
ooooo`?o00001Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001
ooooo`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001oooo
o`005Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo087ooooo0Ol00001ooooo`00
5Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool001Goooooool0000;o`00007ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.43721, -0.268479, \
0.0158161, 0.0134047}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.11976 2.41779 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .24065 -24 -4.5 ]
[-0.0125 .24065 0 4.5 ]
[-0.0125 .36154 -18 -4.5 ]
[-0.0125 .36154 0 4.5 ]
[-0.0125 .48243 -24 -4.5 ]
[-0.0125 .48243 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .24065 m
.00625 .24065 L
s
[(0.05)] -0.0125 .24065 1 0 Mshowa
0 .36154 m
.00625 .36154 L
s
[(0.1)] -0.0125 .36154 1 0 Mshowa
0 .48243 m
.00625 .48243 L
s
[(0.15)] -0.0125 .48243 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .02305 m
.00375 .02305 L
s
0 .04723 m
.00375 .04723 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16812 m
.00375 .16812 L
s
0 .19229 m
.00375 .19229 L
s
0 .21647 m
.00375 .21647 L
s
0 .26483 m
.00375 .26483 L
s
0 .28901 m
.00375 .28901 L
s
0 .31318 m
.00375 .31318 L
s
0 .33736 m
.00375 .33736 L
s
0 .38572 m
.00375 .38572 L
s
0 .4099 m
.00375 .4099 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .50661 m
.00375 .50661 L
s
0 .53079 m
.00375 .53079 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .24065 m
1 .24065 L
s
.99375 .36154 m
1 .36154 L
s
.99375 .48243 m
1 .48243 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .02305 m
1 .02305 L
s
.99625 .04723 m
1 .04723 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16812 m
1 .16812 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .21647 m
1 .21647 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .28901 m
1 .28901 L
s
.99625 .31318 m
1 .31318 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .4099 m
1 .4099 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .50661 m
1 .50661 L
s
.99625 .53079 m
1 .53079 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
1 0 1 r
.01 w
.02381 .11976 m
.02567 .11787 L
.02769 .11578 L
.0296 .11382 L
.03143 .11191 L
.03338 .10987 L
.03525 .1079 L
.03724 .10579 L
.03917 .10376 L
.04101 .10179 L
.04298 .09969 L
.04487 .09767 L
.04669 .09572 L
.04863 .09364 L
.05049 .09164 L
.05248 .08952 L
.05439 .08747 L
.05622 .08551 L
.05818 .08342 L
.06006 .08142 L
.06206 .0793 L
.06399 .07726 L
.06584 .07531 L
.06781 .07325 L
.06971 .07127 L
.07154 .06938 L
.07348 .06739 L
.07535 .06549 L
.07734 .06348 L
.07926 .06157 L
.0811 .05974 L
.08306 .05783 L
.08495 .056 L
.08677 .05427 L
.0887 .05245 L
.09056 .05073 L
.09254 .04892 L
.09445 .04721 L
.09628 .04559 L
.09823 .0439 L
.10011 .04231 L
.10211 .04065 L
.10403 .03909 L
.10588 .03762 L
.10785 .0361 L
.10974 .03468 L
.11156 .03334 L
.1135 .03196 L
.11537 .03068 L
.11736 .02936 L
Mistroke
.11927 .02813 L
.12111 .02699 L
.12307 .02583 L
.12495 .02476 L
.12695 .02368 L
.12888 .02268 L
.13074 .02178 L
.13271 .02087 L
.13462 .02005 L
.13644 .01932 L
.13839 .01859 L
.14026 .01795 L
.14226 .01732 L
.14418 .01678 L
.14602 .01632 L
.14799 .01589 L
.14988 .01554 L
.15169 .01526 L
.15363 .01502 L
.15549 .01486 L
.15646 .0148 L
.15695 .01477 L
.15748 .01475 L
.15797 .01474 L
.15843 .01472 L
.15864 .01472 L
.15876 .01472 L
.15888 .01472 L
.15899 .01472 L
.1591 .01472 L
.15916 .01472 L
.15921 .01472 L
.15926 .01472 L
.15931 .01472 L
.15937 .01472 L
.1594 .01472 L
.15943 .01472 L
.15947 .01472 L
.1595 .01472 L
.15956 .01472 L
.15962 .01472 L
.15968 .01472 L
.15974 .01472 L
.1598 .01472 L
.15994 .01472 L
.16008 .01472 L
.16033 .01472 L
.16057 .01473 L
.16079 .01473 L
.1613 .01475 L
Mistroke
.16176 .01476 L
.1622 .01478 L
.16319 .01484 L
.16417 .01492 L
.16506 .01501 L
.16697 .01524 L
.16881 .01553 L
.17076 .01591 L
.17265 .01635 L
.17465 .01688 L
.17657 .01748 L
.17843 .01812 L
.1804 .01888 L
.1823 .01968 L
.18413 .02052 L
.18607 .02149 L
.18795 .0225 L
.18994 .02365 L
.19185 .02483 L
.1937 .02604 L
.19566 .02741 L
.19755 .0288 L
.19937 .0302 L
.2013 .03178 L
.20316 .03337 L
.20514 .03513 L
.20705 .03692 L
.20888 .0387 L
.21084 .04068 L
.21271 .04266 L
.21471 .04484 L
.21664 .04702 L
.21849 .04919 L
.22046 .05158 L
.22235 .05396 L
.22417 .05631 L
.22612 .0589 L
.22798 .06145 L
.22997 .06425 L
.23188 .06702 L
.23372 .06976 L
.23568 .07274 L
.23757 .07568 L
.23957 .07889 L
.2415 .08205 L
.24336 .08517 L
.24534 .08855 L
.24724 .09188 L
.24907 .09514 L
.25102 .09868 L
Mistroke
.25289 .10216 L
.25488 .10593 L
.2568 .10962 L
.25865 .11324 L
.26061 .11715 L
.26251 .12099 L
.26433 .12473 L
.26626 .12877 L
.26813 .13272 L
.27011 .13698 L
.27202 .14115 L
.27385 .14521 L
.27581 .14958 L
.27769 .15385 L
.27969 .15844 L
.28162 .16292 L
.28347 .16727 L
.28544 .17196 L
.28734 .17652 L
.28917 .18095 L
.29111 .18571 L
.29298 .19033 L
.29497 .19529 L
.29688 .20011 L
.29873 .20479 L
.30069 .2098 L
.30258 .21467 L
.30439 .21938 L
.30632 .22442 L
.30818 .22931 L
.31016 .23454 L
.31207 .23961 L
.3139 .24451 L
.31585 .24975 L
.31773 .25482 L
.31972 .26024 L
.32165 .26547 L
.32349 .27053 L
.32546 .27592 L
.32736 .28113 L
.32918 .28616 L
.33112 .29152 L
.33298 .29669 L
.33497 .30219 L
.33688 .3075 L
.33872 .31262 L
.34068 .31806 L
.34256 .3233 L
.34456 .32887 L
.34649 .33424 L
Mistroke
.34835 .3394 L
.35032 .34488 L
.35222 .35015 L
.35405 .35521 L
.356 .36058 L
.35787 .36574 L
.35986 .37121 L
.36178 .37646 L
.36363 .3815 L
.36559 .38683 L
.36748 .39195 L
.3693 .39684 L
.37123 .40203 L
.3731 .40699 L
.37508 .41224 L
.37698 .41726 L
.37882 .42206 L
.38077 .42713 L
.38265 .43198 L
.38465 .43709 L
.38657 .44197 L
.38843 .44663 L
.3904 .45153 L
.39229 .45621 L
.39412 .46067 L
.39606 .46536 L
.39793 .46983 L
.39992 .47453 L
.40183 .479 L
.40367 .48324 L
.40563 .4877 L
.40752 .49193 L
.40933 .49595 L
.41126 .50016 L
.41312 .50415 L
.4151 .50833 L
.417 .51229 L
.41883 .51603 L
.42078 .51995 L
.42266 .52365 L
.42465 .5275 L
.42657 .53114 L
.42842 .53456 L
.43038 .53813 L
.43228 .54149 L
.4341 .54464 L
.43603 .54792 L
.4379 .551 L
.43988 .55418 L
.44179 .55716 L
Mistroke
.44363 .55995 L
.44559 .56283 L
.44747 .56552 L
.44947 .56828 L
.4514 .57085 L
.45325 .57323 L
.45522 .57567 L
.45712 .57793 L
.45895 .58002 L
.46089 .58214 L
.46277 .5841 L
.46476 .58608 L
.46667 .58788 L
.46852 .58953 L
.47048 .59118 L
.47237 .59268 L
.47418 .59402 L
.47612 .59535 L
.47798 .59654 L
.47996 .5977 L
.48186 .59872 L
.4837 .5996 L
.48565 .60043 L
.48753 .60114 L
.48952 .60178 L
.49145 .60229 L
.4933 .60269 L
.49423 .60285 L
.49526 .603 L
.49625 .60312 L
.49716 .60321 L
.49761 .60324 L
.4981 .60327 L
.49836 .60328 L
.49861 .60329 L
.49887 .6033 L
.4991 .60331 L
.49935 .60331 L
.49947 .60332 L
.49961 .60332 L
.49967 .60332 L
.49973 .60332 L
.49978 .60332 L
.49984 .60332 L
.49987 .60332 L
.49991 .60332 L
.49994 .60332 L
.49997 .60332 L
.50003 .60332 L
.50009 .60332 L
Mistroke
.50015 .60332 L
.50021 .60332 L
.50026 .60332 L
.50031 .60332 L
.50044 .60332 L
.50055 .60331 L
.50076 .60331 L
.50098 .60331 L
.50148 .60329 L
.50201 .60326 L
.50252 .60323 L
.50298 .60319 L
.50389 .60311 L
.50488 .60298 L
.50682 .60267 L
.50869 .60226 L
.51068 .60172 L
.5126 .60109 L
.51444 .6004 L
.5164 .59955 L
.51829 .59864 L
.5201 .59767 L
.52204 .59653 L
.52389 .59535 L
.52587 .59398 L
.52778 .59257 L
.52961 .59111 L
.53156 .58947 L
.53343 .58779 L
.53543 .5859 L
.53735 .58398 L
.5392 .58204 L
.54117 .57989 L
.54306 .57772 L
.54488 .57555 L
.54682 .57314 L
.54869 .57074 L
.55067 .56809 L
.55258 .56545 L
.55442 .56282 L
.55638 .55994 L
.55826 .55708 L
.56026 .55395 L
.56219 .55085 L
.56405 .54779 L
.56602 .54444 L
.56792 .54114 L
.56975 .53789 L
.57169 .53436 L
.57357 .53088 L
Mistroke
.57556 .52711 L
.57747 .52339 L
.57932 .51975 L
.58128 .51581 L
.58317 .51194 L
.58499 .50816 L
.58692 .50406 L
.58879 .50006 L
.59077 .49574 L
.59267 .49151 L
.59451 .48739 L
.59646 .48294 L
.59834 .47861 L
.60033 .47394 L
.60226 .46939 L
.60411 .46496 L
.60608 .46019 L
.60798 .45555 L
.6098 .45105 L
.61174 .44621 L
.61361 .44151 L
.6156 .43646 L
.61751 .43157 L
.61935 .42682 L
.62131 .42173 L
.6232 .41679 L
.6252 .41151 L
.62713 .40639 L
.62899 .40144 L
.63096 .39614 L
.63287 .39101 L
.6347 .38606 L
.63665 .38076 L
.63852 .37564 L
.64051 .37018 L
.64243 .3649 L
.64428 .35981 L
.64625 .35438 L
.64814 .34915 L
.64996 .3441 L
.6519 .33872 L
.65376 .33354 L
.65574 .32802 L
.65765 .32271 L
.65949 .3176 L
.66144 .31216 L
.66333 .30693 L
.66533 .30137 L
.66725 .29603 L
.66911 .2909 L
Mistroke
.67108 .28545 L
.67298 .28021 L
.6748 .27519 L
.67675 .26986 L
.67862 .26475 L
.68061 .25934 L
.68252 .25414 L
.68437 .24917 L
.68633 .2439 L
.68822 .23885 L
.69003 .23403 L
.69197 .22892 L
.69383 .22403 L
.6958 .21887 L
.69771 .21393 L
.69954 .20921 L
.70149 .20423 L
.70337 .19947 L
.70537 .19445 L
.70729 .18966 L
.70914 .18509 L
.71111 .18028 L
.713 .17569 L
.71482 .17132 L
.71676 .16672 L
.71863 .16234 L
.72062 .15773 L
.72253 .15335 L
.72437 .14919 L
.72632 .14481 L
.72821 .14065 L
.73021 .13629 L
.73214 .13215 L
.734 .12823 L
.73597 .12411 L
.73787 .12021 L
.7397 .11652 L
.74165 .11265 L
.74352 .109 L
.74551 .10517 L
.74743 .10156 L
.74928 .09815 L
.75124 .09459 L
.75313 .09122 L
.75495 .08806 L
.75689 .08475 L
.75875 .08164 L
.76073 .0784 L
.76264 .07536 L
.76447 .0725 L
Mistroke
.76643 .06953 L
.76831 .06674 L
.7703 .06386 L
.77223 .06116 L
.77408 .05863 L
.77605 .05602 L
.77795 .05358 L
.77977 .0513 L
.78172 .04895 L
.78359 .04677 L
.78557 .04452 L
.78749 .04244 L
.78933 .04051 L
.79129 .03853 L
.79318 .0367 L
.79499 .03501 L
.79692 .03329 L
.79878 .03171 L
.80076 .0301 L
.80266 .02864 L
.80449 .0273 L
.80644 .02595 L
.80832 .02472 L
.81031 .0235 L
.81223 .0224 L
.81408 .02141 L
.81605 .02044 L
.81794 .01957 L
.81976 .01881 L
.8217 .01807 L
.82357 .01743 L
.82555 .01683 L
.82746 .01632 L
.8293 .0159 L
.83125 .01552 L
.83314 .01522 L
.8341 .0151 L
.83514 .01499 L
.83606 .0149 L
.83706 .01483 L
.83802 .01477 L
.83855 .01475 L
.83904 .01474 L
.83928 .01473 L
.83954 .01472 L
.83979 .01472 L
.83991 .01472 L
.84002 .01472 L
.84012 .01472 L
.84022 .01472 L
Mistroke
.84027 .01472 L
.84033 .01472 L
.84039 .01472 L
.84045 .01472 L
.84051 .01472 L
.84057 .01472 L
.84063 .01472 L
.84069 .01472 L
.84074 .01472 L
.84079 .01472 L
.84091 .01472 L
.84103 .01472 L
.84113 .01472 L
.84138 .01472 L
.8416 .01473 L
.84181 .01473 L
.84229 .01474 L
.84281 .01476 L
.84375 .01481 L
.84476 .01488 L
.84677 .01506 L
.8487 .01531 L
.85055 .01561 L
.85253 .016 L
.85443 .01643 L
.85626 .0169 L
.85821 .01746 L
.86008 .01806 L
.86208 .01876 L
.864 .01949 L
.86584 .02025 L
.86781 .02111 L
.8697 .02199 L
.87152 .02289 L
.87346 .02389 L
.87532 .02491 L
.8773 .02604 L
.87921 .02719 L
.88105 .02833 L
.883 .02959 L
.88488 .03085 L
.88688 .03223 L
.88881 .03361 L
.89066 .03498 L
.89263 .03647 L
.89453 .03795 L
.89636 .0394 L
.8983 .04099 L
.90017 .04255 L
.90216 .04424 L
Mistroke
.90407 .0459 L
.90592 .04753 L
.90788 .0493 L
.90976 .05103 L
.91158 .05272 L
.91351 .05454 L
.91537 .05632 L
.91735 .05823 L
.91925 .0601 L
.92109 .06191 L
.92304 .06386 L
.92491 .06576 L
.92691 .06779 L
.92883 .06977 L
.93068 .07168 L
.93265 .07373 L
.93454 .07571 L
.93636 .07763 L
.9383 .07968 L
.94017 .08166 L
.94215 .08377 L
.94407 .08582 L
.9459 .08778 L
.94786 .08988 L
.94974 .0919 L
.95175 .09405 L
.95367 .09611 L
.95553 .0981 L
.9575 .10021 L
.9594 .10224 L
.96123 .10418 L
.96318 .10624 L
.96505 .10822 L
.96704 .11031 L
.96896 .11232 L
.97081 .11423 L
.97277 .11626 L
.97466 .1182 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`007oooool3o`0000Cooooo0_l0000hooooo`?o0000>Oooool2o`0003[o
oooo0ol0000hooooo`?o00001?ooool2o`0000Cooooo000Pooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo0000=_ooool01Ol0003ooooooooooooooooo000003Oooooo00Co0000oooo
oooooooo0000>?ooool01Ol0003ooooooooooooooooo000003Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`006?ooool5o`0000?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool0000`ooooo`Go00001Oooool00ol0003oooooooooo`0eooooo`04o`00
0?ooooooooooo`0003cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000?ooooo000Pooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo0000>_ooool00ol0003oooooooooo`0eooooo`04o`000?ooooooooooo`0003cooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo000P
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000=_ooool4o`0003Sooooo00Co
0000oooooooooooo0000>?ooool4o`0003Wooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`007oooool2o`0000Cooooo00Co0000oooooooooooo0000=_ooool00ol0003o
ooooooooo`0iooooo`04o`000?ooooooooooo`0003Sooooo00?o0000ooooooooool0>Oooool2o`00
00Cooooo00Co0000oooooooooooo00000oooool0023ooooo00?o0000ooooooooool00oooool2o`00
03Oooooo1Ol0000hooooo`;o0000>Oooool5o`0003Sooooo00?o0000ooooooooool00oooool2o`00
00Cooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo000Koooooooo00001Ol00001ooooo`006oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool001_ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`1nooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool09?ooool5ool0oeKooooo00?o0000ooooooooool0Doooool5
ool0obKooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Pooooo`goo`3oD_ooool00ol0
003oooooooooo`1?ooooo`goo`3o8_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo01go
oooo2?oo0?l2ooooo`Soo`3oD?ooool00ol0003oooooooooo`1=ooooo`Ooo`3o0_ooool8ool0ob3o
oooo0Ol00001ooooo`006oooool2o`0001gooooo1Ooo0?l:ooooo`Goo`3oCoooool00ol0003ooooo
ooooo`1;ooooo`Goo`3o2_ooool6ool0oagooooo0_l00001ooooo`006oooool00ol0003ooooooooo
o`0Jooooo`Goo`3o3_ooool5ool0odgooooo00?o0000ooooooooool0B_ooool4ool0o`kooooo1Ooo
0?lMooooo`7o00000Oooool001_ooooo00?o0000ooooooooool06Oooool4ool0oa;ooooo0ooo0?m=
ooooo`03o`000?oooooooooo04Wooooo1?oo0?lAooooo`Goo`3o6oooool1o`00007ooooo000Koooo
o`03o`000?oooooooooo01Oooooo1Ooo0?lDooooo`Coo`3oBoooool00ol0003oooooooooo`18oooo
o`?oo`3o5?ooool5ool0oa[ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`0Fooooo`Co
o`3o5oooool3ool0od_ooooo00?o0000ooooooooool0Aoooool3ool0oaOooooo1?oo0?lIooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool05Oooool4ool0oaWooooo0ooo0?m:ooooo`03o`00
0?oooooooooo04Kooooo0ooo0?lIooooo`Coo`3o6?ooool1o`00007ooooo000Kooooo`;o00005Ooo
ool4ool0oa_ooooo0ooo0?m9ooooo`03o`000?oooooooooo04Gooooo0ooo0?lKooooo`Coo`3o5_oo
ool2o`00007ooooo000Kooooo`03o`000?oooooooooo01?ooooo0ooo0?lNooooo`?oo`3oB?ooool0
0ol0003oooooooooo`14ooooo`?oo`3o7_ooool3ool0oaKooooo0Ol00001ooooo`006oooool00ol0
003oooooooooo`0Booooo`?oo`3o8?ooool3ool0odOooooo00?o0000ooooooooool0@oooool3ool0
ob3ooooo0ooo0?lEooooo`7o00000Oooool001_ooooo00?o0000ooooooooool04Oooool3ool0ob7o
oooo0ooo0?m7ooooo`03o`000?oooooooooo04;ooooo0ooo0?lRooooo`?oo`3o5?ooool1o`00007o
oooo000Kooooo`03o`000?oooooooooo013ooooo0ooo0?lSooooo`?oo`3oA_ooool00ol0003ooooo
ooooo`12ooooo`?oo`3o8oooool3ool0oa?ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`0?ooooo`?oo`3o9Oooool3ool0odGooooo00?o0000ooooooooool0@Oooool3ool0obGooooo0ooo
0?lBooooo`7o00000Oooool001_ooooo0_l0000?ooooo`?oo`3o9oooool3ool0odCooooo00?o0000
ooooooooool0@?ooool3ool0obOooooo0ooo0?l@ooooo`;o00000Oooool001_ooooo00?o0000oooo
ooooool03Oooool3ool0obSooooo0ooo0?m4ooooo`03o`000?oooooooooo043ooooo0ooo0?lXoooo
o`?oo`3o4?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00cooooo0ooo0?lZooooo`?o
o`3o@oooool00ol0003oooooooooo`0oooooo`?oo`3o:_ooool3ool0o`oooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`0;ooooo`?oo`3o;?ooool2ool0od?ooooo00?o0000ooooooooool0
?oooool2ool0obcooooo0ooo0?l>ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool02_oo
ool3ool0obgooooo0ooo0?m2ooooo`03o`000?oooooooooo03kooooo0ooo0?l]ooooo`?oo`3o3Ooo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Wooooo0ooo0?l_ooooo`?oo`3o@Oooool0
0ol0003oooooooooo`0mooooo`?oo`3o;oooool3ool0o`cooooo0Ol00001ooooo`006oooool2o`00
00Wooooo0ooo0?l`ooooo`?oo`3o@Oooool00ol0003oooooooooo`0mooooo`;oo`3o<Oooool3ool0
o`[ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`07ooooo`?oo`3o<_ooool3ool0od3o
oooo00?o0000ooooooooool0??ooool3ool0oc;ooooo0ooo0?l:ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool01_ooool3ool0ocCooooo0_oo0?m0ooooo`03o`000?oooooooooo03cooooo
0_oo0?lcooooo`Coo`3o2Oooool1o`00007ooooo000Kooooo`03o`000?oooooooooo00Gooooo0ooo
0?leooooo`?oo`3o?oooool00ol0003oooooooooo`0kooooo`?oo`3o=?ooool4ool0o`Sooooo0Ol0
0001ooooo`005?ooool2o`0000Gooooo00?o0000ooooooooool01?ooool4ool0ocKooooo0_oo0?lo
ooooo`03o`000?oooooooooo03_ooooo0_oo0?lfooooo`Coo`3o1oooool1o`00007ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool4ool0ocOooooo0ooo0?ln
ooooo`03o`000?oooooooooo03[ooooo0ooo0?lgooooo`Coo`3o1_ooool1o`00007ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool4ool0ocWooooo0_oo0?ln
ooooo`03o`000?oooooooooo03[ooooo0_oo0?liooooo`Coo`3o1Oooool1o`00007ooooo000Coooo
o`04o`000?ooooooooooo`0000Cooooo1Ol00003ool0oc[o00000ooo0?mio`0000?oo`3o>_l00003
ool0o`Ko00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`;oo`3o??ooool2ool0ocgooooo00?o0000ooooooooool0>Oooool2ool0occooooo0_oo0?l5
ooooo`7o00000Oooool001?ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`10
ooooo`?oo`3o??ooool00ol0003oooooooooo`0hooooo`?oo`3o@oooool1o`00007ooooo000Doooo
o`;o00001Oooool00ol0003oooooooooo`11ooooo`;oo`3o??ooool00ol0003oooooooooo`0hoooo
o`;oo`3oA?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo047ooooo0ooo0?lkooooo`03
o`000?oooooooooo03Oooooo0ooo0?m4ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0
@_ooool2ool0oc_ooooo00?o0000ooooooooool0=oooool2ool0odGooooo0Ol00001ooooo`006ooo
ool2o`0004?ooooo0ooo0?ljooooo`03o`000?oooooooooo03Kooooo0ooo0?m4ooooo`;o00000Ooo
ool001_ooooo00?o0000ooooooooool0@oooool2ool0oc[ooooo00?o0000ooooooooool0=_ooool2
ool0odKooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`13ooooo`;oo`3o>_ooool00ol0
003oooooooooo`0eooooo`?oo`3oA_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo04?o
oooo0ooo0?liooooo`03o`000?oooooooooo03Gooooo0_oo0?m7ooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0A?ooool2ool0ocWooooo00?o0000ooooooooool0=Oooool2ool0odOooooo
0Ol00001ooooo`006oooool00ol0003oooooooooo`14ooooo`?oo`3o>?ooool00ol0003ooooooooo
o`0dooooo`?oo`3oAoooool1o`00007ooooo000Kooooo`;o0000A_ooool2ool0ocSooooo00?o0000
ooooooooool0=?ooool2ool0odOooooo0_l00001ooooo`006oooool00ol0003oooooooooo`15oooo
o`?oo`3o=oooool00ol0003oooooooooo`0cooooo`?oo`3oB?ooool1o`00007ooooo000Kooooo`03
o`000?oooooooooo04Kooooo0_oo0?lgooooo`03o`000?oooooooooo03?ooooo0_oo0?m9ooooo`7o
00000Oooool001_ooooo00?o0000ooooooooool0A_ooool2ool0ocOooooo00?o0000ooooooooool0
<_ooool3ool0odWooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`16ooooo`?oo`3o=_oo
ool00ol0003oooooooooo`0booooo`;oo`3oB_ooool1o`00007ooooo000Kooooo`03o`000?oooooo
oooo04Oooooo0_oo0?lfooooo`03o`000?oooooooooo03;ooooo0_oo0?m:ooooo`7o00000Oooool0
01_ooooo00?o0000ooooooooool0Aoooool3ool0ocGooooo00?o0000ooooooooool0<Oooool3ool0
od[ooooo0Ol00001ooooo`006oooool2o`0004Wooooo0_oo0?leooooo`03o`000?oooooooooo037o
oooo0_oo0?m:ooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0B?ooool2ool0ocGooooo
00?o0000ooooooooool0<?ooool3ool0od_ooooo0Ol00001ooooo`006oooool00ol0003ooooooooo
o`18ooooo`?oo`3o=?ooool00ol0003oooooooooo`0`ooooo`;oo`3oC?ooool1o`00007ooooo000K
ooooo`03o`000?oooooooooo04Wooooo0_oo0?ldooooo`03o`000?oooooooooo033ooooo0_oo0?m<
ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0BOooool3ool0oc?ooooo00?o0000oooo
ooooool0;oooool3ool0odcooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1:ooooo`;o
o`3o<oooool00ol0003oooooooooo`0_ooooo`;oo`3oCOooool1o`00007ooooo000Kooooo`;o0000
Boooool2ool0oc?ooooo00?o0000ooooooooool0;_ooool3ool0odcooooo0_l00001ooooo`006ooo
ool00ol0003oooooooooo`1:ooooo`?oo`3o<_ooool00ol0003oooooooooo`0^ooooo`;oo`3oC_oo
ool1o`00007ooooo000Kooooo`03o`000?oooooooooo04_ooooo0_oo0?lbooooo`03o`000?oooooo
oooo02kooooo0_oo0?m>ooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Boooool3ool0
oc7ooooo00?o0000ooooooooool0;Oooool3ool0odkooooo0Ol00001ooooo`000_ooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000?ooooo0ol00005ooooo`03o`000?oooooooooo04co
oooo0_oo0?laooooo`03o`000?oooooooooo02gooooo0_oo0?m?ooooo`7o00000Oooool00005oooo
ool0003oooooooooool000002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1<ooooo`;oo`3o<Oooool00ol0003oooooooooo`0]
ooooo`;oo`3oCoooool1o`00007ooooo00001Ooooooo0000oooooooooooo000000Sooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`;o0000COooool3ool0oc3ooooo00?o
0000ooooooooool0;?ooool3ool0odkooooo0_l00001ooooo`0000Goooooo`000?ooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`1=ooooo`;oo`3o<?ooool00ol0003oooooooooo`0/ooooo`;oo`3oD?ooool1o`00007ooooo
00001Ooooooo0000oooooooooooo000000Sooooo00Go0000oooooooooooo0000ooooo`04o`0000Go
oooo00?o0000ooooooooool0COooool3ool0oboooooo00?o0000ooooooooool0:oooool3ool0oe3o
oooo0Ol00001ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`06o`000?ooooooooooo`00
0?oooooo00002?ooool00ol0003oooooooooo`1>ooooo`;oo`3o;oooool00ol0003oooooooooo`0[
ooooo`;oo`3oDOooool1o`00007ooooo0002ooooo`;o00002_ooool2o`0000;ooooo1Ol00004oooo
o`03o`000?oooooooooo04kooooo0_oo0?l_ooooo`03o`000?oooooooooo02_ooooo0_oo0?mAoooo
o`7o00000Oooool001_ooooo00?o0000ooooooooool0C_ooool3ool0obkooooo00?o0000oooooooo
ool0:_ooool3ool0oe7ooooo0Ol00001ooooo`006oooool2o`00053ooooo0_oo0?l^ooooo`03o`00
0?oooooooooo02[ooooo0_oo0?mAooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0Cooo
ool2ool0obkooooo00?o0000ooooooooool0:_ooool2ool0oe;ooooo0Ol00001ooooo`006oooool0
0ol0003oooooooooo`1?ooooo`?oo`3o;Oooool00ol0003oooooooooo`0Yooooo`?oo`3oD_ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo053ooooo0_oo0?l]ooooo`03o`000?oooooooooo
02Wooooo0_oo0?mCooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0D?ooool2ool0obgo
oooo00?o0000ooooooooool0:?ooool3ool0oe?ooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1@ooooo`?oo`3o;?ooool00ol0003oooooooooo`0Xooooo`;oo`3oE?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo057ooooo0_oo0?l/ooooo`03o`000?oooooooooo02Sooooo0_oo
0?mDooooo`7o00000Oooool001_ooooo0_l0001Booooo`?oo`3o:oooool00ol0003oooooooooo`0W
ooooo`?oo`3oDoooool2o`00007ooooo000Kooooo`03o`000?oooooooooo05;ooooo0_oo0?l[oooo
o`03o`000?oooooooooo02Oooooo0_oo0?mEooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0D_ooool2ool0ob_ooooo00?o0000ooooooooool09oooool2ool0oeGooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1Booooo`?oo`3o:_ooool00ol0003oooooooooo`0Vooooo`?oo`3o
EOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05?ooooo0_oo0?lZooooo`03o`000?oo
oooooooo02Kooooo0_oo0?mFooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Doooool2
ool0ob[ooooo00?o0000ooooooooool09_ooool2ool0oeKooooo0Ol00001ooooo`006oooool2o`00
05Cooooo0ooo0?lYooooo`03o`000?oooooooooo02Gooooo0ooo0?mEooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool0E?ooool2ool0obWooooo00?o0000ooooooooool09Oooool2ool0oeOo
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Dooooo`;oo`3o:Oooool00ol0003ooooo
ooooo`0Tooooo`?oo`3oEoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05Cooooo0ooo
0?lXooooo`03o`000?oooooooooo02Cooooo0_oo0?mHooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0EOooool2ool0obSooooo00?o0000ooooooooool09?ooool2ool0oeSooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1Eooooo`?oo`3o9oooool00ol0003oooooooooo`0Soooo
o`?oo`3oF?ooool1o`00007ooooo000Kooooo`;o0000Eoooool2ool0obOooooo00?o0000oooooooo
ool08oooool2ool0oeSooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1Fooooo`;oo`3o
9oooool00ol0003oooooooooo`0Sooooo`;oo`3oFOooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo05Kooooo0ooo0?lVooooo`03o`000?oooooooooo02;ooooo0ooo0?mIooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0Eoooool2ool0obKooooo00?o0000ooooooooool08_ooool2
ool0oe[ooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool0Eoooool2ool0obKooooo00?o0000ooooooooool08_ooool2ool0
oe[ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Eoooool3ool0obGooooo00?o0000ooooooooool08_ooool2ool0
oe[ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00Cooooo0_l0001Iooooo`;oo`3o9Oooool00ol0003oooooooooo`0Qooooo`?oo`3oFOooool2o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Hooooo`;oo`3o9Oooool00ol0003oooooooooo`0Qooooo`;oo`3oFoooool1o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`1Hooooo`?oo`3o9?ooool00ol0003oooooooooo`0Qooooo`;oo`3oFoooool1o`00
007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo
05Wooooo0_oo0?lTooooo`03o`000?oooooooooo023ooooo0ooo0?mKooooo`7o00000Oooool000So
oooo0_l0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool3ool0ob?o
oooo00?o0000ooooooooool08?ooool2ool0oecooooo0Ol00001ooooo`006oooool00ol0003ooooo
ooooo`1Jooooo`;oo`3o8oooool00ol0003oooooooooo`0Oooooo`?oo`3oG?ooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo05[ooooo0_oo0?lSooooo`03o`000?oooooooooo01oooooo0_oo
0?mMooooo`7o00000Oooool001_ooooo0_l0001Kooooo`?oo`3o8_ooool00ol0003oooooooooo`0O
ooooo`;oo`3oG?ooool2o`00007ooooo000Kooooo`03o`000?oooooooooo05_ooooo0_oo0?lRoooo
o`03o`000?oooooooooo01kooooo0ooo0?mMooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0Foooool2ool0ob;ooooo00?o0000ooooooooool07_ooool2ool0oekooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1Kooooo`?oo`3o8Oooool00ol0003oooooooooo`0Nooooo`;oo`3o
G_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05cooooo0_oo0?lQooooo`03o`000?oo
oooooooo01gooooo0ooo0?mNooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0G?ooool3
ool0ob3ooooo00?o0000ooooooooool07Oooool2ool0oeoooooo0Ol00001ooooo`006oooool2o`00
05kooooo0_oo0?lPooooo`03o`000?oooooooooo01cooooo0ooo0?mNooooo`;o00000Oooool001_o
oooo00?o0000ooooooooool0GOooool2ool0ob3ooooo00?o0000ooooooooool07?ooool2ool0of3o
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Mooooo`?oo`3o7oooool00ol0003ooooo
ooooo`0Looooo`;oo`3oH?ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo05kooooo0_oo
0?lOooooo`03o`000?oooooooooo01_ooooo0ooo0?mPooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0G_ooool3ool0oakooooo00?o0000ooooooooool06oooool2ool0of7ooooo0Ol00001
ooooo`006oooool00ol0003oooooooooo`1Oooooo`;oo`3o7_ooool00ol0003oooooooooo`0Koooo
o`;oo`3oHOooool1o`00007ooooo000Kooooo`;o0000H?ooool2ool0oakooooo00?o0000oooooooo
ool06_ooool3ool0of3ooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1Oooooo`?oo`3o
7Oooool00ol0003oooooooooo`0Jooooo`;oo`3oH_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo063ooooo0_oo0?lMooooo`03o`000?oooooooooo01Wooooo0ooo0?mRooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0H?ooool2ool0oagooooo00?o0000ooooooooool06Oooool2
ool0of?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Pooooo`?oo`3o7?ooool00ol0
003oooooooooo`0Iooooo`;oo`3oHoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo067o
oooo0_oo0?lLooooo`03o`000?oooooooooo01Sooooo0ooo0?mSooooo`7o00000Oooool001_ooooo
00?o0000ooooooooool0HOooool3ool0oa_ooooo00?o0000ooooooooool06?ooool2ool0ofCooooo
0Ol00001ooooo`006oooool2o`0006?ooooo0_oo0?lKooooo`03o`000?oooooooooo01Oooooo0ooo
0?mSooooo`;o00000Oooool001_ooooo00?o0000ooooooooool0H_ooool3ool0oa[ooooo00?o0000
ooooooooool05oooool2ool0ofGooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1Soooo
o`;oo`3o6_ooool00ol0003oooooooooo`0Fooooo`?oo`3oIOooool1o`00007ooooo0002ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`?o00000oooool3o`0000Gooooo00?o0000oooooooo
ool0Hoooool2ool0oa[ooooo00?o0000ooooooooool05_ooool2ool0ofKooooo0Ol00001ooooo`00
00Goooooo`000?ooooooooooo`000009ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo06?ooooo0ooo0?lIooooo`03o`000?oooooooooo
01Kooooo0_oo0?mVooooo`7o00000Oooool00005ooooool0003oooooooooool000002Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0I?ooool2ool0
oaWooooo00?o0000ooooooooool05Oooool3ool0ofKooooo0Ol00001ooooo`0000Goooooo`000?oo
ooooooooo`000009ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool2o`00
06Gooooo0ooo0?lHooooo`03o`000?oooooooooo01Gooooo0_oo0?mVooooo`;o00000Oooool00005
ooooool0003oooooooooool000002Oooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000
ooooooooool0IOooool2ool0oaSooooo00?o0000ooooooooool05?ooool3ool0ofOooooo0Ol00001
ooooo`0000Goooooo`000?ooooooooooo`000008ooooo`;o00000oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo06Gooooo0ooo0?lGooooo`03o`000?oooooooooo01Cooooo0_oo0?mX
ooooo`7o00000Oooool000;ooooo0_l0000:ooooo`04o`000?ooooooooooooooo`Go00001?ooool0
0ol0003oooooooooo`1Vooooo`;oo`3o5oooool00ol0003oooooooooo`0Cooooo`?oo`3oJ?ooool1
o`00007ooooo000Kooooo`03o`000?oooooooooo06Kooooo0ooo0?lFooooo`03o`000?oooooooooo
01?ooooo0_oo0?mYooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0Ioooool2ool0oaKo
oooo00?o0000ooooooooool04_ooool3ool0ofWooooo0Ol00001ooooo`006oooool2o`0006Sooooo
0_oo0?lFooooo`03o`000?oooooooooo01;ooooo0_oo0?mYooooo`;o00000Oooool001_ooooo00?o
0000ooooooooool0Ioooool3ool0oaGooooo00?o0000ooooooooool04Oooool3ool0of[ooooo0Ol0
0001ooooo`006oooool00ol0003oooooooooo`1Xooooo`;oo`3o5Oooool00ol0003oooooooooo`0A
ooooo`?oo`3oJ_ooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06Sooooo0_oo0?lEoooo
o`03o`000?oooooooooo017ooooo0_oo0?m[ooooo`7o00000Oooool001_ooooo00?o0000oooooooo
ool0J?ooool3ool0oaCooooo00?o0000ooooooooool04?ooool3ool0of_ooooo0Ol00001ooooo`00
6oooool00ol0003oooooooooo`1Yooooo`;oo`3o5?ooool00ol0003oooooooooo`0?ooooo`?oo`3o
K?ooool1o`00007ooooo000Kooooo`;o0000J_ooool3ool0oa?ooooo00?o0000ooooooooool03ooo
ool2ool0ofcooooo0_l00001ooooo`006oooool00ol0003oooooooooo`1Zooooo`?oo`3o4_ooool0
0ol0003oooooooooo`0>ooooo`?oo`3oKOooool1o`00007ooooo000Kooooo`03o`000?oooooooooo
06_ooooo0_oo0?lBooooo`03o`000?oooooooooo00kooooo0_oo0?m^ooooo`7o00000Oooool001_o
oooo00?o0000ooooooooool0Joooool3ool0oa7ooooo00?o0000ooooooooool03Oooool3ool0ofko
oooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1/ooooo`;oo`3o4Oooool00ol0003ooooo
ooooo`0=ooooo`;oo`3oKoooool1o`00007ooooo000Kooooo`03o`000?oooooooooo06cooooo0ooo
0?l@ooooo`03o`000?oooooooooo00cooooo0ooo0?m_ooooo`7o00000Oooool001_ooooo00?o0000
ooooooooool0KOooool3ool0o`oooooo00?o0000ooooooooool02oooool3ool0og3ooooo0Ol00001
ooooo`006oooool2o`0006kooooo0ooo0?l?ooooo`03o`000?oooooooooo00_ooooo0ooo0?m_oooo
o`;o00000Oooool001_ooooo00?o0000ooooooooool0K_ooool3ool0o`kooooo00?o0000oooooooo
ool02_ooool3ool0og7ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1_ooooo`?oo`3o
3Oooool00ol0003oooooooooo`09ooooo`?oo`3oL_ooool1o`00007ooooo000Kooooo`03o`000?oo
oooooooo06oooooo0ooo0?l=ooooo`03o`000?oooooooooo00Wooooo0ooo0?mbooooo`7o00000Ooo
ool001_ooooo00?o0000ooooooooool0L?ooool3ool0o`cooooo00?o0000ooooooooool02?ooool3
ool0og?ooooo0Ol00001ooooo`006oooool00ol0003oooooooooo`1aooooo`?oo`3o2oooool00ol0
003oooooooooo`07ooooo`?oo`3oM?ooool1o`00007ooooo000Kooooo`;o0000Loooool3ool0o`[o
oooo00?o0000ooooooooool01_ooool3ool0ogCooooo0_l00001ooooo`006oooool00ol0003ooooo
ooooo`1booooo`Coo`3o2Oooool00ol0003oooooooooo`05ooooo`Coo`3oMOooool1o`00007ooooo
000Kooooo`03o`000?oooooooooo07?ooooo1?oo0?l8ooooo`03o`000?oooooooooo00Cooooo1?oo
0?mfooooo`7o00000Oooool001_ooooo00?o0000ooooooooool0M?ooool4ool0o`Oooooo00?o0000
ooooooooool00oooool4ool0ogOooooo0Ol00001ooooo`002?ooool2o`0000Cooooo00Co0000oooo
oooooooooooo1Ol00004ooooo`03o`000?oooooooooo07Gooooo1Ooo0?l5ooooo`04o`000?oooooo
ooooooooo`Goo`3oN?ooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`1gooooo`Goo`3o0oooool00ol0003ooooo
ool0o`04ool0og[ooooo0Ol00001ooooo`001oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Cooooo0_l0001iooooo`goo`3oN_ooool2o`00007ooooo0007ooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1jooooo`Woo`3o
OOooool1o`00007ooooo0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool000Oooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool1o`00007ooooo0008ooooo`;o
00002Oooool3o`0000Goooooool00005o`00007ooooo003oooooob7ooooo003oooooob7ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-12.7039, -0.0718712, \
0.0808853, 0.00159306}}]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Compare frequency spectra of three pulses", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[GraphicsArray[{{gx1, gX1}, {gx2, gX2}, {gx3, gX3}}], 
        ImageSize \[Rule] 504];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .94177 
%%ImageSize: 504 474.65 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.022423 0.47619 [
[ 0 0 0 0 ]
[ 1 .94177 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .94177 L
0 .94177 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.022423 0.477324 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0280925 0.280925 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44948 -18 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.5)] -0.0125 .16855 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(1.5)] -0.0125 .44948 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(2)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 1 r
.01 w
.02381 .02809 m
.02567 .02809 L
.02769 .02809 L
.0296 .02809 L
.03143 .02809 L
.03338 .02809 L
.03525 .02809 L
.03724 .02809 L
.03917 .02809 L
.04101 .02809 L
.04298 .02809 L
.04487 .02809 L
.04669 .02809 L
.04863 .02809 L
.05049 .02809 L
.05248 .02809 L
.05439 .02809 L
.05622 .02809 L
.05818 .02809 L
.06006 .02809 L
.06206 .02809 L
.06399 .02809 L
.06584 .02809 L
.06781 .02809 L
.06971 .02809 L
.07154 .02809 L
.07348 .02809 L
.07535 .02809 L
.07734 .02809 L
.07926 .02809 L
.0811 .02809 L
.08306 .02809 L
.08495 .02809 L
.08677 .02809 L
.0887 .02809 L
.09056 .02809 L
.09254 .02809 L
.09445 .02809 L
.09628 .02809 L
.09823 .02809 L
.10011 .02809 L
.10211 .02809 L
.10403 .02809 L
.10588 .02809 L
.10785 .02809 L
.10974 .02809 L
.11156 .02809 L
.1135 .02809 L
.11537 .02809 L
.11736 .02809 L
Mistroke
.11927 .02809 L
.12111 .02809 L
.12307 .02809 L
.12495 .02809 L
.12695 .02809 L
.12888 .02809 L
.13074 .02809 L
.13271 .02809 L
.13462 .02809 L
.13644 .02809 L
.13839 .02809 L
.14026 .02809 L
.14226 .02809 L
.14418 .02809 L
.14602 .02809 L
.14799 .02809 L
.14988 .02809 L
.15169 .02809 L
.15363 .02809 L
.15549 .02809 L
.15748 .02809 L
.15938 .02809 L
.16122 .02809 L
.16317 .02809 L
.16505 .02809 L
.16705 .02809 L
.16898 .02809 L
.17083 .02809 L
.1728 .02809 L
.1747 .02809 L
.17652 .02809 L
.17846 .02809 L
.18033 .02809 L
.18232 .02809 L
.18424 .02809 L
.18608 .02809 L
.18804 .02809 L
.18993 .02809 L
.19174 .02809 L
.19367 .02809 L
.19553 .02809 L
.19751 .02809 L
.19941 .02809 L
.20124 .02809 L
.20319 .02809 L
.20507 .02809 L
.20706 .02809 L
.20899 .02809 L
.21083 .02809 L
.2128 .02809 L
Mistroke
.21469 .02809 L
.21651 .02809 L
.21845 .02809 L
.22032 .02809 L
.2223 .02809 L
.22421 .02809 L
.22605 .02809 L
.22801 .02809 L
.22989 .02809 L
.23189 .02809 L
.23382 .02809 L
.23567 .02809 L
.23765 .02809 L
.23955 .02809 L
.24137 .02809 L
.24332 .02809 L
.24519 .02809 L
.24718 .02809 L
.2491 .02809 L
.25094 .02809 L
.25291 .02809 L
.2548 .02809 L
.25661 .02809 L
.25855 .02809 L
.26041 .02809 L
.26239 .02809 L
.2643 .02809 L
.26613 .02809 L
.26808 .02809 L
.26996 .02809 L
.27196 .02809 L
.27388 .02809 L
.27573 .02809 L
.2777 .02809 L
.2796 .02809 L
.28142 .02809 L
.28336 .02809 L
.28523 .02809 L
.28722 .02809 L
.28913 .02809 L
.29097 .02809 L
.29293 .02809 L
.29481 .02809 L
.29682 .02809 L
.29875 .02809 L
.3006 .02809 L
.30258 .02809 L
.30448 .02809 L
.30631 .02809 L
.30826 .02809 L
Mistroke
.31014 .02809 L
.31213 .02809 L
.31405 .02809 L
.31589 .02809 L
.31786 .02809 L
.31975 .02809 L
.32157 .02809 L
.32351 .02809 L
.32537 .02809 L
.32735 .02809 L
.32926 .02809 L
.3311 .02809 L
.33305 .02809 L
.33494 .02809 L
.33694 .02809 L
.33886 .02809 L
.34072 .02809 L
.34269 .02809 L
.34459 .02809 L
.34641 .02809 L
.34835 .02809 L
.35023 .02809 L
.35221 .02809 L
.35413 .02809 L
.35597 .02809 L
.35793 .02809 L
.35982 .02809 L
.36164 .02809 L
.36357 .02809 L
.36543 .02809 L
.36741 .02809 L
.36931 .02809 L
.37115 .02809 L
.3731 .02809 L
.37497 .02809 L
.37697 .02809 L
.37889 .02809 L
.38074 .02809 L
.38271 .02809 L
.3846 .02809 L
.38642 .02809 L
.38836 .02809 L
.39023 .02809 L
.39221 .02809 L
.39413 .02809 L
.39597 .02809 L
.39792 .02809 L
.39981 .02809 L
.40181 .02809 L
.40374 .02809 L
Mistroke
.40559 .02809 L
.40757 .02809 L
.40947 .02809 L
.4113 .02809 L
.41324 .02809 L
.41512 .02809 L
.41711 .02809 L
.41903 .02809 L
.42087 .02809 L
.42283 .02809 L
.42472 .02809 L
.42654 .02809 L
.42848 .02809 L
.43034 .02809 L
.43232 .02809 L
.43423 .02809 L
.43606 .02809 L
.43802 .02809 L
.4399 .02809 L
.44189 .02809 L
.44382 .02809 L
.44567 .02809 L
.44764 .02809 L
.44954 .02809 L
.45136 .02809 L
.4533 .02809 L
.45517 .02809 L
.45716 .02809 L
.45907 .02809 L
.46092 .02809 L
.46288 .02809 L
.46476 .02809 L
.46658 .02809 L
.46851 .02809 L
.47037 .02809 L
.47234 .02809 L
.47425 .02809 L
.4752 .02809 L
.47562 .02809 L
.47584 .02809 L
.47596 .02809 L
.47608 .02809 L
.47613 .02809 L
.4762 .30902 L
.47623 .30902 L
.47626 .30902 L
.47633 .30902 L
.47656 .30902 L
.47702 .30902 L
.47802 .30902 L
Mistroke
.47986 .30902 L
.48182 .30902 L
.4837 .30902 L
.4857 .30902 L
.48763 .30902 L
.48948 .30902 L
.49145 .30902 L
.49335 .30902 L
.49518 .30902 L
.49713 .30902 L
.499 .30902 L
.50099 .30902 L
.5029 .30902 L
.50475 .30902 L
.50671 .30902 L
.5086 .30902 L
.51041 .30902 L
.51235 .30902 L
.51421 .30902 L
.51619 .30902 L
.51809 .30902 L
.51993 .30902 L
.52188 .30902 L
.52278 .30902 L
.52325 .30902 L
.52351 .30902 L
.52364 .30902 L
.5237 .30902 L
.52376 .30902 L
.52382 .02809 L
.52388 .02809 L
.52401 .02809 L
.52429 .02809 L
.52478 .02809 L
.52575 .02809 L
.52771 .02809 L
.5296 .02809 L
.5316 .02809 L
.53353 .02809 L
.53539 .02809 L
.53736 .02809 L
.53926 .02809 L
.54109 .02809 L
.54304 .02809 L
.54491 .02809 L
.54691 .02809 L
.54882 .02809 L
.55067 .02809 L
.55264 .02809 L
.55453 .02809 L
Mistroke
.55635 .02809 L
.55828 .02809 L
.56015 .02809 L
.56213 .02809 L
.56404 .02809 L
.56587 .02809 L
.56783 .02809 L
.56971 .02809 L
.5717 .02809 L
.57363 .02809 L
.57548 .02809 L
.57745 .02809 L
.57935 .02809 L
.58118 .02809 L
.58312 .02809 L
.58499 .02809 L
.58698 .02809 L
.58889 .02809 L
.59074 .02809 L
.5927 .02809 L
.59458 .02809 L
.5964 .02809 L
.59833 .02809 L
.60019 .02809 L
.60217 .02809 L
.60407 .02809 L
.6059 .02809 L
.60785 .02809 L
.60973 .02809 L
.61173 .02809 L
.61365 .02809 L
.6155 .02809 L
.61746 .02809 L
.61936 .02809 L
.62118 .02809 L
.62312 .02809 L
.62498 .02809 L
.62697 .02809 L
.62888 .02809 L
.63072 .02809 L
.63267 .02809 L
.63456 .02809 L
.63656 .02809 L
.63849 .02809 L
.64034 .02809 L
.64231 .02809 L
.64422 .02809 L
.64604 .02809 L
.64799 .02809 L
.64986 .02809 L
Mistroke
.65185 .02809 L
.65377 .02809 L
.65561 .02809 L
.65758 .02809 L
.65947 .02809 L
.66128 .02809 L
.66322 .02809 L
.66508 .02809 L
.66706 .02809 L
.66897 .02809 L
.6708 .02809 L
.67275 .02809 L
.67463 .02809 L
.67663 .02809 L
.67856 .02809 L
.68041 .02809 L
.68238 .02809 L
.68427 .02809 L
.6861 .02809 L
.68804 .02809 L
.68991 .02809 L
.69189 .02809 L
.69381 .02809 L
.69565 .02809 L
.69761 .02809 L
.69949 .02809 L
.7015 .02809 L
.70343 .02809 L
.70528 .02809 L
.70726 .02809 L
.70916 .02809 L
.71099 .02809 L
.71294 .02809 L
.71482 .02809 L
.71681 .02809 L
.71873 .02809 L
.72058 .02809 L
.72254 .02809 L
.72444 .02809 L
.72625 .02809 L
.72819 .02809 L
.73006 .02809 L
.73204 .02809 L
.73395 .02809 L
.73579 .02809 L
.73774 .02809 L
.73962 .02809 L
.74162 .02809 L
.74355 .02809 L
.7454 .02809 L
Mistroke
.74737 .02809 L
.74927 .02809 L
.7511 .02809 L
.75304 .02809 L
.75491 .02809 L
.7569 .02809 L
.75882 .02809 L
.76066 .02809 L
.76262 .02809 L
.76451 .02809 L
.76633 .02809 L
.76826 .02809 L
.77012 .02809 L
.7721 .02809 L
.77401 .02809 L
.77584 .02809 L
.77779 .02809 L
.77967 .02809 L
.78166 .02809 L
.78359 .02809 L
.78543 .02809 L
.7874 .02809 L
.7893 .02809 L
.79112 .02809 L
.79306 .02809 L
.79493 .02809 L
.79691 .02809 L
.79882 .02809 L
.80066 .02809 L
.80262 .02809 L
.8045 .02809 L
.80651 .02809 L
.80844 .02809 L
.81029 .02809 L
.81227 .02809 L
.81417 .02809 L
.816 .02809 L
.81794 .02809 L
.81982 .02809 L
.82181 .02809 L
.82373 .02809 L
.82557 .02809 L
.82754 .02809 L
.82943 .02809 L
.83125 .02809 L
.83318 .02809 L
.83504 .02809 L
.83703 .02809 L
.83893 .02809 L
.84077 .02809 L
Mistroke
.84272 .02809 L
.8446 .02809 L
.8466 .02809 L
.84853 .02809 L
.85038 .02809 L
.85235 .02809 L
.85425 .02809 L
.85607 .02809 L
.85801 .02809 L
.85988 .02809 L
.86187 .02809 L
.86378 .02809 L
.86563 .02809 L
.86759 .02809 L
.86947 .02809 L
.87129 .02809 L
.87322 .02809 L
.87508 .02809 L
.87705 .02809 L
.87896 .02809 L
.88079 .02809 L
.88274 .02809 L
.88461 .02809 L
.88661 .02809 L
.88853 .02809 L
.89038 .02809 L
.89234 .02809 L
.89424 .02809 L
.89606 .02809 L
.898 .02809 L
.89986 .02809 L
.90185 .02809 L
.90376 .02809 L
.90559 .02809 L
.90755 .02809 L
.90943 .02809 L
.91143 .02809 L
.91336 .02809 L
.91522 .02809 L
.91719 .02809 L
.91909 .02809 L
.92092 .02809 L
.92286 .02809 L
.92473 .02809 L
.92672 .02809 L
.92864 .02809 L
.93048 .02809 L
.93245 .02809 L
.93434 .02809 L
.93615 .02809 L
Mistroke
.93809 .02809 L
.93995 .02809 L
.94193 .02809 L
.94383 .02809 L
.94567 .02809 L
.94762 .02809 L
.9495 .02809 L
.95149 .02809 L
.95342 .02809 L
.95527 .02809 L
.95724 .02809 L
.95913 .02809 L
.96096 .02809 L
.9629 .02809 L
.96476 .02809 L
.96675 .02809 L
.96866 .02809 L
.9705 .02809 L
.97246 .02809 L
.97435 .02809 L
.97619 .02809 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.022423 0.97619 0.302711 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.11976 2.41779 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .24065 -24 -4.5 ]
[-0.0125 .24065 0 4.5 ]
[-0.0125 .36154 -18 -4.5 ]
[-0.0125 .36154 0 4.5 ]
[-0.0125 .48243 -24 -4.5 ]
[-0.0125 .48243 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .24065 m
.00625 .24065 L
s
[(0.05)] -0.0125 .24065 1 0 Mshowa
0 .36154 m
.00625 .36154 L
s
[(0.1)] -0.0125 .36154 1 0 Mshowa
0 .48243 m
.00625 .48243 L
s
[(0.15)] -0.0125 .48243 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0.2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .02305 m
.00375 .02305 L
s
0 .04723 m
.00375 .04723 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16812 m
.00375 .16812 L
s
0 .19229 m
.00375 .19229 L
s
0 .21647 m
.00375 .21647 L
s
0 .26483 m
.00375 .26483 L
s
0 .28901 m
.00375 .28901 L
s
0 .31318 m
.00375 .31318 L
s
0 .33736 m
.00375 .33736 L
s
0 .38572 m
.00375 .38572 L
s
0 .4099 m
.00375 .4099 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .50661 m
.00375 .50661 L
s
0 .53079 m
.00375 .53079 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .24065 m
1 .24065 L
s
.99375 .36154 m
1 .36154 L
s
.99375 .48243 m
1 .48243 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .02305 m
1 .02305 L
s
.99625 .04723 m
1 .04723 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16812 m
1 .16812 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .21647 m
1 .21647 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .28901 m
1 .28901 L
s
.99625 .31318 m
1 .31318 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .4099 m
1 .4099 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .50661 m
1 .50661 L
s
.99625 .53079 m
1 .53079 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
1 0 1 r
.01 w
.02381 .11976 m
.02567 .11787 L
.02769 .11578 L
.0296 .11382 L
.03143 .11191 L
.03338 .10987 L
.03525 .1079 L
.03724 .10579 L
.03917 .10376 L
.04101 .10179 L
.04298 .09969 L
.04487 .09767 L
.04669 .09572 L
.04863 .09364 L
.05049 .09164 L
.05248 .08952 L
.05439 .08747 L
.05622 .08551 L
.05818 .08342 L
.06006 .08142 L
.06206 .0793 L
.06399 .07726 L
.06584 .07531 L
.06781 .07325 L
.06971 .07127 L
.07154 .06938 L
.07348 .06739 L
.07535 .06549 L
.07734 .06348 L
.07926 .06157 L
.0811 .05974 L
.08306 .05783 L
.08495 .056 L
.08677 .05427 L
.0887 .05245 L
.09056 .05073 L
.09254 .04892 L
.09445 .04721 L
.09628 .04559 L
.09823 .0439 L
.10011 .04231 L
.10211 .04065 L
.10403 .03909 L
.10588 .03762 L
.10785 .0361 L
.10974 .03468 L
.11156 .03334 L
.1135 .03196 L
.11537 .03068 L
.11736 .02936 L
Mistroke
.11927 .02813 L
.12111 .02699 L
.12307 .02583 L
.12495 .02476 L
.12695 .02368 L
.12888 .02268 L
.13074 .02178 L
.13271 .02087 L
.13462 .02005 L
.13644 .01932 L
.13839 .01859 L
.14026 .01795 L
.14226 .01732 L
.14418 .01678 L
.14602 .01632 L
.14799 .01589 L
.14988 .01554 L
.15169 .01526 L
.15363 .01502 L
.15549 .01486 L
.15646 .0148 L
.15695 .01477 L
.15748 .01475 L
.15797 .01474 L
.15843 .01472 L
.15864 .01472 L
.15876 .01472 L
.15888 .01472 L
.15899 .01472 L
.1591 .01472 L
.15916 .01472 L
.15921 .01472 L
.15926 .01472 L
.15931 .01472 L
.15937 .01472 L
.1594 .01472 L
.15943 .01472 L
.15947 .01472 L
.1595 .01472 L
.15956 .01472 L
.15962 .01472 L
.15968 .01472 L
.15974 .01472 L
.1598 .01472 L
.15994 .01472 L
.16008 .01472 L
.16033 .01472 L
.16057 .01473 L
.16079 .01473 L
.1613 .01475 L
Mistroke
.16176 .01476 L
.1622 .01478 L
.16319 .01484 L
.16417 .01492 L
.16506 .01501 L
.16697 .01524 L
.16881 .01553 L
.17076 .01591 L
.17265 .01635 L
.17465 .01688 L
.17657 .01748 L
.17843 .01812 L
.1804 .01888 L
.1823 .01968 L
.18413 .02052 L
.18607 .02149 L
.18795 .0225 L
.18994 .02365 L
.19185 .02483 L
.1937 .02604 L
.19566 .02741 L
.19755 .0288 L
.19937 .0302 L
.2013 .03178 L
.20316 .03337 L
.20514 .03513 L
.20705 .03692 L
.20888 .0387 L
.21084 .04068 L
.21271 .04266 L
.21471 .04484 L
.21664 .04702 L
.21849 .04919 L
.22046 .05158 L
.22235 .05396 L
.22417 .05631 L
.22612 .0589 L
.22798 .06145 L
.22997 .06425 L
.23188 .06702 L
.23372 .06976 L
.23568 .07274 L
.23757 .07568 L
.23957 .07889 L
.2415 .08205 L
.24336 .08517 L
.24534 .08855 L
.24724 .09188 L
.24907 .09514 L
.25102 .09868 L
Mistroke
.25289 .10216 L
.25488 .10593 L
.2568 .10962 L
.25865 .11324 L
.26061 .11715 L
.26251 .12099 L
.26433 .12473 L
.26626 .12877 L
.26813 .13272 L
.27011 .13698 L
.27202 .14115 L
.27385 .14521 L
.27581 .14958 L
.27769 .15385 L
.27969 .15844 L
.28162 .16292 L
.28347 .16727 L
.28544 .17196 L
.28734 .17652 L
.28917 .18095 L
.29111 .18571 L
.29298 .19033 L
.29497 .19529 L
.29688 .20011 L
.29873 .20479 L
.30069 .2098 L
.30258 .21467 L
.30439 .21938 L
.30632 .22442 L
.30818 .22931 L
.31016 .23454 L
.31207 .23961 L
.3139 .24451 L
.31585 .24975 L
.31773 .25482 L
.31972 .26024 L
.32165 .26547 L
.32349 .27053 L
.32546 .27592 L
.32736 .28113 L
.32918 .28616 L
.33112 .29152 L
.33298 .29669 L
.33497 .30219 L
.33688 .3075 L
.33872 .31262 L
.34068 .31806 L
.34256 .3233 L
.34456 .32887 L
.34649 .33424 L
Mistroke
.34835 .3394 L
.35032 .34488 L
.35222 .35015 L
.35405 .35521 L
.356 .36058 L
.35787 .36574 L
.35986 .37121 L
.36178 .37646 L
.36363 .3815 L
.36559 .38683 L
.36748 .39195 L
.3693 .39684 L
.37123 .40203 L
.3731 .40699 L
.37508 .41224 L
.37698 .41726 L
.37882 .42206 L
.38077 .42713 L
.38265 .43198 L
.38465 .43709 L
.38657 .44197 L
.38843 .44663 L
.3904 .45153 L
.39229 .45621 L
.39412 .46067 L
.39606 .46536 L
.39793 .46983 L
.39992 .47453 L
.40183 .479 L
.40367 .48324 L
.40563 .4877 L
.40752 .49193 L
.40933 .49595 L
.41126 .50016 L
.41312 .50415 L
.4151 .50833 L
.417 .51229 L
.41883 .51603 L
.42078 .51995 L
.42266 .52365 L
.42465 .5275 L
.42657 .53114 L
.42842 .53456 L
.43038 .53813 L
.43228 .54149 L
.4341 .54464 L
.43603 .54792 L
.4379 .551 L
.43988 .55418 L
.44179 .55716 L
Mistroke
.44363 .55995 L
.44559 .56283 L
.44747 .56552 L
.44947 .56828 L
.4514 .57085 L
.45325 .57323 L
.45522 .57567 L
.45712 .57793 L
.45895 .58002 L
.46089 .58214 L
.46277 .5841 L
.46476 .58608 L
.46667 .58788 L
.46852 .58953 L
.47048 .59118 L
.47237 .59268 L
.47418 .59402 L
.47612 .59535 L
.47798 .59654 L
.47996 .5977 L
.48186 .59872 L
.4837 .5996 L
.48565 .60043 L
.48753 .60114 L
.48952 .60178 L
.49145 .60229 L
.4933 .60269 L
.49423 .60285 L
.49526 .603 L
.49625 .60312 L
.49716 .60321 L
.49761 .60324 L
.4981 .60327 L
.49836 .60328 L
.49861 .60329 L
.49887 .6033 L
.4991 .60331 L
.49935 .60331 L
.49947 .60332 L
.49961 .60332 L
.49967 .60332 L
.49973 .60332 L
.49978 .60332 L
.49984 .60332 L
.49987 .60332 L
.49991 .60332 L
.49994 .60332 L
.49997 .60332 L
.50003 .60332 L
.50009 .60332 L
Mistroke
.50015 .60332 L
.50021 .60332 L
.50026 .60332 L
.50031 .60332 L
.50044 .60332 L
.50055 .60331 L
.50076 .60331 L
.50098 .60331 L
.50148 .60329 L
.50201 .60326 L
.50252 .60323 L
.50298 .60319 L
.50389 .60311 L
.50488 .60298 L
.50682 .60267 L
.50869 .60226 L
.51068 .60172 L
.5126 .60109 L
.51444 .6004 L
.5164 .59955 L
.51829 .59864 L
.5201 .59767 L
.52204 .59653 L
.52389 .59535 L
.52587 .59398 L
.52778 .59257 L
.52961 .59111 L
.53156 .58947 L
.53343 .58779 L
.53543 .5859 L
.53735 .58398 L
.5392 .58204 L
.54117 .57989 L
.54306 .57772 L
.54488 .57555 L
.54682 .57314 L
.54869 .57074 L
.55067 .56809 L
.55258 .56545 L
.55442 .56282 L
.55638 .55994 L
.55826 .55708 L
.56026 .55395 L
.56219 .55085 L
.56405 .54779 L
.56602 .54444 L
.56792 .54114 L
.56975 .53789 L
.57169 .53436 L
.57357 .53088 L
Mistroke
.57556 .52711 L
.57747 .52339 L
.57932 .51975 L
.58128 .51581 L
.58317 .51194 L
.58499 .50816 L
.58692 .50406 L
.58879 .50006 L
.59077 .49574 L
.59267 .49151 L
.59451 .48739 L
.59646 .48294 L
.59834 .47861 L
.60033 .47394 L
.60226 .46939 L
.60411 .46496 L
.60608 .46019 L
.60798 .45555 L
.6098 .45105 L
.61174 .44621 L
.61361 .44151 L
.6156 .43646 L
.61751 .43157 L
.61935 .42682 L
.62131 .42173 L
.6232 .41679 L
.6252 .41151 L
.62713 .40639 L
.62899 .40144 L
.63096 .39614 L
.63287 .39101 L
.6347 .38606 L
.63665 .38076 L
.63852 .37564 L
.64051 .37018 L
.64243 .3649 L
.64428 .35981 L
.64625 .35438 L
.64814 .34915 L
.64996 .3441 L
.6519 .33872 L
.65376 .33354 L
.65574 .32802 L
.65765 .32271 L
.65949 .3176 L
.66144 .31216 L
.66333 .30693 L
.66533 .30137 L
.66725 .29603 L
.66911 .2909 L
Mistroke
.67108 .28545 L
.67298 .28021 L
.6748 .27519 L
.67675 .26986 L
.67862 .26475 L
.68061 .25934 L
.68252 .25414 L
.68437 .24917 L
.68633 .2439 L
.68822 .23885 L
.69003 .23403 L
.69197 .22892 L
.69383 .22403 L
.6958 .21887 L
.69771 .21393 L
.69954 .20921 L
.70149 .20423 L
.70337 .19947 L
.70537 .19445 L
.70729 .18966 L
.70914 .18509 L
.71111 .18028 L
.713 .17569 L
.71482 .17132 L
.71676 .16672 L
.71863 .16234 L
.72062 .15773 L
.72253 .15335 L
.72437 .14919 L
.72632 .14481 L
.72821 .14065 L
.73021 .13629 L
.73214 .13215 L
.734 .12823 L
.73597 .12411 L
.73787 .12021 L
.7397 .11652 L
.74165 .11265 L
.74352 .109 L
.74551 .10517 L
.74743 .10156 L
.74928 .09815 L
.75124 .09459 L
.75313 .09122 L
.75495 .08806 L
.75689 .08475 L
.75875 .08164 L
.76073 .0784 L
.76264 .07536 L
.76447 .0725 L
Mistroke
.76643 .06953 L
.76831 .06674 L
.7703 .06386 L
.77223 .06116 L
.77408 .05863 L
.77605 .05602 L
.77795 .05358 L
.77977 .0513 L
.78172 .04895 L
.78359 .04677 L
.78557 .04452 L
.78749 .04244 L
.78933 .04051 L
.79129 .03853 L
.79318 .0367 L
.79499 .03501 L
.79692 .03329 L
.79878 .03171 L
.80076 .0301 L
.80266 .02864 L
.80449 .0273 L
.80644 .02595 L
.80832 .02472 L
.81031 .0235 L
.81223 .0224 L
.81408 .02141 L
.81605 .02044 L
.81794 .01957 L
.81976 .01881 L
.8217 .01807 L
.82357 .01743 L
.82555 .01683 L
.82746 .01632 L
.8293 .0159 L
.83125 .01552 L
.83314 .01522 L
.8341 .0151 L
.83514 .01499 L
.83606 .0149 L
.83706 .01483 L
.83802 .01477 L
.83855 .01475 L
.83904 .01474 L
.83928 .01473 L
.83954 .01472 L
.83979 .01472 L
.83991 .01472 L
.84002 .01472 L
.84012 .01472 L
.84022 .01472 L
Mistroke
.84027 .01472 L
.84033 .01472 L
.84039 .01472 L
.84045 .01472 L
.84051 .01472 L
.84057 .01472 L
.84063 .01472 L
.84069 .01472 L
.84074 .01472 L
.84079 .01472 L
.84091 .01472 L
.84103 .01472 L
.84113 .01472 L
.84138 .01472 L
.8416 .01473 L
.84181 .01473 L
.84229 .01474 L
.84281 .01476 L
.84375 .01481 L
.84476 .01488 L
.84677 .01506 L
.8487 .01531 L
.85055 .01561 L
.85253 .016 L
.85443 .01643 L
.85626 .0169 L
.85821 .01746 L
.86008 .01806 L
.86208 .01876 L
.864 .01949 L
.86584 .02025 L
.86781 .02111 L
.8697 .02199 L
.87152 .02289 L
.87346 .02389 L
.87532 .02491 L
.8773 .02604 L
.87921 .02719 L
.88105 .02833 L
.883 .02959 L
.88488 .03085 L
.88688 .03223 L
.88881 .03361 L
.89066 .03498 L
.89263 .03647 L
.89453 .03795 L
.89636 .0394 L
.8983 .04099 L
.90017 .04255 L
.90216 .04424 L
Mistroke
.90407 .0459 L
.90592 .04753 L
.90788 .0493 L
.90976 .05103 L
.91158 .05272 L
.91351 .05454 L
.91537 .05632 L
.91735 .05823 L
.91925 .0601 L
.92109 .06191 L
.92304 .06386 L
.92491 .06576 L
.92691 .06779 L
.92883 .06977 L
.93068 .07168 L
.93265 .07373 L
.93454 .07571 L
.93636 .07763 L
.9383 .07968 L
.94017 .08166 L
.94215 .08377 L
.94407 .08582 L
.9459 .08778 L
.94786 .08988 L
.94974 .0919 L
.95175 .09405 L
.95367 .09611 L
.95553 .0981 L
.9575 .10021 L
.9594 .10224 L
.96123 .10418 L
.96318 .10624 L
.96505 .10822 L
.96704 .11031 L
.96896 .11232 L
.97081 .11423 L
.97277 .11626 L
.97466 .1182 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.330739 0.477324 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0280925 0.280925 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44948 -18 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.5)] -0.0125 .16855 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(1.5)] -0.0125 .44948 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(2)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .02809 m
.02567 .02809 L
.02769 .02809 L
.0296 .02809 L
.03143 .02809 L
.03338 .02809 L
.03525 .02809 L
.03724 .02809 L
.03917 .02809 L
.04101 .02809 L
.04298 .02809 L
.04487 .02809 L
.04669 .02809 L
.04863 .02809 L
.05049 .02809 L
.05248 .02809 L
.05439 .02809 L
.05622 .02809 L
.05818 .02809 L
.06006 .02809 L
.06206 .02809 L
.06399 .02809 L
.06584 .02809 L
.06781 .02809 L
.06971 .02809 L
.07154 .02809 L
.07348 .02809 L
.07535 .02809 L
.07734 .02809 L
.07926 .02809 L
.0811 .02809 L
.08306 .02809 L
.08495 .02809 L
.08677 .02809 L
.0887 .02809 L
.09056 .02809 L
.09254 .02809 L
.09445 .02809 L
.09628 .02809 L
.09823 .02809 L
.10011 .02809 L
.10211 .02809 L
.10403 .02809 L
.10588 .02809 L
.10785 .02809 L
.10974 .02809 L
.11156 .02809 L
.1135 .02809 L
.11537 .02809 L
.11736 .02809 L
Mistroke
.11927 .02809 L
.12111 .02809 L
.12307 .02809 L
.12495 .02809 L
.12695 .02809 L
.12888 .02809 L
.13074 .02809 L
.13271 .02809 L
.13462 .02809 L
.13644 .02809 L
.13839 .02809 L
.14026 .02809 L
.14226 .02809 L
.14418 .02809 L
.14602 .02809 L
.14799 .02809 L
.14988 .02809 L
.15169 .02809 L
.15363 .02809 L
.15549 .02809 L
.15748 .02809 L
.15938 .02809 L
.16122 .02809 L
.16317 .02809 L
.16505 .02809 L
.16705 .02809 L
.16898 .02809 L
.17083 .02809 L
.1728 .02809 L
.1747 .02809 L
.17652 .02809 L
.17846 .02809 L
.18033 .02809 L
.18232 .02809 L
.18424 .02809 L
.18608 .02809 L
.18804 .02809 L
.18993 .02809 L
.19174 .02809 L
.19367 .02809 L
.19553 .02809 L
.19751 .02809 L
.19941 .02809 L
.20124 .02809 L
.20319 .02809 L
.20507 .02809 L
.20706 .02809 L
.20899 .02809 L
.21083 .02809 L
.2128 .02809 L
Mistroke
.21469 .02809 L
.21651 .02809 L
.21845 .02809 L
.22032 .02809 L
.2223 .02809 L
.22421 .02809 L
.22605 .02809 L
.22801 .02809 L
.22989 .02809 L
.23189 .02809 L
.23382 .02809 L
.23567 .02809 L
.23765 .02809 L
.23955 .02809 L
.24137 .02809 L
.24332 .02809 L
.24519 .02809 L
.24718 .02809 L
.2491 .02809 L
.25094 .02809 L
.25291 .02809 L
.2548 .02809 L
.25661 .02809 L
.25855 .02809 L
.26041 .02809 L
.26239 .02809 L
.2643 .02809 L
.26613 .02809 L
.26808 .02809 L
.26996 .02809 L
.27196 .02809 L
.27388 .02809 L
.27573 .02809 L
.2777 .02809 L
.2796 .02809 L
.28142 .02809 L
.28336 .02809 L
.28523 .02809 L
.28722 .02809 L
.28913 .02809 L
.29097 .02809 L
.29293 .02809 L
.29481 .02809 L
.29682 .02809 L
.29875 .02809 L
.3006 .02809 L
.30258 .02809 L
.30448 .02809 L
.30631 .02809 L
.30826 .02809 L
Mistroke
.31014 .02809 L
.31213 .02809 L
.31405 .02809 L
.31589 .02809 L
.31786 .02809 L
.31975 .02809 L
.32157 .02809 L
.32351 .02809 L
.32537 .02809 L
.32735 .02809 L
.32926 .02809 L
.3311 .02809 L
.33305 .02809 L
.33494 .02809 L
.33694 .02809 L
.33886 .02809 L
.34072 .02809 L
.34269 .02809 L
.34459 .02809 L
.34641 .02809 L
.34835 .02809 L
.35023 .02809 L
.35221 .02809 L
.35413 .02809 L
.35597 .02809 L
.35793 .02809 L
.35982 .02809 L
.36164 .02809 L
.36357 .02809 L
.36543 .02809 L
.36741 .02809 L
.36931 .02809 L
.37115 .02809 L
.3731 .02809 L
.37497 .02809 L
.37697 .02809 L
.37889 .02809 L
.37977 .02809 L
.38027 .02809 L
.38052 .02809 L
.38074 .02809 L
.38085 .02809 L
.38088 .02809 L
.38092 .02809 L
.38098 .30902 L
.38104 .30902 L
.38109 .30902 L
.3812 .30902 L
.3817 .30902 L
.38271 .30902 L
Mistroke
.38456 .30902 L
.38654 .30902 L
.38844 .30902 L
.39027 .30902 L
.39221 .30902 L
.39409 .30902 L
.39608 .30902 L
.398 .30902 L
.39984 .30902 L
.4018 .30902 L
.4037 .30902 L
.40551 .30902 L
.40745 .30902 L
.40931 .30902 L
.41129 .30902 L
.4132 .30902 L
.41503 .30902 L
.41699 .30902 L
.41887 .30902 L
.42086 .30902 L
.42279 .30902 L
.42464 .30902 L
.42661 .30902 L
.42851 .30902 L
.43033 .30902 L
.43227 .30902 L
.43414 .30902 L
.43613 .30902 L
.43805 .30902 L
.43989 .30902 L
.44185 .30902 L
.44373 .30902 L
.44555 .30902 L
.44748 .30902 L
.44934 .30902 L
.45131 .30902 L
.45322 .30902 L
.45505 .30902 L
.457 .30902 L
.45887 .30902 L
.46086 .30902 L
.46279 .30902 L
.46463 .30902 L
.4666 .30902 L
.46849 .30902 L
.47031 .30902 L
.47225 .30902 L
.47412 .30902 L
.4761 .30902 L
.47801 .30902 L
Mistroke
.47985 .30902 L
.4818 .30902 L
.48368 .30902 L
.48568 .30902 L
.48761 .30902 L
.48947 .30902 L
.49144 .30902 L
.49334 .30902 L
.49517 .30902 L
.49711 .30902 L
.49898 .30902 L
.50097 .30902 L
.50289 .30902 L
.50473 .30902 L
.50669 .30902 L
.50858 .30902 L
.5104 .30902 L
.51233 .30902 L
.51419 .30902 L
.51617 .30902 L
.51808 .30902 L
.51991 .30902 L
.52186 .30902 L
.52374 .30902 L
.52574 .30902 L
.52766 .30902 L
.52951 .30902 L
.53148 .30902 L
.53338 .30902 L
.5352 .30902 L
.53714 .30902 L
.53901 .30902 L
.54099 .30902 L
.5429 .30902 L
.54474 .30902 L
.5467 .30902 L
.54859 .30902 L
.55059 .30902 L
.55252 .30902 L
.55438 .30902 L
.55635 .30902 L
.55825 .30902 L
.56008 .30902 L
.56203 .30902 L
.5639 .30902 L
.5659 .30902 L
.56782 .30902 L
.56966 .30902 L
.57163 .30902 L
.57352 .30902 L
Mistroke
.57534 .30902 L
.57727 .30902 L
.57914 .30902 L
.58112 .30902 L
.58303 .30902 L
.58486 .30902 L
.58682 .30902 L
.5887 .30902 L
.5907 .30902 L
.59262 .30902 L
.59447 .30902 L
.59645 .30902 L
.59834 .30902 L
.60017 .30902 L
.60211 .30902 L
.60398 .30902 L
.60597 .30902 L
.60789 .30902 L
.60973 .30902 L
.61169 .30902 L
.61358 .30902 L
.61539 .30902 L
.6164 .30902 L
.61732 .30902 L
.61823 .30902 L
.61868 .30902 L
.61881 .30902 L
.61888 .30902 L
.61894 .30902 L
.619 .30902 L
.61904 .30902 L
.61907 .02809 L
.61912 .02809 L
.61918 .02809 L
.621 .02809 L
.62294 .02809 L
.62481 .02809 L
.62679 .02809 L
.6287 .02809 L
.63054 .02809 L
.6325 .02809 L
.63438 .02809 L
.63638 .02809 L
.63831 .02809 L
.64017 .02809 L
.64214 .02809 L
.64404 .02809 L
.64587 .02809 L
.64781 .02809 L
.64969 .02809 L
Mistroke
.65168 .02809 L
.65359 .02809 L
.65544 .02809 L
.6574 .02809 L
.65929 .02809 L
.66111 .02809 L
.66304 .02809 L
.66491 .02809 L
.66689 .02809 L
.66879 .02809 L
.67063 .02809 L
.67258 .02809 L
.67446 .02809 L
.67646 .02809 L
.67838 .02809 L
.68023 .02809 L
.6822 .02809 L
.6841 .02809 L
.68592 .02809 L
.68786 .02809 L
.68973 .02809 L
.69172 .02809 L
.69363 .02809 L
.69547 .02809 L
.69743 .02809 L
.69932 .02809 L
.70132 .02809 L
.70325 .02809 L
.70511 .02809 L
.70708 .02809 L
.70899 .02809 L
.71082 .02809 L
.71277 .02809 L
.71464 .02809 L
.71663 .02809 L
.71855 .02809 L
.7204 .02809 L
.72237 .02809 L
.72426 .02809 L
.72608 .02809 L
.72802 .02809 L
.72988 .02809 L
.73186 .02809 L
.73377 .02809 L
.73561 .02809 L
.73756 .02809 L
.73945 .02809 L
.74145 .02809 L
.74337 .02809 L
.74523 .02809 L
Mistroke
.7472 .02809 L
.7491 .02809 L
.75092 .02809 L
.75287 .02809 L
.75474 .02809 L
.75673 .02809 L
.75864 .02809 L
.76049 .02809 L
.76245 .02809 L
.76434 .02809 L
.76615 .02809 L
.76809 .02809 L
.76995 .02809 L
.77192 .02809 L
.77383 .02809 L
.77566 .02809 L
.77761 .02809 L
.77949 .02809 L
.78149 .02809 L
.78341 .02809 L
.78526 .02809 L
.78723 .02809 L
.78912 .02809 L
.79094 .02809 L
.79288 .02809 L
.79475 .02809 L
.79674 .02809 L
.79865 .02809 L
.80049 .02809 L
.80245 .02809 L
.80433 .02809 L
.80633 .02809 L
.80826 .02809 L
.81012 .02809 L
.81209 .02809 L
.81399 .02809 L
.81582 .02809 L
.81777 .02809 L
.81964 .02809 L
.82163 .02809 L
.82355 .02809 L
.8254 .02809 L
.82736 .02809 L
.82925 .02809 L
.83107 .02809 L
.83301 .02809 L
.83487 .02809 L
.83685 .02809 L
.83876 .02809 L
.84059 .02809 L
Mistroke
.84255 .02809 L
.84443 .02809 L
.84643 .02809 L
.84835 .02809 L
.8502 .02809 L
.85217 .02809 L
.85407 .02809 L
.85589 .02809 L
.85784 .02809 L
.85971 .02809 L
.86169 .02809 L
.86361 .02809 L
.86545 .02809 L
.86741 .02809 L
.8693 .02809 L
.87111 .02809 L
.87304 .02809 L
.8749 .02809 L
.87688 .02809 L
.87878 .02809 L
.88061 .02809 L
.88256 .02809 L
.88444 .02809 L
.88643 .02809 L
.88835 .02809 L
.8902 .02809 L
.89217 .02809 L
.89406 .02809 L
.89588 .02809 L
.89782 .02809 L
.89969 .02809 L
.90167 .02809 L
.90358 .02809 L
.90542 .02809 L
.90737 .02809 L
.90926 .02809 L
.91126 .02809 L
.91319 .02809 L
.91504 .02809 L
.91701 .02809 L
.91891 .02809 L
.92074 .02809 L
.92268 .02809 L
.92456 .02809 L
.92655 .02809 L
.92846 .02809 L
.93031 .02809 L
.93227 .02809 L
.93416 .02809 L
.93598 .02809 L
Mistroke
.93791 .02809 L
.93977 .02809 L
.94175 .02809 L
.94366 .02809 L
.94549 .02809 L
.94744 .02809 L
.94932 .02809 L
.95132 .02809 L
.95324 .02809 L
.95509 .02809 L
.95706 .02809 L
.95896 .02809 L
.96078 .02809 L
.96272 .02809 L
.96459 .02809 L
.96658 .02809 L
.96849 .02809 L
.97033 .02809 L
.97229 .02809 L
.97417 .02809 L
.97618 .02809 L
.97619 .02809 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.330739 0.97619 0.611027 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.11976 0.483559 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02305 -24 -4.5 ]
[-0.0125 .02305 0 4.5 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .21647 -18 -4.5 ]
[-0.0125 .21647 0 4.5 ]
[-0.0125 .31318 -18 -4.5 ]
[-0.0125 .31318 0 4.5 ]
[-0.0125 .4099 -18 -4.5 ]
[-0.0125 .4099 0 4.5 ]
[-0.0125 .50661 -18 -4.5 ]
[-0.0125 .50661 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02305 m
.00625 .02305 L
s
[(-0.2)] -0.0125 .02305 1 0 Mshowa
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .21647 m
.00625 .21647 L
s
[(0.2)] -0.0125 .21647 1 0 Mshowa
0 .31318 m
.00625 .31318 L
s
[(0.4)] -0.0125 .31318 1 0 Mshowa
0 .4099 m
.00625 .4099 L
s
[(0.6)] -0.0125 .4099 1 0 Mshowa
0 .50661 m
.00625 .50661 L
s
[(0.8)] -0.0125 .50661 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04723 m
.00375 .04723 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16812 m
.00375 .16812 L
s
0 .19229 m
.00375 .19229 L
s
0 .24065 m
.00375 .24065 L
s
0 .26483 m
.00375 .26483 L
s
0 .28901 m
.00375 .28901 L
s
0 .33736 m
.00375 .33736 L
s
0 .36154 m
.00375 .36154 L
s
0 .38572 m
.00375 .38572 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .48243 m
.00375 .48243 L
s
0 .53079 m
.00375 .53079 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02305 m
1 .02305 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .21647 m
1 .21647 L
s
.99375 .31318 m
1 .31318 L
s
.99375 .4099 m
1 .4099 L
s
.99375 .50661 m
1 .50661 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .04723 m
1 .04723 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16812 m
1 .16812 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .24065 m
1 .24065 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .28901 m
1 .28901 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .36154 m
1 .36154 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .48243 m
1 .48243 L
s
.99625 .53079 m
1 .53079 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
1 0 0 r
.5 Mabswid
.02381 .11976 m
.02567 .11787 L
.02769 .11583 L
.0296 .11395 L
.03143 .11223 L
.03338 .11049 L
.03525 .10895 L
.03724 .10749 L
.03917 .10627 L
.04101 .10528 L
.04195 .10487 L
.04298 .10447 L
.04397 .10415 L
.04487 .10392 L
.0458 .10374 L
.04632 .10366 L
.04658 .10363 L
.04681 .10361 L
.04703 .10359 L
.04727 .10357 L
.0474 .10357 L
.04752 .10356 L
.04765 .10356 L
.04776 .10355 L
.04786 .10355 L
.04792 .10355 L
.04797 .10355 L
.04802 .10355 L
.04808 .10355 L
.04814 .10355 L
.04819 .10355 L
.04825 .10355 L
.0483 .10355 L
.04835 .10355 L
.04841 .10355 L
.04853 .10355 L
.04865 .10356 L
.04887 .10357 L
.04912 .10358 L
.04956 .10362 L
.05008 .10368 L
.05055 .10376 L
.05147 .10394 L
.05247 .10422 L
.05444 .10495 L
.05634 .1059 L
.05816 .10702 L
.0601 .10843 L
.06197 .10998 L
.06395 .1118 L
Mistroke
.06587 .1137 L
.0677 .11564 L
.06966 .11778 L
.07155 .11989 L
.07355 .12216 L
.07548 .12432 L
.07734 .12635 L
.07931 .12842 L
.08121 .13029 L
.08304 .13195 L
.08499 .13353 L
.08686 .13486 L
.08885 .13603 L
.08985 .13651 L
.09077 .1369 L
.09172 .13723 L
.09262 .13748 L
.09352 .13768 L
.09399 .13775 L
.09426 .13779 L
.09451 .13782 L
.09475 .13784 L
.09497 .13785 L
.09521 .13787 L
.09535 .13787 L
.09541 .13788 L
.09547 .13788 L
.09553 .13788 L
.0956 .13788 L
.09563 .13788 L
.09567 .13788 L
.09573 .13788 L
.09579 .13788 L
.09585 .13788 L
.09591 .13788 L
.09596 .13788 L
.09602 .13788 L
.09608 .13788 L
.09622 .13787 L
.09635 .13787 L
.09649 .13786 L
.09673 .13785 L
.09695 .13783 L
.09745 .13777 L
.09794 .1377 L
.09847 .1376 L
.09949 .13734 L
.10046 .13703 L
.10231 .13622 L
.10428 .13509 L
Mistroke
.10617 .13374 L
.10799 .13222 L
.10993 .13039 L
.11179 .12845 L
.11378 .12623 L
.11569 .12395 L
.11753 .12168 L
.11948 .11921 L
.12137 .11681 L
.12337 .11429 L
.1253 .11192 L
.12715 .10975 L
.12912 .10757 L
.13102 .10565 L
.13285 .10399 L
.1348 .10246 L
.13667 .10125 L
.13762 .10073 L
.13866 .10025 L
.13957 .0999 L
.14058 .0996 L
.14103 .09949 L
.14153 .09939 L
.14205 .09931 L
.1423 .09928 L
.14254 .09926 L
.14276 .09924 L
.14288 .09924 L
.143 .09923 L
.14307 .09923 L
.14313 .09922 L
.1432 .09922 L
.14326 .09922 L
.14332 .09922 L
.14338 .09922 L
.14344 .09922 L
.14347 .09922 L
.1435 .09922 L
.14357 .09922 L
.1436 .09922 L
.14363 .09922 L
.14369 .09922 L
.14375 .09922 L
.14382 .09922 L
.14388 .09923 L
.14402 .09923 L
.14414 .09924 L
.14426 .09924 L
.14452 .09927 L
.14501 .09932 L
Mistroke
.14546 .09939 L
.14647 .09961 L
.14739 .09989 L
.14839 .10029 L
.15035 .10131 L
.15224 .1026 L
.15406 .1041 L
.156 .10597 L
.15786 .10801 L
.15984 .11039 L
.16175 .11286 L
.16359 .11537 L
.16554 .11814 L
.16743 .12086 L
.16943 .12377 L
.17135 .12654 L
.17321 .12914 L
.17518 .13177 L
.17708 .13415 L
.1789 .13625 L
.18085 .13824 L
.18272 .1399 L
.1847 .14134 L
.1857 .14193 L
.18662 .1424 L
.18757 .14279 L
.18846 .14308 L
.18936 .14329 L
.18984 .14337 L
.19011 .14341 L
.19035 .14343 L
.19058 .14345 L
.19071 .14346 L
.19082 .14346 L
.19093 .14346 L
.19099 .14347 L
.19105 .14347 L
.1911 .14347 L
.19115 .14347 L
.19121 .14347 L
.19126 .14347 L
.19132 .14347 L
.19136 .14347 L
.19139 .14347 L
.19145 .14347 L
.19151 .14346 L
.19163 .14346 L
.19174 .14345 L
.19201 .14344 L
.19226 .14341 L
Mistroke
.19273 .14335 L
.19322 .14326 L
.19411 .14304 L
.19506 .14271 L
.19594 .14232 L
.19781 .14123 L
.19981 .1397 L
.20172 .13787 L
.20357 .13582 L
.20553 .13335 L
.20742 .13072 L
.20924 .128 L
.21118 .12493 L
.21304 .12186 L
.21502 .11852 L
.21693 .11527 L
.21876 .11218 L
.22071 .10896 L
.22259 .10599 L
.22459 .10303 L
.22652 .10041 L
.22837 .09814 L
.23034 .09606 L
.23224 .09441 L
.23406 .09317 L
.235 .09268 L
.236 .09226 L
.23649 .0921 L
.23702 .09196 L
.23752 .09186 L
.23775 .09182 L
.23799 .09179 L
.23823 .09176 L
.23834 .09175 L
.23845 .09174 L
.23855 .09174 L
.23866 .09173 L
.23872 .09173 L
.23878 .09173 L
.23883 .09173 L
.23889 .09173 L
.23894 .09173 L
.23901 .09173 L
.23904 .09173 L
.23907 .09173 L
.23913 .09173 L
.23919 .09173 L
.23925 .09173 L
.23936 .09174 L
.23949 .09174 L
Mistroke
.23961 .09175 L
.23988 .09178 L
.24012 .09181 L
.24038 .09185 L
.24086 .09195 L
.24176 .0922 L
.24272 .09259 L
.24373 .09311 L
.24556 .09437 L
.2475 .09614 L
.24937 .09824 L
.25136 .10087 L
.25328 .10375 L
.25512 .10681 L
.25709 .11033 L
.25897 .11392 L
.26079 .11751 L
.26272 .12143 L
.26459 .12524 L
.26656 .12926 L
.26847 .13305 L
.2703 .13655 L
.27226 .14007 L
.27413 .14319 L
.27613 .14617 L
.27805 .14866 L
.2799 .15064 L
.28084 .15149 L
.28187 .15229 L
.28286 .15292 L
.28377 .15338 L
.2847 .15373 L
.28522 .15387 L
.28548 .15392 L
.28571 .15396 L
.28593 .154 L
.28617 .15402 L
.2863 .15403 L
.28642 .15404 L
.28654 .15405 L
.2866 .15405 L
.28663 .15405 L
.28666 .15405 L
.28672 .15405 L
.28678 .15405 L
.28683 .15405 L
.28688 .15405 L
.28694 .15405 L
.287 .15405 L
.28706 .15405 L
Mistroke
.28712 .15404 L
.28723 .15404 L
.28733 .15403 L
.28755 .15401 L
.28778 .15398 L
.28802 .15394 L
.28846 .15384 L
.28898 .15369 L
.28946 .15352 L
.29038 .15308 L
.29138 .15247 L
.29335 .15082 L
.29525 .1487 L
.29708 .1462 L
.29902 .14306 L
.30089 .13961 L
.30288 .13555 L
.30479 .13129 L
.30664 .12694 L
.3086 .1221 L
.31048 .11731 L
.3123 .11265 L
.31423 .10771 L
.31609 .10303 L
.31807 .09824 L
.31997 .09387 L
.3218 .08997 L
.32375 .08621 L
.32563 .08304 L
.32762 .08022 L
.32955 .0781 L
.33043 .07733 L
.3314 .07664 L
.33235 .07613 L
.33287 .07592 L
.33336 .07578 L
.3336 .07572 L
.33386 .07567 L
.33398 .07565 L
.33411 .07564 L
.33423 .07562 L
.33434 .07561 L
.33445 .07561 L
.33451 .0756 L
.33454 .0756 L
.33458 .0756 L
.33463 .0756 L
.33469 .0756 L
.33475 .0756 L
.3348 .0756 L
Mistroke
.33486 .0756 L
.33491 .0756 L
.33496 .0756 L
.33502 .07561 L
.33512 .07561 L
.33523 .07562 L
.33546 .07565 L
.33571 .07569 L
.33616 .0758 L
.33664 .07596 L
.33716 .07618 L
.33811 .07671 L
.33912 .07748 L
.34111 .07957 L
.34304 .08231 L
.34489 .08558 L
.34686 .08972 L
.34875 .09429 L
.35058 .09917 L
.35252 .10483 L
.35439 .11066 L
.35637 .11717 L
.35829 .12366 L
.36013 .13002 L
.36209 .13679 L
.36397 .14323 L
.36598 .14986 L
.36791 .15594 L
.36977 .1614 L
.37174 .16668 L
.37364 .17116 L
.37547 .17482 L
.37742 .17794 L
.37832 .17909 L
.3793 .18012 L
.37983 .18059 L
.38032 .18095 L
.38082 .18126 L
.38129 .18149 L
.38173 .18165 L
.38197 .18172 L
.38219 .18177 L
.38231 .18179 L
.38243 .18181 L
.38251 .18182 L
.38257 .18182 L
.38264 .18183 L
.3827 .18183 L
.38276 .18183 L
.38282 .18184 L
Mistroke
.38288 .18184 L
.38292 .18184 L
.38295 .18184 L
.38301 .18184 L
.38306 .18183 L
.38312 .18183 L
.38318 .18183 L
.3833 .18182 L
.3834 .1818 L
.38365 .18176 L
.38389 .18171 L
.38414 .18163 L
.3846 .18144 L
.38503 .18122 L
.38594 .18058 L
.38693 .17961 L
.38788 .17843 L
.38888 .1769 L
.39088 .17303 L
.3928 .16829 L
.39465 .1628 L
.39662 .15604 L
.39851 .14869 L
.40034 .14093 L
.40228 .13201 L
.40414 .12288 L
.40613 .11273 L
.40804 .10266 L
.40988 .09282 L
.41184 .08235 L
.41372 .07242 L
.41572 .06221 L
.41765 .05286 L
.41951 .0445 L
.42148 .03643 L
.42338 .02964 L
.42521 .02415 L
.42623 .02158 L
.42716 .01957 L
.42813 .01781 L
.42903 .01653 L
.42995 .01556 L
.43044 .01519 L
.43071 .01503 L
.43095 .01491 L
.43117 .01483 L
.4314 .01477 L
.43152 .01475 L
.43164 .01473 L
.4317 .01472 L
Mistroke
.43176 .01472 L
.43179 .01472 L
.43183 .01472 L
.43186 .01472 L
.43189 .01472 L
.43194 .01472 L
.432 .01472 L
.43205 .01472 L
.43209 .01472 L
.43215 .01473 L
.43221 .01474 L
.43232 .01476 L
.43243 .01478 L
.43255 .01482 L
.43277 .01489 L
.433 .015 L
.43322 .01512 L
.43371 .01548 L
.43413 .01589 L
.43458 .01641 L
.43553 .01785 L
.43642 .01958 L
.43829 .02458 L
.44029 .03188 L
.44221 .04088 L
.44405 .05136 L
.44602 .06444 L
.44791 .07889 L
.44973 .09443 L
.45167 .11268 L
.45354 .1318 L
.45552 .15367 L
.45743 .17609 L
.45927 .19877 L
.46123 .22392 L
.46311 .24893 L
.46511 .27616 L
.46704 .3028 L
.46889 .32859 L
.47087 .35597 L
.47276 .38204 L
.47459 .40663 L
.47654 .43207 L
.47841 .45561 L
.4804 .47938 L
.48232 .50085 L
.48416 .51999 L
.48612 .53854 L
.48801 .55446 L
.48983 .56784 L
Mistroke
.49176 .57987 L
.49362 .58919 L
.49457 .59304 L
.4956 .59657 L
.4966 .59928 L
.49751 .60115 L
.498 .60191 L
.49845 .60248 L
.49894 .60292 L
.49921 .6031 L
.49934 .60317 L
.49946 .60322 L
.49957 .60325 L
.49969 .60328 L
.49975 .6033 L
.49981 .60331 L
.49987 .60331 L
.49993 .60332 L
.49999 .60332 L
.50005 .60332 L
.5001 .60332 L
.50016 .60331 L
.50021 .6033 L
.50026 .6033 L
.50036 .60327 L
.50049 .60323 L
.50061 .60319 L
.50088 .60305 L
.50112 .60288 L
.50136 .60267 L
.50182 .60215 L
.50232 .60144 L
.5032 .59973 L
.50414 .59732 L
.50502 .59452 L
.50689 .58685 L
.50887 .57619 L
.51078 .56359 L
.51261 .5494 L
.51457 .53224 L
.51645 .51384 L
.51845 .49247 L
.52037 .4703 L
.52223 .44771 L
.5242 .42254 L
.5261 .39742 L
.52792 .37264 L
.52987 .34584 L
.53174 .31983 L
.53373 .29222 L
Mistroke
.53564 .26587 L
.53748 .24098 L
.53944 .21518 L
.54133 .19122 L
.54315 .16915 L
.54508 .14687 L
.54694 .12675 L
.54892 .10694 L
.55082 .08951 L
.55265 .07436 L
.5546 .06006 L
.55648 .04813 L
.55848 .03746 L
.5604 .02914 L
.56225 .02296 L
.56318 .0205 L
.56422 .0183 L
.56519 .01671 L
.56611 .01565 L
.56661 .01524 L
.56686 .01508 L
.56709 .01496 L
.56731 .01486 L
.56751 .0148 L
.56763 .01477 L
.56774 .01475 L
.56785 .01473 L
.56792 .01472 L
.56798 .01472 L
.56804 .01472 L
.56809 .01472 L
.56815 .01472 L
.5682 .01472 L
.56826 .01472 L
.56829 .01472 L
.56833 .01473 L
.56845 .01474 L
.56855 .01476 L
.56867 .01479 L
.56888 .01485 L
.56914 .01495 L
.5694 .01509 L
.56988 .01542 L
.57034 .01582 L
.57083 .01636 L
.57171 .01757 L
.57371 .02144 L
.57563 .02656 L
.57749 .03262 L
.57946 .04015 L
Mistroke
.58135 .04829 L
.58318 .05681 L
.58512 .06645 L
.58699 .07613 L
.58897 .08668 L
.59089 .09693 L
.59273 .10674 L
.59469 .11695 L
.59657 .12644 L
.59839 .13513 L
.60032 .1438 L
.60218 .15147 L
.60415 .15881 L
.60606 .16501 L
.60789 .1701 L
.60984 .17454 L
.61171 .17784 L
.61274 .17922 L
.61371 .18026 L
.61417 .18067 L
.61467 .18103 L
.61513 .18131 L
.61555 .18151 L
.61601 .18168 L
.61626 .18174 L
.61637 .18177 L
.61649 .18179 L
.61661 .1818 L
.61671 .18182 L
.61676 .18182 L
.61682 .18183 L
.61687 .18183 L
.61691 .18183 L
.61697 .18183 L
.61703 .18184 L
.61709 .18184 L
.61715 .18184 L
.61721 .18184 L
.61727 .18183 L
.61732 .18183 L
.61737 .18183 L
.61749 .18182 L
.61761 .1818 L
.61782 .18177 L
.61809 .18171 L
.61832 .18163 L
.61882 .18144 L
.61933 .18117 L
.62028 .18049 L
.62117 .17966 L
Mistroke
.62305 .17727 L
.62504 .17385 L
.62696 .16979 L
.62881 .16525 L
.63078 .15983 L
.63268 .15413 L
.6345 .1483 L
.63644 .14183 L
.63831 .13543 L
.64029 .12855 L
.64221 .12197 L
.64405 .11577 L
.646 .10941 L
.64789 .10361 L
.64989 .09788 L
.65182 .09285 L
.65368 .08853 L
.65565 .08457 L
.65755 .0814 L
.65938 .07898 L
.6604 .07791 L
.66133 .07712 L
.66229 .07646 L
.6632 .07602 L
.66367 .07585 L
.66392 .07578 L
.66416 .07572 L
.66438 .07568 L
.66458 .07565 L
.66481 .07562 L
.66493 .07561 L
.66499 .07561 L
.66505 .0756 L
.66511 .0756 L
.66514 .0756 L
.66517 .0756 L
.66523 .0756 L
.66529 .0756 L
.66535 .0756 L
.6654 .0756 L
.66546 .0756 L
.66551 .0756 L
.66563 .07561 L
.6657 .07562 L
.66576 .07562 L
.666 .07565 L
.6662 .07568 L
.66643 .07573 L
.66689 .07584 L
.66737 .07601 L
Mistroke
.66781 .07621 L
.66882 .07678 L
.66973 .07745 L
.67072 .07835 L
.67267 .0806 L
.67455 .08332 L
.67654 .08675 L
.67846 .09051 L
.68031 .0945 L
.68228 .09906 L
.68417 .10368 L
.68599 .10828 L
.68793 .11325 L
.6898 .11803 L
.69178 .12305 L
.69369 .12773 L
.69553 .13203 L
.69749 .13632 L
.69937 .14012 L
.70137 .14373 L
.7033 .14675 L
.70515 .1492 L
.70713 .15127 L
.70811 .1521 L
.70903 .15274 L
.70997 .15326 L
.71086 .15364 L
.71132 .15378 L
.71157 .15385 L
.71184 .15391 L
.71206 .15395 L
.7123 .15399 L
.71252 .15402 L
.71273 .15403 L
.71285 .15404 L
.71295 .15405 L
.71302 .15405 L
.71307 .15405 L
.71311 .15405 L
.71314 .15405 L
.7132 .15405 L
.71326 .15405 L
.7133 .15405 L
.71333 .15405 L
.71336 .15405 L
.71339 .15405 L
.71346 .15405 L
.71352 .15404 L
.71358 .15404 L
.7137 .15403 L
Mistroke
.71392 .15401 L
.71416 .15398 L
.71459 .15391 L
.71509 .15379 L
.71562 .15362 L
.71659 .15321 L
.71755 .15267 L
.71857 .15196 L
.7204 .15035 L
.72235 .14817 L
.72422 .14567 L
.72621 .14263 L
.72813 .13939 L
.72998 .13602 L
.73195 .13223 L
.73384 .12845 L
.73566 .12474 L
.7376 .12078 L
.73946 .11701 L
.74144 .11311 L
.74335 .10952 L
.74519 .10628 L
.74714 .10309 L
.74902 .10033 L
.75102 .09777 L
.75295 .0957 L
.7548 .09409 L
.75574 .09344 L
.75678 .09283 L
.75776 .09238 L
.75867 .09207 L
.75918 .09194 L
.75965 .09184 L
.76008 .09178 L
.76032 .09176 L
.76044 .09175 L
.76055 .09174 L
.76065 .09174 L
.76077 .09173 L
.76083 .09173 L
.76088 .09173 L
.76094 .09173 L
.76098 .09173 L
.76101 .09173 L
.76106 .09173 L
.76112 .09173 L
.76117 .09173 L
.76123 .09173 L
.76128 .09173 L
.76133 .09173 L
Mistroke
.76144 .09174 L
.76157 .09175 L
.76169 .09175 L
.76192 .09178 L
.76217 .09181 L
.76243 .09185 L
.76293 .09195 L
.76338 .09206 L
.76439 .09241 L
.76532 .09283 L
.76632 .0934 L
.76829 .09483 L
.77019 .09659 L
.77202 .0986 L
.77397 .10104 L
.77584 .10365 L
.77783 .10665 L
.77975 .10972 L
.7816 .11278 L
.78356 .1161 L
.78545 .11932 L
.78727 .12237 L
.78921 .12555 L
.79107 .12847 L
.79305 .1314 L
.79496 .13399 L
.79679 .13624 L
.79874 .13835 L
.80062 .14006 L
.80262 .14151 L
.80362 .1421 L
.80455 .14254 L
.80551 .14291 L
.8064 .14318 L
.80684 .14327 L
.8073 .14336 L
.80757 .14339 L
.80782 .14342 L
.80805 .14344 L
.80817 .14345 L
.8083 .14346 L
.80842 .14346 L
.80847 .14346 L
.80853 .14347 L
.80858 .14347 L
.80864 .14347 L
.80869 .14347 L
.80875 .14347 L
.80878 .14347 L
.80881 .14347 L
Mistroke
.80885 .14347 L
.80888 .14347 L
.80894 .14347 L
.80898 .14347 L
.80901 .14347 L
.80912 .14346 L
.80925 .14346 L
.80938 .14345 L
.80952 .14344 L
.80977 .14342 L
.81002 .14339 L
.81026 .14336 L
.81077 .14327 L
.81124 .14316 L
.81214 .14289 L
.81311 .14252 L
.81399 .1421 L
.81589 .14094 L
.81772 .13954 L
.81966 .13775 L
.82154 .13576 L
.82353 .13342 L
.82544 .13096 L
.82729 .12846 L
.82925 .12569 L
.83114 .12295 L
.83295 .12031 L
.83489 .11752 L
.83675 .1149 L
.83873 .11222 L
.84064 .10979 L
.84247 .10763 L
.84442 .10555 L
.8463 .10378 L
.8483 .1022 L
.85022 .10098 L
.85207 .1001 L
.85303 .09976 L
.85351 .09962 L
.85404 .09949 L
.85453 .09939 L
.85498 .09932 L
.8552 .09929 L
.85543 .09927 L
.85564 .09925 L
.85586 .09924 L
.85599 .09923 L
.85612 .09923 L
.85623 .09922 L
.85629 .09922 L
Mistroke
.85633 .09922 L
.85636 .09922 L
.85642 .09922 L
.85647 .09922 L
.85653 .09922 L
.85659 .09922 L
.85665 .09922 L
.8567 .09922 L
.85675 .09922 L
.85681 .09922 L
.85694 .09923 L
.85706 .09923 L
.85733 .09925 L
.85758 .09927 L
.85782 .0993 L
.85828 .09936 L
.85877 .09945 L
.85965 .09966 L
.86068 .09999 L
.86165 .10038 L
.86351 .10135 L
.86548 .10266 L
.86738 .10419 L
.8692 .10586 L
.87114 .10785 L
.87301 .10993 L
.875 .11228 L
.87692 .11465 L
.87876 .11697 L
.88072 .11947 L
.88261 .12185 L
.88442 .12409 L
.88636 .12638 L
.88822 .12846 L
.89019 .13052 L
.8921 .1323 L
.89393 .13381 L
.89588 .13519 L
.89776 .13625 L
.89871 .1367 L
.89975 .1371 L
.90067 .13739 L
.90119 .13752 L
.90167 .13763 L
.90217 .13772 L
.90263 .13778 L
.90312 .13784 L
.90338 .13786 L
.90352 .13786 L
.90364 .13787 L
Mistroke
.90376 .13787 L
.90382 .13788 L
.90388 .13788 L
.90394 .13788 L
.904 .13788 L
.90405 .13788 L
.9041 .13788 L
.90413 .13788 L
.90417 .13788 L
.90423 .13788 L
.90428 .13788 L
.90434 .13788 L
.9044 .13788 L
.90446 .13788 L
.90459 .13788 L
.90471 .13787 L
.90481 .13787 L
.90505 .13785 L
.90526 .13784 L
.90548 .13782 L
.90594 .13776 L
.90643 .13769 L
.90731 .1375 L
.90834 .13721 L
.90931 .13687 L
.91116 .13602 L
.91313 .13487 L
.91503 .13352 L
.91685 .13204 L
.91879 .13028 L
.92066 .12845 L
.92265 .12637 L
.92456 .12427 L
.9264 .12221 L
.92836 .12 L
.93025 .11788 L
.93225 .11568 L
.93418 .11365 L
.93604 .11181 L
.93802 .10999 L
.93992 .10842 L
.94175 .10708 L
.9437 .10588 L
.94557 .10494 L
.94653 .10455 L
.94757 .1042 L
.94857 .10394 L
.94904 .10383 L
.94949 .10375 L
.94996 .10368 L
Mistroke
.95039 .10363 L
.95062 .1036 L
.95087 .10358 L
.95113 .10357 L
.95126 .10356 L
.95138 .10356 L
.9515 .10355 L
.95157 .10355 L
.95164 .10355 L
.9517 .10355 L
.95175 .10355 L
.95181 .10355 L
.95185 .10355 L
.95188 .10355 L
.95193 .10355 L
.95199 .10355 L
.95205 .10355 L
.95211 .10355 L
.95221 .10355 L
.95233 .10356 L
.95246 .10356 L
.95258 .10357 L
.95285 .10358 L
.95308 .1036 L
.95333 .10362 L
.95379 .10368 L
.95428 .10375 L
.95517 .10393 L
.95619 .1042 L
.95716 .10452 L
.95901 .1053 L
.96098 .10635 L
.96288 .10757 L
.9647 .10892 L
.96664 .1105 L
.96851 .11216 L
.97049 .11404 L
.9724 .11592 L
.97424 .11778 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.639056 0.477324 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0280925 0.280925 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .02809 -6 -4.5 ]
[-0.0125 .02809 0 4.5 ]
[-0.0125 .16855 -18 -4.5 ]
[-0.0125 .16855 0 4.5 ]
[-0.0125 .30902 -6 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .44948 -18 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .58994 -6 -4.5 ]
[-0.0125 .58994 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .02809 m
.00625 .02809 L
s
[(0)] -0.0125 .02809 1 0 Mshowa
0 .16855 m
.00625 .16855 L
s
[(0.5)] -0.0125 .16855 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(1)] -0.0125 .30902 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(1.5)] -0.0125 .44948 1 0 Mshowa
0 .58994 m
.00625 .58994 L
s
[(2)] -0.0125 .58994 1 0 Mshowa
.125 Mabswid
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .11237 m
.00375 .11237 L
s
0 .14046 m
.00375 .14046 L
s
0 .19665 m
.00375 .19665 L
s
0 .22474 m
.00375 .22474 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .33711 m
.00375 .33711 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .56185 m
.00375 .56185 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .02809 m
1 .02809 L
s
.99375 .16855 m
1 .16855 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .58994 m
1 .58994 L
s
.125 Mabswid
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .11237 m
1 .11237 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .22474 m
1 .22474 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .33711 m
1 .33711 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .56185 m
1 .56185 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .02809 m
.02567 .02809 L
.02769 .02809 L
.0296 .02809 L
.03143 .02809 L
.03338 .02809 L
.03525 .02809 L
.03724 .02809 L
.03917 .02809 L
.04101 .02809 L
.04298 .02809 L
.04487 .02809 L
.04669 .02809 L
.04863 .02809 L
.05049 .02809 L
.05248 .02809 L
.05439 .02809 L
.05622 .02809 L
.05818 .02809 L
.06006 .02809 L
.06206 .02809 L
.06399 .02809 L
.06584 .02809 L
.06781 .02809 L
.06971 .02809 L
.07154 .02809 L
.07348 .02809 L
.07535 .02809 L
.07734 .02809 L
.07926 .02809 L
.0811 .02809 L
.08306 .02809 L
.08495 .02809 L
.08677 .02809 L
.0887 .02809 L
.09056 .02809 L
.09254 .02809 L
.09445 .02809 L
.09628 .02809 L
.09823 .02809 L
.10011 .02809 L
.10211 .02809 L
.10403 .02809 L
.10588 .02809 L
.10785 .02809 L
.10974 .02809 L
.11156 .02809 L
.1135 .02809 L
.11537 .02809 L
.11736 .02809 L
Mistroke
.11927 .02809 L
.12111 .02809 L
.12307 .02809 L
.12495 .02809 L
.12695 .02809 L
.12888 .02809 L
.13074 .02809 L
.13271 .02809 L
.13462 .02809 L
.13644 .02809 L
.13839 .02809 L
.14026 .02809 L
.14226 .02809 L
.14418 .02809 L
.14602 .02809 L
.14799 .02809 L
.14988 .02809 L
.15169 .02809 L
.15363 .02809 L
.15549 .02809 L
.15748 .02809 L
.15938 .02809 L
.16122 .02809 L
.16317 .02809 L
.16505 .02809 L
.16705 .02809 L
.16898 .02809 L
.17083 .02809 L
.1728 .02809 L
.1747 .02809 L
.17652 .02809 L
.17846 .02809 L
.18033 .02809 L
.18232 .02809 L
.18424 .02809 L
.18608 .02809 L
.18804 .02809 L
.18993 .02809 L
.19174 .02809 L
.19367 .02809 L
.19553 .02809 L
.19751 .02809 L
.19941 .02809 L
.20124 .02809 L
.20319 .02809 L
.20507 .02809 L
.20706 .02809 L
.20899 .02809 L
.21083 .02809 L
.2128 .02809 L
Mistroke
.21469 .02809 L
.21651 .02809 L
.21845 .02809 L
.22032 .02809 L
.2223 .02809 L
.22421 .02809 L
.22605 .02809 L
.22801 .02809 L
.22989 .02809 L
.23189 .02809 L
.23382 .02809 L
.23567 .02809 L
.23765 .02809 L
.23955 .02809 L
.24137 .02809 L
.24332 .02809 L
.24519 .02809 L
.24718 .02809 L
.2491 .02809 L
.25094 .02809 L
.25291 .02809 L
.2548 .02809 L
.25661 .02809 L
.25855 .02809 L
.26041 .02809 L
.26137 .02809 L
.26161 .02809 L
.26174 .02809 L
.2618 .02809 L
.26186 .02809 L
.26189 .02809 L
.26193 .30902 L
.26196 .30902 L
.262 .30902 L
.26213 .30902 L
.26239 .30902 L
.26433 .30902 L
.2662 .30902 L
.26818 .30902 L
.2701 .30902 L
.27194 .30902 L
.2739 .30902 L
.27578 .30902 L
.27779 .30902 L
.27972 .30902 L
.28157 .30902 L
.28355 .30902 L
.28545 .30902 L
.28728 .30902 L
.28923 .30902 L
Mistroke
.2911 .30902 L
.2931 .30902 L
.29502 .30902 L
.29686 .30902 L
.29883 .30902 L
.30072 .30902 L
.30254 .30902 L
.30448 .30902 L
.30634 .30902 L
.30832 .30902 L
.31023 .30902 L
.31207 .30902 L
.31402 .30902 L
.3159 .30902 L
.3179 .30902 L
.31983 .30902 L
.32168 .30902 L
.32366 .30902 L
.32555 .30902 L
.32738 .30902 L
.32932 .30902 L
.33119 .30902 L
.33318 .30902 L
.3351 .30902 L
.33694 .30902 L
.3389 .30902 L
.34079 .30902 L
.34261 .30902 L
.34454 .30902 L
.3464 .30902 L
.34838 .30902 L
.35028 .30902 L
.35211 .30902 L
.35406 .30902 L
.35594 .30902 L
.35794 .30902 L
.35986 .30902 L
.36171 .30902 L
.36368 .30902 L
.36557 .30902 L
.36739 .30902 L
.36933 .30902 L
.3712 .30902 L
.37318 .30902 L
.3751 .30902 L
.37693 .30902 L
.37889 .30902 L
.38077 .30902 L
.38278 .30902 L
.38471 .30902 L
Mistroke
.38656 .30902 L
.38854 .30902 L
.39044 .30902 L
.39226 .30902 L
.39421 .30902 L
.39608 .30902 L
.39808 .30902 L
.39999 .30902 L
.40184 .30902 L
.4038 .30902 L
.40569 .30902 L
.40751 .30902 L
.40945 .30902 L
.41131 .30902 L
.41329 .30902 L
.4152 .30902 L
.41703 .30902 L
.41898 .30902 L
.42086 .30902 L
.42286 .30902 L
.42479 .30902 L
.42664 .30902 L
.42861 .30902 L
.43051 .30902 L
.43233 .30902 L
.43427 .30902 L
.43614 .30902 L
.43813 .30902 L
.44004 .30902 L
.44188 .30902 L
.44384 .30902 L
.44573 .30902 L
.44754 .30902 L
.44948 .30902 L
.45133 .30902 L
.45331 .30902 L
.45521 .30902 L
.45704 .30902 L
.45899 .30902 L
.46087 .30902 L
.46286 .30902 L
.46478 .30902 L
.46663 .30902 L
.4686 .30902 L
.47049 .30902 L
.47231 .30902 L
.47425 .30902 L
.47611 .30902 L
.4781 .30902 L
.48001 .30902 L
Mistroke
.48184 .30902 L
.4838 .30902 L
.48568 .30902 L
.48768 .30902 L
.48961 .30902 L
.49146 .30902 L
.49344 .30902 L
.49534 .30902 L
.49716 .30902 L
.49911 .30902 L
.50098 .30902 L
.50297 .30902 L
.50489 .30902 L
.50673 .30902 L
.50869 .30902 L
.51058 .30902 L
.5124 .30902 L
.51433 .30902 L
.51619 .30902 L
.51817 .30902 L
.52008 .30902 L
.52191 .30902 L
.52386 .30902 L
.52574 .30902 L
.52774 .30902 L
.52966 .30902 L
.53151 .30902 L
.53348 .30902 L
.53537 .30902 L
.5372 .30902 L
.53914 .30902 L
.541 .30902 L
.54299 .30902 L
.5449 .30902 L
.54674 .30902 L
.5487 .30902 L
.55058 .30902 L
.55259 .30902 L
.55452 .30902 L
.55637 .30902 L
.55835 .30902 L
.56025 .30902 L
.56208 .30902 L
.56403 .30902 L
.5659 .30902 L
.56789 .30902 L
.56981 .30902 L
.57166 .30902 L
.57362 .30902 L
.57552 .30902 L
Mistroke
.57733 .30902 L
.57927 .30902 L
.58113 .30902 L
.58312 .30902 L
.58502 .30902 L
.58686 .30902 L
.58881 .30902 L
.5907 .30902 L
.59269 .30902 L
.59462 .30902 L
.59647 .30902 L
.59844 .30902 L
.60034 .30902 L
.60217 .30902 L
.60411 .30902 L
.60598 .30902 L
.60797 .30902 L
.60988 .30902 L
.61173 .30902 L
.61369 .30902 L
.61557 .30902 L
.61739 .30902 L
.61932 .30902 L
.62118 .30902 L
.62316 .30902 L
.62506 .30902 L
.62689 .30902 L
.62884 .30902 L
.63072 .30902 L
.63271 .30902 L
.63464 .30902 L
.63649 .30902 L
.63845 .30902 L
.64035 .30902 L
.64217 .30902 L
.64411 .30902 L
.64597 .30902 L
.64796 .30902 L
.64987 .30902 L
.65171 .30902 L
.65366 .30902 L
.65555 .30902 L
.65755 .30902 L
.65947 .30902 L
.66133 .30902 L
.6633 .30902 L
.6652 .30902 L
.66703 .30902 L
.66898 .30902 L
.67085 .30902 L
Mistroke
.67284 .30902 L
.67476 .30902 L
.6766 .30902 L
.67857 .30902 L
.68046 .30902 L
.68227 .30902 L
.68421 .30902 L
.68607 .30902 L
.68805 .30902 L
.68996 .30902 L
.69179 .30902 L
.69374 .30902 L
.69562 .30902 L
.69762 .30902 L
.69954 .30902 L
.7014 .30902 L
.70336 .30902 L
.70526 .30902 L
.70708 .30902 L
.70903 .30902 L
.7109 .30902 L
.71288 .30902 L
.7148 .30902 L
.71664 .30902 L
.71859 .30902 L
.72048 .30902 L
.72248 .30902 L
.72442 .30902 L
.72627 .30902 L
.72825 .30902 L
.73015 .30902 L
.73198 .30902 L
.73393 .30902 L
.73581 .30902 L
.73676 .30902 L
.73726 .30902 L
.73754 .30902 L
.7378 .30902 L
.73792 .30902 L
.73803 .30902 L
.73809 .30902 L
.73812 .02809 L
.73816 .02809 L
.73827 .02809 L
.7388 .02809 L
.73972 .02809 L
.7416 .02809 L
.7436 .02809 L
.74553 .02809 L
.74738 .02809 L
Mistroke
.74935 .02809 L
.75125 .02809 L
.75308 .02809 L
.75502 .02809 L
.75689 .02809 L
.75888 .02809 L
.7608 .02809 L
.76264 .02809 L
.7646 .02809 L
.76649 .02809 L
.76831 .02809 L
.77024 .02809 L
.7721 .02809 L
.77408 .02809 L
.77598 .02809 L
.77782 .02809 L
.77977 .02809 L
.78165 .02809 L
.78364 .02809 L
.78556 .02809 L
.78741 .02809 L
.78938 .02809 L
.79128 .02809 L
.7931 .02809 L
.79504 .02809 L
.79691 .02809 L
.79889 .02809 L
.8008 .02809 L
.80264 .02809 L
.8046 .02809 L
.80648 .02809 L
.80849 .02809 L
.81042 .02809 L
.81227 .02809 L
.81425 .02809 L
.81615 .02809 L
.81798 .02809 L
.81992 .02809 L
.8218 .02809 L
.82379 .02809 L
.82571 .02809 L
.82755 .02809 L
.82952 .02809 L
.83141 .02809 L
.83322 .02809 L
.83516 .02809 L
.83702 .02809 L
.839 .02809 L
.84091 .02809 L
.84275 .02809 L
Mistroke
.8447 .02809 L
.84658 .02809 L
.84858 .02809 L
.8505 .02809 L
.85236 .02809 L
.85433 .02809 L
.85622 .02809 L
.85805 .02809 L
.85999 .02809 L
.86186 .02809 L
.86385 .02809 L
.86576 .02809 L
.86761 .02809 L
.86956 .02809 L
.87145 .02809 L
.87327 .02809 L
.8752 .02809 L
.87706 .02809 L
.87903 .02809 L
.88094 .02809 L
.88277 .02809 L
.88472 .02809 L
.88659 .02809 L
.88859 .02809 L
.89051 .02809 L
.89236 .02809 L
.89432 .02809 L
.89622 .02809 L
.89804 .02809 L
.89998 .02809 L
.90184 .02809 L
.90382 .02809 L
.90574 .02809 L
.90757 .02809 L
.90953 .02809 L
.91141 .02809 L
.91341 .02809 L
.91534 .02809 L
.91719 .02809 L
.91917 .02809 L
.92107 .02809 L
.92289 .02809 L
.92484 .02809 L
.92671 .02809 L
.9287 .02809 L
.93062 .02809 L
.93246 .02809 L
.93442 .02809 L
.93631 .02809 L
.93813 .02809 L
Mistroke
.94006 .02809 L
.94193 .02809 L
.94391 .02809 L
.94581 .02809 L
.94765 .02809 L
.9496 .02809 L
.95148 .02809 L
.95347 .02809 L
.9554 .02809 L
.95725 .02809 L
.95922 .02809 L
.96111 .02809 L
.96293 .02809 L
.96488 .02809 L
.96674 .02809 L
.96873 .02809 L
.97064 .02809 L
.97248 .02809 L
.97444 .02809 L
.97619 .02809 L
Mfstroke
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.522676 0.639056 0.97619 0.919343 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.047619 0.11976 0.24178 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .11976 -6 -4.5 ]
[-0.0125 .11976 0 4.5 ]
[-0.0125 .24065 -18 -4.5 ]
[-0.0125 .24065 0 4.5 ]
[-0.0125 .36154 -6 -4.5 ]
[-0.0125 .36154 0 4.5 ]
[-0.0125 .48243 -18 -4.5 ]
[-0.0125 .48243 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-10)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-5)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(5)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(10)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .11976 m
.00625 .11976 L
s
[(0)] -0.0125 .11976 1 0 Mshowa
0 .24065 m
.00625 .24065 L
s
[(0.5)] -0.0125 .24065 1 0 Mshowa
0 .36154 m
.00625 .36154 L
s
[(1)] -0.0125 .36154 1 0 Mshowa
0 .48243 m
.00625 .48243 L
s
[(1.5)] -0.0125 .48243 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .02305 m
.00375 .02305 L
s
0 .04723 m
.00375 .04723 L
s
0 .0714 m
.00375 .0714 L
s
0 .09558 m
.00375 .09558 L
s
0 .14394 m
.00375 .14394 L
s
0 .16812 m
.00375 .16812 L
s
0 .19229 m
.00375 .19229 L
s
0 .21647 m
.00375 .21647 L
s
0 .26483 m
.00375 .26483 L
s
0 .28901 m
.00375 .28901 L
s
0 .31318 m
.00375 .31318 L
s
0 .33736 m
.00375 .33736 L
s
0 .38572 m
.00375 .38572 L
s
0 .4099 m
.00375 .4099 L
s
0 .43407 m
.00375 .43407 L
s
0 .45825 m
.00375 .45825 L
s
0 .50661 m
.00375 .50661 L
s
0 .53079 m
.00375 .53079 L
s
0 .55496 m
.00375 .55496 L
s
0 .57914 m
.00375 .57914 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .11976 m
1 .11976 L
s
.99375 .24065 m
1 .24065 L
s
.99375 .36154 m
1 .36154 L
s
.99375 .48243 m
1 .48243 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .02305 m
1 .02305 L
s
.99625 .04723 m
1 .04723 L
s
.99625 .0714 m
1 .0714 L
s
.99625 .09558 m
1 .09558 L
s
.99625 .14394 m
1 .14394 L
s
.99625 .16812 m
1 .16812 L
s
.99625 .19229 m
1 .19229 L
s
.99625 .21647 m
1 .21647 L
s
.99625 .26483 m
1 .26483 L
s
.99625 .28901 m
1 .28901 L
s
.99625 .31318 m
1 .31318 L
s
.99625 .33736 m
1 .33736 L
s
.99625 .38572 m
1 .38572 L
s
.99625 .4099 m
1 .4099 L
s
.99625 .43407 m
1 .43407 L
s
.99625 .45825 m
1 .45825 L
s
.99625 .50661 m
1 .50661 L
s
.99625 .53079 m
1 .53079 L
s
.99625 .55496 m
1 .55496 L
s
.99625 .57914 m
1 .57914 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .11976 m
1 .11976 L
s
.5 0 m
.5 .61803 L
s
0 0 1 r
.5 Mabswid
.02381 .11976 m
.02567 .11788 L
.02769 .11595 L
.0296 .11437 L
.03143 .11316 L
.03237 .11267 L
.03338 .11228 L
.03387 .11213 L
.03413 .11207 L
.0344 .11201 L
.03464 .11196 L
.0349 .11193 L
.03514 .1119 L
.03525 .11189 L
.03537 .11188 L
.03549 .11187 L
.03555 .11187 L
.03561 .11187 L
.03564 .11187 L
.03568 .11187 L
.03571 .11187 L
.03574 .11187 L
.03581 .11187 L
.03584 .11187 L
.03587 .11187 L
.03593 .11187 L
.03599 .11187 L
.03604 .11187 L
.0361 .11187 L
.03623 .11188 L
.03634 .11188 L
.03655 .1119 L
.03678 .11193 L
.03723 .112 L
.03772 .11211 L
.03816 .11224 L
.03917 .11262 L
.04008 .11308 L
.04107 .11369 L
.04302 .11519 L
.0449 .11694 L
.0469 .11899 L
.04882 .12104 L
.05067 .12296 L
.05264 .1248 L
.05453 .12627 L
.05549 .12686 L
.05636 .12731 L
.05729 .12768 L
.05781 .12784 L
Mistroke
.0583 .12795 L
.05854 .12799 L
.05876 .12802 L
.05888 .12804 L
.05902 .12805 L
.05913 .12806 L
.05925 .12807 L
.05931 .12807 L
.05937 .12808 L
.05942 .12808 L
.05948 .12808 L
.05951 .12808 L
.05954 .12808 L
.0596 .12808 L
.05965 .12808 L
.05971 .12808 L
.05976 .12808 L
.05982 .12808 L
.05987 .12808 L
.05991 .12808 L
.06002 .12807 L
.06014 .12806 L
.06038 .12804 L
.0606 .12802 L
.06085 .12798 L
.06109 .12793 L
.06197 .12769 L
.06244 .12752 L
.06294 .12731 L
.06382 .12685 L
.06565 .12559 L
.06759 .12387 L
.06946 .12194 L
.07145 .11974 L
.07336 .11759 L
.07521 .11564 L
.07717 .11381 L
.07814 .11303 L
.07905 .11241 L
.07994 .1119 L
.08087 .11148 L
.08133 .11131 L
.08184 .11117 L
.08206 .11112 L
.0823 .11107 L
.08251 .11103 L
.08273 .11101 L
.08285 .11099 L
.08298 .11098 L
.0831 .11097 L
Mistroke
.08322 .11097 L
.08325 .11097 L
.08329 .11097 L
.08332 .11097 L
.08335 .11096 L
.08339 .11096 L
.08342 .11096 L
.08348 .11096 L
.08351 .11096 L
.08354 .11096 L
.08358 .11096 L
.08362 .11096 L
.08368 .11097 L
.08375 .11097 L
.08388 .11098 L
.08399 .11098 L
.08425 .11101 L
.08449 .11104 L
.08472 .11108 L
.08519 .11119 L
.08568 .11134 L
.08657 .11169 L
.0875 .11219 L
.08838 .11276 L
.09024 .11428 L
.09222 .11628 L
.09413 .11844 L
.09596 .12063 L
.09792 .12291 L
.09979 .12494 L
.10179 .12676 L
.10279 .12751 L
.10372 .12808 L
.10461 .12852 L
.10507 .1287 L
.10557 .12885 L
.10582 .12892 L
.10606 .12897 L
.10629 .12901 L
.10651 .12904 L
.10671 .12906 L
.10683 .12907 L
.10693 .12908 L
.10704 .12909 L
.10711 .12909 L
.10717 .12909 L
.10722 .12909 L
.10728 .12909 L
.10733 .12909 L
.10739 .12909 L
Mistroke
.10745 .12909 L
.10748 .12909 L
.10752 .12909 L
.10763 .12908 L
.1077 .12908 L
.10777 .12907 L
.10789 .12906 L
.10814 .12903 L
.10837 .129 L
.10883 .1289 L
.10926 .12877 L
.11022 .1284 L
.1111 .12793 L
.11298 .12656 L
.11498 .12463 L
.11691 .12243 L
.11876 .12012 L
.12073 .11763 L
.12263 .11534 L
.12446 .11337 L
.1264 .11167 L
.1273 .11105 L
.12827 .11051 L
.1288 .11028 L
.12929 .11011 L
.12976 .10998 L
.13 .10993 L
.13026 .10989 L
.1305 .10986 L
.13062 .10985 L
.13075 .10984 L
.13086 .10983 L
.13092 .10983 L
.13098 .10983 L
.13103 .10983 L
.13109 .10983 L
.13114 .10983 L
.13119 .10983 L
.13125 .10983 L
.13131 .10983 L
.13137 .10983 L
.13142 .10984 L
.13155 .10984 L
.13168 .10986 L
.13192 .10989 L
.13219 .10993 L
.13269 .11004 L
.13314 .11018 L
.13415 .11062 L
.13508 .11117 L
Mistroke
.13608 .11191 L
.13805 .11376 L
.13995 .11596 L
.14178 .11831 L
.14373 .12094 L
.1456 .12342 L
.14759 .12584 L
.14951 .12781 L
.15136 .12923 L
.15231 .12975 L
.15279 .12996 L
.15332 .13014 L
.15356 .13021 L
.15381 .13026 L
.15402 .1303 L
.15425 .13034 L
.15438 .13035 L
.1545 .13036 L
.15456 .13037 L
.15462 .13037 L
.15468 .13037 L
.15473 .13037 L
.15479 .13038 L
.15483 .13038 L
.15486 .13038 L
.1549 .13038 L
.15494 .13038 L
.15497 .13038 L
.155 .13038 L
.15507 .13038 L
.1551 .13038 L
.15513 .13037 L
.1552 .13037 L
.15526 .13037 L
.15537 .13036 L
.15549 .13035 L
.15574 .13032 L
.15595 .13028 L
.15618 .13023 L
.15671 .13009 L
.15719 .12991 L
.15811 .12945 L
.15911 .12879 L
.16107 .12703 L
.16297 .12486 L
.16479 .12244 L
.16673 .11968 L
.16859 .11698 L
.17057 .11428 L
.17248 .11199 L
Mistroke
.17432 .11023 L
.17527 .10953 L
.17628 .10895 L
.17677 .10874 L
.17703 .10865 L
.17731 .10856 L
.17755 .1085 L
.17781 .10844 L
.17805 .1084 L
.17816 .10839 L
.17828 .10838 L
.1784 .10837 L
.17846 .10836 L
.17852 .10836 L
.17855 .10836 L
.17858 .10836 L
.17864 .10836 L
.17867 .10836 L
.17871 .10836 L
.17875 .10836 L
.17878 .10836 L
.17884 .10836 L
.1789 .10836 L
.17895 .10836 L
.17901 .10836 L
.17914 .10837 L
.17926 .10838 L
.17946 .10841 L
.17969 .10844 L
.18015 .10855 L
.18064 .10871 L
.18108 .10889 L
.18209 .10945 L
.183 .11012 L
.184 .11101 L
.18596 .11321 L
.18784 .11576 L
.18985 .11878 L
.19178 .12179 L
.19363 .1246 L
.19561 .1273 L
.19751 .12946 L
.19847 .13033 L
.19934 .13098 L
.20028 .13152 L
.2008 .13174 L
.20103 .13182 L
.20129 .1319 L
.20151 .13196 L
.20175 .13201 L
Mistroke
.20189 .13203 L
.20201 .13204 L
.20213 .13206 L
.20225 .13207 L
.2023 .13207 L
.20235 .13207 L
.20241 .13208 L
.20246 .13208 L
.20252 .13208 L
.20258 .13208 L
.20264 .13208 L
.2027 .13208 L
.20275 .13207 L
.20281 .13207 L
.20291 .13207 L
.20303 .13206 L
.20313 .13204 L
.20336 .13201 L
.20361 .13196 L
.20405 .13184 L
.20452 .13167 L
.20505 .13142 L
.20598 .13085 L
.20698 .13003 L
.20896 .1279 L
.21086 .12529 L
.21269 .12242 L
.21464 .11915 L
.21652 .116 L
.21852 .11286 L
.22044 .11025 L
.22229 .10828 L
.22324 .10751 L
.22373 .10719 L
.22425 .1069 L
.22474 .10669 L
.22519 .10654 L
.22541 .10648 L
.22565 .10644 L
.22575 .10642 L
.22587 .1064 L
.22597 .10639 L
.22607 .10638 L
.22614 .10638 L
.2262 .10638 L
.22623 .10637 L
.22626 .10637 L
.2263 .10637 L
.22633 .10637 L
.22639 .10637 L
Mistroke
.22645 .10637 L
.22651 .10637 L
.22654 .10637 L
.22657 .10637 L
.22664 .10638 L
.2267 .10638 L
.22685 .10639 L
.22697 .10641 L
.22711 .10643 L
.22735 .10647 L
.22757 .10653 L
.22808 .1067 L
.22858 .10692 L
.22906 .10719 L
.22996 .10783 L
.23181 .10968 L
.23378 .11233 L
.23567 .1154 L
.2375 .11866 L
.23944 .12224 L
.24131 .12558 L
.24329 .1288 L
.24521 .13136 L
.24617 .1324 L
.24705 .13316 L
.248 .1338 L
.24852 .13405 L
.24875 .13415 L
.24901 .13424 L
.24923 .1343 L
.24948 .13435 L
.24961 .13438 L
.24973 .13439 L
.24986 .13441 L
.24991 .13441 L
.24997 .13442 L
.25003 .13442 L
.25008 .13442 L
.25014 .13443 L
.2502 .13443 L
.25025 .13443 L
.2503 .13443 L
.25035 .13442 L
.2504 .13442 L
.25046 .13442 L
.25052 .13442 L
.25064 .1344 L
.25076 .13439 L
.25086 .13437 L
.25109 .13433 L
Mistroke
.25133 .13427 L
.25183 .1341 L
.25229 .13389 L
.25272 .13364 L
.2537 .1329 L
.25459 .13204 L
.25651 .1296 L
.25835 .12662 L
.26031 .12295 L
.2622 .11916 L
.26401 .1155 L
.26595 .1118 L
.26781 .10867 L
.26875 .10731 L
.26979 .10603 L
.27078 .10503 L
.27169 .10433 L
.27218 .10405 L
.27263 .10384 L
.27287 .10375 L
.27312 .10367 L
.27325 .10364 L
.27339 .10361 L
.27351 .10359 L
.27364 .10357 L
.2737 .10357 L
.27377 .10356 L
.27383 .10356 L
.27389 .10355 L
.27393 .10355 L
.27396 .10355 L
.27402 .10355 L
.27407 .10355 L
.27413 .10355 L
.27418 .10355 L
.27424 .10355 L
.27429 .10356 L
.27434 .10356 L
.27446 .10357 L
.27458 .10359 L
.27483 .10363 L
.27506 .10369 L
.27531 .10377 L
.27558 .10387 L
.27603 .1041 L
.27652 .1044 L
.2774 .10511 L
.27837 .10612 L
.27938 .10744 L
.28122 .11039 L
Mistroke
.28317 .11419 L
.28505 .11827 L
.28705 .12277 L
.28897 .127 L
.29082 .1307 L
.2928 .13398 L
.29378 .1353 L
.29469 .1363 L
.29557 .13704 L
.29607 .13736 L
.29652 .13758 L
.29675 .13767 L
.29699 .13775 L
.2972 .1378 L
.29732 .13783 L
.29743 .13785 L
.2975 .13786 L
.29756 .13786 L
.29762 .13787 L
.29768 .13787 L
.29775 .13788 L
.29778 .13788 L
.29782 .13788 L
.29788 .13788 L
.29792 .13788 L
.29795 .13788 L
.29801 .13788 L
.29806 .13788 L
.29812 .13787 L
.29818 .13787 L
.29831 .13785 L
.29843 .13784 L
.29866 .13779 L
.29891 .13772 L
.29935 .13755 L
.29987 .13727 L
.30034 .13694 L
.30127 .1361 L
.30227 .13491 L
.30424 .13177 L
.30614 .12792 L
.30797 .12365 L
.30991 .11877 L
.31179 .11403 L
.31378 .10929 L
.31569 .1053 L
.31754 .10226 L
.31849 .10107 L
.31898 .10057 L
.3195 .10011 L
Mistroke
.31999 .09977 L
.32044 .09952 L
.32087 .09936 L
.32108 .0993 L
.3212 .09927 L
.32132 .09925 L
.32144 .09924 L
.3215 .09923 L
.32154 .09923 L
.32157 .09922 L
.32163 .09922 L
.32169 .09922 L
.32172 .09922 L
.32175 .09922 L
.32181 .09922 L
.32187 .09922 L
.32192 .09922 L
.32198 .09923 L
.32203 .09923 L
.32215 .09925 L
.32226 .09927 L
.32251 .09932 L
.32275 .0994 L
.323 .0995 L
.32327 .09963 L
.32373 .09992 L
.32422 .10031 L
.3251 .10122 L
.32612 .1026 L
.32709 .10421 L
.32894 .10802 L
.3309 .11293 L
.33279 .1182 L
.33461 .12348 L
.33655 .12899 L
.33841 .13385 L
.3404 .13819 L
.34139 .13994 L
.3423 .14128 L
.34319 .14229 L
.34369 .14272 L
.34414 .14303 L
.34437 .14316 L
.34462 .14327 L
.34483 .14335 L
.34507 .14341 L
.3452 .14343 L
.34532 .14345 L
.34538 .14346 L
.34542 .14346 L
Mistroke
.34545 .14346 L
.34549 .14347 L
.34552 .14347 L
.34558 .14347 L
.34565 .14347 L
.3457 .14347 L
.34577 .14346 L
.3458 .14346 L
.34583 .14346 L
.34595 .14344 L
.34607 .14343 L
.34619 .1434 L
.34631 .14337 L
.34657 .14328 L
.3468 .14317 L
.34705 .14304 L
.34748 .14275 L
.34794 .14234 L
.34888 .14127 L
.34988 .13973 L
.35187 .13562 L
.35378 .13052 L
.35562 .12483 L
.35757 .1183 L
.35946 .11192 L
.36146 .10549 L
.36339 .10007 L
.36524 .09592 L
.3662 .09427 L
.36669 .09358 L
.36722 .09296 L
.36771 .09249 L
.36816 .09215 L
.36838 .09202 L
.36862 .09191 L
.36884 .09183 L
.36905 .09177 L
.36916 .09175 L
.36922 .09175 L
.36927 .09174 L
.36933 .09173 L
.36939 .09173 L
.36945 .09173 L
.36948 .09173 L
.36951 .09173 L
.36957 .09173 L
.36962 .09173 L
.36967 .09174 L
.36973 .09174 L
.36983 .09176 L
Mistroke
.36995 .09178 L
.37007 .09181 L
.37019 .09185 L
.37046 .09196 L
.3707 .09209 L
.37094 .09224 L
.3714 .09262 L
.37189 .09314 L
.37278 .09437 L
.37371 .09607 L
.37459 .09801 L
.37645 .10315 L
.37843 .1099 L
.38033 .11724 L
.38216 .12469 L
.38411 .13255 L
.38598 .13956 L
.38798 .14592 L
.38898 .14853 L
.3899 .15054 L
.39079 .15208 L
.39125 .15271 L
.39175 .15325 L
.392 .15347 L
.39224 .15365 L
.39247 .1538 L
.39268 .1539 L
.39289 .15397 L
.393 .15401 L
.39311 .15403 L
.39317 .15404 L
.39322 .15404 L
.39328 .15405 L
.39334 .15405 L
.3934 .15405 L
.39345 .15405 L
.3935 .15405 L
.39357 .15404 L
.39362 .15404 L
.39369 .15403 L
.39382 .154 L
.39394 .15396 L
.39405 .15392 L
.39431 .1538 L
.39459 .15362 L
.39509 .15319 L
.39555 .15265 L
.39646 .15122 L
.39746 .14911 L
.39941 .1434 L
Mistroke
.40129 .13618 L
.40329 .12709 L
.40521 .11748 L
.40706 .10799 L
.40903 .09827 L
.41092 .08988 L
.41274 .08326 L
.41376 .08036 L
.41469 .07826 L
.41514 .07744 L
.41564 .07671 L
.41587 .07644 L
.41612 .07619 L
.41633 .076 L
.41655 .07585 L
.41668 .07578 L
.41681 .07571 L
.41693 .07567 L
.41705 .07564 L
.41712 .07562 L
.41715 .07562 L
.41718 .07561 L
.41724 .0756 L
.41727 .0756 L
.41731 .0756 L
.41734 .0756 L
.41738 .0756 L
.41741 .0756 L
.41744 .0756 L
.41747 .0756 L
.41751 .07561 L
.41755 .07561 L
.41758 .07562 L
.41765 .07563 L
.41771 .07565 L
.41783 .07568 L
.41805 .07579 L
.41831 .07595 L
.41856 .07615 L
.41902 .07667 L
.41946 .07731 L
.42045 .07932 L
.42143 .08203 L
.42232 .08512 L
.42424 .09358 L
.42608 .10375 L
.42804 .11619 L
.42993 .12907 L
.43174 .14157 L
.43367 .15421 L
Mistroke
.43553 .16494 L
.43648 .1696 L
.43751 .17397 L
.43851 .17736 L
.43941 .17966 L
.4399 .18056 L
.44036 .1812 L
.44061 .18146 L
.44084 .18164 L
.44096 .18171 L
.44109 .18177 L
.44116 .18179 L
.44123 .18181 L
.44127 .18182 L
.4413 .18182 L
.44136 .18183 L
.44142 .18184 L
.44146 .18184 L
.44149 .18184 L
.44155 .18183 L
.44161 .18182 L
.44166 .18181 L
.44171 .1818 L
.44183 .18176 L
.44195 .1817 L
.44206 .18163 L
.44232 .18143 L
.44254 .1812 L
.44277 .18088 L
.4432 .18016 L
.44365 .17917 L
.44415 .17781 L
.44516 .17421 L
.4461 .1699 L
.4471 .16423 L
.44908 .15013 L
.45099 .13345 L
.45282 .11526 L
.45477 .09462 L
.45665 .07461 L
.45865 .05455 L
.46057 .03775 L
.46242 .02516 L
.46338 .0204 L
.46386 .01851 L
.46439 .01685 L
.46464 .01622 L
.46488 .01573 L
.4651 .01536 L
.46533 .01506 L
Mistroke
.46546 .01493 L
.46558 .01484 L
.46564 .0148 L
.4657 .01477 L
.46576 .01475 L
.46581 .01473 L
.46587 .01472 L
.46593 .01472 L
.46596 .01472 L
.466 .01472 L
.46603 .01472 L
.46606 .01473 L
.4661 .01474 L
.46613 .01475 L
.46619 .01477 L
.46626 .01481 L
.46633 .01485 L
.46645 .01495 L
.46658 .01509 L
.46682 .01543 L
.46705 .01586 L
.46727 .01635 L
.46775 .0178 L
.46827 .01986 L
.4693 .02558 L
.47027 .03297 L
.47212 .05256 L
.4741 .08115 L
.47599 .11581 L
.47782 .15502 L
.47976 .20202 L
.48163 .2511 L
.48362 .30571 L
.48554 .35893 L
.48738 .40894 L
.48934 .45901 L
.49123 .50244 L
.49305 .53829 L
.49498 .56873 L
.49587 .57972 L
.49684 .58943 L
.4978 .59658 L
.49833 .59941 L
.49882 .60136 L
.49906 .60208 L
.49919 .6024 L
.49932 .60268 L
.49944 .60288 L
.49957 .60306 L
.49963 .60313 L
Mistroke
.49969 .60319 L
.49975 .60323 L
.4998 .60326 L
.49986 .60329 L
.49992 .60331 L
.49995 .60332 L
.49998 .60332 L
.50004 .60332 L
.5001 .60331 L
.50015 .60329 L
.50021 .60326 L
.50027 .60322 L
.50037 .60312 L
.50047 .60301 L
.5007 .60264 L
.50094 .60209 L
.5012 .6013 L
.50168 .59938 L
.50214 .59692 L
.50257 .59411 L
.50347 .58661 L
.50446 .57589 L
.5064 .54793 L
.50826 .51314 L
.51024 .46907 L
.51215 .4213 L
.51398 .37208 L
.51594 .31798 L
.51782 .26603 L
.51981 .21284 L
.52174 .16527 L
.52359 .12426 L
.52556 .08693 L
.52746 .05797 L
.52928 .03704 L
.53022 .029 L
.53122 .02239 L
.53171 .01994 L
.53224 .01781 L
.53249 .01703 L
.53275 .01632 L
.53299 .01577 L
.53321 .01538 L
.53343 .01508 L
.53354 .01496 L
.53366 .01486 L
.53378 .01478 L
.53385 .01475 L
.53391 .01473 L
.53397 .01472 L
Mistroke
.53403 .01472 L
.53409 .01472 L
.53415 .01472 L
.5342 .01473 L
.53425 .01475 L
.5343 .01477 L
.53435 .01479 L
.53446 .01487 L
.53457 .01496 L
.53479 .0152 L
.53502 .01556 L
.53552 .01662 L
.53597 .01794 L
.53698 .02204 L
.53791 .0271 L
.53891 .03381 L
.54088 .05015 L
.54278 .06871 L
.54461 .08796 L
.54655 .10871 L
.54842 .12778 L
.55041 .14596 L
.55233 .16054 L
.55417 .17124 L
.55513 .17536 L
.55561 .17708 L
.55614 .17863 L
.55663 .1798 L
.55707 .18064 L
.5575 .18124 L
.55772 .18146 L
.55795 .18164 L
.55807 .18172 L
.55814 .18175 L
.55821 .18177 L
.55827 .18179 L
.55833 .18181 L
.55839 .18182 L
.55845 .18183 L
.5585 .18184 L
.55856 .18184 L
.55861 .18183 L
.55866 .18183 L
.55872 .18182 L
.55878 .18181 L
.55884 .18179 L
.5589 .18177 L
.55903 .18171 L
.55915 .18165 L
.55942 .18143 L
Mistroke
.55965 .18119 L
.5599 .18086 L
.56036 .1801 L
.56085 .17907 L
.56173 .17662 L
.56276 .17292 L
.56373 .16866 L
.56557 .15878 L
.56754 .14642 L
.56943 .13353 L
.57125 .12099 L
.57318 .10827 L
.57505 .09732 L
.57703 .08772 L
.57802 .08387 L
.57894 .08093 L
.57983 .07868 L
.58032 .07769 L
.58077 .07695 L
.58127 .07633 L
.58153 .07608 L
.5818 .07587 L
.58192 .0758 L
.58204 .07574 L
.58215 .07569 L
.58226 .07565 L
.58234 .07563 L
.5824 .07562 L
.58246 .07561 L
.5825 .07561 L
.58253 .0756 L
.58259 .0756 L
.58262 .0756 L
.58266 .0756 L
.58271 .0756 L
.58277 .07561 L
.58283 .07561 L
.5829 .07562 L
.58301 .07565 L
.58313 .07569 L
.58323 .07573 L
.58347 .07586 L
.58372 .07604 L
.58414 .07645 L
.5846 .07705 L
.58554 .07872 L
.58654 .08116 L
.58853 .08771 L
.59044 .09578 L
.59228 .10464 L
Mistroke
.59423 .11462 L
.59612 .12417 L
.59812 .13362 L
.60005 .14147 L
.6019 .14746 L
.60286 .14986 L
.60335 .15088 L
.60388 .15181 L
.60437 .15255 L
.60482 .1531 L
.60527 .15352 L
.6057 .15381 L
.60593 .15391 L
.60605 .15396 L
.60617 .15399 L
.60629 .15402 L
.60636 .15403 L
.60642 .15404 L
.60648 .15405 L
.60654 .15405 L
.6066 .15405 L
.60663 .15405 L
.60666 .15405 L
.60672 .15405 L
.60678 .15404 L
.60683 .15404 L
.60688 .15403 L
.607 .154 L
.60712 .15397 L
.60733 .1539 L
.60755 .15379 L
.60804 .15345 L
.60857 .15292 L
.60954 .15156 L
.61048 .14976 L
.61149 .14736 L
.6135 .14135 L
.61543 .13435 L
.61729 .12695 L
.61926 .11888 L
.62117 .11141 L
.623 .10493 L
.62495 .09917 L
.62584 .09701 L
.62682 .09505 L
.62735 .09417 L
.62785 .09347 L
.62835 .09288 L
.62881 .09243 L
.62925 .09212 L
Mistroke
.62949 .09198 L
.62971 .09188 L
.62996 .0918 L
.6301 .09177 L
.63016 .09176 L
.63022 .09175 L
.63028 .09174 L
.63031 .09174 L
.63035 .09173 L
.6304 .09173 L
.63046 .09173 L
.63052 .09173 L
.63058 .09173 L
.63064 .09173 L
.63067 .09173 L
.63071 .09174 L
.63082 .09175 L
.63088 .09176 L
.63094 .09177 L
.63118 .09184 L
.6314 .09192 L
.63162 .09203 L
.63215 .09237 L
.63262 .0928 L
.63353 .09389 L
.63453 .0955 L
.63648 .09974 L
.63836 .10494 L
.64035 .11129 L
.64228 .11779 L
.64413 .124 L
.64609 .13015 L
.64799 .13528 L
.64981 .13919 L
.65075 .14074 L
.65175 .14203 L
.65224 .14251 L
.65277 .14292 L
.65301 .14308 L
.65327 .14321 L
.6535 .1433 L
.65374 .14338 L
.65386 .14341 L
.65399 .14344 L
.65405 .14345 L
.65412 .14345 L
.65418 .14346 L
.65423 .14346 L
.65427 .14347 L
.6543 .14347 L
Mistroke
.65434 .14347 L
.65438 .14347 L
.65441 .14347 L
.65445 .14347 L
.65448 .14347 L
.65451 .14347 L
.65457 .14346 L
.65464 .14346 L
.6547 .14345 L
.65477 .14344 L
.65489 .14342 L
.65501 .14339 L
.65524 .14332 L
.65548 .14323 L
.65574 .1431 L
.65619 .14281 L
.6567 .14239 L
.65771 .14126 L
.65865 .13989 L
.65965 .1381 L
.66164 .13372 L
.66355 .12871 L
.6654 .12346 L
.66736 .11777 L
.66924 .11254 L
.67106 .10803 L
.67299 .10407 L
.67388 .1026 L
.67485 .10128 L
.67581 .10028 L
.67634 .09987 L
.67682 .09958 L
.67707 .09947 L
.67733 .09937 L
.67745 .09933 L
.67758 .0993 L
.67769 .09928 L
.67781 .09925 L
.67792 .09924 L
.67803 .09923 L
.67808 .09922 L
.67813 .09922 L
.67818 .09922 L
.67823 .09922 L
.67829 .09922 L
.67835 .09922 L
.6784 .09922 L
.67846 .09923 L
.67852 .09923 L
.67859 .09924 L
Mistroke
.6787 .09926 L
.67882 .09928 L
.67894 .0993 L
.67916 .09937 L
.67939 .09945 L
.67965 .09956 L
.6801 .09983 L
.68053 .10013 L
.68143 .10098 L
.68242 .1022 L
.68435 .10539 L
.68621 .10927 L
.68819 .11398 L
.6901 .1188 L
.69193 .12341 L
.69389 .12798 L
.69576 .13179 L
.69672 .13343 L
.69776 .13495 L
.69868 .13605 L
.6992 .13656 L
.69968 .13696 L
.70018 .1373 L
.70064 .13755 L
.70087 .13765 L
.70113 .13773 L
.70127 .13777 L
.7014 .1378 L
.70153 .13783 L
.70165 .13785 L
.70177 .13786 L
.70183 .13787 L
.7019 .13788 L
.70193 .13788 L
.70197 .13788 L
.702 .13788 L
.70204 .13788 L
.7021 .13788 L
.70213 .13788 L
.70216 .13788 L
.70222 .13788 L
.70227 .13788 L
.70233 .13787 L
.7024 .13787 L
.70253 .13785 L
.70264 .13783 L
.70286 .13779 L
.7031 .13772 L
.70354 .13756 L
.70403 .1373 L
Mistroke
.70448 .137 L
.70549 .13611 L
.70642 .13505 L
.70742 .13367 L
.70939 .13029 L
.71129 .12644 L
.71312 .12241 L
.71506 .11803 L
.71693 .11399 L
.71892 .11015 L
.72083 .10714 L
.72171 .10604 L
.72268 .10504 L
.72363 .1043 L
.72415 .104 L
.72438 .10389 L
.72464 .10379 L
.72487 .10371 L
.72511 .10365 L
.72524 .10362 L
.72537 .10359 L
.72549 .10358 L
.72561 .10356 L
.72571 .10356 L
.72577 .10355 L
.72583 .10355 L
.72589 .10355 L
.72592 .10355 L
.72595 .10355 L
.72601 .10355 L
.72607 .10355 L
.72612 .10355 L
.72617 .10356 L
.72627 .10356 L
.72639 .10358 L
.7265 .10359 L
.72673 .10364 L
.72698 .1037 L
.72742 .10386 L
.7279 .10409 L
.72843 .10441 L
.72937 .10516 L
.73037 .10621 L
.73236 .10894 L
.73428 .11222 L
.73613 .11577 L
.73809 .11975 L
.73998 .12352 L
.7418 .12687 L
.74373 .12994 L
Mistroke
.7456 .13223 L
.74656 .13312 L
.74705 .13349 L
.74758 .13381 L
.74808 .13406 L
.74853 .13423 L
.74875 .13429 L
.74898 .13435 L
.74909 .13437 L
.74921 .13439 L
.7493 .1344 L
.74941 .13441 L
.74947 .13442 L
.74953 .13442 L
.74959 .13442 L
.74965 .13442 L
.7497 .13443 L
.74975 .13443 L
.74981 .13443 L
.74987 .13442 L
.74993 .13442 L
.74996 .13442 L
.74999 .13442 L
.75006 .13442 L
.75012 .13441 L
.75023 .1344 L
.75035 .13438 L
.75057 .13434 L
.75081 .13429 L
.75124 .13415 L
.75169 .13396 L
.75219 .13369 L
.7532 .13296 L
.75414 .13209 L
.75514 .13095 L
.75712 .12817 L
.75903 .12499 L
.76087 .12167 L
.76282 .11807 L
.76471 .11476 L
.76671 .11162 L
.76863 .10918 L
.76952 .10828 L
.77049 .10749 L
.77145 .10691 L
.77197 .10668 L
.77246 .10652 L
.7727 .10646 L
.77283 .10644 L
.77296 .10642 L
Mistroke
.77308 .1064 L
.77321 .10639 L
.77327 .10638 L
.77333 .10638 L
.77339 .10638 L
.77344 .10637 L
.77349 .10637 L
.77355 .10637 L
.77361 .10637 L
.77367 .10637 L
.77373 .10637 L
.77376 .10637 L
.77379 .10637 L
.77385 .10638 L
.77391 .10638 L
.774 .10639 L
.77411 .1064 L
.77433 .10643 L
.77457 .10648 L
.77483 .10655 L
.77531 .10671 L
.77577 .10691 L
.7762 .10715 L
.77719 .10783 L
.77809 .10862 L
.78002 .11082 L
.78187 .11345 L
.78385 .11661 L
.78575 .11982 L
.78758 .12286 L
.78953 .12586 L
.7914 .12833 L
.79235 .12939 L
.79339 .13036 L
.79439 .1311 L
.79486 .13138 L
.79531 .1316 L
.79578 .13179 L
.79621 .13192 L
.79644 .13197 L
.79669 .13202 L
.79681 .13204 L
.79693 .13205 L
.79701 .13206 L
.79707 .13206 L
.79714 .13207 L
.7972 .13207 L
.79726 .13207 L
.79731 .13208 L
.79735 .13208 L
Mistroke
.79738 .13208 L
.79744 .13208 L
.7975 .13208 L
.79755 .13208 L
.79762 .13207 L
.79768 .13207 L
.79779 .13206 L
.79789 .13205 L
.79813 .13203 L
.79838 .13198 L
.79861 .13193 L
.79913 .13177 L
.7996 .13158 L
.80004 .13136 L
.80103 .13072 L
.80291 .12903 L
.8049 .12664 L
.80683 .12392 L
.80867 .12109 L
.81064 .11803 L
.81253 .11522 L
.81436 .11282 L
.81629 .11073 L
.81719 .10997 L
.81816 .1093 L
.81869 .109 L
.81918 .10878 L
.81965 .10861 L
.81991 .10853 L
.82014 .10848 L
.82039 .10843 L
.82064 .10839 L
.82077 .10838 L
.8209 .10837 L
.82097 .10836 L
.82103 .10836 L
.82107 .10836 L
.8211 .10836 L
.82114 .10836 L
.82118 .10836 L
.82123 .10836 L
.82129 .10836 L
.82135 .10836 L
.8214 .10836 L
.82146 .10836 L
.82152 .10836 L
.82165 .10837 L
.82177 .10838 L
.8219 .1084 L
.82215 .10843 L
Mistroke
.8224 .10849 L
.82264 .10855 L
.82317 .10872 L
.82364 .10892 L
.82414 .10917 L
.82597 .11047 L
.82791 .11243 L
.82978 .11473 L
.83176 .11749 L
.83368 .12026 L
.83552 .12286 L
.83748 .1254 L
.83936 .12747 L
.84032 .12834 L
.84137 .12912 L
.84237 .12971 L
.84285 .12992 L
.8433 .13009 L
.84373 .13021 L
.84396 .13026 L
.8442 .13031 L
.84434 .13033 L
.84447 .13034 L
.84459 .13036 L
.84466 .13036 L
.84472 .13037 L
.84479 .13037 L
.84484 .13037 L
.8449 .13038 L
.84495 .13038 L
.84502 .13038 L
.84507 .13038 L
.84513 .13038 L
.84517 .13038 L
.8452 .13038 L
.84526 .13037 L
.84531 .13037 L
.84543 .13037 L
.84555 .13036 L
.84568 .13034 L
.84591 .13031 L
.84612 .13028 L
.84664 .13015 L
.84713 .12999 L
.84808 .12956 L
.84897 .12902 L
.85086 .12746 L
.85267 .12554 L
.85461 .12316 L
.85647 .12068 L
Mistroke
.85844 .11801 L
.86035 .11558 L
.86218 .11352 L
.8632 .11252 L
.86413 .11174 L
.86511 .11105 L
.86601 .11054 L
.86693 .11016 L
.86742 .11002 L
.86769 .10995 L
.86793 .10991 L
.86817 .10987 L
.86839 .10985 L
.86851 .10984 L
.86862 .10983 L
.86868 .10983 L
.86874 .10983 L
.86878 .10983 L
.86881 .10983 L
.86887 .10983 L
.86893 .10983 L
.86898 .10983 L
.86904 .10983 L
.8691 .10983 L
.86916 .10983 L
.86922 .10984 L
.86933 .10984 L
.86954 .10986 L
.86976 .10989 L
.86999 .10993 L
.87021 .10998 L
.87071 .11011 L
.87119 .11028 L
.87172 .11051 L
.87268 .11104 L
.8737 .11174 L
.87553 .11336 L
.87749 .11548 L
.87937 .11776 L
.88137 .12028 L
.88329 .12266 L
.88514 .12476 L
.88711 .12664 L
.88809 .1274 L
.88901 .12799 L
.88989 .12845 L
.89038 .12865 L
.89084 .12881 L
.89132 .12893 L
.89158 .12899 L
Mistroke
.89186 .12903 L
.89197 .12905 L
.89209 .12906 L
.8922 .12907 L
.89232 .12908 L
.89238 .12908 L
.89244 .12908 L
.89251 .12909 L
.89255 .12909 L
.89258 .12909 L
.89261 .12909 L
.89265 .12909 L
.89271 .12909 L
.89276 .12909 L
.89282 .12909 L
.89288 .12909 L
.89294 .12909 L
.893 .12908 L
.89306 .12908 L
.89328 .12906 L
.8934 .12905 L
.89351 .12904 L
.89376 .129 L
.89422 .12891 L
.89464 .12879 L
.89561 .12842 L
.8965 .12796 L
.8984 .12661 L
.90022 .12492 L
.90217 .12282 L
.90404 .12062 L
.90603 .11826 L
.90795 .11609 L
.90979 .11425 L
.91073 .11344 L
.91176 .11266 L
.91274 .11205 L
.91364 .1116 L
.91458 .11125 L
.91506 .11113 L
.91533 .11107 L
.91558 .11103 L
.91581 .111 L
.91604 .11098 L
.91616 .11097 L
.91627 .11097 L
.91633 .11097 L
.91637 .11097 L
.9164 .11096 L
.91643 .11096 L
Mistroke
.91647 .11096 L
.91653 .11096 L
.91658 .11096 L
.91664 .11096 L
.9167 .11097 L
.91675 .11097 L
.9168 .11097 L
.91687 .11097 L
.91698 .11098 L
.91709 .11099 L
.91721 .111 L
.91741 .11102 L
.91787 .1111 L
.91836 .11122 L
.91924 .11152 L
.92027 .112 L
.92123 .11259 L
.92308 .11402 L
.92505 .11589 L
.92694 .11792 L
.92876 .11997 L
.93069 .12211 L
.93256 .12401 L
.93454 .12574 L
.93553 .12644 L
.93645 .127 L
.93734 .12743 L
.93828 .12777 L
.93878 .1279 L
.93904 .12796 L
.93931 .128 L
.93955 .12804 L
.93968 .12805 L
.93982 .12806 L
.93994 .12807 L
.94006 .12808 L
.94011 .12808 L
.94017 .12808 L
.94023 .12808 L
.94028 .12808 L
.94034 .12808 L
.9404 .12808 L
.94045 .12808 L
.9405 .12808 L
.94056 .12808 L
.94063 .12808 L
.94074 .12807 L
.94086 .12806 L
.94097 .12805 L
.94118 .12803 L
Mistroke
.94143 .128 L
.94165 .12796 L
.94217 .12784 L
.94264 .12771 L
.94307 .12755 L
.94406 .12711 L
.94593 .12594 L
.94791 .12431 L
.94983 .12245 L
.95166 .12053 L
.95362 .11844 L
.9555 .11654 L
.95751 .11475 L
.95851 .11398 L
.95944 .11336 L
.9604 .11283 L
.96129 .11243 L
.9622 .11213 L
.96268 .11202 L
.96294 .11197 L
.96319 .11193 L
.96343 .1119 L
.96355 .11189 L
.96368 .11188 L
.96375 .11188 L
.96381 .11187 L
.96388 .11187 L
.96394 .11187 L
.964 .11187 L
.96403 .11187 L
.96407 .11187 L
.96411 .11187 L
.96415 .11187 L
.96418 .11187 L
.96421 .11187 L
.96427 .11187 L
.96433 .11187 L
.96439 .11187 L
.96446 .11187 L
.96459 .11188 L
.96472 .11189 L
.96496 .11191 L
.96518 .11194 L
.96565 .11202 L
.96614 .11213 L
.96702 .11242 L
.96796 .11283 L
.96884 .11331 L
.9707 .1146 L
.97267 .11629 L
Mistroke
.97457 .11813 L
.97619 .11976 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{504, 474.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001fR000`400?l00000o`00003ooooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`009Oooool5o`0002gooooo0ol0000]ooooo`;o0000
;_ooool3o`0002kooooo1Ol0003oooooo`cooooo000Vooooo`04o`000?ooooooooooo`0002kooooo
00?o0000ooooooooool0:oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo02ko
oooo00Co0000oooooooooooo0000=oooool3o`0000Cooooo0_l0000Yooooo`?o0000:oooool2o`00
02gooooo0ol0000Yooooo`?o00001?ooool2o`00013ooooo000Oooooo`Go00000oooool00ol0003o
ooooooooo`0Vooooo`Go00000oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`00
02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00009oooool01Ol0003ooooooooooooooooo000002Wooooo00Co
0000oooooooooooo0000:oooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000?ooooo`00:?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02_ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02oooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00008Oooool5o`0000Gooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0
000_ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool0000?ooooo`009Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool0
:oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo02gooooo00Go0000oooooooo
ooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:oooool0
0ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000oooooo000Uooooo`05o`000?oo
ooooooooooooool00000;Oooool2o`0002gooooo00Co0000oooooooooooo0000;Oooool2o`0002oo
oooo00Go0000ooooooooooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00009oooool4o`0002[ooooo00Co0000oooooooooooo0000:oooool4o`0002[ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool0000?ooooo`009_ooool3o`0002oooooo00?o
0000ooooooooool0;?ooool2o`0002oooooo00?o0000ooooooooool0;_ooool3o`0003Sooooo0_l0
0004ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool0:oooool01?l0003ooooo
ooooool0000[ooooo`03o`000?oooooooooo02[ooooo0_l00004ooooo`04o`000?ooooooooooo`00
00oooooo003oooooobKooooo00?o0000ooooooooool00oooool2o`0002Sooooo1Ol0000Zooooo`;o
0000;?ooool5o`0002Wooooo00?o0000ooooooooool00oooool2o`00013ooooo003oooooooWooooo
003oooooooWooooo000Pooooom3o0000ooooool9ooooo`008?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
00000?oooooo2Oooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_oooo
o`05o`000?ooooooooooooooool00000<Oooooo9o`0000kooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo000Jooooo`;o00001?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Looooo`?oo`3o@_ooool00ol0003o
ooooooooo`11ooooo`;oo`3o7_ooool00ol0003oooooooooo`0<ooooo`006Oooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo01Sooooo2_oo0?loooooo`03o`000?oooooooooo03co
oooo2ooo0?lJooooo`03o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`0000?o
oooo0_l00002ooooof3oo`3o1?ooool01?l0003ooooooooooooooomPool0o`;ooooo0_l0000aoooo
o`;o00005_ooool?ool0ocgooooo00?o0000ooooooooool0>_ooool>ool0oaSooooo0_l0000>oooo
o`006Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooof3oo`3o1?ooool0
1?l0003ooooooooooooooomPool0o`?ooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`0Dooooo`Goo`3o1oooool5ool0occooooo00?o0000ooooooooool0>Oooool5ool0o`Oooooo1Ooo
0?lGooooo`03o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool04_ooool5ool0o`_ooooo1Ooo0?ljooooo`03o`00
0?oooooooooo03Sooooo1?oo0?l;ooooo`Goo`3o5Oooool00ol0003oooooooooo`0<ooooo`006Ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo017o
oooo1?oo0?l?ooooo`Coo`3o>Oooool00ol0003oooooooooo`0fooooo`Coo`3o3oooool4ool0oaCo
oooo00?o0000ooooooooool03?ooool001[ooooo0_l00004ooooo`03o`000?oooooooooo05oooooo
0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo013ooooo1?oo0?lAooooo`?oo`3o>Oooool00ol0003oooooooooo`0fooooo`?o
o`3o4Oooool4ool0oa?ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0
Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02oo
oooo0_l0000@ooooo`Coo`3o4oooool3ool0ocSooooo00?o0000ooooooooool0=Oooool3ool0oa?o
oooo1?oo0?lAooooo`;o00003_ooool0023ooooo0_l0001Pooooo`;oo`3o1?ooool01?l0003ooooo
ooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0>ooooo`Co
o`3o5Oooool3ool0ocOooooo00?o0000ooooooooool0=?ooool3ool0oaKooooo0ooo0?lAooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00go
oooo0ooo0?lHooooo`?oo`3o=_ooool00ol0003oooooooooo`0cooooo`?oo`3o6?ooool4ool0o`oo
oooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo
00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool02oooool4ool0oaWooooo1?oo0?leooooo`03o`000?oooooooooo03?ooooo0_oo0?lJooooo`?o
o`3o3oooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o
1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`0;ooooo`?oo`3o6oooool3ool0ocGooooo00?o0000ooooooooool0<_ooool3ool0oa_o
oooo1?oo0?l=ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo
0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`;o
00002_ooool4ool0oagooooo0ooo0?ldooooo`03o`000?oooooooooo037ooooo0ooo0?lMooooo`Co
o`3o2oooool2o`0000kooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wo
oooo0ooo0?lOooooo`;oo`3o=?ooool00ol0003oooooooooo`0`ooooo`?oo`3o7oooool3ool0o`co
oooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Pooooo`;oo`3o1?ooool01?l0003ooooo
ooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`?o
o`3o8?ooool3ool0oc?ooooo00?o0000ooooooooool0<?ooool3ool0ob3ooooo0ooo0?l;ooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oo
oooo0ooo0?lRooooo`?oo`3o<_ooool00ol0003oooooooooo`0_ooooo`?oo`3o8_ooool3ool0o`[o
oooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo
00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool01_ooool3ool0obCooooo0_oo0?lbooooo`03o`000?oooooooooo02oooooo0ooo0?lSooooo`?o
o`3o2Oooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o
1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool2o`0000Ko
oooo0ooo0?lUooooo`?oo`3o<Oooool00ol0003oooooooooo`0^ooooo`?oo`3o9Oooool3ool0o`Oo
oooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003ooooo
ooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`04ooooo`?o
o`3o9oooool3ool0oc3ooooo00?o0000ooooooooool0;_ooool2ool0obOooooo0ooo0?l7ooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0Xooooo`;o00001Oooool00ol0003o
ooooooooo`03ooooo`?oo`3o:Oooool2ool0oc3ooooo00?o0000ooooooooool0;Oooool3ool0obSo
oooo0ooo0?l6ooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000H?ooool2ool0o`Cooooo
00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`02ooooo`Coo`3o:Oooool3ool0oboooooo00?o0000oooo
ooooool0;?ooool3ool0obWooooo1?oo0?l5ooooo`03o`000?oooooooooo00cooooo000Pooooo`03
o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0
003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo1?oo
0?lZooooo`?oo`3o;oooool00ol0003oooooooooo`0/ooooo`?oo`3o:oooool3ool0o`Cooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000
oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo0000
1?ooool4o`0000?oo`3o;?l00002ool0oeko00000_oo0?l/o`0000?oo`3o1Ol0000>ooooo`008?oo
ool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo
00?o0000ooooooooool09oooool01?l0003oooooooooool00004ooooo`04o`000?oooooooooooooo
o`;oo`3o;Oooool3ool0obkooooo00?o0000ooooooooool0:oooool3ool0obgooooo0_oo0?l4oooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04
o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0Wooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0<Oooool3ool0obgooooo00?o0000ooooooooool0:oooool2
ool0ocCooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0Goooool2ool0
o`Cooooo00Co0000oooooooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02Sooooo0_l00005
ooooo`03o`000?oooooooooo037ooooo0ooo0?l]ooooo`03o`000?oooooooooo02[ooooo0ooo0?ld
ooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000H?ooool2ool0o`Cooooo00Co0000oooo
oooooooooooo0_oo0?mQooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<_ooool2
ool0obgooooo00?o0000ooooooooool0:_ooool2ool0ocGooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQ
ooooo`03o`000?oooooooooo02oooooo0_l0000cooooo`?oo`3o;?ooool00ol0003oooooooooo`0Y
ooooo`?oo`3o=?ooool2o`0000kooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4oooo
o`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo03?ooooo0_oo0?l/ooooo`03o`000?oooooooooo02Wooooo0_oo0?lfooooo`03o`000?oooooo
oooo00cooooo000>ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0
003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0cooooo`?oo`3o:oooool00ol0003oooooooooo`0X
ooooo`?oo`3o=_ooool00ol0003oooooooooo`0<ooooo`003Oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Oooooo`;oo`3o1?oo
ool01?l0003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0dooooo`;oo`3o:oooool00ol0003oooooooooo`0Xooooo`;oo`3o=oooool00ol0003ooooo
ooooo`0<ooooo`003Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooooooo`;o
0000H?ooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mPooooo`;o0000<Oooool2o`00
03Gooooo0ooo0?lZooooo`03o`000?oooooooooo02Oooooo0ooo0?lfooooo`;o00003_ooool000go
oooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo0000067ooooo0_oo0?l4
ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo03Gooooo0_oo0?lZooooo`03o`000?oooooooooo02Oooooo0_oo0?lhooooo`03o`000?oo
oooooooo00cooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo1?l00004ooooo`03o`000?oo
oooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo03Gooooo0_oo0?lZooooo`03o`000?oooooooooo02Oooooo
0_oo0?lhooooo`03o`000?oooooooooo00cooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003ooooo
ooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0eooooo`?o
o`3o:Oooool00ol0003oooooooooo`0Vooooo`?oo`3o>?ooool00ol0003oooooooooo`0<ooooo`00
3_ooool2o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Ko
oooo0_oo0?lYooooo`03o`000?oooooooooo02Kooooo0_oo0?liooooo`03o`000?oooooooooo00co
oooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;o
o`3oHOooool00ol0003oooooooooo`0_ooooo`;o0000=oooool3ool0obSooooo00?o0000oooooooo
ool09_ooool2ool0ocSooooo0_l0000>ooooo`008?ooool2o`00063ooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Oo
oooo0_oo0?lXooooo`03o`000?oooooooooo02Gooooo0ooo0?liooooo`03o`000?oooooooooo00co
oooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;o
o`3oHOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03Oooooo0_oo0?lXooooo`03
o`000?oooooooooo02Gooooo0_oo0?ljooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`00
0?oooooooooo05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo03Oooooo0ooo0?lWooooo`03o`000?oooooooooo02Co
oooo0ooo0?ljooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo
0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo03Sooooo0_oo0?lWooooo`03o`000?oooooooooo02Cooooo0_oo0?lkooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`;o0000>Oooool2ool0obOo
oooo00?o0000ooooooooool09?ooool2ool0oc[ooooo0_l0000>ooooo`008?ooool00ol0003ooooo
ooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0hooooo`?oo`3o9_ooool00ol0003oooooooooo`0Sooooo`?o
o`3o>oooool00ol0003oooooooooo`0<ooooo`008?ooool2o`00063ooooo0_oo0?l4ooooo`04o`00
0?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0Fooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00?o0000ooooooooool0>Oooool2ool0obKo
oooo00?o0000ooooooooool08oooool2ool0occooooo00?o0000ooooooooool03?ooool0023ooooo
00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0iooooo`?oo`3o9Ooo
ool00ol0003oooooooooo`0Sooooo`;oo`3o??ooool00ol0003oooooooooo`0<ooooo`008?ooool0
0ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o
0000ooooooooool05Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0jooooo`;oo`3o9Oooool00ol0003o
ooooooooo`0Rooooo`?oo`3o??ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003ooooo
ooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000oooooooo
ool05Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool00_ooool2o`0003_ooooo0_oo0?lUooooo`03o`000?oooooooooo02;ooooo0_oo0?ll
ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooo
oooooooooooo0_oo0?mQooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?oo
ool01Ol0003oooooooooool0003ooooo00Co00001Oooool00ol0003oooooooooo`0jooooo`?oo`3o
9?ooool00ol0003oooooooooo`0Qooooo`?oo`3o?Oooool00ol0003oooooooooo`0<ooooo`008?oo
ool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo
00?o0000ooooooooool05Oooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00002?ooool00ol0003oooooooooo`0kooooo`;oo`3o9?ooool00ol0003oooooooooo`0Q
ooooo`;oo`3o?_ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`00063ooooo0_oo0?l4oooo
o`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0Fooooo`;o00002_ooool2
o`0000;ooooo1Ol00004ooooo`03o`000?oooooooooo03_ooooo0ooo0?lSooooo`03o`000?oooooo
oooo027ooooo0_oo0?lnooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo03cooooo0_oo0?lSooooo`03o`000?oooooooooo023ooooo0ooo0?ln
ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo05oooooo0_oo0?l4oooo
o`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_ooooo`;o0000?Oooool2
ool0ob?ooooo00?o0000ooooooooool08?ooool2ool0ockooooo0_l0000>ooooo`008?ooool00ol0
003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0looooo`?oo`3o8_ooool00ol0003oooooooooo`0O
ooooo`?oo`3o?oooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Ooooo
o`;oo`3o1?ooool01?l0003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0mooooo`;oo`3o8_ooool00ol0003oooooooooo`0Oooooo`;oo`3o@?ooool0
0ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0
003oooooooooooooool2ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0m
ooooo`;oo`3o8_ooool00ol0003oooooooooo`0Oooooo`;oo`3o@?ooool00ol0003oooooooooo`0<
ooooo`008?ooool2o`00063ooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03gooooo0ooo0?lQooooo`03o`000?oooooo
oooo01kooooo0ooo0?m0ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
05oooooo0_oo0?l4ooooo`04o`000?ooooooooooooooo`;oo`3oHOooool00ol0003oooooooooo`0_
ooooo`;o0000?oooool2ool0ob7ooooo00?o0000ooooooooool07_ooool2ool0od3ooooo0_l0000>
ooooo`008?ooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2
ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0nooooo`?oo`3o8?ooool0
0ol0003oooooooooo`0Nooooo`;oo`3o@Oooool00ol0003oooooooooo`0<ooooo`006Oooool3o`00
00Cooooo00?o0000ooooooooool0Goooool2ool0o`Cooooo00Co0000oooooooooooooooo0_oo0?mQ
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0?oooool2ool0ob3ooooo00?o0000
ooooooooool07Oooool3ool0od7ooooo00?o0000ooooooooool03?ooool001[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Oooooo`;oo`3o1?ooool01?l0003oooooooooooooool2
ool0of7ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0oooooo`;oo`3o8?ooool0
0ol0003oooooooooo`0Mooooo`;oo`3o@_ooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0
003oooooooooo`03ooooo`;o0000H?ooool<ool0of3ooooo0_l0000aooooo`;o0000@?ooool3ool0
oaoooooo00?o0000ooooooooool07?ooool3ool0od7ooooo0_l0000>ooooo`006_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo05oooooo3?oo0?mQooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0@?ooool2ool0oaoooooo00?o0000ooooooooool07?ooool2ool0od?o
oooo00?o0000ooooooooool03?ooool001[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`10ooooo`?oo`3o7_ooool00ol0003oooooooooo`0Looooo`;oo`3o@oooool00ol0003ooooo
ooooo`0<ooooo`006Oooool2o`0000Gooooo00?o0000ooooooooool0IOooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0@Oooool2ool0oakooooo00?o
0000ooooooooool06oooool3ool0od?ooooo00?o0000ooooooooool03?ooool001[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`11ooooo`;oo`3o7_ooool00ol0003oooooooooo`0K
ooooo`;oo`3oA?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool2o`0004;ooooo0_oo0?lNoooo
o`03o`000?oooooooooo01_ooooo0_oo0?m3ooooo`;o00003_ooool0023ooooo0_l0001Vooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`11ooooo`?o
o`3o7Oooool00ol0003oooooooooo`0Jooooo`?oo`3oA?ooool00ol0003oooooooooo`0<ooooo`00
8?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`12ooooo`;oo`3o7Oooool00ol0003oooooooooo`0Jooooo`;oo`3o
AOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool07?ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool0@_ooool2ool0oagooooo00?o0000ooooooooool06_oo
ool2ool0odGooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo0ooo0?lLooooo`03o`000?oo
oooooooo01Wooooo0ooo0?m5ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`0004Cooooo0_oo0?lLooooo`03o`000?oo
oooooooo01Wooooo0_oo0?m5ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04?ooooo0ooo0?lKooooo`03o`000?oo
oooooooo01Wooooo0_oo0?m6ooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000I_ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo0_oo0?lKooooo`03o`000?oo
oooooooo01Sooooo0ooo0?m6ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Sooooo0_l00006ooooo`03o`000?oooooooooo04Cooooo0_oo0?lKooooo`03o`000?oo
oooooooo01Sooooo0_oo0?m7ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`;o00002_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo0ooo0?lJooooo`03o`000?oooooo
oooo01Oooooo0ooo0?m7ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000A_ooool2ool0
oa[ooooo00?o0000ooooooooool05oooool2ool0odOooooo0_l0000>ooooo`008?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`15ooooo`;oo`3o6_ooool00ol0003oooooooooo`0Gooooo`;oo`3oB?ooool00ol0003o
ooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`15ooooo`?oo`3o6Oooool00ol0003ooooo
ooooo`0Fooooo`?oo`3oB?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Kooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Kooooo0_oo
0?lIooooo`03o`000?oooooooooo01Kooooo0_oo0?m9ooooo`03o`000?oooooooooo00cooooo000P
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo04Kooooo0ooo0?lHooooo`03o`000?oooooooooo01Kooooo0_oo0?m9
ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000B?ooool2ool0oaSooooo00?o0000oooo
ooooool05Oooool3ool0odSooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`17ooooo`;o
o`3o6?ooool00ol0003oooooooooo`0Eooooo`;oo`3oB_ooool00ol0003oooooooooo`0<ooooo`00
8?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`17ooooo`?oo`3o5oooool00ol0003oooooooooo`0Dooooo`?oo`3o
B_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`18ooooo`;oo`3o5ooo
ool00ol0003oooooooooo`0Dooooo`;oo`3oBoooool00ol0003oooooooooo`0<ooooo`008?ooool2
o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo04Sooooo0ooo0?lFooooo`03o`000?oooooooooo01Cooooo0_oo0?m;ooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0_ooooo`;o0000B_ooool2ool0oaKooooo00?o0000ooooooooool04oooool3ool0
od[ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`19ooooo`;oo`3o5_ooool00ol0003o
ooooooooo`0Cooooo`;oo`3oC?ooool00ol0003oooooooooo`0<ooooo`003Oooool3o`0000Cooooo
00?o0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0IOooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0BOooool3ool0oaGooooo
00?o0000ooooooooool04_ooool3ool0odcooooo00?o0000ooooooooool03?ooool000kooooo00?o
0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
B_ooool2ool0oaGooooo00?o0000ooooooooool04_ooool2ool0odgooooo00?o0000ooooooooool0
3?ooool000kooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000006Oooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04[ooooo
0_oo0?lEooooo`03o`000?oooooooooo01;ooooo0_oo0?m=ooooo`03o`000?oooooooooo00cooooo
000>ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0_l0001Vooooo`03o`00
0?oooooooooo06?ooooo0_l0000aooooo`;o0000Boooool3ool0oaCooooo00?o0000ooooooooool0
4Oooool3ool0odcooooo0_l0000>ooooo`003_ooool00ol0003oooooooooo`07ooooo`Co00001?oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`1;ooooo`;oo`3o5?ooool00ol0003oooooooooo`0Aooooo`;oo`3oC_oo
ool00ol0003oooooooooo`0<ooooo`003Oooool2o`0000Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool05_ooool2
o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol00005ooooo`03o`000?oooooo
oooo04_ooooo0ooo0?lCooooo`03o`000?oooooooooo017ooooo0_oo0?m>ooooo`03o`000?oooooo
oooo00cooooo000>ooooo`03o`000?oooooooooo00Oooooo1Ol00003ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`0000Wooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0C?ooool2ool0oa?ooooo00?o0000ooooooooool04?ooool3ool0odkooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo0_l0001=ooooo`;oo`3o4oooool00ol0003ooooooooo
o`0?ooooo`?oo`3oC_ooool2o`0000kooooo000Pooooo`;o0000I_ooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C?ooool3ool0oa;ooooo00?o
0000ooooooooool03oooool3ool0odoooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Gooooo00Co0000
oooooooooooo00002Oooool01?l0003oooooooooooooool4o`0000Gooooo00?o0000ooooooooool0
COooool3ool0oa7ooooo00?o0000ooooooooool03oooool2ool0oe3ooooo00?o0000ooooooooool0
3?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo00002?ooool2o`0000?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1>ooooo`;oo`3o4Oooool00ol0003oooooooooo`0>ooooo`?oo`3o
D?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool05_ooool2o`0000[ooooo00Co0000oooooooooooooooo
1Ol00004ooooo`03o`000?oooooooooo04kooooo0_oo0?lAooooo`03o`000?oooooooooo00kooooo
0_oo0?mAooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000Coooool3ool0oa3ooooo00?o
0000ooooooooool03Oooool3ool0oe3ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1?
ooooo`;oo`3o4?ooool00ol0003oooooooooo`0=ooooo`;oo`3oD_ooool00ol0003oooooooooo`0<
ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo04oooooo0ooo0?l?ooooo`03o`000?oooooooooo00cooooo0ooo0?mBoooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo053ooooo0_oo0?l?ooooo`03
o`000?oooooooooo00cooooo0_oo0?mCooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo053ooooo0ooo0?l>ooooo`03o`000?oooooooooo00_ooooo0ooo0?mCooooo`03o`00
0?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`0_ooooo`;o0000D_ooool2ool0o`kooooo00?o0000ooooooooool02ooo
ool3ool0oe;ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Aooooo`?oo`3o3Oooool0
0ol0003oooooooooo`0:ooooo`?oo`3oE?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`1Booooo`;oo`3o3Oooool00ol0003oooooooooo`0:ooooo`;oo`3oEOooool00ol0
003oooooooooo`0<ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo05;ooooo0ooo0?l<ooooo`03o`000?oooooooooo00Wo
oooo0ooo0?mEooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05?ooooo
0ooo0?l;ooooo`03o`000?oooooooooo00Wooooo0_oo0?mFooooo`03o`000?oooooooooo00cooooo
000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0_ooooo`;o0000EOooool2ool0o`_ooooo00?o0000ooooooooool02?ooool3ool0oeGooooo0_l0
000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`1Dooooo`?oo`3o2_ooool00ol0003oooooooooo`07
ooooo`?oo`3oEoooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Eoooo
o`?oo`3o2Oooool00ol0003oooooooooo`07ooooo`;oo`3oF?ooool00ol0003oooooooooo`0<oooo
o`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`1Fooooo`;oo`3o2Oooool00ol0003oooooooooo`06ooooo`?o
o`3oF?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05Kooooo0ooo0?l8ooooo`03o`00
0?oooooooooo00Gooooo0ooo0?mIooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000F?oo
ool3ool0o`Oooooo00?o0000ooooooooool01?ooool3ool0oeWooooo0_l0000>ooooo`008?ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`1Gooooo`Coo`3o1_ooool00ol0003oooooooooo`03ooooo`?oo`3oFoooool0
0ol0003oooooooooo`0<ooooo`006?ooool5o`0000?ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo01cooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00001?ooool00ol0003oooooooooo`1Iooooo`Coo`3o1?ooool00ol0003oooooooooo`02
ooooo`Coo`3oFoooool00ol0003oooooooooo`0<ooooo`006Oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0K
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Jooooo`Coo`3o0oooool00ol0003oooooooooo`04ool0oegooooo00?o0000ooooooooool0
3?ooool001[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Foooool<ool0oekooooo00?o0000ooooooooool0
3?ooool001_ooooo00?o0000ooooooooool00_ooool2o`0006Kooooo00?o0000ooooooooool0Hooo
ool2o`0001gooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`;o0000
GOooool:ool0oekooooo0_l0000>ooooo`006?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo1?oo0?l^oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<oooo
o`006?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`006Oooool3o`0000Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo01cooooo0_l00009ooooo`?o00001Oooooo9o`0000kooooo000Poooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo
00000?oooooo2Oooool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00003oooooo`Wooooo000Poooo
om3o0000ooooool9ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`009Oooool5o`0002gooooo0ol0000]ooooo`;o0000;_ooool3o`0002ko
oooo1Ol0003oooooo`cooooo000Vooooo`04o`000?ooooooooooo`0002kooooo00?o0000oooooooo
ool0:oooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo02kooooo00Co0000oooo
oooooooo0000=oooool3o`0000Cooooo0_l0000Yooooo`?o0000:oooool2o`0002gooooo0ol0000Y
ooooo`?o00001?ooool2o`00013ooooo000Oooooo`Go00000oooool00ol0003oooooooooo`0Voooo
o`Go00000oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00009oooool01Ol0003ooooooooooooooooo000002Wooooo00Co0000oooooooooooo
0000:oooool01Ol0003ooooooooooooooooo000002Wooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool0000?ooooo`00:?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
02_ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo02oooooo1Ol00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008Ooo
ool5o`0000Gooooo00?o0000ooooooooool09oooool01?l0003oooooooooool0000_ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000?ooooo`00
9Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool0:oooool01?l0003o
ooooooooool0000^ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00000h
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000:oooool00ol0003ooooooooo
o`0Wooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000oooooo000Uooooo`05o`000?ooooooooooooooool0
0000;Oooool2o`0002gooooo00Co0000oooooooooooo0000;Oooool2o`0002oooooo00Go0000oooo
ooooooooooooo`00000hooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00009ooo
ool4o`0002[ooooo00Co0000oooooooooooo0000:oooool4o`0002[ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000?ooooo`009_ooool3o`0002oooooo00?o0000ooooooooool0
;?ooool2o`0002oooooo00?o0000ooooooooool0;_ooool3o`0003Sooooo0_l00004ooooo`04o`00
0?ooooooooooo`0002Oooooo00?o0000ooooooooool0:oooool01?l0003oooooooooool0000[oooo
o`03o`000?oooooooooo02[ooooo0_l00004ooooo`04o`000?ooooooooooo`0000oooooo003ooooo
obKooooo00?o0000ooooooooool00oooool2o`0002Sooooo1Ol0000Zooooo`;o0000;?ooool5o`00
02Wooooo00?o0000ooooooooool00oooool2o`00013ooooo003oooooooWooooo003oooooooWooooo
000Pooooom3o0000ooooool9ooooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo00000?oooooo2Ooo
ool0023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`05o`000?oooooo
ooooooooool00000<Oooooo9o`0000kooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03?ooool001[ooooo0_l00004ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0Looooo`;o00001?ooool01?l0003oooooooooooooool5
o`0000Cooooo00?o0000ooooooooool0E?ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?oo`00ooooooooool0Doooool00ol0003oooooooooo`0<ooooo`006Oooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1Cooooo`;oo`003?ooool00ol0003oooooooooo`0:ooooo`;oo`00
EOooool00ol0003oooooooooo`0<ooooo`006Oooool01?l0003oooooooooool00003ooooo`;o0000
0ooooom;ool001Sooooo00?o0000ooooooooool05Ooooom<ool000;ooooo0_l0000Fooooo`Go0000
0_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l0001Cooooo`03
ool00?ooooooo`0000cooooo00?o0000ooooooooool02_ooool00ooo003oooooool0001Cooooo`;o
00003_ooool001Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`1<ooooo`03
ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03
o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05;ooooo00Coo`00ooooooooooooo`002oooool00ol0003oooooooooo`0:
ooooo`03ool00?ooooooo`0005Cooooo00?o0000ooooooooool03?ooool001Wooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000
ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo01_ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
D_ooool01?oo003ooooooooooooo000;ooooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooo
ooooooooool0001Cooooo`03o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo
01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo057ooooo00Go
o`00ooooooooooooooooool0000;ooooo`03o`000?oooooooooo00Wooooo00Goo`00oooooooooooo
ooooool0001Cooooo`03o`000?oooooooooo00cooooo000Jooooo`;o00001?ooool00ol0003ooooo
ooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003ooooo
ooooo`1<ooooo`03o`000?oooooooooo01cooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`1Aooooo`05ool00?oooooooooooooooooo00002oooool00ol0003oooooooooo`09ooooo`05
ool00?oooooooooooooooooo0000Doooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003o
ooooooooo`1<ooooo`03o`000?oooooooooo02oooooo0_l0001Booooo`05ool00?oooooooooooooo
oooo00002oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00;ooooo00?oo`00oooo
ooooool0D?ooool2o`0000kooooo000Pooooo`;o0000COooool00ooo003oooooooooo`0Fooooo`03
o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo057ooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1Aooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`1Aooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0
D?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool00?oo
oooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0D?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`03ooooo`03ool00?oo
oooooooo053ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0C?ooool0
0ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo053ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`1@ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
04cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo
04cooooo00?o0000ooooooooool0;oooool2o`00057ooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool00oooool00ooo
003oooooooooo`1?ooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0C?ooool00ooo003o
ooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo03oooooo0ooo000>ooooo`03ool00?oooooooooo00Co
oooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00?o
oooo00?oo`00ooooooooool03?ooool3ool0047ooooo00?o0000ooooooooool03?ooool0023ooooo
0_l0001=ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003ooooo
ooooo`1<ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0?_ooool2ool00003oooo
oooo003oo`0000cooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0<ooooo`04ool0
0?ooooooooooool0043ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0
C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0
C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03kooooo00Goo`00oooooooooooo
ooooool0000<ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02_ooool01Ooo003o
ooooooooooooooooo`00043ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooooooo
ool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02cooooo0ooo000>ooooo`03
ool00?oooooooooo00;ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`05ooooo`03
ool00?oooooooooo00Wooooo0_oo0004ooooo`03ool00?oooooooooo00cooooo0ooo000^ooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0
;oooool2o`0001_ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`02ool000gooooo
00?oo`00ooooooooool00oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool01oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00Gooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00_ooooo
0_oo0002ooooo`03ool00?oooooooooo00kooooo0_oo000Jooooo`;o00003_ooool0023ooooo00?o
0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo00?o
o`00ooooooooool03_ooool4ool000kooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02Oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01?ooool00ooo003ooooooooo
o`0:ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool03?ooool4ool0017ooooo00?o
o`00ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<
ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<
ooooo`03o`000?oooooooooo02Sooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo1_oo000=
ooooo`03ool00?oooooooooo00;ooooo0_oo000;ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`03ooooo`;oo`003?ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo00cooooo1Ooo0006ooooo`03o`000?oooooooooo00cooooo000Poooo
o`;o0000COooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool0C?ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00oooool2ool000Cooooo0_oo000;ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool02Oooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool01_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo00Oooooo0_oo0006
ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`09
ooooo`;oo`001?ooool2ool000Gooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooo
ooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool0C?ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool00_ooool2ool000Kooooo0_oo0009ooooo`;oo`001oooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`06
ooooo`03ool00?oooooooooo00Oooooo0_oo0007ooooo`03ool00?oooooooooo00Oooooo0_oo0006
ooooo`;oo`001?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<oooo
o`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<oooo
o`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00001?ooool5o`000003ool00?l0003o
000000Ko00000_oo0007o`0000;oo`002?l000000ooo003o0000o`000007o`000003ool00?l0003o
000000Oo000000?oo`00o`000?l000001_l000000ooo003o0000o`000006o`000003ool00?l0003o
000000Oo000000?oo`00o`000?l000001_l000000ooo003o0000o`00000@o`000003ool00?l0003o
000000Oo000000?oo`00o`000?l000001ol000000ooo003o0000o`000006o`000003ool00?l0003o
000000Oo000000?oo`00o`000?l000001_l00002ool000Oo00000_oo0008o`0000;oo`001ol00002
ool000So000000?oo`00o`000?l000000ol0000>ooooo`008?ooool00ol0003oooooooooo`1<oooo
o`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<oooo
o`03o`000?oooooooooo02Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0<
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`07
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`05
ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooo
ooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooo
ooooool0C?ooool00ol0003oooooooooo`0Wooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool03Oooool2ool000Cooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`03
ooooo`03ool00?oooooooooo00Wooooo0_oo0006ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?oo`00
ooooooooool02?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Sooooo0_oo0005
ooooo`;oo`002oooool2ool000Cooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000oooo
ooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo02Sooooo0_l00005oooo
o`03o`000?oooooooooo00kooooo1Ooo000=ooooo`;oo`000oooool2ool000cooooo00?oo`00oooo
ooooool01?ooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo00Gooooo00?oo`00oooo
ooooool02?ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?oo`00oooo
ooooool02?ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooo
ooooool00oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00;ooooo0_oo000=oooo
o`Goo`004?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0004gooooo00?oo`00oooooooo
ool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0Qooooo`Goo`003Oooool2ool000Cooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool01?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo00;ooooo0_oo000=ooooo`Go
o`008oooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool0
0?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`00
0?oooooooooo02oooooo0_l0000Tooooo`03ool00?oooooooooo00kooooo00Goo`00oooooooooooo
ooooool0000=ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02?ooool00ooo003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool02?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo00[ooooo0_oo0003ooooo`03ool00?oooooooooo00ko
oooo00?oo`00ooooooooool08_ooool2o`0000kooooo000Pooooo`03o`000?oooooooooo04cooooo
00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0eooooo`Coo`003Oooool00ooo003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool00oooool00ooo003ooooo
ooooo`0;ooooo`Coo`00=oooool00ol0003oooooooooo`0<ooooo`003_ooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Cooooo00?o0000ooooooooool0C?ooool00ooo003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo03Kooooo0_oo000?ooooo`03ool00?oooooooooo00;ooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
o`00ooooooooool02Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo00cooooo0_oo
000hooooo`03o`000?oooooooooo00cooooo000=ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`17ooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo04Oooooo00?o0000ooooooooool0
3?ooool000gooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooooooool2o`0004go
oooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04_o
oooo0_l0000aooooo`;o0000B?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`16ooooo`;o00003_ooool000gooooo
00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooooooo000004kooooo00?oo`00oooo
ooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`18ooooo`03ool00?oooooooooo00;oo`003?ooool00ooo
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool02_ooool01?oo
003ooooooooooooo001:ooooo`03o`000?oooooooooo00cooooo000=ooooo`04o`000?oooooooooo
o`0000Oooooo1?l00004ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool05_ooool0
0ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`18ooooo`04ool00?ooooooooooool000gooooo00?oo`00ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00[ooooo00Coo`00ooooooooooooo`00
B_ooool00ol0003oooooooooo`0<ooooo`003Oooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo04Wooooo0ooo000=ooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ooo003oooooooooo`0;ooooo`;oo`00Boooool00ol0003oooooooooo`0<ooooo`003_oo
ool2o`0000Sooooo1Ol00003ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool05_oo
ool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo04cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooo
oooo04cooooo00?o0000ooooooooool0;oooool2o`0005[ooooo00?oo`00ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo05Sooooo0_l0000>ooooo`008?ooool2o`00
04gooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo
04cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo
00cooooo000Pooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool05_ooool00ol0003o
ooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ooo003o
ooooooooo`1Iooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo04cooooo
00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo
00?o0000ooooooooool07?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol00004ooooo`03
o`000?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo05Wooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0
C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0
C?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00cooooo000Pooooo`03
o`000?oooooooooo04cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03
ool00?oooooooooo04cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00Cooooo0_l0001Jooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`1Hooooo`;o00003_ooool0023ooooo00?o0000oooooooo
ool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooooooo
ool0C?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Iooooo`03ool00?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ooo003oooooooooo`1Iooooo`03o`000?oooooooooo00cooooo000Pooooo`;o
0000COooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooooooo
ool0C?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo05Wooooo00?oo`00ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo
01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05Wooooo00?o
o`00ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo05Wooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0F
ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0L
ooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0FOooool00ooo003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0FOooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000oooo
ooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo02oooooo0_l0001Koooo
o`03ool00?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1Hoooo
o`;o00003_ooool0023ooooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03
o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo05[ooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
ool00?oooooooooo05Wooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0
C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0
C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05[ooooo00?oo`00ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo05Wooooo00?o0000ooooooooool0
3?ooool0023ooooo0_l0001=ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Ooo
ool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0F_oo
ool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0F_oo
ool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<ooooo`03ool00?oooooo
oooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool0F_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0
003oooooooooo`1<ooooo`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo
003oooooooooo`1<ooooo`03o`000?oooooooooo02oooooo0_l0001Kooooo`03ool00?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`1Iooooo`;o00003_ooool0023o
oooo00?o0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Go
oooo00?oo`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05[o
oooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05[o
oooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0C?ooool00ooo003ooooo
ooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool0C?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo05[ooooo00?oo`00ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo05[ooooo00?o0000ooooooooool03?ooool0023ooooo00?o
0000ooooooooool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o
o`00ooooooooool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05[ooooo00?o
o`00ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05[ooooo00?o
0000ooooooooool03?ooool0023ooooo0_l0001=ooooo`03ool00?oooooooooo01Kooooo00?o0000
ooooooooool05Oooool00ooo003oooooooooo`1<ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0F_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oo`00
ooooooooool0F_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1<oooo
o`03ool00?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`1<oooo
o`03o`000?oooooooooo02oooooo0_l0001Kooooo`03ool00?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ooo003oooooooooo`1Iooooo`;o00003_ooool0023ooooo00?o0000oooooooo
ool0C?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?oo`00oooooooo
ool0C?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05[ooooo00?oo`00oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo05[ooooo00?o0000oooooooo
ool03?ooool001Wooooo0ol00004ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03ool00?oooooooooo04cooooo00?o0000ooooooooool0
7?ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0
F_ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0
F_ooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04cooooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03ool00?oo
oooooooo04cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0F_ooool00ooo003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?oo`00ooooooooool0F_ooool00ol0003oooooooooo`0<ooooo`006_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo00?oo`00ooooooooool05_oo
ool00ol0003oooooooooo`0Eooooo`;oo`00COooool00ol0003oooooooooo`0Kooooo`04o`000?oo
ooooooooo`0000Oooooo1Ol00004ooooo`03o`000?oooooooooo05[ooooo00?oo`00ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0
3?ooool001[ooooo00?o0000ooooooooool00oooool2o`0004gooooo<_oo001=ooooo`;o00007Ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo0_l0001Kooooo`03
ool00?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Jooooo`;o
00003_ooool001[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Uooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool0Foooool00ooo003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0<ooooo`00
6Oooool2o`0000Gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo01_ooooo00Co0000oooooooooooo00002Oooool2o`0000Gooooo00?o0000oooooooo
ool0Foooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool0Foooool00ol0003oooooooooo`0<ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`;o0000
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool0
3?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo02oooooo0_l0001Looooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ooo003oooooooooo`1Jooooo`;o00003_ooool0023ooooo0_l0001Vooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Kooooo`03ool00?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Kooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool03?ooool0023o
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0Foooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`1Kooooo`03ool00?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ooo003ooooo
ooooo`1Kooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000G?ooool00ooo003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0F_ooool2o`0000kooooo000P
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo05_ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo05_ooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Voooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Loooo
o`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`1Koooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05cooooo00?oo`00oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo05_ooooo00?o0000oooooooo
ool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?oo`00ooooooooool0Foooool00ol0003oooooooooo`0<ooooo`008?oo
ool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;ooo
ool2o`0005gooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03ool00?oo
oooooooo05_ooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Looooo`03ool00?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1Looooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Looooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0
003oooooooooo`1Looooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ooo
003oooooooooo`1Looooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000I_ooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool06oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ooo003oooooooooo`1Looooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Oooooo1?l00005ooooo`;o0000GOooool00ooo003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?oo`00ooooooooool0Foooool2o`0000kooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Looooo`03ool00?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`1Looooo`03o`000?oo
oooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool0
0ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Looooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ooo003oooooooooo`1Looooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Looooo`;o00002_ooool2
o`0000Gooooo00?o0000ooooooooool0G?ooool00ooo003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?oo`00ooooooooool0G?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`00
06Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
05cooooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo
05cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo02oooooo0_l0001Mooooo`03ool00?oooooooooo00;o
oooo00Go0000ooooooooooooooooool0001Nooooo`;o00003_ooool0023ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0G?ooool00ooo003oooooooooo`02ooooo`05o`000?oooooooooooooooooo0000Goooool00ol0
003oooooooooo`0<ooooo`003Oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Co
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0GOooool01Ooo003ooooooooooooooooo000000?ooooo00?oo`00oooo
ooooool0GOooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003oooooooooo`07ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Mooooo`05ool00?oooooooooo
ooooool000000oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00001Wooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Mooooo`05ool00?oooooo
ooooooooool000000oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00cooooo000>
ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooooooo0_l0001Vooooo`03o`000?oo
oooooooo06?ooooo0_l0000aooooo`;o0000G_ooool01Ooo003ooooooooooooooooo000000?ooooo
00?oo`00ooooooooool0G?ooool2o`0000kooooo000>ooooo`03o`000?oooooooooo00Oooooo1?l0
0004ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo05gooooo00Goo`00ooooooooooooooooo`000003ooooo`03ool0
0?oooooooooo05gooooo00?o0000ooooooooool03?ooool000gooooo0_l00009ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0GOooool01Ooo003ooooooooooooooooo000000?ooooo
00?oo`00ooooooooool0GOooool00ol0003oooooooooo`0<ooooo`003_ooool00ol0003ooooooooo
o`07ooooo`Go00000oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`1Mooooo`05ool00?ooooooooooooooool00000
0oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oo
oooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o0000G_oo
ool01Ooo003ooooooooooooooooo000000?ooooo00?oo`00ooooooooool0G?ooool2o`0000kooooo
000Pooooo`;o0000I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0GOooool01Ooo003ooooooooooooooooo000000?ooooo00?oo`00ooooooooool0
GOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Mooooo`05ool00?oo
ooooooooooooool000000oooool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00cooooo
000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`0Looooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooooooo
o`1Nooooo`04ool00?ooooooooooo`0000?ooooo00?oo`00ooooooooool0GOooool00ol0003ooooo
ooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool06oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`1Nooooo`04ool00?ooooooooooo`0000?ooooo00?oo`00oooo
ooooool0GOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001?ooool2o`0005oooooo00Coo`00oooooooooooo00000_oo
ool00ooo003oooooooooo`1Mooooo`;o00003_ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?oo
ool3o`0000Gooooo00?o0000ooooooooool0G_ooool01?oo003oooooooooool00002ooooo`03ool0
0?oooooooooo05kooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Vooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Nooooo`04ool00?ooooooooooo`00
00;ooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool06oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1N
ooooo`04ool00?ooooooooooo`0000;ooooo00?oo`00ooooooooool0G_ooool00ol0003ooooooooo
o`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool07?ooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo05kooooo00Coo`00
oooooooooooo00000_ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000P
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_
ooooo`;o0000Goooool01?oo003oooooooooool00002ooooo`03ool00?oooooooooo05gooooo0_l0
000>ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`1Nooooo`04ool00?ooooooooooo`0000;ooooo00?o
o`00ooooooooool0G_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1N
ooooo`04ool00?ooooooooooo`0000;ooooo00?oo`00ooooooooool0G_ooool00ol0003ooooooooo
o`0<ooooo`008?ooool2o`0006Kooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo05kooooo00Coo`00oooooooooooo00000_ooool00ooo003ooooooooo
o`1Nooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05oooooo00?oo`00
ooooool000000_ooool00ooo003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo000Poooo
o`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_oooo
o`;o0000H?ooool00ooo003oooooo`000002ooooo`03ool00?oooooooooo05gooooo0_l0000>oooo
o`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`1Oooooo`05ool00?oooooo0000oooooooo0000HOooool00ol0
003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Oooooo`05ool00?oooooo0000oooo
oooo0000HOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Oooooo`05
ool00?oooooo0000oooooooo0000HOooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Ko
oooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05oo
oooo00Goo`00ooooool0003oooooool0001Qooooo`03o`000?oooooooooo00cooooo000Pooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0_ooooo`;o
0000H?ooool01Ooo003oooooo`000?ooooooo`00063ooooo0_l0000>ooooo`008?ooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`1Oooooo`04ool00?oooooo0000ool006;ooooo00?o0000ooooooooool03?ooool001So
oooo1Ol00003ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0Wooooo`?o00001Oooool00ol0003oooooooooo`1Pooooo`03ool00?l0003oo`0006;o
oooo00?o0000ooooooooool03?ooool001Wooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo063ooooo00?oo`00o`000?oo0000H_ooool00ol0003o
ooooooooo`0<ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0H?ooool3ool006;ooooo00?o0000ooooooooool03?ooool001_ooooo00?o
0000ooooooooool00_ooool2o`0006Kooooo00?o0000ooooooooool0Hoooool2o`0002[ooooo00?o
0000ooooooooool01?ooool2o`0006;ooooo00?oo`00ooooooooool0H?ooool2o`0000kooooo000H
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00cooooo000Hooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool09oooool2o`0000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`006Oooool3o`0000Cooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01?ooooo9o`0000kooooo000Pooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0;oooool01Ol0003ooooooooooooooooo00000?oooooo2Oooool0023ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`00003oooooo`Wooooo000Pooooom3o0000ooooool9ooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00
oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooolOooooo`?o00001?ooool2o`00
02_ooooo0ol0000/ooooo`;o0000;_ooool3o`0002_ooooo0ol00004ooooo`;o00004?ooool002Go
oooo1Ol0000]ooooo`?o0000;Oooool2o`0002kooooo0ol0000^ooooo`Go0000<_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0002Wooooo00Go0000ooooooooooooooooo`00000Z
ooooo`04o`000?ooooooooooo`0002cooooo00Go0000ooooooooooooooooo`00000[ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00003oooool002Kooooo00Co0000oooooooooooo
0000;_ooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0002kooooo00?o0000oooo
ooooool0;_ooool01?l0003oooooooooool0000Zooooo`Go00000oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0002?ooooo1Ol00005ooooo`03o`000?oooooooooo02Sooooo00Co
0000oooooooooooo0000<?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00003oooool001oooooo1Ol00003ooooo`03o`000?oooooooooo02Kooooo
1Ol00003ooooo`03o`000?oooooooooo02_ooooo00Co0000oooooooooooo0000;_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooool0000]ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000<?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00003ooo
ool002Sooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0[ooooo`04o`000?oooooo
ooooo`0002kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo0000:Oooool4o`0002_ooooo00Co0000oooooooooooo
0000;?ooool4o`0002cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000?oooo
o`009Oooool01Ol0003ooooooooooooooooo000002kooooo00?o0000ooooooooool0:oooool01?l0
003oooooooooool0000^ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00
000aooooo`;o00001?ooool01?l0003oooooooooool0000Yooooo`03o`000?oooooooooo02cooooo
00Co0000oooooooooooo0000;?ooool00ol0003oooooooooo`0/ooooo`;o00001?ooool01?l0003o
ooooooooool0000?ooooo`009Oooool01Ol0003ooooooooooooooooo000002gooooo0_l0000]oooo
o`04o`000?ooooooooooo`0002gooooo0_l0000_ooooo`05o`000?ooooooooooooooool00000<_oo
ool00ol0003oooooooooo`03ooooo`;o0000:_ooool5o`0002_ooooo0_l0000]ooooo`Go0000:ooo
ool00ol0003oooooooooo`03ooooo`;o00004?ooool002Kooooo0ol0000_ooooo`03o`000?oooooo
oooo02cooooo0_l0000_ooooo`03o`000?oooooooooo02kooooo0ol0003oooooo`gooooo003ooooo
ooWooooo003oooooooWooooo003oooooooWooooo003ooooooacooooocol0000>ooooo`008?ooooo@
o`0002_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Mooooo`03o`00oooooooooooo00Cooooo00?o0000oooo
ooooool01?ooool2o`00oekooooo00?o0000ooooooooool03?ooool001[ooooo0_l00004ooooo`03
o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo05gooooo0_l00?l5ooooo`03o`000?oooooooooo00Cooooo0_l00?mNooooo`03
o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo0_l0001Mooooo`03
o`00oooooooo003o00Gooooo00?o0000ooooooooool01?ooool2o`00oekooooo00?o0000oooooooo
ool03?ooool001Wooooo00Co0000oooooooooooo00000oooool2o`0000?ooooo<ol00?l`ooooo`03
o`000?oooooooooo02kooooo<ol00?l2ooooo`;o0000:oooool00ol0003oooooooooo`1Looooo`03
o`00oooooooo003o00Gooooo00?o0000ooooooooool00oooool00ol00?ooooooo`00o`1Nooooo`03
o`000?oooooooooo00cooooo000Iooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05cooooo00?o003oooooool0
0?l01Oooool00ol0003oooooooooo`03ooooo`03o`00oooooooo003o05kooooo00?o0000oooooooo
ool03?ooool001Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`0cooooo`03
o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0G?ooool00ol00?ooooooo`00o`05ooooo`03
o`000?oooooooooo00?ooooo00?o003oooooool00?l0G_ooool00ol0003oooooooooo`0<ooooo`00
6Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo03?ooooo00?o003ooooooooo
ool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1Looooo`03o`00oooooooo003o00Gooooo00?o0000oooooooo
ool00oooool01?l00?ooooooooooool00?mMooooo`03o`000?oooooooooo00cooooo000Jooooo`;o
00001?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000oooooooo
ool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo0_l0001Mooooo`03
o`00oooooooo003o00Gooooo00?o0000ooooooooool00oooool01?l00?ooooooooooool00?mMoooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003ooooooooo
ool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1Looooo`03o`00oooooooo003o00Gooooo00?o0000oooooooo
ool00oooool01?l00?ooooooooooool00?mMooooo`03o`000?oooooooooo00cooooo000Pooooo`;o
0000=?ooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05cooooo00?o003oooooool0
0?l01Oooool00ol0003oooooooooo`03ooooo`04o`00ooooooooooooo`00oegooooo00?o0000oooo
ooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03
o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo05cooooo00?o003oooooool00?l01Oooool00ol0003oooooooooo`03ooooo`04
o`00ooooooooooooo`00oegooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05_ooooo00Co003ooooooooo
oooo003o1Oooool00ol0003oooooooooo`03ooooo`04o`00ooooooooooooo`00oegooooo00?o0000
ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_oooo
o`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yoooo
o`;o0000E?ooool00ol00?ooooooooooo`05ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol0003oooooooooo`03ooooo`04o`00ooooooooooooo`00o`Oooooo0_l00?mDooooo`03o`000?oo
oooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool0
0ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`1Cooooo`;o003o1_ooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Oooooo0_l00?mDooooo`03o`00
0?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;ooo
ool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1Booooo`03o`00oooooooo003o00Kooooo00Go003ooooooooooooooooo
o`00o`04ooooo`03o`000?oooooooooo00;ooooo00Go003oooooooooooooooooo`00o`06ooooo`03
o`00oooooooo003o05Cooooo00?o0000ooooooooool03?ooool0023ooooo0_l0000dooooo`03o`00
oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0D_ooool00ol00?ooooooo`00o`06ooooo`05o`00
ooooooooooooooooool00?l01?ooool00ol0003oooooooooo`02ooooo`05o`00oooooooooooooooo
ool00?l01_ooool00ol00?ooooooo`00o`1Dooooo`03o`000?oooooooooo00cooooo000Pooooo`03
o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03
o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`19ooooo`;o
003o1oooool01?l00?ooooooooooool00?l5ooooo`05o`00ooooooooooooooooool00?l01?ooool0
0ol0003oooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01_ooool00ol00?ooooooo`00
o`07ooooo`?o003oB_ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`0c
ooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0c
ooooo`03o`000?oooooooooo02Wooooo0_l00011ooooo`03o`00oooooooooooo00Gooooo0ol00?l6
ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00Cooooo
00?o0000ooooooooool00_ooool01Ol00?oooooooooooooooooo003o00Kooooo00Co003ooooooooo
oooo003o1_ooool00ol00?ooooooo`00o`08ooooo`03o`00oooooooooooo03oooooo00?o0000oooo
ooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03
o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Gooooo0_l00?l7ooooo`?o003o1oooool01?l00?ooooooooooool00?l5oooo
o`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00Cooooo00?o
0000ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00?ooooo00Co
003ooooooooooooo003o1_ooool00ol00?ooooooo`00o`07ooooo`?o003o2?ooool00ol00?oooooo
ooooo`0eooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o
003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o
0000ooooooooool08_ooool2o`0000Gooooo00?o0000ooooooooool06?ooool00ol00?oooooooooo
o`06ooooo`;o003o2?ooool2o`00o`Oooooo1?l00?l6ooooo`04o`00oooooooo003oo`00o`Kooooo
00Co003ooooooooooooo003o1Oooool01Ol00?oooooooooooooooooo003o00Gooooo00Go003ooooo
ooooooooooooo`00o`04ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool0
0ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01_ooool01?l00?oooooooooo
ool00?l5ooooo`;o003o00?oooooo`00ooooool01_ooool3o`00o`Oooooo0ol00?l7ooooo`;o003o
2?ooool2o`00oaWooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<ooo
ool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<ooo
ool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0oooool3o`00o`Oooooo0ol00?l7ooooo`?o003o1oooool3o`00o`Kooooo00Co003ooooooooooooo
003o1_ooool01?l00?ooooooooooool00?l6ooooo`04o`00ooooooooooooo`00o`Gooooo00Go003o
ooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01?ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`05
o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00Gooooo00?o003o
ooooooooool00_l00?l5ooooo`;o003o00?oooooo`00ooooool01Oooool4o`00o`Kooooo1?l00?l6
ooooo`?o003o1oooool3o`00o`Gooooo00?o0000ooooooooool03?ooool0023ooooo0_l0000doooo
o`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0coooo
o`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02
ooooo`;o003o00?oooooo`00ool00?l01Oooool2o`00o`;ooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`02o`00o`Gooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool00?l01?ooool01?l00?ooooooooooooooool2o`00o`Cooooo00?o003ooooooooo
ool00_ooool00ol00?ooooooooooo`02ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol0
0?oooooooooooooooooo003o00Cooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`03o`00oooooooooooo00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool00?l01?ooool2o`00o`?ooooo00?o003oooooooooool00_ooool2o`00o`;ooooo
0_l00?l4ooooo`;o003o0_ooool00ol00?ooooooooooo`03ooooo`;o003o00?oooooo`00ool00?l0
1Oooool2o`00o`03ooooool00?oo003o00Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o
0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o
003oooooooooool0<oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Cooooo
1Ol000000ol00?oo0000o`000002o`000004o`00ool0003o0000o`0000;o003o0ol00002o`00o`?o
000000?o003oo`000?l000000ol000001Ol00?oo0000o`000?l0003o003o00Co00000_l00?l3o`00
0003o`00ool0003o000000;o000000?o003oo`000?l000000_l000000ol00?oo0000o`000002o`00
0003o`00ool0003o000000;o000000?o003oo`000?l000000_l000000ol00?oo0000o`000002o`00
0005o`00ool0003o0000o`000?l00?l01Ol000001Ol00?oo0000o`000?l0003o003o00Co000000?o
003oo`000?l000000_l000000ol00?oo0000o`000007o`000003o`00ool0003o000000;o000000?o
003oo`000?l000000_l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o
003oo`000?l000000_l000000ol00?oo0000o`000002o`000005o`00ool0003o0000o`000?l00?l0
1?l000000ol00?oo0000o`000002o`000003o`00ool0003o000000;o000000?o003oo`000?l00000
0_l00002o`00o`?o000000?o003oo`000?l000000_l000001?l00?oo0000o`000?l00002o`00o`Co
000000Co003oo`000?l0003o00000_l00?l4o`000004o`00ool0003o0000o`0000;o003o0ol00000
0ol00?oo0000o`000003o`0000kooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003ooooo
ooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000oooo
ooooool08Oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Sooooo1?l00?l6
ooooo`Co003o1Oooool2o`00o`03ooooool00?oo003o00Gooooo00Co003ooooooooooooo003o1_oo
ool01?l00?ooooooooooool00?l6ooooo`03o`00oooooooooooo00;o003o1?ooool01Ol00?oooooo
oooooooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooooooooooo
ooooool00?l01?ooool00ol00?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool00_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooo
oooooooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`05ooooo`04o`00oooooooooooo
o`00o`Kooooo00Co003ooooooooooooo003o1_ooool4o`00o`Gooooo1Ol00?l9ooooo`03o`000?oo
oooooooo00cooooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool0
0ol0003oooooooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool08Oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo01?ooooo0_l00?l7ooooo`?o003o1ooo
ool3o`00o`Kooooo1?l00?l6ooooo`04o`00ooooooooooooo`00o`Gooooo00Go003ooooooooooooo
ooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo
003o00Cooooo00?o003oooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00oooooooo
oooo00;ooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00ooooooooooooooooool00?l0
1Oooool01Ol00?oooooooooooooooooo003o00Kooooo00?o003oooooool00?l01_ooool2o`00o`03
ooooool00?oooooo00Gooooo1?l00?l6ooooo`?o003o2?ooool2o`00oaCooooo00?o0000oooooooo
ool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`00
0?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Rooooo`;o0000
1Oooool00ol0003oooooooooo`0`ooooo`;o003o1oooool3o`00o`Oooooo00Co003ooooooooooooo
003o1Oooool01Ol00?oooooooooooooooooo003o00Gooooo00Go003oooooooooooooooooo`00o`04
ooooo`03o`00oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`02
ooooo`05o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo003o00Kooooo
00Co003ooooooooooooo003o1_ooool3o`00o`Oooooo0_l00?lbooooo`03o`000?oooooooooo00co
oooo000Pooooo`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0jooooo`;o003o1oooool3o`00o`Oooooo00Co003ooooooooooooo003o1Oooool01Ol00?oo
oooooooooooooooo003o00Gooooo00Go003oooooooooooooooooo`000004ooooo`03o`00oooooooo
oooo00?ooooo00Co003ooooooooooooo003o1_ooool01?l00?ooooooooooool00?l6ooooo`?o003o
2?ooool00ol00?ooooooooooo`0jooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000=?oo
ool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<ooo
ool00ol0003oooooooooo`0Yooooo`;o0000AOooool2o`00o`Oooooo00?o003oooooool00?l01_oo
ool01Ol00?oooooooooooooooooo003o00Gooooo00Go003oooooooooooooooooo`000004ooooo`03
o`00oooooooooooo00?ooooo00Co003ooooooooooooo003o1_ooool00ol00?ooooooo`00o`08oooo
o`03o`00oooooooooooo04Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04gooooo0ol00?l6ooooo`05
o`00ooooooooooooooooool00?l01Oooool01Ol00?oooooooooooooooooo000000Cooooo00?o003o
ooooooooool00oooool01?l00?ooooooooooool00?l6ooooo`?o003oCoooool00ol0003ooooooooo
o`0<ooooo`008?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000
ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0C_ooool2o`00o`Kooooo00Go003oooooooooooooooooo`00o`05ooooo`05o`00oooo
ooooooooooooool000001?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00o`Oo
oooo0_l00?m?ooooo`03o`000?oooooooooo00cooooo000>ooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo
00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0E_ooool01?l00?ooooooooooool00?l6ooooo`05o`00oooooooooooooooo
ool000001?ooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooooooo`00oeSooooo00?o0000
ooooooooool03?ooool000gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oo
oooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo05Oooooo00?o003oooooool00?l01_ooool01Ol00?oooooooooooooooooo000000Cooooo
00?o003oooooooooool00oooool01?l00?ooooooooooool00?mHooooo`03o`000?oooooooooo00co
oooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooooooo0_l0000doooo
o`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0boooo
o`;o0000:oooool2o`0005Sooooo00?o003oooooool00?l01_ooool01Ol00?oooooooooooooooooo
000000Cooooo00?o003oooooooooool00oooool00ol00?ooooooo`00o`1Iooooo`03o`000?oooooo
oooo00cooooo000=ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00
000eooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?oooooooooo
o`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Eoooool00ol00?ooooooo`00
o`06ooooo`05o`00ooooooooooooooooool000001?ooool00ol00?ooooooooooo`04ooooo`;o003o
FOooool00ol0003oooooooooo`0<ooooo`003Oooool01?l0003oooooooooool00007ooooo`Co0000
1?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0
;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
Eoooool3o`00o`Kooooo00Go003oooooooooooooooooo`000004ooooo`03o`00oooooooooooo00Co
oooo0_l00?mIooooo`03o`000?oooooooooo00cooooo000=ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oo
oooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0F?ooool00ol00?ooooooooooo`05ooooo`05o`00oooooooooooooooo
ool000001?ooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo05Sooooo00?o0000oooo
ooooool03?ooool000kooooo0_l00008ooooo`Go00000oooool00ol0003oooooooooo`0cooooo`03
o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooooooo0000
00Cooooo00?o003oooooooooool0Goooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?oo
ooooooooo`0cooooo`03o`000?oooooooooo02Wooooo0_l0001Qooooo`05o`00oooooooooooooooo
ool000000oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`;o
0000=?ooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo063ooooo00Go003ooooooooo
ooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool03?ooool0023o
oooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02ko
oooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo063o
oooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000oooo
ooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03
o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooooooo
063ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?oo
ooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`000003oooo
o`03o`00oooooooooooo063ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000oooooooo
ool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003ooooooooo
ool0<oooool00ol0003oooooooooo`0Yooooo`;o0000HOooool01Ol00?oooooooooooooooooo0000
00?ooooo00?o003oooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?oo
ooooooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H?ooool01Ol00?oo
oooooooooooooooo000000?ooooo00?o003oooooooooool0H?ooool00ol0003oooooooooo`0<oooo
o`008?ooool2o`0003Cooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03
o`00oooooooooooo03?ooooo00?o0000ooooooooool05_ooool2o`0000Cooooo00?o0000oooooooo
ool00_ooool3o`0000Gooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooooooo0000
00?ooooo00?o003oooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003o
ooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?oo
ooooooooo`0cooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0H?ooool01Ol00?oooooooooooooo
oooo000000?ooooo00?o003oooooooooool0H?ooool00ol0003oooooooooo`0<ooooo`008?ooool0
0ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oooooo00?o0000ooooooooool0;_ooool0
0ol00?ooooooooooo`0cooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo063ooooo00Go003ooooooooooooooooo
o`000003ooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool03?ooool0023ooooo00?o
0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o
003oooooooooool0<oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool00_ooool2o`00067ooooo00Go003oooooooooooooooooo`000003ooooo`03
o`00oooooooooooo05oooooo0_l0000>ooooo`008?ooool00ol0003oooooooooo`0cooooo`03o`00
oooooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`00
0?oooooooooo01Gooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo00?o0000oooooooo
ool0H?ooool01Ol00?oooooooooooooooooo000000?ooooo00?o003oooooooooool0H?ooool00ol0
003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo02oo
oooo00?o0000ooooooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo01Go
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
063ooooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000
ooooooooool03?ooool0023ooooo0_l0000dooooo`03o`00oooooooooooo02oooooo00?o0000oooo
ooooool0;_ooool00ol00?ooooooooooo`0cooooo`03o`000?oooooooooo01Kooooo0_l00008oooo
o`Go00001?ooool00ol0003oooooooooo`1Pooooo`05o`00ooooooooooooooooool000000oooool0
0ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo
03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Pooooo`05o`00oooooooooooo
ooooool000000oooool00ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Poooo
o`03o`000?oooooooooo03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^oooo
o`03o`00oooooooooooo03?ooooo00?o0000ooooooooool0:Oooool2o`00067ooooo00Go003ooooo
ooooooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo
02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
063ooooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooooooo063ooooo00?o0000
ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_oooo
o`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo063ooooo00Go003oooooooooooooooooo`000003ooooo`03o`00oooooooo
oooo063ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0<oooool00ol0
0?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000oooool0
0ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000=?ooool00ol0
0?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000oooool0
0ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo
03?ooooo00?o0000ooooooooool0:Oooool2o`0006;ooooo00Co003ooooooooooooo00000oooool0
0ol00?ooooooooooo`1Pooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
03?ooooo00?o003oooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00oooooooooooo
03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Qooooo`04o`00oooooooooooo
o`0000;ooooo00?o003oooooooooool0HOooool00ol0003oooooooooo`0<ooooo`006Oooool3o`00
00Cooooo00?o0000ooooooooool0<oooool00ol00?ooooooooooo`0_ooooo`03o`000?oooooooooo
02kooooo00?o003oooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
067ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool00ol0
0?ooooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool0<oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0<oooool2o`00oc3ooooo00?o0000ooooooooool0;_ooool00ol0
0?ooooooooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0HOooool01?l0
0?ooooooooooool00002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
01[ooooo00?o0000ooooooooool00oooool2o`0003CoooooI?l00?ldooooo`;o0000:oooool2o`00
06;ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0HOooool01?l0
0?ooooooooooool00002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
01Wooooo0_l00005ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0HOooool01?l00?ooooooooooool00002ooooo`03o`00oooooooo
oooo067ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0HOooool01?l0
0?ooooooooooool00002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
023ooooo0_l0001Vooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool2o`00
06;ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Qooooo`?o00001Oooool00ol0
003oooooooooo`1Qooooo`04o`00ooooooooooooo`0000;ooooo00?o003oooooooooool0HOooool0
0ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
067ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0HOooool01?l0
0?ooooooooooool00002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool01?ooool2o`0006;ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Pooooo`;o00003_ooool0023ooooo0_l0001Vooooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
067ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Qooooo`;o00001_ooool00ol0003oooooooooo`1Qooooo`04o`00oooooooooooo
o`0000;ooooo00?o003oooooooooool0HOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0
003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo067ooooo00Co003ooooooooooooo00000_ooool0
0ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
067ooooo00Co003ooooooooooooo00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooo
oooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`0Yooooo`;o0000Hoooool00ol00?ooooooo`000002ooooo`03o`00oooooooooooo
067ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H_ooool00ol00?oo
ooooo`000002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0023ooooo
0_l0001Vooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1Rooooo`03o`00oooooooo000000;ooooo00?o003oooooooooool0HOooool00ol0003ooooo
ooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1Rooooo`03o`00oooooooo000000;ooooo00?o
003oooooooooool0HOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1U
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1R
ooooo`03o`00oooooooo000000;ooooo00?o003oooooooooool0HOooool00ol0003oooooooooo`0<
ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0:Oooool2o`0006?ooooo00?o003oooooool000000_ooool00ol00?ooooooooooo`1Qoooo
o`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000oooooooo
ool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06;ooooo00?o003oooooool0
00000_ooool00ol00?ooooooooooo`1Qooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`00
0?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo06;ooooo00?o003oooooool000000_ooool00ol00?ooooooooooo`1Qooooo`03o`00
0?oooooooooo00cooooo000Pooooo`;o0000I_ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0H_ooool00ol00?ooooooo`000002ooooo`03o`00oooo
oooooooo067ooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H_ooool0
0ol00?ooooooo`000002ooooo`03o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02Wooooo0_l0001Sooooo`03o`00oooooooo000000;ooooo00?o003oooooooooool0HOooool00ol0
003oooooooooo`0<ooooo`003Oooool3o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Co
oooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0H_ooool00ol00?ooooooo`000002ooooo`03o`00oooooooooooo067o
oooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool01oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0H_ooool00ol00?ooooooo`000002ooooo`03
o`00oooooooooooo067ooooo00?o0000ooooooooool03?ooool000kooooo00?o0000ooooooooool0
2oooool01Ol0003ooooooooooooooooo000006Oooooo00?o0000ooooooooool0I?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo06;ooooo00Go003oooooool0003oooooo`00o`1Toooo
o`03o`000?oooooooooo00cooooo000>ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooo
oooooooo0_l0001Vooooo`03o`000?oooooooooo06?ooooo0_l0000[ooooo`03o`000?oooooooooo
06;ooooo00Go003oooooool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000>oooo
o`03o`000?oooooooooo00Oooooo1?l00004ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0Yooooo`;o0000Hoooool01Ol00?ooooooo`000?oooooo
003o06Cooooo00?o0000ooooooooool03?ooool000gooooo0_l00009ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0H_ooool01Ol00?ooooooo`000?oooooo003o06Cooooo00?o0000
ooooooooool03?ooool000kooooo00?o0000ooooooooool01oooool5o`0000?ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Gooooo0ol00004oooo
o`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo06;ooooo00Go003ooooo
ool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo06;ooooo00Go003o
ooooool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Rooooo`05o`00oooooooo
0000ooooool00?l0I?ooool00ol0003oooooooooo`0<ooooo`008?ooool2o`0006Kooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00_ooool2o`0006?ooooo00Go003oooooool0003oooooo`00o`1Sooooo`;o00003_oo
ool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01oooool4o`0000Gooooo00?o0000ooooooooool0H_ooool0
1Ol00?ooooooo`000?oooooo003o06Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000
ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Gooooo0_l00009
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0H_ooool01Ol00?ooooooo`000?oo
oooo003o06Cooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool5
o`0000Cooooo00?o0000ooooooooool0H_ooool01Ol00?ooooooo`000?oooooo003o06Cooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0H_ooool01Ol00?ooooooo`000?oo
oooo003o06Cooooo00?o0000ooooooooool03?ooool0023ooooo0_l0001Vooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0:Oooool2o`0006?ooooo00Go003oooooool0003oooooo`00
o`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000
ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06;ooooo00Go003o
ooooool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo06;ooooo00Go003oooooool0003oooooo`00o`1Tooooo`03o`000?oooooooooo00cooooo000P
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo06?ooooo00Co003oo`000?oooooo003oI?ooool00ol0003ooooooooo
o`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1Sooooo`04o`00ool0003oooooo`00ofCooooo00?o
0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo02Wooooo0_l0001Tooooo`03o`00ool0003o003o06Gooooo00?o0000
ooooooooool03?ooool0023ooooo0_l0001Vooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1Sooooo`03o`00ool0003o003o06Gooooo00?o0000oooo
ooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0Hoooool00ol00?oo0000o`00o`1Uooooo`03
o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06?ooooo00?o003oo`000?l00?l0
IOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Sooooo`03o`00ool0
003o003o06Gooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo0_l0001Tooooo`03o`00ool0003o
003o06Gooooo00?o0000ooooooooool03?ooool0023ooooo00?o0000ooooooooool0IOooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Hoooool00ol0
0?oo0000o`00o`1Uooooo`03o`000?oooooooooo00cooooo000Pooooo`;o0000I_ooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Hoooool00ol00?oo
0000o`00o`1Uooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo06Gooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06?ooooo
00?o003oo`000?l00?l0IOooool00ol0003oooooooooo`0<ooooo`008?ooool00ol0003ooooooooo
o`1Uooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1Sooooo`03o`00ool0003o003o06Gooooo00?o0000ooooooooool03?ooool001Sooooo1Ol00003
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Y
ooooo`;o0000I?ooool00ol00?oo0000o`00o`1Uooooo`03o`000?oooooooooo00cooooo000Ioooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Hoooool00ol00?oo0000o`00o`1U
ooooo`03o`000?oooooooooo00cooooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo023ooooo1Ol00004oooo
o`03o`000?oooooooooo06Cooooo0_l00?mUooooo`03o`000?oooooooooo00cooooo000Kooooo`03
o`000?oooooooooo00;ooooo0_l0001Vooooo`03o`000?oooooooooo06?ooooo0_l0000Sooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0I?ooool2o`00ofGooooo00?o0000oooo
ooooool03?ooool001Sooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0I?ooool2o`00ofGooooo00?o0000ooooooooool03?ooool001So
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo06Gooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo0_l0001Uoooo
o`03o`00oooooooooooo06?ooooo0_l0000>ooooo`006Oooool3o`0000Cooooo00?o0000oooooooo
ool0IOooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo023ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo000Pooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;oooool01Ol0003ooooooooooooooooo000002;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool0
023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`00000Sooooo`?o00001Oooooo?o`0000kooooo000Poooo
om3o0000ooooool9ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooi
ooooo`00oooooooiooooo`00oooooooiooooo`00\
\>"],
  ImageRangeCache->{{{0, 503}, {473.625, 0}} -> {-0.0501996, -0.0470982, \
0.00417575, 0.00417575}, {{12, 240.062}, {462.312, 321.375}} -> {-2.76021, \
-0.503531, 0.0202563, 0.017168}, {{262.875, 490.938}, {462.312, 321.375}} -> \
{-40.8355, -0.100845, 0.104829, 0.00206464}, {{12, 240.062}, {307.25, \
166.312}} -> {-2.76021, -3.16564, 0.0202563, 0.017168}, {{262.875, 490.938}, \
{307.25, 166.312}} -> {-40.8355, -2.10496, 0.104829, 0.0103232}, {{12, \
240.062}, {152.188, 11.25}} -> {-2.76021, -5.82775, 0.0202563, 0.017168}, \
{{262.875, 490.938}, {152.188, 11.25}} -> {-39.3408, -7.1721, 0.101747, \
0.0200392}}]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 800}, {0, 578}},
ScreenStyleEnvironment->"Working",
WindowSize->{834, 726},
WindowMargins->{{112, Automatic}, {Automatic, 0}},
CellLabelAutoDelete->True,
Magnification->1,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1705, 50, 66, 0, 62, "Title"],

Cell[CellGroupData[{
Cell[1796, 54, 99, 4, 59, "Section"],

Cell[CellGroupData[{
Cell[1920, 62, 60, 0, 49, "Subsection"],
Cell[1983, 64, 127, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2147, 71, 37, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[2209, 75, 59, 0, 43, "Subsubsection"],
Cell[2271, 77, 118, 2, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2426, 84, 67, 0, 43, "Subsubsection"],
Cell[2496, 86, 820, 15, 143, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[3365, 107, 45, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[3435, 111, 62, 0, 43, "Subsubsection"],
Cell[3500, 113, 330, 6, 111, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3867, 124, 67, 0, 42, "Subsubsection"],
Cell[3937, 126, 227, 4, 28, "Text"],
Cell[4167, 132, 551, 10, 142, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4755, 147, 48, 0, 42, "Subsubsection"],
Cell[4806, 149, 367, 8, 46, "Text"],
Cell[5176, 159, 302, 4, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5515, 168, 83, 1, 42, "Subsubsection"],
Cell[5601, 171, 683, 12, 190, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6333, 189, 39, 0, 49, "Subsection"],
Cell[6375, 191, 333, 7, 46, "Text"],
Cell[6711, 200, 541, 10, 143, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7289, 215, 41, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[7355, 219, 45, 0, 43, "Subsubsection"],
Cell[7403, 221, 67, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7507, 227, 43, 0, 43, "Subsubsection"],
Cell[7553, 229, 58, 1, 47, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7648, 235, 104, 4, 43, "Subsubsection"],
Cell[7755, 241, 74, 1, 47, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7878, 248, 109, 4, 49, "Subsection"],
Cell[7990, 254, 136, 3, 63, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8163, 262, 50, 0, 49, "Subsection"],
Cell[8216, 264, 181, 3, 63, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8446, 273, 54, 0, 39, "Section"],

Cell[CellGroupData[{
Cell[8525, 277, 40, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[8590, 281, 52, 0, 43, "Subsubsection"],
Cell[8645, 283, 44, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[8714, 288, 457, 11, 95, "Input"],
Cell[9174, 301, 48309, 1157, 186, 9188, 669, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[57532, 1464, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[57600, 1468, 396, 8, 95, "Input"],
Cell[57999, 1478, 29279, 763, 186, 5653, 467, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[87339, 2248, 40, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[87404, 2252, 52, 0, 43, "Subsubsection"],
Cell[87459, 2254, 44, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[87528, 2259, 457, 11, 79, "Input"],
Cell[87988, 2272, 36104, 927, 186, 7647, 571, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[124141, 3205, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[124209, 3209, 396, 8, 63, "Input"],
Cell[124608, 3219, 42783, 984, 186, 6490, 531, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[167452, 4210, 40, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[167517, 4214, 52, 0, 43, "Subsubsection"],
Cell[167572, 4216, 44, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[167641, 4221, 457, 11, 79, "Input"],
Cell[168101, 4234, 31044, 824, 186, 6856, 521, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[199194, 5064, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[199262, 5068, 396, 8, 63, "Input"],
Cell[199661, 5078, 53982, 1117, 70, 6508, 526, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[253704, 6202, 40, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[253769, 6206, 52, 0, 43, "Subsubsection"],
Cell[253824, 6208, 44, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[253893, 6213, 457, 11, 79, "Input"],
Cell[254353, 6226, 31158, 831, 186, 6970, 528, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[285560, 7063, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[285628, 7067, 396, 8, 63, "Input"],
Cell[286027, 7077, 55699, 1252, 186, 8277, 662, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[341787, 8336, 63, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[341875, 8340, 111, 2, 47, "Input"],
Cell[341989, 8344, 119479, 3386, 320, 30621, 2286, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],

Cell[CellGroupData[{
Cell[461505, 11735, 111, 2, 47, "Input"],
Cell[461619, 11739, 142312, 3611, 320, 26888, 2183, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[603980, 15356, 43, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[604048, 15360, 53, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[604126, 15364, 320, 7, 63, "Input"],
Cell[604449, 15373, 26140, 731, 186, 6216, 480, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[630638, 16110, 43, 0, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[630706, 16114, 195, 4, 63, "Input"],
Cell[630904, 16120, 82, 1, 79, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[631023, 16126, 141, 3, 47, "Input"],
Cell[631167, 16131, 36561, 925, 186, 7556, 562, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[667789, 17063, 39, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[667853, 17067, 111, 2, 47, "Input"],
Cell[667967, 17071, 135151, 3546, 320, 27936, 2219, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[803179, 20624, 67, 0, 59, "Section"],

Cell[CellGroupData[{
Cell[803271, 20628, 34, 0, 49, "Subsection"],
Cell[803308, 20630, 70, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[803403, 20635, 395, 8, 95, "Input"],
Cell[803801, 20645, 640, 16, 73, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[804478, 20666, 318, 5, 95, "Input"],

Cell[CellGroupData[{
Cell[804821, 20675, 32721, 1134, 186, 12566, 881, "GraphicsData", \
"PostScript", "Graphics"],
Cell[837545, 21811, 60468, 2392, 186, 30062, 2012, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[898074, 24210, 36, 0, 33, "Subsection"],
Cell[898113, 24212, 74, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[898212, 24217, 395, 8, 63, "Input"],
Cell[898610, 24227, 643, 16, 94, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[899290, 24248, 316, 5, 63, "Input"],

Cell[CellGroupData[{
Cell[899631, 24257, 32787, 1137, 186, 12607, 883, "GraphicsData", \
"PostScript", "Graphics"],
Cell[932421, 25396, 53037, 1841, 186, 21261, 1444, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[985519, 27244, 37, 0, 33, "Subsection"],
Cell[985559, 27246, 76, 1, 47, "Input"],

Cell[CellGroupData[{
Cell[985660, 27251, 395, 8, 63, "Input"],
Cell[986058, 27261, 652, 16, 91, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[986747, 27282, 378, 7, 63, "Input"],

Cell[CellGroupData[{
Cell[987150, 27293, 30728, 1111, 186, 12585, 882, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1017881, 28406, 35580, 1251, 186, 13871, 978, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1053522, 29664, 63, 0, 33, "Subsection"],

Cell[CellGroupData[{
Cell[1053610, 29668, 127, 2, 47, "Input"],
Cell[1053740, 29672, 219791, 8508, 483, 102576, 7057, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

